(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    506725,      15972]*)
(*NotebookOutlinePosition[    517374,      16221]*)
(*  CellTagsIndexPosition[    517248,      16213]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Designing a Pseudo-Diagonalizing Compensator", "Section",
  CellTags->{"5.0", "c:1"}],

Cell["\<\
When the Perron-Frobenius scaling approach is not able to produce a \
diagonal scaling compensator that achieves diagonal dominance, the designer \
has to consider the use of a nondiagonal matrix compensator. One such \
approach is illustrated here.\
\>", "Text",
  CellTags->"5.3.5"],

Cell["Make sure the application is loaded.", "MathCaption",
  CellTags->"5.3.5"],

Cell[BoxData[
    \(<< PolynomialControlSystems`\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"5.3.5"],

Cell["\<\
Consider a two-input, two-output multivariable system described by \
the transfer-function model.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tf = 
      TransferFunction[
        s, {{1\/\(1 + 4\ s\), 0.7\/\(1 + 5\ s\)}, {0.7\/\(1 + 5\ s\), 
            1\/\(1 + 4\ s\)}}]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"5.3.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/\(4\ \[ScriptS] + 1\)\), \(0.7`\/\(5\ \[ScriptS] + 
                            1\)\)},
                    {\(0.7`\/\(5\ \[ScriptS] + 1\)\), \(1\/\(4\ \[ScriptS] + 
                            1\)\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Center},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[InvisibleSpace]\"\>",
                ShowStringCharacters->False],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"5.3.5"]
}, Open  ]],

Cell["\<\
The time responses of the open-loop system, when a unit step is \
applied to each input separately, show that there is considerable interaction \
present in the system.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SimulationPlot[tf, UnitStep[t - 1], {t, 0, 30}, 
        PlotRange \[Rule] All];\)\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 0.589022 [
[.18254 .00222 -2.4 -7.2 ]
[.18254 .00222 2.4 0 ]
[.34127 .00222 -4.8 -7.2 ]
[.34127 .00222 4.8 0 ]
[.5 .00222 -4.8 -7.2 ]
[.5 .00222 4.8 0 ]
[.65873 .00222 -4.8 -7.2 ]
[.65873 .00222 4.8 0 ]
[.81746 .00222 -4.8 -7.2 ]
[.81746 .00222 4.8 0 ]
[.97619 .00222 -4.8 -7.2 ]
[.97619 .00222 4.8 0 ]
[.01131 .13252 -14.4 -3.6 ]
[.01131 .13252 0 3.6 ]
[.01131 .25032 -14.4 -3.6 ]
[.01131 .25032 0 3.6 ]
[.01131 .36813 -14.4 -3.6 ]
[.01131 .36813 0 3.6 ]
[.01131 .48593 -14.4 -3.6 ]
[.01131 .48593 0 3.6 ]
[.01131 .60374 -4.8 -3.6 ]
[.01131 .60374 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13252 m
.03006 .13252 L
s
[(0.2)] .01131 .13252 1 0 Mshowa
.02381 .25032 m
.03006 .25032 L
s
[(0.4)] .01131 .25032 1 0 Mshowa
.02381 .36813 m
.03006 .36813 L
s
[(0.6)] .01131 .36813 1 0 Mshowa
.02381 .48593 m
.03006 .48593 L
s
[(0.8)] .01131 .48593 1 0 Mshowa
.02381 .60374 m
.03006 .60374 L
s
[(1)] .01131 .60374 1 0 Mshowa
.125 Mabswid
.02381 .04417 m
.02756 .04417 L
s
.02381 .07362 m
.02756 .07362 L
s
.02381 .10307 m
.02756 .10307 L
s
.02381 .16197 m
.02756 .16197 L
s
.02381 .19142 m
.02756 .19142 L
s
.02381 .22087 m
.02756 .22087 L
s
.02381 .27978 m
.02756 .27978 L
s
.02381 .30923 m
.02756 .30923 L
s
.02381 .33868 m
.02756 .33868 L
s
.02381 .39758 m
.02756 .39758 L
s
.02381 .42703 m
.02756 .42703 L
s
.02381 .45648 m
.02756 .45648 L
s
.02381 .51538 m
.02756 .51538 L
s
.02381 .54483 m
.02756 .54483 L
s
.02381 .57429 m
.02756 .57429 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(1) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 1 r
.5 Mabswid
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.04758 .01472 L
.0503 .01472 L
.05288 .01472 L
.05405 .01472 L
.05528 .01472 L
.05593 .01644 L
.05664 .01972 L
.05789 .02544 L
.06244 .04582 L
.10458 .20336 L
.14487 .31221 L
.18364 .38892 L
.22486 .44847 L
.26457 .49016 L
.30277 .51966 L
.34341 .54269 L
.38254 .55888 L
.42412 .57141 L
.46419 .58016 L
.50274 .58633 L
.54374 .59113 L
.58323 .5945 L
.6212 .59689 L
.66163 .59876 L
.70054 .60007 L
.7419 .60109 L
.78174 .6018 L
.82007 .60231 L
.86085 .6027 L
.90012 .60298 L
.93787 .60317 L
.97619 .60332 L
s
1 0 0 r
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.04758 .01472 L
.0503 .01472 L
.05288 .01472 L
.05405 .01472 L
.05528 .01472 L
.05593 .01568 L
.05664 .01752 L
.05789 .02073 L
.06244 .03223 L
.10458 .12427 L
.14487 .19214 L
.18364 .24304 L
.22486 .28513 L
.26457 .31653 L
.30277 .34016 L
.34341 .35979 L
.38254 .37448 L
.42412 .38659 L
.46419 .39561 L
.50274 .40239 L
.54374 .408 L
.58323 .41219 L
.6212 .41535 L
.66163 .41797 L
.70054 .41994 L
.7419 .42157 L
.78174 .42278 L
.82007 .42369 L
.86085 .42445 L
.90012 .42501 L
.93787 .42544 L
.97619 .42578 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00@oooool3o`0002;ooooo0ol00003ooooo`03o`000?oooooooooo023o
oooo0ol00002ooooo`?o00008?ooool3o`0000?ooooo00?o0000ooooooooool07oooool3o`0000;o
oooo0ol0000Qooooo`?o00000oooool00ol0003oooooooooo`0=ooooo`00AOooool00ol0003ooooo
ooooo`0Qooooo`07o`000?ooooooooooooooool0003oooooo`00000Rooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07oooool01ol0003ooooooooooooooooo0000ooooool000008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00Ko0000oooooooooooo0000
ooooool0000>ooooo`00@oooool3o`0002?ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
02;ooooo00Co0000oooooooooooooooo0ol0000Rooooo`06o`000?ooooooooooo`000?oooooo0000
8_ooool00ol0003oooooooooo`03o`0002;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00kooooo0013ooooo`03o`000?oooooooooo02?ooooo00Oo0000ooooooooooooooooo`000?oooooo
000002;ooooo00Go0000ooooooooooooooooo`00000Tooooo`06o`000?ooooooooooo`000?oooooo
00008_ooool01?l0003oooooooooool0000Uooooo`06o`000?ooooooooooo`000?oooooo00003_oo
ool001cooooo00?o0000ooooooooool09?ooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooo
oooo023ooooo0_l00003ooooo`?o00008?ooool3o`0000?ooooo00?o0000ooooooooool07oooool3
o`0000;ooooo0ol0000Qooooo`?o00000oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0
003oooooooooo`3oooooo`;ooooo000Looooo`03o`000?oooooooooo0?oooooo0_ooool001cooooo
00?o0000ooooooooool0ooooool2ooooo`005_ooool6o`0000Woo`00l?l0000;ooooo`007?ooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00oooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0?ooool00?ooool0nOooool001cooooo
00?o0000ooooooooool01Oooool00ol0ooooooooool0003iooooo`007?ooool00ol0003ooooooooo
o`06ooooo`03o`3ooooo003ooooo0?Sooooo000Looooo`03o`000?oooooooooo00Kooooo00?o0?oo
oooooooo0000n?ooool001cooooo0_l00007ooooo`03o`3oooooooooo`000?Sooooo000Looooo`03
o`000?oooooooooo00Oooooo00?o0?ooool00?ooool0moooool001cooooo00?o0000ooooooooool0
1oooool00ol0ooooooooool0003gooooo`007?ooool00ol0003oooooooooo`07ooooo`03o`3ooooo
ooooo`000?Oooooo000Looooo`03o`000?oooooooooo00Sooooo00?o0?oooooooooo0000m_ooool0
01cooooo00?o0000ooooooooool02?ooool00ol0ooooooooool0003fooooo`007?ooool00ol0003o
ooooooooo`08ooooo`04o`3oooooooooooooool00?Gooooo000Looooo`03o`000?oooooooooo00So
oooo00Co0?ooooooooooooooo`00mOooool001cooooo0_l0000:ooooo`03o`3oooooooooo`000?Go
oooo000Looooo`03o`000?oooooooooo00Wooooo00Co0?ooooooooooooooo`00m?ooool001cooooo
00?o0000ooooooooool02Oooool01?l0oooooooooooooooo003dooooo`007?ooool00ol0003ooooo
ooooo`09ooooo`05o`3ooooooooooooooooooooo0000loooool001cooooo00?o0000ooooooooool0
2_ooool01?l0oooooooooooooooo003cooooo`007?ooool00ol0003oooooooooo`0:ooooo`04o`3o
ooooooooooooool00??ooooo000Looooo`03o`000?oooooooooo00[ooooo00Go0?oooooooooooooo
ooooool0003booooo`007?ooool2o`0000_ooooo00Go0?ooooooooooooooooooool0003booooo`00
7?ooool00ol0003oooooooooo`0;ooooo`05o`3ooooooooooooooooooooo0000lOooool001cooooo
00?o0000ooooooooool02oooool01Ol0ooooooooooooooooooooo`000?7ooooo000Looooo`03o`00
0?oooooooooo00_ooooo00?o0?ooooooooooool00_ooool00ooo003oooooooooo`3^ooooo`007?oo
ool00ol0003oooooooooo`0;ooooo`03o`3ooooooooooooo00;ooooo00?oo`00ooooooooool0k_oo
ool001cooooo00?o0000ooooooooool03?ooool01Ol0ooooooooooooooooooooo`000?3ooooo000L
ooooo`03o`000?oooooooooo00cooooo00?o0?ooooooooooool00_ooool00ooo003oooooooooo`3]
ooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00001?ooool0
0ol0003oooooooooo`0<ooooo`03o`3ooooooooooooo00;ooooo00?oo`00ooooooooool0kOooool0
00_ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`;o00003Oooool00ol0
ooooooooooooo`03ooooo`03ool00?oooooooooo0>cooooo000;ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`3ooooooooooooo00;o
oooo00?oo`00ooooooooool0k?ooool000_ooooo00?o0000ooooool000002Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0?ooooooooooool00oooool00ooo003ooooo
ooooo`3[ooooo`003?ooool00ol0003oooooooooo`06ooooo`?o00001?ooool00ol0003ooooooooo
o`0=ooooo`03o`3ooooooooooooo00Cooooo00?oo`00ooooooooool0j_ooool001cooooo00?o0000
ooooooooool03Oooool00ol0ooooooooooooo`04ooooo`03ool00?oooooooooo0>[ooooo000Loooo
o`03o`000?oooooooooo00kooooo00?o0?ooooooooooool01?ooool00ooo003oooooooooo`3Yoooo
o`007?ooool00ol0003oooooooooo`0>ooooo`03o`3ooooooooooooo00Cooooo00?oo`00oooooooo
ool0jOooool001cooooo0_l0000?ooooo`03o`3ooooooooooooo00Gooooo00?oo`00ooooooooool0
j?ooool001cooooo00?o0000ooooooooool03_ooool00ol0ooooooooooooo`06ooooo`03ool00?oo
oooooooo0>Oooooo000Looooo`03o`000?oooooooooo00oooooo00?o0?ooooooooooool01Oooool0
0ooo003oooooooooo`3Wooooo`007?ooool00ol0003oooooooooo`0?ooooo`03o`3ooooooooooooo
00Kooooo00?oo`00ooooooooool0i_ooool001cooooo00?o0000ooooooooool03oooool00ol0oooo
ooooooooo`06ooooo`03ool00?oooooooooo0>Kooooo000Looooo`03o`000?oooooooooo00oooooo
00?o0?ooooooooooool01oooool00ooo003oooooooooo`3Uooooo`007?ooool00ol0003ooooooooo
o`0@ooooo`03o`3ooooooooooooo00Oooooo00?oo`00ooooooooool0i?ooool001cooooo00?o0000
ooooooooool04?ooool00ol0ooooooooooooo`07ooooo`03ool00?oooooooooo0>Cooooo000Loooo
o`;o00004Oooool00ol0ooooooooooooo`08ooooo`03ool00?oooooooooo0>?ooooo000Looooo`03
o`000?oooooooooo013ooooo00?o0?ooooooooooool02?ooool00ooo003oooooooooo`3Sooooo`00
7?ooool00ol0003oooooooooo`0Aooooo`03o`3ooooooooooooo00Sooooo00?oo`00ooooooooool0
h_ooool001cooooo00?o0000ooooooooool04Oooool00ol0ooooooooooooo`09ooooo`03ool00?oo
oooooooo0>7ooooo000Looooo`03o`000?oooooooooo017ooooo00?o0?ooooooooooool02_ooool0
0ooo003oooooooooo`3Pooooo`007?ooool00ol0003oooooooooo`0Booooo`03o`3ooooooooooooo
00Wooooo00?oo`00ooooooooool0h?ooool001cooooo00?o0000ooooooooool04_ooool00ol0oooo
ooooooooo`0:ooooo`03ool00?oooooooooo0=oooooo000Looooo`;o00004oooool00ol0oooooooo
ooooo`0;ooooo`03ool00?oooooooooo0=kooooo000Looooo`03o`000?oooooooooo01?ooooo00?o
0?ooooooooooool02oooool00ooo003oooooooooo`3Mooooo`007?ooool00ol0003oooooooooo`0C
ooooo`03o`3ooooooooooooo00cooooo00?oo`00ooooooooool0g?ooool001cooooo00?o0000oooo
ooooool04oooool00ol0ooooooooooooo`0<ooooo`03ool00?oooooooooo0=cooooo000Looooo`03
o`000?oooooooooo01Cooooo00?o0?ooooooooooool03?ooool00ooo003oooooooooo`3Kooooo`00
7?ooool00ol0003oooooooooo`0Dooooo`03o`3ooooooooooooo00gooooo00?oo`00ooooooooool0
f_ooool001cooooo00?o0000ooooooooool05?ooool00ol0ooooooooooooo`0>ooooo`03ool00?oo
oooooooo0=Wooooo000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0?ooooooooooool03_ooool0
0ooo003oooooooooo`3Hooooo`002oooool00ol0003oooooo`000007ooooo`?o00001?ooool2o`00
01Kooooo00?o0?ooooooooooool03oooool00ooo003oooooooooo`3Gooooo`002oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool05Oooool00ol0oooo
ooooooooo`0@ooooo`03ool00?oooooooooo0=Kooooo000;ooooo`03o`000?oooooo000000Sooooo
0_l00004ooooo`03o`000?oooooooooo01Kooooo00?o0?ooooooooooool04?ooool00ooo003ooooo
ooooo`3Eooooo`003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05_ooool00ol0ooooooooooooo`0Aooooo`03ool00?oooooooooo0=Cooooo000L
ooooo`03o`000?oooooooooo01Oooooo00?o0?ooooooooooool04Oooool00ooo003oooooooooo`3C
ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03o`3ooooooooooooo01;ooooo00?oo`00oooo
ooooool0d_ooool001cooooo00?o0000ooooooooool05oooool00ol0ooooooooooooo`0Cooooo`03
ool00?oooooooooo0=7ooooo000Looooo`;o00006Oooool00ol0ooooooooooooo`0Cooooo`03ool0
0?oooooooooo0=3ooooo000Looooo`03o`000?oooooooooo01Sooooo00?o0?ooooooooooool05?oo
ool00ooo003oooooooooo`3?ooooo`007?ooool00ol0003oooooooooo`0Hooooo`03o`3ooooooooo
oooo01Gooooo0_oo003?ooooo`007?ooool00ol0003oooooooooo`0Iooooo`03o`3ooooooooooooo
01Kooooo00?oo`00ooooooooool0c?ooool001cooooo00?o0000ooooooooool06Oooool00ol0oooo
ooooooooo`0Gooooo`03ool00?oooooooooo0<_ooooo000Looooo`03o`000?oooooooooo01Wooooo
00?o0?ooooooooooool06?ooool00ooo003oooooooooo`3:ooooo`007?ooool00ol0003ooooooooo
o`0Jooooo`03o`3ooooooooooooo01Sooooo0_oo003:ooooo`007?ooool00ol0003oooooooooo`0J
ooooo`03o`3ooooooooooooo01[ooooo00?oo`00ooooooooool0aoooool001cooooo0_l0000Koooo
o`03o`3ooooooooooooo01_ooooo00?oo`00ooooooooool0a_ooool001cooooo00?o0000oooooooo
ool06oooool00ol0ooooooooooooo`0Kooooo`03ool00?oooooooooo0<Gooooo000Looooo`03o`00
0?oooooooooo01_ooooo00?o0?ooooooooooool07?ooool2ool00<Gooooo000Looooo`03o`000?oo
oooooooo01cooooo00?o0?ooooooooooool07Oooool2ool00<?ooooo000Looooo`03o`000?oooooo
oooo01cooooo00?o0?ooooooooooool07oooool00ooo003oooooooooo`30ooooo`007?ooool00ol0
003oooooooooo`0Mooooo`03o`3ooooooooooooo01oooooo0_oo0030ooooo`007?ooool00ol0003o
ooooooooo`0Mooooo`03o`3ooooooooooooo027ooooo0_oo002nooooo`007?ooool2o`0001oooooo
00?o0?ooooooooooool08_ooool00ooo003oooooooooo`2kooooo`007?ooool00ol0003ooooooooo
o`0Nooooo`03o`3ooooooooooooo02?ooooo0_oo002kooooo`007?ooool00ol0003oooooooooo`0O
ooooo`03o`3ooooooooooooo02Cooooo0_oo002iooooo`007?ooool00ol0003oooooooooo`0Ooooo
o`03o`3ooooooooooooo02Kooooo0_oo002gooooo`007?ooool00ol0003oooooooooo`0Pooooo`03
o`3ooooooooooooo02Oooooo0_oo002eooooo`007?ooool00ol0003oooooooooo`0Qooooo`03o`3o
oooooooooooo02Sooooo0_oo002cooooo`007?ooool00ol0003oooooooooo`0Qooooo`03o`3ooooo
oooooooo02[ooooo0ooo002`ooooo`003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`03o`000?oooooooooo02;ooooo00?o0?ooooooooooool0;?ooool3
ool00:gooooo000;ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000001?ooool2o`00
02?ooooo00?o0?ooooooooooool0;oooool3ool00:[ooooo000;ooooo`03o`000?oooooo000000Oo
oooo0ol00004ooooo`03o`000?oooooooooo02?ooooo00?o0?ooooooooooool0<Oooool4ool00:Ko
oooo000;ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Sooooo`03o`3ooooooooooooo03Gooooo0ooo002Sooooo`003?ooool00ol0003ooooooooo
o`07ooooo`;o00001?ooool00ol0003oooooooooo`0Tooooo`03o`3ooooooooooooo03Oooooo0ooo
002Pooooo`007?ooool00ol0003oooooooooo`0Tooooo`03o`3ooooooooooooo03[ooooo1?oo002L
ooooo`007?ooool00ol0003oooooooooo`0Uooooo`03o`3ooooooooooooo03gooooo1?oo002Hoooo
o`007?ooool00ol0003oooooooooo`0Uooooo`03o`3ooooooooooooo047ooooo0ooo002Eooooo`00
7?ooool2o`0002Oooooo00?o0?ooooooooooool0@oooool7ool008kooooo000Looooo`03o`000?oo
oooooooo02Oooooo00?o0?ooooooooooool0BOooool7ool008Oooooo000Looooo`03o`000?oooooo
oooo02Sooooo00?o0?ooooooooooool0Coooool5ool008;ooooo000Looooo`03o`000?oooooooooo
02Sooooo00?o0?ooooooooooool0E?ooool8ool007[ooooo000Looooo`03o`000?oooooooooo02Wo
oooo00?o0?ooooooooooool0Foooool:ool0073ooooo000Looooo`03o`000?oooooooooo02[ooooo
00?o0?ooooooooooool0I?oooolDool005cooooo000Looooo`03o`000?oooooooooo02_ooooo00?o
0?ooooooooooool0MooooolDool004Sooooo000Looooo`03o`000?oooooooooo02_ooooo00?o0?oo
ooooooooool0Rooooolgool0017ooooo000Looooo`;o0000;Oooool00ol0ooooooooooooo`3Boooo
o`007?ooool00ol0003oooooooooo`0]ooooo`03o`3ooooooooooooo0=7ooooo000Looooo`03o`00
0?oooooooooo02gooooo00?o0?ooooooooooool0dOooool001cooooo00?o0000ooooooooool0;_oo
ool00ol0ooooooooooooo`3@ooooo`007?ooool00ol0003oooooooooo`0_ooooo`03o`3ooooooooo
oooo0<oooooo000Looooo`03o`000?oooooooooo033ooooo00?o0?ooooooooooool0c_ooool001co
oooo00?o0000ooooooooool0<?ooool00ol0ooooooooooooo`3>ooooo`007?ooool2o`0003;ooooo
00?o0?ooooooooooool0cOooool001cooooo00?o0000ooooooooool0<_ooool00ol0oooooooooooo
o`3<ooooo`007?ooool00ol0003oooooooooo`0cooooo`03o`3ooooooooooooo0<_ooooo000Loooo
o`03o`000?oooooooooo03Cooooo00?o0?ooooooooooool0b_ooool001cooooo00?o0000oooooooo
ool0=Oooool00ol0ooooooooooooo`39ooooo`007?ooool00ol0003oooooooooo`0fooooo`03o`3o
oooooooooooo0<Sooooo000Looooo`03o`000?oooooooooo03Oooooo00?o0?ooooooooooool0aooo
ool000cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0000Cooooo00?o
0000ooooooooool0>?ooool00ol0ooooooooooooo`36ooooo`002oooool00ol0003oooooo`000007
ooooo`03o`000?oooooo000000Cooooo0_l0000jooooo`03o`3ooooooooooooo0<Gooooo000;oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0joooo
o`;o0?ooaOooool000_ooooo00?o0000ooooool000001oooool00ol0003oooooo`000004ooooo`03
o`000?oooooooooo03cooooo00?o0?ooooooooooool0`_ooool000cooooo00?o0000ooooooooool0
1_ooool3o`0000Cooooo00?o0000ooooooooool0?Oooool2o`3ool;ooooo000Looooo`03o`000?oo
oooooooo03oooooo00?o0?ooooooooooool0_oooool001cooooo00?o0000ooooooooool0@?ooool0
0ol0ooooooooooooo`2nooooo`007?ooool00ol0003oooooooooo`11ooooo`;o0?oo__ooool001co
oooo0_l00014ooooo`03o`3ooooooooooooo0;_ooooo000Looooo`03o`000?oooooooooo04Cooooo
0_l0oonkooooo`007?ooool00ol0003oooooooooo`16ooooo`;o0?oo^Oooool001cooooo00?o0000
ooooooooool0B?ooool00ol0ooooooooooooo`2fooooo`007?ooool00ol0003oooooooooo`19oooo
o`;o0?oo]_ooool001cooooo00?o0000ooooooooool0Boooool2o`3ookCooooo000Looooo`03o`00
0?oooooooooo04gooooo00?o0?ooooooooooool0/Oooool001cooooo00?o0000ooooooooool0C_oo
ool2o`3ook7ooooo000Looooo`;o0000DOooool3o`3oojkooooo000Looooo`03o`000?oooooooooo
05?ooooo0_l0oon/ooooo`007?ooool00ol0003oooooooooo`1Eooooo`?o0?ooZOooool001cooooo
00?o0000ooooooooool0F?ooool3o`3oojKooooo000Looooo`03o`000?oooooooooo05_ooooo0ol0
oonSooooo`007?ooool00ol0003oooooooooo`1Nooooo`?o0?ooX?ooool001cooooo00?o0000oooo
ooooool0HOooool4o`3ooicooooo000Looooo`;o0000I_ooool4o`3ooiSooooo000Looooo`03o`00
0?oooooooooo06Wooooo0ol0oonEooooo`007?ooool00ol0003oooooooooo`1/ooooo`Oo0?ooS_oo
ool001cooooo00?o0000ooooooooool0Loooool:o`3oohCooooo000Looooo`03o`000?oooooooooo
07gooooo2_l0oomjooooo`007?ooool00ol0003oooooooooo`27ooooo`[o0?ooL?ooool001cooooo
00?o0000ooooooooool0TOoooolDo`3ooecooooo000Eooooo`?o00001?ooool00ol0003ooooooooo
o`2Uooooocco0?oo8?ooool001Kooooo00?o0000ooooooooool00oooool2o`000>;ooooo3ol0oolA
ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo0_ooool001Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooo`;ooooo000Eooooo`;o0000
1Oooool00ol0003oooooooooo`3oooooo`;ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo002>ooooo`?o0000Soooool008oooooo00?o0000ooooooooool0S_oo
ool008Gooooo0ol00002ooooo`03o`000?oooooo000000;ooooo0ol00002ooooo`?o00000_ooool3
o`0000Kooooo0ol0001kooooo`00Q_ooool01ol0003ooooooooooooooooo0000ooooool000000_oo
ool02?l0003oooooooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07[ooooo0026ooooo`07o`000?ooooooooooooooool0003oooooo`000002
ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0N_ooool008Kooooo00?o0000ooooooooool01?l000000ooooooo0000
o`000002o`000006ooooool0003o0000ooooool0003ooooo1?l00007ooooo`03o`000?oooooooooo
07[ooooo0025ooooo`?o00004Oooool00ol0003oooooooooo`06ooooo`;o0000O?ooool00?oooooo
8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.49406, -0.0692995, \
0.123903, 0.0066779}},
  CellTags->"5.3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 0.589022 [
[.18254 .00222 -2.4 -7.2 ]
[.18254 .00222 2.4 0 ]
[.34127 .00222 -4.8 -7.2 ]
[.34127 .00222 4.8 0 ]
[.5 .00222 -4.8 -7.2 ]
[.5 .00222 4.8 0 ]
[.65873 .00222 -4.8 -7.2 ]
[.65873 .00222 4.8 0 ]
[.81746 .00222 -4.8 -7.2 ]
[.81746 .00222 4.8 0 ]
[.97619 .00222 -4.8 -7.2 ]
[.97619 .00222 4.8 0 ]
[.01131 .13252 -14.4 -3.6 ]
[.01131 .13252 0 3.6 ]
[.01131 .25032 -14.4 -3.6 ]
[.01131 .25032 0 3.6 ]
[.01131 .36813 -14.4 -3.6 ]
[.01131 .36813 0 3.6 ]
[.01131 .48593 -14.4 -3.6 ]
[.01131 .48593 0 3.6 ]
[.01131 .60374 -4.8 -3.6 ]
[.01131 .60374 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13252 m
.03006 .13252 L
s
[(0.2)] .01131 .13252 1 0 Mshowa
.02381 .25032 m
.03006 .25032 L
s
[(0.4)] .01131 .25032 1 0 Mshowa
.02381 .36813 m
.03006 .36813 L
s
[(0.6)] .01131 .36813 1 0 Mshowa
.02381 .48593 m
.03006 .48593 L
s
[(0.8)] .01131 .48593 1 0 Mshowa
.02381 .60374 m
.03006 .60374 L
s
[(1)] .01131 .60374 1 0 Mshowa
.125 Mabswid
.02381 .04417 m
.02756 .04417 L
s
.02381 .07362 m
.02756 .07362 L
s
.02381 .10307 m
.02756 .10307 L
s
.02381 .16197 m
.02756 .16197 L
s
.02381 .19142 m
.02756 .19142 L
s
.02381 .22087 m
.02756 .22087 L
s
.02381 .27978 m
.02756 .27978 L
s
.02381 .30923 m
.02756 .30923 L
s
.02381 .33868 m
.02756 .33868 L
s
.02381 .39758 m
.02756 .39758 L
s
.02381 .42703 m
.02756 .42703 L
s
.02381 .45648 m
.02756 .45648 L
s
.02381 .51538 m
.02756 .51538 L
s
.02381 .54483 m
.02756 .54483 L
s
.02381 .57429 m
.02756 .57429 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(2) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 1 r
.5 Mabswid
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.04758 .01472 L
.0503 .01472 L
.05288 .01472 L
.05405 .01472 L
.05528 .01472 L
.05593 .01568 L
.05664 .01752 L
.05789 .02073 L
.06244 .03223 L
.10458 .12427 L
.14487 .19214 L
.18364 .24304 L
.22486 .28513 L
.26457 .31653 L
.30277 .34016 L
.34341 .35979 L
.38254 .37448 L
.42412 .38659 L
.46419 .39561 L
.50274 .40239 L
.54374 .408 L
.58323 .41219 L
.6212 .41535 L
.66163 .41797 L
.70054 .41994 L
.7419 .42157 L
.78174 .42278 L
.82007 .42369 L
.86085 .42445 L
.90012 .42501 L
.93787 .42544 L
.97619 .42578 L
s
1 0 0 r
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.04758 .01472 L
.0503 .01472 L
.05288 .01472 L
.05405 .01472 L
.05528 .01472 L
.05593 .01644 L
.05664 .01972 L
.05789 .02544 L
.06244 .04582 L
.10458 .20336 L
.14487 .31221 L
.18364 .38892 L
.22486 .44847 L
.26457 .49016 L
.30277 .51966 L
.34341 .54269 L
.38254 .55888 L
.42412 .57141 L
.46419 .58016 L
.50274 .58633 L
.54374 .59113 L
.58323 .5945 L
.6212 .59689 L
.66163 .59876 L
.70054 .60007 L
.7419 .60109 L
.78174 .6018 L
.82007 .60231 L
.86085 .6027 L
.90012 .60298 L
.93787 .60317 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00@oooool3o`0002;ooooo0ol00003ooooo`03o`000?oooooooooo023o
oooo0ol00002ooooo`?o00008?ooool3o`0000?ooooo00?o0000ooooooooool07oooool3o`0000;o
oooo0ol0000Qooooo`?o00000oooool00ol0003oooooooooo`0=ooooo`00AOooool00ol0003ooooo
ooooo`0Qooooo`07o`000?ooooooooooooooool0003oooooo`00000Rooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07oooool01ol0003ooooooooooooooooo0000ooooool000008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00Ko0000oooooooooooo0000
ooooool0000>ooooo`00@oooool3o`0002?ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
02;ooooo00Co0000oooooooooooooooo0ol0000Rooooo`06o`000?ooooooooooo`000?oooooo0000
8_ooool00ol0003oooooooooo`03o`0002;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00kooooo0013ooooo`03o`000?oooooooooo02?ooooo00Oo0000ooooooooooooooooo`000?oooooo
000002;ooooo00Go0000ooooooooooooooooo`00000Tooooo`06o`000?ooooooooooo`000?oooooo
00008_ooool01?l0003oooooooooool0000Uooooo`06o`000?ooooooooooo`000?oooooo00003_oo
ool001cooooo00?o0000ooooooooool09?ooool3o`0002;ooooo0_l00004ooooo`03o`000?oooooo
oooo023ooooo0_l00003ooooo`?o00008?ooool3o`0000?ooooo00?o0000ooooooooool07oooool3
o`0000;ooooo0ol0000Qooooo`?o00000oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0
003oooooooooo`3oooooo`;ooooo000Looooo`03o`000?oooooooooo0?oooooo0_ooool001cooooo
00?o0000ooooooooool0ooooool2ooooo`005_ooool6o`0000Woo`00l?l0000;ooooo`007?ooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0?ooooo`007?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
01gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00oooooo000Looooo`03o`000?oooooooooo00Gooooo00?oo`00o`3oooooool0nOooool001cooooo
00?o0000ooooooooool01Oooool00ooo003oooooo`3oo`3iooooo`007?ooool00ol0003ooooooooo
o`06ooooo`03ool00?l0oooooooo0?Sooooo000Looooo`03o`000?oooooooooo00Kooooo00?oo`00
ooooool0ool0n?ooool001cooooo0_l00007ooooo`03ool00?oooooo0?oo0?Sooooo000Looooo`03
o`000?oooooooooo00Oooooo00?oo`00o`3oooooool0moooool001cooooo00?o0000ooooooooool0
1oooool00ooo003oooooo`3oo`3gooooo`007?ooool00ol0003oooooooooo`07ooooo`03ool00?oo
oooo0?oo0?Oooooo000Looooo`03o`000?oooooooooo00Sooooo00?oo`00ooooool0ool0m_ooool0
01cooooo00?o0000ooooooooool02?ooool00ooo003oooooo`3oo`3fooooo`007?ooool00ol0003o
ooooooooo`08ooooo`04ool00?ooooooooooo`3oooGooooo000Looooo`03o`000?oooooooooo00So
oooo00Coo`00oooooooooooo0?oomOooool001cooooo0_l0000:ooooo`03ool00?oooooo0?oo0?Go
oooo000Looooo`03o`000?oooooooooo00Wooooo00Coo`00oooooooooooo0?oom?ooool001cooooo
00?o0000ooooooooool02Oooool01?oo003oooooooooool0ooodooooo`007?ooool00ol0003ooooo
ooooo`09ooooo`05ool00?ooooooooooooooool0ool0loooool001cooooo00?o0000ooooooooool0
2_ooool01?oo003oooooooooool0ooocooooo`007?ooool00ol0003oooooooooo`0:ooooo`04ool0
0?ooooooooooo`3ooo?ooooo000Looooo`03o`000?oooooooooo00[ooooo00Goo`00oooooooooooo
ooooo`3oo`3booooo`007?ooool2o`0000_ooooo00Goo`00ooooooooooooooooo`3oo`3booooo`00
7?ooool00ol0003oooooooooo`0;ooooo`05ool00?ooooooooooooooool0ool0lOooool001cooooo
00?o0000ooooooooool02oooool01Ooo003ooooooooooooooooo0?oo0?7ooooo000Looooo`03o`00
0?oooooooooo00_ooooo00?oo`00ooooooooool00_ooool00ol0ooooooooooooo`3^ooooo`007?oo
ool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00;ooooo00?o0?ooooooooooool0k_oo
ool001cooooo00?o0000ooooooooool03?ooool01Ooo003ooooooooooooooooo0?oo0?3ooooo000L
ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool00_ooool00ol0ooooooooooooo`3]
ooooo`003?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00001?ooool0
0ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?o0?ooooooooooool0kOooool0
00_ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`;o00003Oooool00ooo
003oooooooooo`03ooooo`03o`3ooooooooooooo0>cooooo000;ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo00;o
oooo00?o0?ooooooooooool0k?ooool000_ooooo00?o0000ooooool000002Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool00oooool00ol0oooooooo
ooooo`3[ooooo`003?ooool00ol0003oooooooooo`06ooooo`?o00001?ooool00ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo00Cooooo00?o0?ooooooooooool0j_ooool001cooooo00?o0000
ooooooooool03Oooool00ooo003oooooooooo`04ooooo`03o`3ooooooooooooo0>[ooooo000Loooo
o`03o`000?oooooooooo00kooooo00?oo`00ooooooooool01?ooool00ol0ooooooooooooo`3Yoooo
o`007?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00Cooooo00?o0?oooooooooo
ool0jOooool001cooooo0_l0000?ooooo`03ool00?oooooooooo00Gooooo00?o0?ooooooooooool0
j?ooool001cooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`06ooooo`03o`3ooooo
oooooooo0>Oooooo000Looooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool01Oooool0
0ol0ooooooooooooo`3Wooooo`007?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo
00Kooooo00?o0?ooooooooooool0i_ooool001cooooo00?o0000ooooooooool03oooool00ooo003o
ooooooooo`06ooooo`03o`3ooooooooooooo0>Kooooo000Looooo`03o`000?oooooooooo00oooooo
00?oo`00ooooooooool01oooool00ol0ooooooooooooo`3Uooooo`007?ooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo00Oooooo00?o0?ooooooooooool0i?ooool001cooooo00?o0000
ooooooooool04?ooool00ooo003oooooooooo`07ooooo`03o`3ooooooooooooo0>Cooooo000Loooo
o`;o00004Oooool00ooo003oooooooooo`08ooooo`03o`3ooooooooooooo0>?ooooo000Looooo`03
o`000?oooooooooo013ooooo00?oo`00ooooooooool02?ooool00ol0ooooooooooooo`3Sooooo`00
7?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo00Sooooo00?o0?ooooooooooool0
h_ooool001cooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`09ooooo`03o`3ooooo
oooooooo0>7ooooo000Looooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool02_ooool0
0ol0ooooooooooooo`3Pooooo`007?ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo
00Wooooo00?o0?ooooooooooool0h?ooool001cooooo00?o0000ooooooooool04_ooool00ooo003o
ooooooooo`0:ooooo`03o`3ooooooooooooo0=oooooo000Looooo`;o00004oooool00ooo003ooooo
ooooo`0;ooooo`03o`3ooooooooooooo0=kooooo000Looooo`03o`000?oooooooooo01?ooooo00?o
o`00ooooooooool02oooool00ol0ooooooooooooo`3Mooooo`007?ooool00ol0003oooooooooo`0C
ooooo`03ool00?oooooooooo00cooooo00?o0?ooooooooooool0g?ooool001cooooo00?o0000oooo
ooooool04oooool00ooo003oooooooooo`0<ooooo`03o`3ooooooooooooo0=cooooo000Looooo`03
o`000?oooooooooo01Cooooo00?oo`00ooooooooool03?ooool00ol0ooooooooooooo`3Kooooo`00
7?ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo00gooooo00?o0?ooooooooooool0
f_ooool001cooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0>ooooo`03o`3ooooo
oooooooo0=Wooooo000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool03_ooool0
0ol0ooooooooooooo`3Hooooo`002oooool00ol0003oooooo`000007ooooo`?o00001?ooool2o`00
01Kooooo00?oo`00ooooooooool03oooool00ol0ooooooooooooo`3Gooooo`002oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool05Oooool00ooo003o
ooooooooo`0@ooooo`03o`3ooooooooooooo0=Kooooo000;ooooo`03o`000?oooooo000000Sooooo
0_l00004ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool04?ooool00ol0oooooooo
ooooo`3Eooooo`003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05_ooool00ooo003oooooooooo`0Aooooo`03o`3ooooooooooooo0=Cooooo000L
ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool04Oooool00ol0ooooooooooooo`3C
ooooo`007?ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo01;ooooo00?o0?oooooo
ooooool0d_ooool001cooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`0Cooooo`03
o`3ooooooooooooo0=7ooooo000Looooo`;o00006Oooool00ooo003oooooooooo`0Cooooo`03o`3o
oooooooooooo0=3ooooo000Looooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool05?oo
ool00ol0ooooooooooooo`3?ooooo`007?ooool00ol0003oooooooooo`0Hooooo`03ool00?oooooo
oooo01Gooooo0_l0ooo?ooooo`007?ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo
01Kooooo00?o0?ooooooooooool0c?ooool001cooooo00?o0000ooooooooool06Oooool00ooo003o
ooooooooo`0Gooooo`03o`3ooooooooooooo0<_ooooo000Looooo`03o`000?oooooooooo01Wooooo
00?oo`00ooooooooool06?ooool00ol0ooooooooooooo`3:ooooo`007?ooool00ol0003ooooooooo
o`0Jooooo`03ool00?oooooooooo01Sooooo0_l0ooo:ooooo`007?ooool00ol0003oooooooooo`0J
ooooo`03ool00?oooooooooo01[ooooo00?o0?ooooooooooool0aoooool001cooooo0_l0000Koooo
o`03ool00?oooooooooo01_ooooo00?o0?ooooooooooool0a_ooool001cooooo00?o0000oooooooo
ool06oooool00ooo003oooooooooo`0Kooooo`03o`3ooooooooooooo0<Gooooo000Looooo`03o`00
0?oooooooooo01_ooooo00?oo`00ooooooooool07?ooool2o`3oolGooooo000Looooo`03o`000?oo
oooooooo01cooooo00?oo`00ooooooooool07Oooool2o`3ool?ooooo000Looooo`03o`000?oooooo
oooo01cooooo00?oo`00ooooooooool07oooool00ol0ooooooooooooo`30ooooo`007?ooool00ol0
003oooooooooo`0Mooooo`03ool00?oooooooooo01oooooo0_l0ooo0ooooo`007?ooool00ol0003o
ooooooooo`0Mooooo`03ool00?oooooooooo027ooooo0_l0oonnooooo`007?ooool2o`0001oooooo
00?oo`00ooooooooool08_ooool00ol0ooooooooooooo`2kooooo`007?ooool00ol0003ooooooooo
o`0Nooooo`03ool00?oooooooooo02?ooooo0_l0oonkooooo`007?ooool00ol0003oooooooooo`0O
ooooo`03ool00?oooooooooo02Cooooo0_l0ooniooooo`007?ooool00ol0003oooooooooo`0Ooooo
o`03ool00?oooooooooo02Kooooo0_l0oongooooo`007?ooool00ol0003oooooooooo`0Pooooo`03
ool00?oooooooooo02Oooooo0_l0ooneooooo`007?ooool00ol0003oooooooooo`0Qooooo`03ool0
0?oooooooooo02Sooooo0_l0ooncooooo`007?ooool00ol0003oooooooooo`0Qooooo`03ool00?oo
oooooooo02[ooooo0ol0oon`ooooo`003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool0;?ooool3
o`3oojgooooo000;ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000001?ooool2o`00
02?ooooo00?oo`00ooooooooool0;oooool3o`3ooj[ooooo000;ooooo`03o`000?oooooo000000Oo
oooo0ol00004ooooo`03o`000?oooooooooo02?ooooo00?oo`00ooooooooool0<Oooool4o`3oojKo
oooo000;ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Sooooo`03ool00?oooooooooo03Gooooo0ol0oonSooooo`003?ooool00ol0003ooooooooo
o`07ooooo`;o00001?ooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo03Oooooo0ol0
oonPooooo`007?ooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo03[ooooo1?l0oonL
ooooo`007?ooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo03gooooo1?l0oonHoooo
o`007?ooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo047ooooo0ol0oonEooooo`00
7?ooool2o`0002Oooooo00?oo`00ooooooooool0@oooool7o`3oohkooooo000Looooo`03o`000?oo
oooooooo02Oooooo00?oo`00ooooooooool0BOooool7o`3oohOooooo000Looooo`03o`000?oooooo
oooo02Sooooo00?oo`00ooooooooool0Coooool5o`3ooh;ooooo000Looooo`03o`000?oooooooooo
02Sooooo00?oo`00ooooooooool0E?ooool8o`3oog[ooooo000Looooo`03o`000?oooooooooo02Wo
oooo00?oo`00ooooooooool0Foooool:o`3oog3ooooo000Looooo`03o`000?oooooooooo02[ooooo
00?oo`00ooooooooool0I?oooolDo`3ooecooooo000Looooo`03o`000?oooooooooo02_ooooo00?o
o`00ooooooooool0MooooolDo`3oodSooooo000Looooo`03o`000?oooooooooo02_ooooo00?oo`00
ooooooooool0Rooooolgo`3ooa7ooooo000Looooo`;o0000;Oooool00ooo003oooooooooo`3Boooo
o`007?ooool00ol0003oooooooooo`0]ooooo`03ool00?oooooooooo0=7ooooo000Looooo`03o`00
0?oooooooooo02gooooo00?oo`00ooooooooool0dOooool001cooooo00?o0000ooooooooool0;_oo
ool00ooo003oooooooooo`3@ooooo`007?ooool00ol0003oooooooooo`0_ooooo`03ool00?oooooo
oooo0<oooooo000Looooo`03o`000?oooooooooo033ooooo00?oo`00ooooooooool0c_ooool001co
oooo00?o0000ooooooooool0<?ooool00ooo003oooooooooo`3>ooooo`007?ooool2o`0003;ooooo
00?oo`00ooooooooool0cOooool001cooooo00?o0000ooooooooool0<_ooool00ooo003ooooooooo
o`3<ooooo`007?ooool00ol0003oooooooooo`0cooooo`03ool00?oooooooooo0<_ooooo000Loooo
o`03o`000?oooooooooo03Cooooo00?oo`00ooooooooool0b_ooool001cooooo00?o0000oooooooo
ool0=Oooool00ooo003oooooooooo`39ooooo`007?ooool00ol0003oooooooooo`0fooooo`03ool0
0?oooooooooo0<Sooooo000Looooo`03o`000?oooooooooo03Oooooo00?oo`00ooooooooool0aooo
ool000cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0000Cooooo00?o
0000ooooooooool0>?ooool00ooo003oooooooooo`36ooooo`002oooool00ol0003oooooo`000007
ooooo`03o`000?oooooo000000Cooooo0_l0000jooooo`03ool00?oooooooooo0<Gooooo000;oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0joooo
o`;oo`00aOooool000_ooooo00?o0000ooooool000001oooool00ol0003oooooo`000004ooooo`03
o`000?oooooooooo03cooooo00?oo`00ooooooooool0`_ooool000cooooo00?o0000ooooooooool0
1_ooool3o`0000Cooooo00?o0000ooooooooool0?Oooool2ool00<;ooooo000Looooo`03o`000?oo
oooooooo03oooooo00?oo`00ooooooooool0_oooool001cooooo00?o0000ooooooooool0@?ooool0
0ooo003oooooooooo`2nooooo`007?ooool00ol0003oooooooooo`11ooooo`;oo`00__ooool001co
oooo0_l00014ooooo`03ool00?oooooooooo0;_ooooo000Looooo`03o`000?oooooooooo04Cooooo
0_oo002kooooo`007?ooool00ol0003oooooooooo`16ooooo`;oo`00^Oooool001cooooo00?o0000
ooooooooool0B?ooool00ooo003oooooooooo`2fooooo`007?ooool00ol0003oooooooooo`19oooo
o`;oo`00]_ooool001cooooo00?o0000ooooooooool0Boooool2ool00;Cooooo000Looooo`03o`00
0?oooooooooo04gooooo00?oo`00ooooooooool0/Oooool001cooooo00?o0000ooooooooool0C_oo
ool2ool00;7ooooo000Looooo`;o0000DOooool3ool00:kooooo000Looooo`03o`000?oooooooooo
05?ooooo0_oo002/ooooo`007?ooool00ol0003oooooooooo`1Eooooo`?oo`00ZOooool001cooooo
00?o0000ooooooooool0F?ooool3ool00:Kooooo000Looooo`03o`000?oooooooooo05_ooooo0ooo
002Sooooo`007?ooool00ol0003oooooooooo`1Nooooo`?oo`00X?ooool001cooooo00?o0000oooo
ooooool0HOooool4ool009cooooo000Looooo`;o0000I_ooool4ool009Sooooo000Looooo`03o`00
0?oooooooooo06Wooooo0ooo002Eooooo`007?ooool00ol0003oooooooooo`1/ooooo`Ooo`00S_oo
ool001cooooo00?o0000ooooooooool0Loooool:ool008Cooooo000Looooo`03o`000?oooooooooo
07gooooo2_oo001jooooo`007?ooool00ol0003oooooooooo`27ooooo`[oo`00L?ooool001cooooo
00?o0000ooooooooool0TOoooolDool005cooooo000Eooooo`?o00001?ooool00ol0003ooooooooo
o`2Uoooooccoo`008?ooool001Kooooo00?o0000ooooooooool00oooool2o`000>;ooooo3ooo000A
ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo0_ooool001Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooo`;ooooo000Eooooo`;o0000
1Oooool00ol0003oooooooooo`3oooooo`;ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo002>ooooo`?o0000Soooool008oooooo00?o0000ooooooooool0S_oo
ool008Gooooo0ol00002ooooo`03o`000?oooooo000000;ooooo0ol00002ooooo`?o00000_ooool3
o`0000Kooooo0ol0001kooooo`00Q_ooool01ol0003ooooooooooooooooo0000ooooool000000_oo
ool02?l0003oooooooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07[ooooo0026ooooo`07o`000?ooooooooooooooool0003oooooo`000002
ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0NOooool008Kooooo00?o0000ooooooooool01?l000000ooooooo0000
o`000002o`000006ooooool0003o0000ooooool0003ooooo1?l00008ooooo`03o`000?oooooooooo
07Wooooo0025ooooo`?o00004Oooool00ol0003oooooooooo`06ooooo`?o0000Noooool00?oooooo
8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.49406, -0.0692995, \
0.123903, 0.0066779}},
  CellTags->"5.3.5"]
}, Open  ]]
}, Open  ]],

Cell["\<\
Here is the inverse-system Nyquist array of this system, with the \
Gershgorin circles for row dominance superimposed on the diagonal \
terms.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NyquistArrayPlot[InverseSystem[tf], {0.001, 1}, 
        GershgorinCircles \[Rule] RowDominance];\)\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"5.3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.82798 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0435234 0.47619 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1.82798 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1.82798 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1.82798 L
s
0 1.82798 m
1 1.82798 L
s
1 0 m
1 1.82798 L
s
0 0 m
1 0 L
1 1.82798 L
0 1.82798 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0435234 0.477324 0.87254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.22773 0.1575 0.521506 0.1575 [
[.07023 .50901 -4.8 -7.2 ]
[.07023 .50901 4.8 0 ]
[.38523 .50901 -2.4 -7.2 ]
[.38523 .50901 2.4 0 ]
[.54273 .50901 -2.4 -7.2 ]
[.54273 .50901 2.4 0 ]
[.70023 .50901 -2.4 -7.2 ]
[.70023 .50901 2.4 0 ]
[.85773 .50901 -2.4 -7.2 ]
[.85773 .50901 2.4 0 ]
[.21523 .20651 -9.6 -3.6 ]
[.21523 .20651 0 3.6 ]
[.21523 .83651 -4.8 -3.6 ]
[.21523 .83651 0 3.6 ]
[.21523 1.15151 -4.8 -3.6 ]
[.21523 1.15151 0 3.6 ]
[.21523 1.46651 -4.8 -3.6 ]
[.21523 1.46651 0 3.6 ]
[.21523 1.78151 -4.8 -3.6 ]
[.21523 1.78151 0 3.6 ]
[ 0 0 0 0 ]
[ 1 1.82798 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07023 .52151 m
.07023 .52776 L
s
[(-1)] .07023 .50901 0 1 Mshowa
.38523 .52151 m
.38523 .52776 L
s
[(1)] .38523 .50901 0 1 Mshowa
.54273 .52151 m
.54273 .52776 L
s
[(2)] .54273 .50901 0 1 Mshowa
.70023 .52151 m
.70023 .52776 L
s
[(3)] .70023 .50901 0 1 Mshowa
.85773 .52151 m
.85773 .52776 L
s
[(4)] .85773 .50901 0 1 Mshowa
.125 Mabswid
.10173 .52151 m
.10173 .52526 L
s
.13323 .52151 m
.13323 .52526 L
s
.16473 .52151 m
.16473 .52526 L
s
.19623 .52151 m
.19623 .52526 L
s
.25923 .52151 m
.25923 .52526 L
s
.29073 .52151 m
.29073 .52526 L
s
.32223 .52151 m
.32223 .52526 L
s
.35373 .52151 m
.35373 .52526 L
s
.41673 .52151 m
.41673 .52526 L
s
.44823 .52151 m
.44823 .52526 L
s
.47973 .52151 m
.47973 .52526 L
s
.51123 .52151 m
.51123 .52526 L
s
.57423 .52151 m
.57423 .52526 L
s
.60573 .52151 m
.60573 .52526 L
s
.63723 .52151 m
.63723 .52526 L
s
.66873 .52151 m
.66873 .52526 L
s
.73173 .52151 m
.73173 .52526 L
s
.76323 .52151 m
.76323 .52526 L
s
.79473 .52151 m
.79473 .52526 L
s
.82623 .52151 m
.82623 .52526 L
s
.03873 .52151 m
.03873 .52526 L
s
.00723 .52151 m
.00723 .52526 L
s
.88923 .52151 m
.88923 .52526 L
s
.92073 .52151 m
.92073 .52526 L
s
.95223 .52151 m
.95223 .52526 L
s
.98373 .52151 m
.98373 .52526 L
s
.25 Mabswid
0 .52151 m
1 .52151 L
s
.22773 .20651 m
.23398 .20651 L
s
[(-2)] .21523 .20651 1 0 Mshowa
.22773 .83651 m
.23398 .83651 L
s
[(2)] .21523 .83651 1 0 Mshowa
.22773 1.15151 m
.23398 1.15151 L
s
[(4)] .21523 1.15151 1 0 Mshowa
.22773 1.46651 m
.23398 1.46651 L
s
[(6)] .21523 1.46651 1 0 Mshowa
.22773 1.78151 m
.23398 1.78151 L
s
[(8)] .21523 1.78151 1 0 Mshowa
.125 Mabswid
.22773 .28526 m
.23148 .28526 L
s
.22773 .36401 m
.23148 .36401 L
s
.22773 .44276 m
.23148 .44276 L
s
.22773 .60026 m
.23148 .60026 L
s
.22773 .67901 m
.23148 .67901 L
s
.22773 .75776 m
.23148 .75776 L
s
.22773 .91526 m
.23148 .91526 L
s
.22773 .99401 m
.23148 .99401 L
s
.22773 1.07276 m
.23148 1.07276 L
s
.22773 1.23026 m
.23148 1.23026 L
s
.22773 1.30901 m
.23148 1.30901 L
s
.22773 1.38776 m
.23148 1.38776 L
s
.22773 1.54526 m
.23148 1.54526 L
s
.22773 1.62401 m
.23148 1.62401 L
s
.22773 1.70276 m
.23148 1.70276 L
s
.22773 .12776 m
.23148 .12776 L
s
.22773 .04901 m
.23148 .04901 L
s
.25 Mabswid
.22773 0 m
.22773 1.82798 L
s
0 0 m
1 0 L
1 1.82798 L
0 1.82798 L
closepath
clip
newpath
.5 Mabswid
.01156 .52127 m
.01156 .52126 L
.01156 .52126 L
.01156 .52125 L
.01156 .52124 L
.01156 .52123 L
.01156 .52122 L
.01156 .52121 L
.01156 .5212 L
.01156 .52119 L
.01156 .52118 L
.01156 .52116 L
.01156 .52115 L
.01156 .52114 L
.01156 .52113 L
.01156 .52111 L
.01156 .5211 L
.01156 .52109 L
.01156 .52107 L
.01156 .52106 L
.01156 .52104 L
.01156 .52102 L
.01156 .52101 L
.01156 .52099 L
.01156 .52097 L
.01157 .52095 L
.01157 .52093 L
.01157 .52091 L
.01157 .52089 L
.01157 .52087 L
.01157 .52085 L
.01157 .52082 L
.01157 .5208 L
.01157 .52077 L
.01158 .52075 L
.01158 .52072 L
.01158 .52069 L
.01158 .52066 L
.01158 .52063 L
.01158 .5206 L
.01159 .52057 L
.01159 .52054 L
.01159 .5205 L
.01159 .52047 L
.0116 .52043 L
.0116 .52039 L
.0116 .52035 L
.01161 .52031 L
.01161 .52027 L
.01162 .52023 L
Mistroke
.01162 .52018 L
.01162 .52013 L
.01163 .52009 L
.01164 .52003 L
.01164 .51998 L
.01165 .51993 L
.01165 .51987 L
.01166 .51981 L
.01167 .51975 L
.01168 .51969 L
.01169 .51963 L
.0117 .51956 L
.01171 .51949 L
.01172 .51942 L
.01173 .51934 L
.01174 .51927 L
.01175 .51919 L
.01177 .5191 L
.01178 .51902 L
.0118 .51893 L
.01182 .51884 L
.01184 .51874 L
.01186 .51864 L
.01188 .51854 L
.0119 .51843 L
.01193 .51832 L
.01195 .5182 L
.01198 .51809 L
.01201 .51796 L
.01204 .51783 L
.01208 .5177 L
.01211 .51756 L
.01215 .51741 L
.0122 .51726 L
.01224 .51711 L
.01229 .51695 L
.01234 .51678 L
.0124 .5166 L
.01246 .51642 L
.01252 .51623 L
.01259 .51603 L
.01266 .51583 L
.01274 .51561 L
.01282 .51539 L
.01291 .51516 L
.013 .51491 L
.0131 .51466 L
.01321 .5144 L
.01332 .51412 L
.01344 .51383 L
Mistroke
.01357 .51353 L
.0137 .51322 L
.01385 .51289 L
.014 .51254 L
.01417 .51218 L
.01434 .5118 L
.01453 .51141 L
.01472 .51099 L
.01493 .51055 L
.01515 .5101 L
.01538 .50962 L
.01563 .50911 L
.01589 .50858 L
.01616 .50802 L
.01645 .50744 L
.01676 .50682 L
.01708 .50617 L
.01741 .50548 L
.01777 .50476 L
.01814 .504 L
.01852 .5032 L
.01893 .50236 L
.01935 .50147 L
.01979 .50053 L
.02025 .49954 L
.02073 .4985 L
.02122 .4974 L
.02173 .49624 L
.02226 .49502 L
.0228 .49374 L
.02336 .49238 L
.02393 .49096 L
.02452 .48946 L
.02513 .48788 L
.02574 .48622 L
.02637 .48448 L
.027 .48265 L
.02765 .48073 L
.0283 .47871 L
.02896 .4766 L
.02962 .47439 L
.03029 .47208 L
.03095 .46966 L
.03162 .46714 L
.03228 .4645 L
.03294 .46174 L
.0336 .45887 L
.03425 .45588 L
.03489 .45277 L
.03552 .44953 L
Mistroke
.03614 .44616 L
.03675 .44266 L
.03734 .43902 L
.03793 .43525 L
.03849 .43134 L
.03904 .42728 L
.03958 .42307 L
.0401 .41872 L
.0406 .41421 L
.04109 .40953 L
.04155 .4047 L
.042 .3997 L
.04243 .39453 L
.04285 .38918 L
.04325 .38365 L
.04362 .37793 L
.04399 .37202 L
.04433 .36592 L
.04466 .35961 L
.04497 .35308 L
.04527 .34635 L
.04555 .33938 L
.04582 .33219 L
.04608 .32475 L
.04632 .31707 L
.04654 .30913 L
.04676 .30093 L
.04696 .29245 L
.04715 .28369 L
.04733 .27464 L
.0475 .26528 L
.04766 .25561 L
.04781 .24561 L
.04796 .23527 L
.04809 .22459 L
.04821 .21354 L
.04833 .20212 L
.04844 .19031 L
.04855 .1781 L
.04864 .16548 L
.04873 .15242 L
.04882 .13891 L
.0489 .12494 L
.04897 .11049 L
.04905 .09555 L
.04911 .08009 L
.04917 .06409 L
.04923 .04754 L
.04928 .03043 L
.04933 .01271 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0435234 0.97619 0.87254 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.22773 0.1575 0.521506 0.1575 [
[.07023 .50901 -4.8 -7.2 ]
[.07023 .50901 4.8 0 ]
[.38523 .50901 -2.4 -7.2 ]
[.38523 .50901 2.4 0 ]
[.54273 .50901 -2.4 -7.2 ]
[.54273 .50901 2.4 0 ]
[.70023 .50901 -2.4 -7.2 ]
[.70023 .50901 2.4 0 ]
[.85773 .50901 -2.4 -7.2 ]
[.85773 .50901 2.4 0 ]
[.21523 .20651 -9.6 -3.6 ]
[.21523 .20651 0 3.6 ]
[.21523 .83651 -4.8 -3.6 ]
[.21523 .83651 0 3.6 ]
[.21523 1.15151 -4.8 -3.6 ]
[.21523 1.15151 0 3.6 ]
[.21523 1.46651 -4.8 -3.6 ]
[.21523 1.46651 0 3.6 ]
[.21523 1.78151 -4.8 -3.6 ]
[.21523 1.78151 0 3.6 ]
[ 0 0 0 0 ]
[ 1 1.82798 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07023 .52151 m
.07023 .52776 L
s
[(-1)] .07023 .50901 0 1 Mshowa
.38523 .52151 m
.38523 .52776 L
s
[(1)] .38523 .50901 0 1 Mshowa
.54273 .52151 m
.54273 .52776 L
s
[(2)] .54273 .50901 0 1 Mshowa
.70023 .52151 m
.70023 .52776 L
s
[(3)] .70023 .50901 0 1 Mshowa
.85773 .52151 m
.85773 .52776 L
s
[(4)] .85773 .50901 0 1 Mshowa
.125 Mabswid
.10173 .52151 m
.10173 .52526 L
s
.13323 .52151 m
.13323 .52526 L
s
.16473 .52151 m
.16473 .52526 L
s
.19623 .52151 m
.19623 .52526 L
s
.25923 .52151 m
.25923 .52526 L
s
.29073 .52151 m
.29073 .52526 L
s
.32223 .52151 m
.32223 .52526 L
s
.35373 .52151 m
.35373 .52526 L
s
.41673 .52151 m
.41673 .52526 L
s
.44823 .52151 m
.44823 .52526 L
s
.47973 .52151 m
.47973 .52526 L
s
.51123 .52151 m
.51123 .52526 L
s
.57423 .52151 m
.57423 .52526 L
s
.60573 .52151 m
.60573 .52526 L
s
.63723 .52151 m
.63723 .52526 L
s
.66873 .52151 m
.66873 .52526 L
s
.73173 .52151 m
.73173 .52526 L
s
.76323 .52151 m
.76323 .52526 L
s
.79473 .52151 m
.79473 .52526 L
s
.82623 .52151 m
.82623 .52526 L
s
.03873 .52151 m
.03873 .52526 L
s
.00723 .52151 m
.00723 .52526 L
s
.88923 .52151 m
.88923 .52526 L
s
.92073 .52151 m
.92073 .52526 L
s
.95223 .52151 m
.95223 .52526 L
s
.98373 .52151 m
.98373 .52526 L
s
.25 Mabswid
0 .52151 m
1 .52151 L
s
.22773 .20651 m
.23398 .20651 L
s
[(-2)] .21523 .20651 1 0 Mshowa
.22773 .83651 m
.23398 .83651 L
s
[(2)] .21523 .83651 1 0 Mshowa
.22773 1.15151 m
.23398 1.15151 L
s
[(4)] .21523 1.15151 1 0 Mshowa
.22773 1.46651 m
.23398 1.46651 L
s
[(6)] .21523 1.46651 1 0 Mshowa
.22773 1.78151 m
.23398 1.78151 L
s
[(8)] .21523 1.78151 1 0 Mshowa
.125 Mabswid
.22773 .28526 m
.23148 .28526 L
s
.22773 .36401 m
.23148 .36401 L
s
.22773 .44276 m
.23148 .44276 L
s
.22773 .60026 m
.23148 .60026 L
s
.22773 .67901 m
.23148 .67901 L
s
.22773 .75776 m
.23148 .75776 L
s
.22773 .91526 m
.23148 .91526 L
s
.22773 .99401 m
.23148 .99401 L
s
.22773 1.07276 m
.23148 1.07276 L
s
.22773 1.23026 m
.23148 1.23026 L
s
.22773 1.30901 m
.23148 1.30901 L
s
.22773 1.38776 m
.23148 1.38776 L
s
.22773 1.54526 m
.23148 1.54526 L
s
.22773 1.62401 m
.23148 1.62401 L
s
.22773 1.70276 m
.23148 1.70276 L
s
.22773 .12776 m
.23148 .12776 L
s
.22773 .04901 m
.23148 .04901 L
s
.25 Mabswid
.22773 0 m
.22773 1.82798 L
s
0 0 m
1 0 L
1 1.82798 L
0 1.82798 L
closepath
clip
newpath
.5 Mabswid
.53655 .52215 m
.53655 .52217 L
.53655 .52219 L
.53655 .52222 L
.53655 .52224 L
.53655 .52227 L
.53655 .5223 L
.53655 .52232 L
.53655 .52235 L
.53655 .52238 L
.53655 .52241 L
.53655 .52245 L
.53655 .52248 L
.53655 .52251 L
.53655 .52255 L
.53655 .52259 L
.53655 .52262 L
.53655 .52266 L
.53655 .52271 L
.53655 .52275 L
.53655 .52279 L
.53655 .52284 L
.53654 .52288 L
.53654 .52293 L
.53654 .52298 L
.53654 .52304 L
.53654 .52309 L
.53654 .52315 L
.53654 .5232 L
.53654 .52326 L
.53654 .52333 L
.53654 .52339 L
.53654 .52346 L
.53653 .52352 L
.53653 .5236 L
.53653 .52367 L
.53653 .52375 L
.53653 .52383 L
.53653 .52391 L
.53652 .52399 L
.53652 .52408 L
.53652 .52417 L
.53652 .52427 L
.53651 .52436 L
.53651 .52446 L
.53651 .52457 L
.5365 .52468 L
.5365 .52479 L
.5365 .52491 L
.53649 .52503 L
Mistroke
.53649 .52515 L
.53648 .52528 L
.53648 .52541 L
.53647 .52555 L
.53647 .52569 L
.53646 .52584 L
.53645 .526 L
.53645 .52615 L
.53644 .52632 L
.53643 .52649 L
.53642 .52667 L
.53641 .52685 L
.5364 .52704 L
.53639 .52723 L
.53638 .52744 L
.53637 .52765 L
.53636 .52787 L
.53634 .52809 L
.53633 .52832 L
.53631 .52857 L
.53629 .52882 L
.53628 .52908 L
.53626 .52935 L
.53623 .52963 L
.53621 .52991 L
.53619 .53021 L
.53616 .53052 L
.53613 .53085 L
.5361 .53118 L
.53607 .53152 L
.53604 .53188 L
.536 .53225 L
.53596 .53264 L
.53592 .53304 L
.53587 .53345 L
.53583 .53388 L
.53577 .53432 L
.53572 .53478 L
.53566 .53526 L
.5356 .53576 L
.53553 .53627 L
.53546 .53681 L
.53538 .53736 L
.5353 .53794 L
.53522 .53853 L
.53512 .53915 L
.53503 .5398 L
.53492 .54046 L
.53481 .54116 L
.53469 .54188 L
Mistroke
.53456 .54263 L
.53443 .54341 L
.53428 .54422 L
.53413 .54506 L
.53397 .54594 L
.5338 .54685 L
.53361 .5478 L
.53342 .54878 L
.53322 .54981 L
.533 .55088 L
.53277 .552 L
.53253 .55316 L
.53227 .55437 L
.532 .55563 L
.53171 .55694 L
.53141 .55832 L
.5311 .55975 L
.53076 .56124 L
.53042 .5628 L
.53005 .56442 L
.52967 .56612 L
.52927 .56789 L
.52885 .56974 L
.52842 .57167 L
.52797 .57369 L
.5275 .5758 L
.52701 .578 L
.52651 .5803 L
.52599 .5827 L
.52546 .5852 L
.52491 .58782 L
.52434 .59056 L
.52376 .59341 L
.52317 .59639 L
.52257 .59951 L
.52195 .60275 L
.52133 .60614 L
.5207 .60967 L
.52006 .61335 L
.51941 .61718 L
.51876 .62118 L
.51811 .62534 L
.51746 .62967 L
.51681 .63417 L
.51616 .63886 L
.51552 .64374 L
.51488 .6488 L
.51425 .65406 L
.51363 .65953 L
.51301 .6652 L
Mistroke
.51241 .67109 L
.51182 .67719 L
.51124 .68353 L
.51068 .69009 L
.51013 .6969 L
.50959 .70395 L
.50908 .71125 L
.50858 .71881 L
.50809 .72664 L
.50763 .73475 L
.50718 .74313 L
.50675 .75182 L
.50633 .7608 L
.50593 .77009 L
.50555 .7797 L
.50519 .78965 L
.50485 .79993 L
.50452 .81057 L
.5042 .82157 L
.50391 .83295 L
.50362 .84472 L
.50335 .85688 L
.5031 .86947 L
.50286 .88248 L
.50263 .89594 L
.50242 .90986 L
.50221 .92425 L
.50202 .93914 L
.50184 .95454 L
.50167 .97047 L
.50151 .98694 L
.50136 1.00398 L
.50122 1.0216 L
.50108 1.03984 L
.50096 1.0587 L
.50084 1.07821 L
.50073 1.09839 L
.50063 1.11928 L
.50053 1.14089 L
.50044 1.16324 L
.50035 1.18637 L
.50027 1.21031 L
.5002 1.23508 L
.50013 1.2607 L
.50006 1.28722 L
.5 1.31467 L
.49994 1.34307 L
.49989 1.37246 L
.49984 1.40288 L
.49979 1.43437 L
Mistroke
Mfstroke
newpath
.53655 .52215 .21617 0 365.73 arc
s
newpath
.53655 .52227 .21617 0 365.73 arc
s
newpath
.53655 .52241 .21617 0 365.73 arc
s
newpath
.53655 .52259 .21617 0 365.73 arc
s
newpath
.53655 .52279 .21617 0 365.73 arc
s
newpath
.53654 .52304 .21617 0 365.73 arc
s
newpath
.53654 .52333 .21616 0 365.73 arc
s
newpath
.53653 .52367 .21615 0 365.73 arc
s
newpath
.53652 .52408 .21615 0 365.73 arc
s
newpath
.53651 .52457 .21613 0 365.73 arc
s
newpath
.53649 .52515 .21611 0 365.73 arc
s
newpath
.53646 .52584 .21609 0 365.73 arc
s
newpath
.53642 .52667 .21605 0 365.73 arc
s
newpath
.53637 .52765 .216 0 365.73 arc
s
newpath
.53629 .52882 .21593 0 365.73 arc
s
newpath
.53619 .53021 .21583 0 365.73 arc
s
newpath
.53604 .53188 .21569 0 365.73 arc
s
newpath
.53583 .53388 .21549 0 365.73 arc
s
newpath
.53553 .53627 .21521 0 365.73 arc
s
newpath
.53512 .53915 .21483 0 365.73 arc
s
newpath
.53456 .54263 .21431 0 365.73 arc
s
newpath
.5338 .54685 .21361 0 365.73 arc
s
newpath
.53277 .552 .21268 0 365.73 arc
s
newpath
.53141 .55832 .21148 0 365.73 arc
s
newpath
.52967 .56612 .21001 0 365.73 arc
s
newpath
.5275 .5758 .20828 0 365.73 arc
s
newpath
.52491 .58782 .20644 0 365.73 arc
s
newpath
.52195 .60275 .20474 0 365.73 arc
s
newpath
.51876 .62118 .20363 0 365.73 arc
s
newpath
.51552 .64374 .20375 0 365.73 arc
s
newpath
.51241 .67109 .20587 0 365.73 arc
s
newpath
.50959 .70395 .21091 0 365.73 arc
s
newpath
.50718 .74313 .21978 0 365.73 arc
s
newpath
.50519 .78965 .23347 0 365.73 arc
s
newpath
.50362 .84472 .25293 0 365.73 arc
s
newpath
.50242 .90986 .27916 0 365.73 arc
s
newpath
.50151 .98694 .31326 0 365.73 arc
s
newpath
.50084 1.07821 .35646 0 365.73 arc
s
newpath
.50035 1.18637 .4102 0 365.73 arc
s
newpath
.5 1.31467 .47619 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.955442 0.477324 1.78446 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.22773 0.1575 0.521506 0.1575 [
[.07023 .50901 -4.8 -7.2 ]
[.07023 .50901 4.8 0 ]
[.38523 .50901 -2.4 -7.2 ]
[.38523 .50901 2.4 0 ]
[.54273 .50901 -2.4 -7.2 ]
[.54273 .50901 2.4 0 ]
[.70023 .50901 -2.4 -7.2 ]
[.70023 .50901 2.4 0 ]
[.85773 .50901 -2.4 -7.2 ]
[.85773 .50901 2.4 0 ]
[.21523 .20651 -9.6 -3.6 ]
[.21523 .20651 0 3.6 ]
[.21523 .83651 -4.8 -3.6 ]
[.21523 .83651 0 3.6 ]
[.21523 1.15151 -4.8 -3.6 ]
[.21523 1.15151 0 3.6 ]
[.21523 1.46651 -4.8 -3.6 ]
[.21523 1.46651 0 3.6 ]
[.21523 1.78151 -4.8 -3.6 ]
[.21523 1.78151 0 3.6 ]
[ 0 0 0 0 ]
[ 1 1.82798 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07023 .52151 m
.07023 .52776 L
s
[(-1)] .07023 .50901 0 1 Mshowa
.38523 .52151 m
.38523 .52776 L
s
[(1)] .38523 .50901 0 1 Mshowa
.54273 .52151 m
.54273 .52776 L
s
[(2)] .54273 .50901 0 1 Mshowa
.70023 .52151 m
.70023 .52776 L
s
[(3)] .70023 .50901 0 1 Mshowa
.85773 .52151 m
.85773 .52776 L
s
[(4)] .85773 .50901 0 1 Mshowa
.125 Mabswid
.10173 .52151 m
.10173 .52526 L
s
.13323 .52151 m
.13323 .52526 L
s
.16473 .52151 m
.16473 .52526 L
s
.19623 .52151 m
.19623 .52526 L
s
.25923 .52151 m
.25923 .52526 L
s
.29073 .52151 m
.29073 .52526 L
s
.32223 .52151 m
.32223 .52526 L
s
.35373 .52151 m
.35373 .52526 L
s
.41673 .52151 m
.41673 .52526 L
s
.44823 .52151 m
.44823 .52526 L
s
.47973 .52151 m
.47973 .52526 L
s
.51123 .52151 m
.51123 .52526 L
s
.57423 .52151 m
.57423 .52526 L
s
.60573 .52151 m
.60573 .52526 L
s
.63723 .52151 m
.63723 .52526 L
s
.66873 .52151 m
.66873 .52526 L
s
.73173 .52151 m
.73173 .52526 L
s
.76323 .52151 m
.76323 .52526 L
s
.79473 .52151 m
.79473 .52526 L
s
.82623 .52151 m
.82623 .52526 L
s
.03873 .52151 m
.03873 .52526 L
s
.00723 .52151 m
.00723 .52526 L
s
.88923 .52151 m
.88923 .52526 L
s
.92073 .52151 m
.92073 .52526 L
s
.95223 .52151 m
.95223 .52526 L
s
.98373 .52151 m
.98373 .52526 L
s
.25 Mabswid
0 .52151 m
1 .52151 L
s
.22773 .20651 m
.23398 .20651 L
s
[(-2)] .21523 .20651 1 0 Mshowa
.22773 .83651 m
.23398 .83651 L
s
[(2)] .21523 .83651 1 0 Mshowa
.22773 1.15151 m
.23398 1.15151 L
s
[(4)] .21523 1.15151 1 0 Mshowa
.22773 1.46651 m
.23398 1.46651 L
s
[(6)] .21523 1.46651 1 0 Mshowa
.22773 1.78151 m
.23398 1.78151 L
s
[(8)] .21523 1.78151 1 0 Mshowa
.125 Mabswid
.22773 .28526 m
.23148 .28526 L
s
.22773 .36401 m
.23148 .36401 L
s
.22773 .44276 m
.23148 .44276 L
s
.22773 .60026 m
.23148 .60026 L
s
.22773 .67901 m
.23148 .67901 L
s
.22773 .75776 m
.23148 .75776 L
s
.22773 .91526 m
.23148 .91526 L
s
.22773 .99401 m
.23148 .99401 L
s
.22773 1.07276 m
.23148 1.07276 L
s
.22773 1.23026 m
.23148 1.23026 L
s
.22773 1.30901 m
.23148 1.30901 L
s
.22773 1.38776 m
.23148 1.38776 L
s
.22773 1.54526 m
.23148 1.54526 L
s
.22773 1.62401 m
.23148 1.62401 L
s
.22773 1.70276 m
.23148 1.70276 L
s
.22773 .12776 m
.23148 .12776 L
s
.22773 .04901 m
.23148 .04901 L
s
.25 Mabswid
.22773 0 m
.22773 1.82798 L
s
0 0 m
1 0 L
1 1.82798 L
0 1.82798 L
closepath
clip
newpath
.5 Mabswid
.53655 .52215 m
.53655 .52217 L
.53655 .52219 L
.53655 .52222 L
.53655 .52224 L
.53655 .52227 L
.53655 .5223 L
.53655 .52232 L
.53655 .52235 L
.53655 .52238 L
.53655 .52241 L
.53655 .52245 L
.53655 .52248 L
.53655 .52251 L
.53655 .52255 L
.53655 .52259 L
.53655 .52262 L
.53655 .52266 L
.53655 .52271 L
.53655 .52275 L
.53655 .52279 L
.53655 .52284 L
.53654 .52288 L
.53654 .52293 L
.53654 .52298 L
.53654 .52304 L
.53654 .52309 L
.53654 .52315 L
.53654 .5232 L
.53654 .52326 L
.53654 .52333 L
.53654 .52339 L
.53654 .52346 L
.53653 .52352 L
.53653 .5236 L
.53653 .52367 L
.53653 .52375 L
.53653 .52383 L
.53653 .52391 L
.53652 .52399 L
.53652 .52408 L
.53652 .52417 L
.53652 .52427 L
.53651 .52436 L
.53651 .52446 L
.53651 .52457 L
.5365 .52468 L
.5365 .52479 L
.5365 .52491 L
.53649 .52503 L
Mistroke
.53649 .52515 L
.53648 .52528 L
.53648 .52541 L
.53647 .52555 L
.53647 .52569 L
.53646 .52584 L
.53645 .526 L
.53645 .52615 L
.53644 .52632 L
.53643 .52649 L
.53642 .52667 L
.53641 .52685 L
.5364 .52704 L
.53639 .52723 L
.53638 .52744 L
.53637 .52765 L
.53636 .52787 L
.53634 .52809 L
.53633 .52832 L
.53631 .52857 L
.53629 .52882 L
.53628 .52908 L
.53626 .52935 L
.53623 .52963 L
.53621 .52991 L
.53619 .53021 L
.53616 .53052 L
.53613 .53085 L
.5361 .53118 L
.53607 .53152 L
.53604 .53188 L
.536 .53225 L
.53596 .53264 L
.53592 .53304 L
.53587 .53345 L
.53583 .53388 L
.53577 .53432 L
.53572 .53478 L
.53566 .53526 L
.5356 .53576 L
.53553 .53627 L
.53546 .53681 L
.53538 .53736 L
.5353 .53794 L
.53522 .53853 L
.53512 .53915 L
.53503 .5398 L
.53492 .54046 L
.53481 .54116 L
.53469 .54188 L
Mistroke
.53456 .54263 L
.53443 .54341 L
.53428 .54422 L
.53413 .54506 L
.53397 .54594 L
.5338 .54685 L
.53361 .5478 L
.53342 .54878 L
.53322 .54981 L
.533 .55088 L
.53277 .552 L
.53253 .55316 L
.53227 .55437 L
.532 .55563 L
.53171 .55694 L
.53141 .55832 L
.5311 .55975 L
.53076 .56124 L
.53042 .5628 L
.53005 .56442 L
.52967 .56612 L
.52927 .56789 L
.52885 .56974 L
.52842 .57167 L
.52797 .57369 L
.5275 .5758 L
.52701 .578 L
.52651 .5803 L
.52599 .5827 L
.52546 .5852 L
.52491 .58782 L
.52434 .59056 L
.52376 .59341 L
.52317 .59639 L
.52257 .59951 L
.52195 .60275 L
.52133 .60614 L
.5207 .60967 L
.52006 .61335 L
.51941 .61718 L
.51876 .62118 L
.51811 .62534 L
.51746 .62967 L
.51681 .63417 L
.51616 .63886 L
.51552 .64374 L
.51488 .6488 L
.51425 .65406 L
.51363 .65953 L
.51301 .6652 L
Mistroke
.51241 .67109 L
.51182 .67719 L
.51124 .68353 L
.51068 .69009 L
.51013 .6969 L
.50959 .70395 L
.50908 .71125 L
.50858 .71881 L
.50809 .72664 L
.50763 .73475 L
.50718 .74313 L
.50675 .75182 L
.50633 .7608 L
.50593 .77009 L
.50555 .7797 L
.50519 .78965 L
.50485 .79993 L
.50452 .81057 L
.5042 .82157 L
.50391 .83295 L
.50362 .84472 L
.50335 .85688 L
.5031 .86947 L
.50286 .88248 L
.50263 .89594 L
.50242 .90986 L
.50221 .92425 L
.50202 .93914 L
.50184 .95454 L
.50167 .97047 L
.50151 .98694 L
.50136 1.00398 L
.50122 1.0216 L
.50108 1.03984 L
.50096 1.0587 L
.50084 1.07821 L
.50073 1.09839 L
.50063 1.11928 L
.50053 1.14089 L
.50044 1.16324 L
.50035 1.18637 L
.50027 1.21031 L
.5002 1.23508 L
.50013 1.2607 L
.50006 1.28722 L
.5 1.31467 L
.49994 1.34307 L
.49989 1.37246 L
.49984 1.40288 L
.49979 1.43437 L
Mistroke
Mfstroke
newpath
.53655 .52215 .21617 0 365.73 arc
s
newpath
.53655 .52227 .21617 0 365.73 arc
s
newpath
.53655 .52241 .21617 0 365.73 arc
s
newpath
.53655 .52259 .21617 0 365.73 arc
s
newpath
.53655 .52279 .21617 0 365.73 arc
s
newpath
.53654 .52304 .21617 0 365.73 arc
s
newpath
.53654 .52333 .21616 0 365.73 arc
s
newpath
.53653 .52367 .21615 0 365.73 arc
s
newpath
.53652 .52408 .21615 0 365.73 arc
s
newpath
.53651 .52457 .21613 0 365.73 arc
s
newpath
.53649 .52515 .21611 0 365.73 arc
s
newpath
.53646 .52584 .21609 0 365.73 arc
s
newpath
.53642 .52667 .21605 0 365.73 arc
s
newpath
.53637 .52765 .216 0 365.73 arc
s
newpath
.53629 .52882 .21593 0 365.73 arc
s
newpath
.53619 .53021 .21583 0 365.73 arc
s
newpath
.53604 .53188 .21569 0 365.73 arc
s
newpath
.53583 .53388 .21549 0 365.73 arc
s
newpath
.53553 .53627 .21521 0 365.73 arc
s
newpath
.53512 .53915 .21483 0 365.73 arc
s
newpath
.53456 .54263 .21431 0 365.73 arc
s
newpath
.5338 .54685 .21361 0 365.73 arc
s
newpath
.53277 .552 .21268 0 365.73 arc
s
newpath
.53141 .55832 .21148 0 365.73 arc
s
newpath
.52967 .56612 .21001 0 365.73 arc
s
newpath
.5275 .5758 .20828 0 365.73 arc
s
newpath
.52491 .58782 .20644 0 365.73 arc
s
newpath
.52195 .60275 .20474 0 365.73 arc
s
newpath
.51876 .62118 .20363 0 365.73 arc
s
newpath
.51552 .64374 .20375 0 365.73 arc
s
newpath
.51241 .67109 .20587 0 365.73 arc
s
newpath
.50959 .70395 .21091 0 365.73 arc
s
newpath
.50718 .74313 .21978 0 365.73 arc
s
newpath
.50519 .78965 .23347 0 365.73 arc
s
newpath
.50362 .84472 .25293 0 365.73 arc
s
newpath
.50242 .90986 .27916 0 365.73 arc
s
newpath
.50151 .98694 .31326 0 365.73 arc
s
newpath
.50084 1.07821 .35646 0 365.73 arc
s
newpath
.50035 1.18637 .4102 0 365.73 arc
s
newpath
.5 1.31467 .47619 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.955442 0.97619 1.78446 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.22773 0.1575 0.521506 0.1575 [
[.07023 .50901 -4.8 -7.2 ]
[.07023 .50901 4.8 0 ]
[.38523 .50901 -2.4 -7.2 ]
[.38523 .50901 2.4 0 ]
[.54273 .50901 -2.4 -7.2 ]
[.54273 .50901 2.4 0 ]
[.70023 .50901 -2.4 -7.2 ]
[.70023 .50901 2.4 0 ]
[.85773 .50901 -2.4 -7.2 ]
[.85773 .50901 2.4 0 ]
[.21523 .20651 -9.6 -3.6 ]
[.21523 .20651 0 3.6 ]
[.21523 .83651 -4.8 -3.6 ]
[.21523 .83651 0 3.6 ]
[.21523 1.15151 -4.8 -3.6 ]
[.21523 1.15151 0 3.6 ]
[.21523 1.46651 -4.8 -3.6 ]
[.21523 1.46651 0 3.6 ]
[.21523 1.78151 -4.8 -3.6 ]
[.21523 1.78151 0 3.6 ]
[ 0 0 0 0 ]
[ 1 1.82798 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07023 .52151 m
.07023 .52776 L
s
[(-1)] .07023 .50901 0 1 Mshowa
.38523 .52151 m
.38523 .52776 L
s
[(1)] .38523 .50901 0 1 Mshowa
.54273 .52151 m
.54273 .52776 L
s
[(2)] .54273 .50901 0 1 Mshowa
.70023 .52151 m
.70023 .52776 L
s
[(3)] .70023 .50901 0 1 Mshowa
.85773 .52151 m
.85773 .52776 L
s
[(4)] .85773 .50901 0 1 Mshowa
.125 Mabswid
.10173 .52151 m
.10173 .52526 L
s
.13323 .52151 m
.13323 .52526 L
s
.16473 .52151 m
.16473 .52526 L
s
.19623 .52151 m
.19623 .52526 L
s
.25923 .52151 m
.25923 .52526 L
s
.29073 .52151 m
.29073 .52526 L
s
.32223 .52151 m
.32223 .52526 L
s
.35373 .52151 m
.35373 .52526 L
s
.41673 .52151 m
.41673 .52526 L
s
.44823 .52151 m
.44823 .52526 L
s
.47973 .52151 m
.47973 .52526 L
s
.51123 .52151 m
.51123 .52526 L
s
.57423 .52151 m
.57423 .52526 L
s
.60573 .52151 m
.60573 .52526 L
s
.63723 .52151 m
.63723 .52526 L
s
.66873 .52151 m
.66873 .52526 L
s
.73173 .52151 m
.73173 .52526 L
s
.76323 .52151 m
.76323 .52526 L
s
.79473 .52151 m
.79473 .52526 L
s
.82623 .52151 m
.82623 .52526 L
s
.03873 .52151 m
.03873 .52526 L
s
.00723 .52151 m
.00723 .52526 L
s
.88923 .52151 m
.88923 .52526 L
s
.92073 .52151 m
.92073 .52526 L
s
.95223 .52151 m
.95223 .52526 L
s
.98373 .52151 m
.98373 .52526 L
s
.25 Mabswid
0 .52151 m
1 .52151 L
s
.22773 .20651 m
.23398 .20651 L
s
[(-2)] .21523 .20651 1 0 Mshowa
.22773 .83651 m
.23398 .83651 L
s
[(2)] .21523 .83651 1 0 Mshowa
.22773 1.15151 m
.23398 1.15151 L
s
[(4)] .21523 1.15151 1 0 Mshowa
.22773 1.46651 m
.23398 1.46651 L
s
[(6)] .21523 1.46651 1 0 Mshowa
.22773 1.78151 m
.23398 1.78151 L
s
[(8)] .21523 1.78151 1 0 Mshowa
.125 Mabswid
.22773 .28526 m
.23148 .28526 L
s
.22773 .36401 m
.23148 .36401 L
s
.22773 .44276 m
.23148 .44276 L
s
.22773 .60026 m
.23148 .60026 L
s
.22773 .67901 m
.23148 .67901 L
s
.22773 .75776 m
.23148 .75776 L
s
.22773 .91526 m
.23148 .91526 L
s
.22773 .99401 m
.23148 .99401 L
s
.22773 1.07276 m
.23148 1.07276 L
s
.22773 1.23026 m
.23148 1.23026 L
s
.22773 1.30901 m
.23148 1.30901 L
s
.22773 1.38776 m
.23148 1.38776 L
s
.22773 1.54526 m
.23148 1.54526 L
s
.22773 1.62401 m
.23148 1.62401 L
s
.22773 1.70276 m
.23148 1.70276 L
s
.22773 .12776 m
.23148 .12776 L
s
.22773 .04901 m
.23148 .04901 L
s
.25 Mabswid
.22773 0 m
.22773 1.82798 L
s
0 0 m
1 0 L
1 1.82798 L
0 1.82798 L
closepath
clip
newpath
.5 Mabswid
.01156 .52127 m
.01156 .52126 L
.01156 .52126 L
.01156 .52125 L
.01156 .52124 L
.01156 .52123 L
.01156 .52122 L
.01156 .52121 L
.01156 .5212 L
.01156 .52119 L
.01156 .52118 L
.01156 .52116 L
.01156 .52115 L
.01156 .52114 L
.01156 .52113 L
.01156 .52111 L
.01156 .5211 L
.01156 .52109 L
.01156 .52107 L
.01156 .52106 L
.01156 .52104 L
.01156 .52102 L
.01156 .52101 L
.01156 .52099 L
.01156 .52097 L
.01157 .52095 L
.01157 .52093 L
.01157 .52091 L
.01157 .52089 L
.01157 .52087 L
.01157 .52085 L
.01157 .52082 L
.01157 .5208 L
.01157 .52077 L
.01158 .52075 L
.01158 .52072 L
.01158 .52069 L
.01158 .52066 L
.01158 .52063 L
.01158 .5206 L
.01159 .52057 L
.01159 .52054 L
.01159 .5205 L
.01159 .52047 L
.0116 .52043 L
.0116 .52039 L
.0116 .52035 L
.01161 .52031 L
.01161 .52027 L
.01162 .52023 L
Mistroke
.01162 .52018 L
.01162 .52013 L
.01163 .52009 L
.01164 .52003 L
.01164 .51998 L
.01165 .51993 L
.01165 .51987 L
.01166 .51981 L
.01167 .51975 L
.01168 .51969 L
.01169 .51963 L
.0117 .51956 L
.01171 .51949 L
.01172 .51942 L
.01173 .51934 L
.01174 .51927 L
.01175 .51919 L
.01177 .5191 L
.01178 .51902 L
.0118 .51893 L
.01182 .51884 L
.01184 .51874 L
.01186 .51864 L
.01188 .51854 L
.0119 .51843 L
.01193 .51832 L
.01195 .5182 L
.01198 .51809 L
.01201 .51796 L
.01204 .51783 L
.01208 .5177 L
.01211 .51756 L
.01215 .51741 L
.0122 .51726 L
.01224 .51711 L
.01229 .51695 L
.01234 .51678 L
.0124 .5166 L
.01246 .51642 L
.01252 .51623 L
.01259 .51603 L
.01266 .51583 L
.01274 .51561 L
.01282 .51539 L
.01291 .51516 L
.013 .51491 L
.0131 .51466 L
.01321 .5144 L
.01332 .51412 L
.01344 .51383 L
Mistroke
.01357 .51353 L
.0137 .51322 L
.01385 .51289 L
.014 .51254 L
.01417 .51218 L
.01434 .5118 L
.01453 .51141 L
.01472 .51099 L
.01493 .51055 L
.01515 .5101 L
.01538 .50962 L
.01563 .50911 L
.01589 .50858 L
.01616 .50802 L
.01645 .50744 L
.01676 .50682 L
.01708 .50617 L
.01741 .50548 L
.01777 .50476 L
.01814 .504 L
.01852 .5032 L
.01893 .50236 L
.01935 .50147 L
.01979 .50053 L
.02025 .49954 L
.02073 .4985 L
.02122 .4974 L
.02173 .49624 L
.02226 .49502 L
.0228 .49374 L
.02336 .49238 L
.02393 .49096 L
.02452 .48946 L
.02513 .48788 L
.02574 .48622 L
.02637 .48448 L
.027 .48265 L
.02765 .48073 L
.0283 .47871 L
.02896 .4766 L
.02962 .47439 L
.03029 .47208 L
.03095 .46966 L
.03162 .46714 L
.03228 .4645 L
.03294 .46174 L
.0336 .45887 L
.03425 .45588 L
.03489 .45277 L
.03552 .44953 L
Mistroke
.03614 .44616 L
.03675 .44266 L
.03734 .43902 L
.03793 .43525 L
.03849 .43134 L
.03904 .42728 L
.03958 .42307 L
.0401 .41872 L
.0406 .41421 L
.04109 .40953 L
.04155 .4047 L
.042 .3997 L
.04243 .39453 L
.04285 .38918 L
.04325 .38365 L
.04362 .37793 L
.04399 .37202 L
.04433 .36592 L
.04466 .35961 L
.04497 .35308 L
.04527 .34635 L
.04555 .33938 L
.04582 .33219 L
.04608 .32475 L
.04632 .31707 L
.04654 .30913 L
.04676 .30093 L
.04696 .29245 L
.04715 .28369 L
.04733 .27464 L
.0475 .26528 L
.04766 .25561 L
.04781 .24561 L
.04796 .23527 L
.04809 .22459 L
.04821 .21354 L
.04833 .20212 L
.04844 .19031 L
.04855 .1781 L
.04864 .16548 L
.04873 .15242 L
.04882 .13891 L
.0489 .12494 L
.04897 .11049 L
.04905 .09555 L
.04911 .08009 L
.04917 .06409 L
.04923 .04754 L
.04928 .03043 L
.04933 .01271 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[4]:=",
  ImageSize->{157.5, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002M00017b000`400?l00000o`00003oWOl00000
0003o`000?oooooooooo09Wooooo0Ol000000003o`000?oooooooooo09Wooooo0Ol000000003o`00
0?oooooooooo09Wooooo0Ol000000003o`000?oooooooooo09Wooooo0Ol000000003o`000?oooooo
oooo09Wooooo0Ol000000003o`000?oooooooooo09Wooooo0Ol000000003o`000?oooooooooo017o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0hooooo`7o000000000ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0hooooo`7o000000000ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0h
ooooo`7o000000000ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0B_ooool2o`0003Wooooo0Ol000000003o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo03Sooooo0Ol000000003o`000?oooooooooo00Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo03Sooooo0Ol000000003o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1:ooooo`;o0000>Oooool1o`00000000?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0>?ooool1o`000000
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool0>?ooool1o`00000000?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`?o00000_ooool00ol0003oooooooooo`16ooooo`?o000000?oooooo`000?ooool0>Oooool1o`00
000000?o0000ooooooooool01?ooool00ol0003oooooooooo`04o`0000;ooooo00Go0000oooooooo
ooooooooo`000013ooooo`Co00000_ooool00ol0003oooooooooo`02o`0003Wooooo0Ol000000003
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0001:oooo
o`03o`000?oooooo000003[ooooo0Ol000000003o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooool0001:ooooo`03o`000?oooooo000003[ooooo0Ol000000003
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool3o`0000;ooooo00?o0000oooooooo
ool0A_ooool3o`000003ooooool0003ooooo03Wooooo0Ol000000003o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo03Sooooo
0Ol000000003o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1:ooooo`;o0000>Oooool1o`00000000?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool03_ooool<o`0001kooooo0Ol000000003o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00gooooo3ol0000Looooo`7o
000000000ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`0;oooooa;o00006oooool1o`00000000?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02_oo
oolDo`0001[ooooo0Ol000000003o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1:ooooo`;o00002_oooolFo`0001Wooooo0Ol000000003o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
00Sooooo3_l000001?oooooo0000o`000?ooool6o`0001Sooooo0Ol000000003o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
00Oooooo5_l000000ooooooo0000o`00000Hooooo`7o000000000ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`07ooooo`So
00001oooool8o`000003ooooool0003o000001Oooooo0Ol000000003o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Kooooo
5Ol000000ooooooo0000o`000004o`0001Kooooo0Ol000000003o`000?oooooooooo00?ooooo00?o
0000ooooooooool00ol00008ooooo`03o`000?oooooooooo00Kooooo0ol00008ooooo`?o00002?oo
ool3o`0000_ooooo00?o0000ooooooooool04oooool3o`0000Oooooo0_l00006ooooo`Ko000000Co
ooooo`000?oooooooooo1ol00003ooooo`04o`000?oooooo0000ooooo`Go00002?ooool00ol0003o
ooooooooo`0;ooooo`7o000000001?l0003oooooooooooooool4o`0000;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`07ooooo`?o00004?ooool4o`0000;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`[o00001?ooool00ol0003oooooooooo`02o`0000;o
oooo00Co0000ooooool0003ooooo1Ol00005ooooo`?o00003Oooool1o`00000000?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooo`00000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool8o`00
00?ooooo2?l000000ooooooo0000o`000002o`000003ooooool0003o000000Co00001Oooool00ol0
003oooooo`00000=ooooo`7o000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o00005_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Cooooo1_l00002ooooo`?o00001Oooool01?l0003o
ooooooooool00003ooooo`?o000000?oooooo`000?l000000_l00006ooooo`;o00003Oooool1o`00
000000?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000oooo
ooooool01_ooool2o`0000Wooooo0ol00008ooooo`?o00002oooool00ol0003oooooooooo`0Coooo
o`;o00002?ooool00ol0003oooooooooo`04ooooo`Go000000?oooooo`000?l000000oooool8o`00
0005ooooool0003o0000o`000?ooool01ol00007ooooo`03o`000?oooooooooo00_ooooo0Ol00000
0004o`000?ooooooooooooooo`;o00003_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00Cooooo0_l000001?oooooo0000ooooool00002ooooo`?o00002?ooool01_l0003ooooooooo
oooooooo0000ooooo`?o000000?oooooo`000?l000005Oooool1o`00000000?o0000ooooooooool0
B?l00006ooooodSo00000oooool1o`00000000?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo00Cooooo1?l000000ooooooo0000ooooo`03o`0000Gooooo00?o
0000ooooool000000_l00003ooooo`03o`000?oooooo000000Ko00005?ooool1o`00000000?o0000
ooooooooool04Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Cooooo1ol00005
ooooo`Co00001?ooool3o`000005ooooool0003o0000o`000?ooool00ol0000Eooooo`7o00000000
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01?ooool3
o`000004ooooool0003oooooooooo`Go00000oooool4o`0000Cooooo00?o0000ooooool000001Ol0
000Eooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool01?ooool2o`000005ooooool0003oooooooooool000001oooool2o`0000?ooooo0ol0
00000ooooooo0000ooooo`02o`000004ooooool0003o0000o`0001Gooooo0Ol000000003o`000?oo
oooooooo017ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`04ooooo`?o000000?o
ooooo`000?l000000_ooool:o`0000Cooooo00Ko0000ooooool0003oooooo`000?ooool3o`0001Go
oooo0Ol000000003o`000?oooooooooo017ooooo00?o0000ooooooooool0B_ooool2o`0000Cooooo
0ol000000ooooooo0000ooooo`03o`0000Kooooo00Co0000oooooooooooooooo0ol00002ooooo`So
00005Oooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00?ooooo1_l00009ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`Go0000
5_ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo00?ooooo1?l00005ooooo`co00000oooool00ol0003oooooooooo`04o`0001Kooooo0Ol0
00000003o`000?oooooooooo017ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`03
ooooo`Wo00001_ooool00ol0003oooooooooo`03ooooo`;o00000_ooool6o`0001Kooooo0Ol00000
0003o`000?oooooooooo017ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`03oooo
o`Ko00002Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool3o`0001Oooooo0Ol000000003
o`000?oooooooooo017ooooo00?o0000ooooooooool0B_ooool2o`0000?ooooo2?l000000ooooooo
0000o`00000:o`0000Gooooo00?o0000ooooool000000_l0000Gooooo`7o000000000ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00_ooool:o`0000Gooooo
00?o0000ooooooooool00oooool4o`0000;ooooo1?l0000Gooooo`7o000000000ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00_ooool;o`0000Cooooo00?o
0000ooooooooool01oooool6o`0001Oooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`02ooooob3o00005_ooool1o`00000000?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1:ooooo`04o`000?ooooooooooooooo`Co000000?ooooo
o`000?l000006_l0000Fooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
04[ooooo00Co0000oooooooooooooooo8Ol0000Fooooo`7o000000000ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04[ooooo0_l000000ooooooo0000o`000007o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000004?l0000Fooooo`7o000000000ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01?l000001ooooooo0000ooooool0003o
ooooo`000?ooool04Ol000001Ooooooo0000o`000?l0003ooooo00;o00005Oooool1o`00000000?o
0000ooooooooool04Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo000000Co00000_oo
oolEo`000003ooooool0003ooooo00?o000000?oooooo`000?ooool05?ooool1o`00000000?o0000
ooooooooool04Oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo000000;o000000Cooooo
o`000?l0003ooooo0_l000001?oooooo0000o`000?ooool=o`0000;ooooo0ol000000ooooooo0000
o`000003o`0001Cooooo0Ol000000003o`000?oooooooooo00cooooo0ol00002ooooo`03o`000?oo
oooooooo04Kooooo0ol000001ooooooo0000o`000?l0003oooooo`000?ooool00ol00002ooooo`04
o`000?ooooooooooo`0000?ooooo1ol00003ooooo`Co000000?oooooo`000?ooool01?l0000Doooo
o`7o000000000ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000BOooool00ol0
003oooooooooo`03o`000006ooooool0003o0000o`000?oooooo00000oooool2o`000003ooooool0
003o000000Oo000000Koooooo`000?l0003o0000ooooool00003ooooo`Co000000?oooooo`000?l0
00004oooool1o`00000000?o0000ooooooooool03_ooool01?l0003oooooooooool0001:ooooo`03
o`000?oooooo000000Co00000_ooool01Ol0003oooooo`000?l0003ooooo00Go000000?oooooo`00
0?l000002Ol00003ooooo`03o`000?oooooo000000Go00004oooool1o`00000000?o0000oooooooo
ool03_ooool01?l0003oooooooooool0001:ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`Go00000oooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0ol0
00001_oooooo0000oooooooooooo0000ooooo`?o00004_ooool1o`00000000?o0000ooooooooool0
3?ooool3o`0000;ooooo00?o0000ooooooooool0A_ooool7o`0000;ooooo1?l00003ooooo`;o0000
0oooool8o`0000?ooooo0_l00002ooooo`Co00000_ooool4o`00017ooooo0Ol000000003o`000?oo
oooooooo017ooooo00?o0000ooooooooool0B?ooool3o`000003ooooool0003ooooo00;o00000ooo
ool00ol0003oooooooooo`02ooooo`?o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00ol00002ooooo`;o00004Oooool1o`00000000?o0000
ooooooooool04Oooool00ol0003oooooooooo`18ooooo`04o`000?oooooo0000ooooo`;o00000_oo
ool01Ol0003ooooooooooooooooo000000Kooooo1?l00004ooooo`;o00001?ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?o00004?ooool1o`00000000?o0000ooooooooool0
4Oooool00ol0003oooooooooo`17ooooo`;o000000Goooooo`000?l0003oooooo`000002ooooo`03
o`000?oooooooooo00;ooooo0_l00007ooooo`Go00001Oooool01Ol0003ooooooooooooooooo0000
00;ooooo1?l000000ooooooo0000ooooo`0?ooooo`7o000000000ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo04Oooooo1?l00002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`05o`000?oooooooooo
o`000?ooool00_l000000ooooooo0000o`00000?ooooo`7o000000000ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo04Kooooo0ol000001Ooooooo0000oooooooooooo000000Cooooo00?o0000
ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00Co0000
oooooooooooo00000oooool4o`0000oooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000
ooooooooool0A_ooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`So00001_ooool2o`0000?ooooo00Co0000oooooooooooo00000_oo
ool3o`0000kooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000ooooooooool0AOooool2
o`000003ooooool0003ooooo00;o00000oooool00ol0003oooooooooo`02ooooo`;o00002?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_oo
ool3o`0000kooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000ooooooooool0AOooool0
1Ol0003oooooooooool0003ooooo00;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?oooooo0000o`0000gooooo0Ol000000003o`000?oooooooooo017ooooo
00?o0000ooooooooool0A?ooool2o`0000;ooooo00Co0000ooooool0003o00001?ooool00ol0003o
ooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooo`000?ooool00_l0000=ooooo`7o000000000ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04Cooooo0_l00002ooooo`04o`000?oooooo0000o`00
00Gooooo0_l00006ooooo`_o00001oooool00ol0003oooooooooo`02ooooo`09o`000?oooooooooo
ooooool0003oooooo`000?oooooo000000cooooo0Ol000000003o`000?oooooooooo017ooooo00?o
0000ooooooooool0@oooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000ooooool00000
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo0ol0000;ooooo`7o000000000ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04;ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
ooooo`000?oooooo000000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`00
0003ooooool0003ooooo00Wooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000oooooooo
ool0@Oooool2o`0000;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo
oooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`03o`000?oooooo
oooo00;ooooo00Go0000oooooooooooo0000ooooo`02o`0000[ooooo0Ol000000003o`000?oooooo
oooo017ooooo00?o0000ooooooooool0@Oooool2o`0000;ooooo00Go0000oooooooooooo0000oooo
o`02o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo0ol00007ooooo`03o`000?oooooooooo00;ooooo00Wo0000oooooooooooooooo
o`000?oooooo0000ooooool000002Oooool1o`00000000?o0000ooooooooool04Oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooooooo0_l00003oooo
o`03o`000?oooooooooo00Oooooo1?l00002ooooo`03o`000?oooooo000000?o00002Oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Wooooo0Ol00000
0003o`000?oooooooooo017ooooo00?o0000ooooooooool0?oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`0000_ooooo1?l0000=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Wooooo0Ol0
00000003o`000?oooooooooo017ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Ko0000
oooooooooooo0000ooooool00008ooooo`7o000000000ol0003oooooooooo`0>ooooo`04o`000?oo
ooooooooo`00047ooooo00?o0000ooooool000000oooool01_l0003oooooooooool0003oooooo`00
00Oooooo0_l0000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`07o`000?ooooooooooooooool0003oooooo`000007ooooo`7o00000000
0ol0003oooooooooo`0<ooooo`?o00000_ooool00ol0003oooooooooo`0nooooo`04o`000?oooooo
ooooo`0000?ooooo1?l000000ooooooo0000o`000008ooooo`;o00002?ooool00ol0003ooooooooo
o`07ooooo`;o00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001oooool1o`00000000?o0000ooooooooool03?ooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo00000oooool2o`000003ooooool0
003ooooo00;o00002_ooool2o`0000Kooooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo0Ol0
00000003o`000?oooooooooo00gooooo0_l00002ooooo`03o`000?oooooooooo03kooooo00Co0000
oooooooooooo00000oooool02?l0003oooooo`000?l0003oooooo`000?oooooo00002oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`Co00002_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool1o`00000000?o0000
ooooooooool03_ooool01?l0003oooooooooool00010ooooo`04o`000?ooooooooooo`0000?ooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo00Wooooo2Ol0000=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006
ooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03gooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Kooooo0Ol000000003o`000?oooooooooo017ooooo00?o
0000ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03gooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo0_l00008ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Kooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool1o`00000000?o0000
ooooooooool04Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooo`000008ooooo`;o00002Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000002_ooool2o`0000Oooooo00?o0000ooooooooool01?ooool4o`0000[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0Ol000000003
o`000?oooooooooo017ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo0_l0000<ooooo`Co00000oooool00ol0003oooooooooo`02ooooo`;o
00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`So0000
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool2o`0001;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00000Aooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00004?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000003oooool00ol0003oooooooooo`0;ooooo`;o00002_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool2o`0000gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool2o`0000Gooooo0_l0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`00
0?oooooooooo017ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool3o`0000Sooooo00?o0000ooooooooool0
1oooool2o`0000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`7o0000
00000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000000_ooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
0_l0000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool1o`00000000?o
0000ooooooooool04Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooooooooo00003Oooool>o`00013ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool01oooool01?l0003oooooooooool0000Zooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool1o`00000000?o0000ooooooooool03Oooool2o`0000;ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool0:?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0Ol000000003o`000?oooooo
oooo00cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooool000000ol0000Wooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool1o`00000000?o0000ooooooooool03?ooool3o`0000;ooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`05ooooo`?o000000?oooooo`000?ooool09_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo0Ol000000003o`000?oooooooooo00co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooooooo0ol0000Tooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool1o`00000000?o0000ooooooooool03Oooool2o`0000;ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`05ooooo`;o000000Goooooo`000?ooooooooooo`00000Qoooo
o`;o00003?ooool00ol0003oooooooooo`05ooooo`7o000000000ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
01kooooo0_l0000=ooooo`03o`000?oooooooooo00Kooooo0Ol000000003o`000?oooooooooo017o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`08ooooo`;o00000oooool3o`0001[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`7o000000000ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`;o00005_ooool2o`0000oooooo00?o0000ooooooooool01oooool1o`00000000?o
0000ooooooooool04Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool3o`00013ooooo0ol0000@ooooo`03o`000?oooooooooo00Sooooo0Ol0
00000003o`000?oooooooooo017ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`;o00004oooool00ol0003oooooooooo`08
ooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0=ooooo`_o00005?ooool00ol0003oooooooooo`09oooo
o`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo0Ol000000003o`00
0?oooooooooo017ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`03ooooo`;o0000
:oooool00ol0003oooooooooo`0;ooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00cooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000ooooooooool0A_ooool0
1Ol0003ooooooooooooooooo000002[ooooo00?o0000ooooooooool03Oooool1o`00000000?o0000
ooooooooool04Oooool00ol0003oooooooooo`17ooooo`;o000000?oooooo`000?ooool0:?ooool0
0ol0003oooooooooo`0>ooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
04Wooooo0_l0000Wooooo`;o00004Oooool1o`00000000?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1:ooooo`;o00009Oooool00ol0003oooooooooo`0Aooooo`7o000000000ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04[ooooo00?o0000ooooool000008_ooool2o`0001Cooooo
0Ol000000003o`000?oooooooooo017ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`02o`0001oooooo00?o0000ooooooooool05?ooool1o`00000000?o0000ooooooooool04Oooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Eooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool00oooool3o`0001Kooooo1?l0000Hooooo`7o000000000ol0003o
ooooooooo`0<ooooo`?o00000_ooool00ol0003oooooooooo`16ooooo`?o000000?oooooo`000?oo
ool01oooool3o`00013ooooo0ol0000Looooo`7o000000000ol0003oooooooooo`0<ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool0A_ooool01?l0003oooooo`000?ooool2o`0000[o
oooo1Ol00006ooooo`Go00007oooool1o`00000000?o0000ooooooooool03Oooool01Ol0003ooooo
oooooooooooo000004Wooooo00Co0000oooooooooooo00004?ooool6o`0002Cooooo0Ol000000003
o`000?oooooooooo00cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`16ooooo`05
o`000?oooooo0000ooooool00000>_ooool1o`00000000?o0000ooooooooool03?ooool3o`0000;o
oooo00?o0000ooooooooool0A_ooool3o`000003ooooool0003ooooo03Wooooo0Ol000000003o`00
0?oooooooooo09Wooooo0Ol000000003o`000?oooooooooo09Wooooo0Ol000000003o`000?oooooo
oooo09Wooooo0Ol000000003o`000?oooooooooo09Wooooo0Ol000000003o`000?oooooooooo09Wo
oooo0Ol000000003o`000?oooooooooo09Wooooo0Ol000000003o`000?oooooooooo09Wooooo0Ol0
00000003o`000?oooooooooo09Wooooo0Ol000000003o`000?oooooooooo09Wooooo0Ol000000003
o`000?oooooooooo09Wooooo0Ol000000003o`000?oooooooooo09Wooooo0Ol000000003o`000?oo
oooooooo09Wooooo0Ol000000003o`000?oooooooooo09Wooooo0Ol000000003o`000?oooooooooo
017ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03Sooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oooooooooo017ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Sooooo
0Ol000000003o`000?oooooooooo017ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`09ooooo`;o0000>Oooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo0_l0000iooooo`7o000000000ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0hooooo`7o000000000ol0003oooooooooo`0<ooooo`?o00000_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00Gooooo0ol000000ooooooo0000ooooo`0iooooo`7o00000000
0ol0003oooooooooo`07ooooo`Co00000_ooool01Ol0003ooooooooooooooooo0000043ooooo00?o
0000ooooooooool01?l00002ooooo`03o`000?oooooooooo00;o0000>Oooool1o`00000000?o0000
ooooooooool03_ooool01?l0003oooooooooool00010ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooool00000>_ooool1o`00000000?o0000ooooooooool03_ooool01?l0003oooooooooool0
0010ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000>_ooool1o`00000000?o0000
ooooooooool03?ooool3o`0000;ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`05
ooooo`?o000000?oooooo`000?ooool0>Oooool1o`00000000?o0000ooooooooool04Oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>?ooool1o`00
000000?o0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00Wooooo0_l0000iooooo`7o000000000ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00oooooo1ol0000Xooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`0<
ooooo`go00009Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Sooooo0Ol00000
0003o`000?oooooooooo017ooooo00?o0000ooooooooool02_oooolAo`0002?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Wooooo4ol0000Rooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`08oooooaGo0000
8?ooool2o`0000_ooooo0_l0000iooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Oooooo4Ol000001?oooooo0000o`000?ooool2o`0001oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo6Ol0000Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>?oo
ool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`06oooooa[o00007Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oooooooooo
017ooooo00?o0000ooooooooool01Oooool5o`000004ooooool0003oooooooooo`Oo00000oooool0
0ol0003oooooo`000006o`0001cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0h
ooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo2Ol00007oooo
o`?o000000?oooooo`000?ooool01_l0000Looooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0>?ooool1o`00000000?o0000ooooooooool01_ooool3o`0000Sooooo00?o0000oooooooo
ool01Oooool4o`000003ooooool0003ooooo00_o000000Goooooo`000?l0003o0000ooooo`06o`00
00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03o`0000Oooooo0_l00008oooo
o`?o00002?ooool3o`0000Sooooo0ol0000:ooooo`03o`000?oooooooooo00_ooooo0Ol000000004
o`000?ooooooooooooooo`Co00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Cooooo1?l000001?oooooo0000ooooool00005ooooo`Co00000_ooool2o`000004ooooool0003o
0000ooooo`Go00001_ooool3o`00013ooooo1?l00002ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01_ooool3o`0000gooooo0Ol000000003o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`go00000_ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooo000000;o000000Coooooo`000?l0003o00001_ooool00ol0003ooooo
o`00000Aooooo`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000003Oooool1o`00000000?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Cooooo1ol00006ooooo`?o00000oooool2o`000003ooooool0
003ooooo00Oo00001_ooool2o`00017ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`7o000000000ol0003oooooooooo`06
ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool<o`0000;ooooo00?o0000
ooooool000000ol000001?oooooo0000o`000?l00007ooooo`03o`000?oooooooooo00kooooo0_l0
0003ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`;o00002Oooool3o`0000Sooooo0ol0
000:ooooo`03o`000?oooooooooo00_ooooo0Ol000000003o`000?oooooooooo04So00001_oooom8
o`0000?ooooo0Ol000000009o`000?ooooooooooooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Ko0000ooooool0003oooooo`000?oo
ool4o`000003ooooool0003ooooo00ko000000?oooooo`000?ooool02?l00002ooooo`09o`000?oo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00?o0000ooooool000002?ooool01Ol0
003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool0
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oo
oooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo00?o0000ooooool000001?ooool1o`00000000?o0000oooo
ooooool04Oooool00ol0003oooooooooo`03ooooo`?o000000Coooooo`000?oooooo00002?ooool0
0ol0003oooooooooo`02ooooo`;o000000Goooooo`000?oooooo0000ooooo`05o`0002Oooooo00?o
0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`03
ooooo`Ko00000oooool9o`0000Cooooo00Go0000ooooool0003o0000ooooo`05o`0002Oooooo00?o
0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`03
ooooo`Co00000oooool2o`0000Kooooo00?o0000ooooooooool00ol00002ooooo`05o`000?oooooo
0000o`000?ooool00ol0000Xooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oooooo
oooo017ooooo00?o0000ooooooooool00oooool7o`0000Gooooo1?l00005ooooo`;o000000Gooooo
o`000?oooooo0000ooooo`03o`0002Sooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`Co00000oooool5o`0000;ooooo00?o0000
ooooool000000ol00003ooooo`04o`000?oooooo0000ooooo`Co0000:?ooool2o`0003Wooooo0Ol0
00000003o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool3o`0000;ooooo0_l00007
ooooo`03o`000?oooooooooo00?ooooo0ol000001?oooooo0000o`000?ooool4o`0002Sooooo00?o
0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`02
ooooo`Ko00001Oooool8o`0000Gooooo00Go0000ooooool0003o0000ooooo`02o`0002Wooooo00?o
0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`02
ooooo`Co00000oooool4o`0000Cooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oo
oooo000000?o0000:Oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00;ooooo1ol00008ooooo`03o`000?oooooooooo00?ooooo1?l00000
0ooooooo0000o`000003o`0002Wooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000oooo
ooooool04Oooool01?l0003oooooooooooooool7o`0000Cooooo2?l00007ooooo`03o`000?oooooo
000000;o0000:_ooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`0Aoooo
o`04o`000?ooooooooooooooo`_o00001Oooool00ol0003oooooooooo`04o`0000Cooooo1?l0000Z
ooooo`;o0000>Oooool1o`00000000?o0000ooooooooool04Oooool01?l0003oooooooooooooool;
o`0000Cooooo00?o0000ooooooooool01Oooool8o`0002[ooooo00?o0000ooooooooool0>?ooool1
o`00000000?o0000ooooooooool04Oooool01?l0003oooooooooooooool>o`000003ooooool0003o
oooo00Oooooo1ol0000Zooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oooooooooo
017ooooo00?o0000ooooooooool01?l000000ooooooo0000o`00000Jo`0002Wooooo00?o0000oooo
ooooool0>?ooool1o`00000000?o0000ooooooooool04Oooool00ol0003oooooooooo`05o`000003
ooooool0003o000001Wo0000:Oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003ooooo
ooooo`0Aooooo`03o`000?oooooo0000027o0000:Oooool2o`0003Wooooo0Ol000000003o`000?oo
oooooooo017ooooo00?o0000ooooool000001_l00002ooooo`?o000000?oooooo`000?l000003?l0
00001_oooooo0000o`000?oooooo0000ooooo`;o0000:?ooool00ol0003oooooooooo`0hooooo`7o
000000000ol0003oooooooooo`0Aooooo`Ko000000Goooooo`000?oooooo0000ooooo`0Ao`000004
ooooool0003o0000ooooo`?o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`0hoooo
o`7o000000000ol0003oooooooooo`0Aooooo`Co000000Coooooo`000?l0003ooooo0ol00002oooo
o`04o`000?ooooooooooooooo`oo000000?oooooo`000?l000000ol0000Wooooo`03o`000?oooooo
oooo03Sooooo0Ol000000003o`000?oooooooooo017ooooo1?l000000ooooooo0000o`000003o`00
0003ooooool0003o000000Co00000_ooool3o`0000;ooooo1Ol000001Ooooooo0000o`000?l0003o
oooo00Co00009oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`0<oooo
o`?o00000_ooool2o`000006ooooool0003o0000o`000?oooooo00000_ooool01?l0003ooooooooo
ooooool=o`0000;ooooo00?o0000ooooooooool00ol000001?oooooo0000o`000?l0000Rooooo`?o
000000?oooooo`000?ooool0>Oooool1o`00000000?o0000ooooooooool03Oooool01?l0003ooooo
ooooooooool2o`000006ooooool0003oooooooooool0003ooooo0_l000000ooooooo0000o`00000=
o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_l000000ooooooo0000o`00000S
ooooo`03o`000?oooooooooo00;o0000>Oooool1o`00000000?o0000ooooooooool03_ooool00ol0
003oooooo`000004o`0000;ooooo00?o0000ooooooooool00ol00002ooooo`;o00000oooool00ol0
003oooooooooo`04ooooo`?o000000Koooooo`000?ooooooooooo`000?ooool4o`0002Cooooo00?o
0000ooooool00000>_ooool1o`00000000?o0000ooooooooool03_ooool00ol0003oooooo`000002
o`0000;ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooooooo00;ooooo1?l00000
0ooooooo0000o`000003o`0000?ooooo1?l00002ooooo`03o`000?oooooo000000;o00008oooool0
0ol0003oooooo`00000jooooo`7o000000000ol0003oooooooooo`0<ooooo`Oo00000_ooool2o`00
0003ooooool0003ooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0_l00002oooo
o`04o`000?oooooo0000o`0000;ooooo1?l0000Pooooo`?o000000?oooooo`000?ooool0>Oooool1
o`00000000?o0000ooooooooool03_ooool7o`000005ooooool0003oooooooooool000001?ooool3
o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00Co0000oooooooooooooooo1?l0
00000ooooooo0000o`00000Tooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oooooo
oooo00kooooo1?l000001Ooooooo0000oooooooooooo000000?ooooo00?o0000ooooooooool01?oo
ool8o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`Go00008oooool2o`0003Wooooo
0Ol000000003o`000?oooooooooo00gooooo1Ol000001Ooooooo0000oooooooooooo000000Cooooo
0ol00006ooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooool000008oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003ooooo
ooooo`0=ooooo`;o000000Goooooo`000?l0003oooooo`000003ooooo`03o`000?oooooooooo00Co
oooo0ol00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00003ooooo`Co00008_ooool00ol0003oooooooooo`0hooooo`7o000000000ol0003o
ooooooooo`0<ooooo`?o000000?oooooo`000?l000000_ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Go0000oooooooooooo0000ooooo`05o`0000Cooooo0_l00003ooooo`06o`000?oooooo
ooooooooool0003ooooo0ol0000Qooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oo
oooooooo00_ooooo1?l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool4o`0000Sooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00002ooooo`?o00008Oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003ooooooooo
o`0;ooooo`;o000000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
0ol00007ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooo`000?l0000Pooooo`03o`000?oooooooooo03Sooooo0Ol000000003
o`000?oooooooooo00[ooooo0_l00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01?ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0N
ooooo`;o0000>Oooool1o`00000000?o0000ooooooooool02_ooool2o`0000;ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`05ooooo`?o00000_ooool01?l0003ooooooooooooo
ool3o`0000Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`;o0000
7oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`09ooooo`?o00000_oo
ool00ol0003oooooooooo`02o`0000Gooooo00?o0000ooooooooool01oooool6o`0000Sooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo0ol0000Nooooo`03o`00
0?oooooooooo03Sooooo0Ol000000003o`000?oooooooooo00Wooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooo
ool0003oooooo`0001kooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool0
2?ooool2o`000005ooooool0003oooooooooool000000_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Kooooo00?o0000oooooooo
ool00_ooool01Ol0003oooooooooool0003ooooo00;o00007Oooool00ol0003oooooooooo`0hoooo
o`7o000000000ol0003oooooooooo`07ooooo`05o`000?oooooo0000ooooool000000_ooool01_l0
003oooooooooool0003oooooo`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooo`000?ooool0
0_l0000Mooooo`;o0000>Oooool1o`00000000?o0000ooooooooool01oooool2o`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`?o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`09o`000?oooooooooooooo
ool0003oooooo`000?oooooo000001cooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000
ooooooooool01_ooool00ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003ooooo
o`000003ooooo`03o`000?oooooooooo00Sooooo2_l00009ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`;o00007?ooool00ol0003oooooooooo`0hooooo`7o
000000000ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`;o00001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00006ooo
ool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`05ooooo`03o`000?oooooo
000000?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0>?oo
ool1o`00000000?o0000ooooooooool01Oooool00ol0003oooooo`000003ooooo`05o`000?oooooo
ooooo`000?ooool00_l00006ooooo`;o00002_ooool00ol0003oooooooooo`07ooooo`;o00001ooo
ool00ol0003oooooooooo`03ooooo`07o`000?ooooooooooooooool0003oooooo`00000Hooooo`03
o`000?oooooo000003[ooooo0Ol000000003o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00000oooool4o`0000;ooooo00?o0000ooooooooool01_ooool2o`0000Sooooo00?o0000oooooooo
ool01Oooool2o`0000Wooooo00?o0000ooooooooool00oooool01ol0003ooooooooooooooooo0000
ooooool000005_ooool3o`000003ooooool0003o000003Wooooo0Ol000000003o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00000oooool2o`000005ooooool0003oooooooooool000002_oo
ool2o`0000Kooooo00?o0000ooooooooool00oooool2o`0000[ooooo00?o0000ooooooooool01?oo
ool01ol0003ooooooooooooooooo0000ooooool000005_ooool01Ol0003oooooo`000?oooooo0000
03[ooooo0Ol000000003o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool01?l0
003oooooo`000?l00002ooooo`?o00002_ooool5o`000003ooooool0003ooooo00Co00003?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005_oo
ool2o`000003ooooool0003ooooo03Wooooo0Ol000000003o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo0000
3_ooool3o`0000kooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00005oooool00ol0003oooooo`00000jooooo`7o000000000ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`0hooooo`7o000000000ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000006?ooool00ol0003ooooo
ooooo`0hooooo`7o000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`;o00002?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0003Wooooo0Ol000000003o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo03Sooooo0Ol000000003o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo0_l00009ooooo`03
o`000?oooooooooo00Kooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo000000Wooooo1?l00005ooooo`03o`000?oooooooooo00Cooooo0_l0000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo03Sooooo0Ol000000003o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`;o00003Oooool<o`0000gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>?oo
ool1o`00000000?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo0_l0000Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo0_l0000iooooo`7o000000000ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>?ooool1o`00
000000?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo0_l0000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>?ooool1o`000000
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00Co0000ooooool0003o00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03So
oooo0Ol000000003o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0<ooooo`;o
00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0>?ooool1o`00000000?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo0ol0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o00002ooo
ool00ol0003oooooooooo`07ooooo`;o00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Kooooo0_l0000iooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`?o00002?ooool0
0ol0003oooooooooo`05ooooo`;o00003_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool5o`00
00?ooooo00?o0000ooooooooool00oooool2o`00013ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oooooooooo00?o
oooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000oooooo2Ol0000Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0hoooo
o`7o000000000ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`;o
000000?oooooo`000?ooool0>Oooool1o`00000000?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`06o`000?oooooo0000o`000?oooooo00009oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01?ooooo00Co0000ooooool0003ooooo0_l0000iooooo`7o000000000ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0ol000000ooooooo0000o`00000Voooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool3o`000003ooooool0003ooooo
03Wooooo0Ol000000003o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Dooooo`05o`000?ooooooooooooooool00000>_ooool1o`00000000?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool2o`0002?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Eooooo`;o000000?oooooo`000?ooool0>Oooool1o`000000
00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0000027ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Sooooo
0Ol000000003o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01?l0003ooooooooo
ool0000Nooooo`;o00003Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Sooooo
0Ol000000003o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool01?l0003ooooooooo
ooooool3o`0001Sooooo0ol0000>ooooo`03o`000?oooooooooo01[ooooo0_l0000iooooo`7o0000
00000ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?oo
ool3o`0001;ooooo0ol0000Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>?oo
ool1o`00000000?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo0_l0000>ooooo`;o00004oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo03Sooooo0Ol000000003o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`09ooooo`ko00005Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03Sooooo0Ol000000003o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>?ooool1o`000000
00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool07Oooool2o`0003Wooooo0Ol000000003o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0>?ooool1o`00000000?o0000ooooooooool02oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0h
ooooo`7o000000000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03Sooooo0Ol000000003
o`000?oooooooooo00gooooo0_l00002ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`00
0?oooooo000002Kooooo0_l0000Tooooo`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oo
oooooooo013ooooo0_l0000Uooooo`03o`000?oooooooooo02Cooooo0_l0000iooooo`7o00000000
0ol0003oooooooooo`0Aooooo`;o00008_ooool2o`0002Oooooo00?o0000ooooooooool0>?ooool1
o`00000000?o0000ooooooooool04Oooool00ol0003oooooo`000002o`0001gooooo0_l0000Yoooo
o`03o`000?oooooooooo03Sooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Hooooo`;o0000:oooool00ol0003oooooooooo`0hooooo`7o
000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo1?l0000Cooooo`?o0000
;Oooool00ol0003oooooooooo`0hooooo`7o000000000ol0003oooooooooo`0<ooooo`?o00000_oo
ool00ol0003oooooooooo`07ooooo`?o00003Oooool3o`0002cooooo0ol000000ooooooo0000oooo
o`0iooooo`7o000000000ol0003oooooooooo`0<ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool02_ooool=o`0002oooooo00Co0000ooooool0003ooooo0_l0000iooooo`7o00000000
0ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000BOooool01?l0003ooooooooo
ool0000jooooo`7o000000000ol0003oooooooooo`0<ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool0A_ooool01Ol0003oooooo`000?oooooo000003[ooooo0Ol000000003o`000?oo
oooooooo00cooooo0ol00002ooooo`03o`000?oooooooooo04Kooooo0ol000000ooooooo0000oooo
o`0iooooo`7o000000000ol0003oooooooooo`2Iooooo`7o000000000ol0003oooooooooo`2Ioooo
o`7o000000000ol0003oooooooooo`2Iooooo`7o000000000ol0003oooooooooo`2Iooooo`7o0000
00000ol0003oooooooooo`2Iooooo`7o000000000ol0003oooooooooo`2Iooooo`7o0000002Mo`00
0000\
\>"],
  ImageRangeCache->{{{0, 156.5}, {286.875, 0}} -> {-0.0516905, -0.0998395, \
0.0134401, 0.0134401}, {{3.8125, 74.6875}, {279.438, 149.875}} -> {-1.79591, \
-3.97908, 0.0897989, 0.0897989}, {{81.75, 152.625}, {279.438, 149.875}} -> \
{-8.7946, -3.97908, 0.0897989, 0.0897989}, {{3.8125, 74.6875}, {136.938, \
7.375}} -> {-1.79591, -16.7754, 0.0897989, 0.0897989}, {{81.75, 152.625}, \
{136.938, 7.375}} -> {-8.7946, -16.7754, 0.0897989, 0.0897989}},
  CellTags->"5.3.5"]
}, Open  ]],

Cell["\<\
While the system is diagonal dominant, since none of the Gershgorin \
circles enclose the origin of their respective plots, you can further improve \
the overall diagonal dominance of this system by designing a \
pseudo-diagonalizing compensator.\
\>", "Text",
  CellTags->"5.3.5"],

Cell["\<\
Here is a compensator determined by applying the \
pseudo-diagonalization method to both rows of the inverse-system Nyquist \
array at zero frequency.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kinv = PseudodiagonalizingCompensator[InverseSystem[tf]]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"5.3.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.8192319205190405`", "0.5734623443633283`"},
                    {"0.5734623443633284`", "0.8192319205190405`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Center},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox["\[Bullet]",
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[5]=",
  CellTags->"5.3.5"]
}, Open  ]],

Cell["\<\
This applies the pseudo-diagonalizing compensator to the \
system.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fp = 
      Together /@ SeriesConnect[Normal[InverseSystem[kinv]], tf] // 
        Chop\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"5.3.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(7.2760645238883255`\ \[ScriptS] + 
                            1.2206555615733705`\)\/\(\((4.`\ \[ScriptS] + 
                                1.`)\)\ \((5.`\ \[ScriptS] + 
                                1.`)\)\)\), \(-\(\(1.6754095943163918`\ \
\[ScriptS]\)\/\(\((4.`\ \[ScriptS] + 1.`)\)\ \((5.`\ \[ScriptS] + 
                                  1.`)\)\)\)\)},
                    {\(-\(\(1.6754095943163936`\ \[ScriptS]\)\/\(\((4.`\ \
\[ScriptS] + 1.`)\)\ \((5.`\ \[ScriptS] + 
                                  1.`)\)\)\)\), \(\(7.276064523888326`\ \
\[ScriptS] + 1.2206555615733707`\)\/\(\((4.`\ \[ScriptS] + 
                                1.`)\)\ \((5.`\ \[ScriptS] + 1.`)\)\)\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Center},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[InvisibleSpace]\"\>",
                ShowStringCharacters->False],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[6]=",
  CellTags->"5.3.5"]
}, Open  ]],

Cell["\<\
The compensator has completely eliminated the interaction in both \
rows of the system at zero frequency.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NyquistArrayPlot[InverseSystem[fp], {0.001, 1}, 
        GershgorinCircles \[Rule] RowDominance];\)\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"5.3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.34701 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0558811 0.47619 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 2.34701 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 2.34701 L
s
0 2.34701 m
1 2.34701 L
s
1 0 m
1 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0558811 0.477324 1.12028 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.00112267 0.718224 0.0549004 0.718224 [
[.14477 .0424 -7.2 -7.2 ]
[.14477 .0424 7.2 0 ]
[.28841 .0424 -7.2 -7.2 ]
[.28841 .0424 7.2 0 ]
[.43206 .0424 -7.2 -7.2 ]
[.43206 .0424 7.2 0 ]
[.5757 .0424 -7.2 -7.2 ]
[.5757 .0424 7.2 0 ]
[.71935 .0424 -2.4 -7.2 ]
[.71935 .0424 2.4 0 ]
[.86299 .0424 -7.2 -7.2 ]
[.86299 .0424 7.2 0 ]
[-0.01138 .41401 -14.4 -3.6 ]
[-0.01138 .41401 0 3.6 ]
[-0.01138 .77312 -4.8 -3.6 ]
[-0.01138 .77312 0 3.6 ]
[-0.01138 1.13224 -14.4 -3.6 ]
[-0.01138 1.13224 0 3.6 ]
[-0.01138 1.49135 -4.8 -3.6 ]
[-0.01138 1.49135 0 3.6 ]
[-0.01138 1.85046 -14.4 -3.6 ]
[-0.01138 1.85046 0 3.6 ]
[-0.01138 2.20957 -4.8 -3.6 ]
[-0.01138 2.20957 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14477 .0549 m
.14477 .06115 L
s
[(0.2)] .14477 .0424 0 1 Mshowa
.28841 .0549 m
.28841 .06115 L
s
[(0.4)] .28841 .0424 0 1 Mshowa
.43206 .0549 m
.43206 .06115 L
s
[(0.6)] .43206 .0424 0 1 Mshowa
.5757 .0549 m
.5757 .06115 L
s
[(0.8)] .5757 .0424 0 1 Mshowa
.71935 .0549 m
.71935 .06115 L
s
[(1)] .71935 .0424 0 1 Mshowa
.86299 .0549 m
.86299 .06115 L
s
[(1.2)] .86299 .0424 0 1 Mshowa
.125 Mabswid
.03703 .0549 m
.03703 .05865 L
s
.07295 .0549 m
.07295 .05865 L
s
.10886 .0549 m
.10886 .05865 L
s
.18068 .0549 m
.18068 .05865 L
s
.21659 .0549 m
.21659 .05865 L
s
.2525 .0549 m
.2525 .05865 L
s
.32432 .0549 m
.32432 .05865 L
s
.36023 .0549 m
.36023 .05865 L
s
.39615 .0549 m
.39615 .05865 L
s
.46797 .0549 m
.46797 .05865 L
s
.50388 .0549 m
.50388 .05865 L
s
.53979 .0549 m
.53979 .05865 L
s
.61161 .0549 m
.61161 .05865 L
s
.64752 .0549 m
.64752 .05865 L
s
.68344 .0549 m
.68344 .05865 L
s
.75526 .0549 m
.75526 .05865 L
s
.79117 .0549 m
.79117 .05865 L
s
.82708 .0549 m
.82708 .05865 L
s
.8989 .0549 m
.8989 .05865 L
s
.93481 .0549 m
.93481 .05865 L
s
.97073 .0549 m
.97073 .05865 L
s
.25 Mabswid
0 .0549 m
1 .0549 L
s
.00112 .41401 m
.00737 .41401 L
s
[(0.5)] -0.01138 .41401 1 0 Mshowa
.00112 .77312 m
.00737 .77312 L
s
[(1)] -0.01138 .77312 1 0 Mshowa
.00112 1.13224 m
.00737 1.13224 L
s
[(1.5)] -0.01138 1.13224 1 0 Mshowa
.00112 1.49135 m
.00737 1.49135 L
s
[(2)] -0.01138 1.49135 1 0 Mshowa
.00112 1.85046 m
.00737 1.85046 L
s
[(2.5)] -0.01138 1.85046 1 0 Mshowa
.00112 2.20957 m
.00737 2.20957 L
s
[(3)] -0.01138 2.20957 1 0 Mshowa
.125 Mabswid
.00112 .12672 m
.00487 .12672 L
s
.00112 .19855 m
.00487 .19855 L
s
.00112 .27037 m
.00487 .27037 L
s
.00112 .34219 m
.00487 .34219 L
s
.00112 .48583 m
.00487 .48583 L
s
.00112 .55766 m
.00487 .55766 L
s
.00112 .62948 m
.00487 .62948 L
s
.00112 .7013 m
.00487 .7013 L
s
.00112 .84495 m
.00487 .84495 L
s
.00112 .91677 m
.00487 .91677 L
s
.00112 .98859 m
.00487 .98859 L
s
.00112 1.06041 m
.00487 1.06041 L
s
.00112 1.20406 m
.00487 1.20406 L
s
.00112 1.27588 m
.00487 1.27588 L
s
.00112 1.3477 m
.00487 1.3477 L
s
.00112 1.41953 m
.00487 1.41953 L
s
.00112 1.56317 m
.00487 1.56317 L
s
.00112 1.63499 m
.00487 1.63499 L
s
.00112 1.70682 m
.00487 1.70682 L
s
.00112 1.77864 m
.00487 1.77864 L
s
.00112 1.92228 m
.00487 1.92228 L
s
.00112 1.99411 m
.00487 1.99411 L
s
.00112 2.06593 m
.00487 2.06593 L
s
.00112 2.13775 m
.00487 2.13775 L
s
.00112 2.2814 m
.00487 2.2814 L
s
.25 Mabswid
.00112 0 m
.00112 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
.5 Mabswid
.00113 .05571 m
.00113 .05574 L
.00113 .05577 L
.00113 .0558 L
.00113 .05583 L
.00113 .05586 L
.00113 .05589 L
.00113 .05593 L
.00113 .05597 L
.00113 .056 L
.00113 .05604 L
.00113 .05608 L
.00113 .05613 L
.00113 .05617 L
.00113 .05621 L
.00113 .05626 L
.00113 .05631 L
.00113 .05636 L
.00113 .05641 L
.00113 .05646 L
.00113 .05652 L
.00113 .05657 L
.00113 .05663 L
.00113 .05669 L
.00114 .05676 L
.00114 .05682 L
.00114 .05689 L
.00114 .05696 L
.00114 .05703 L
.00114 .05711 L
.00114 .05719 L
.00114 .05727 L
.00114 .05735 L
.00115 .05744 L
.00115 .05753 L
.00115 .05762 L
.00115 .05772 L
.00115 .05782 L
.00116 .05792 L
.00116 .05803 L
.00116 .05814 L
.00116 .05825 L
.00117 .05837 L
.00117 .05849 L
.00117 .05862 L
.00118 .05875 L
.00118 .05889 L
.00118 .05903 L
.00119 .05917 L
.00119 .05932 L
Mistroke
.0012 .05948 L
.0012 .05964 L
.00121 .05981 L
.00122 .05998 L
.00122 .06016 L
.00123 .06034 L
.00124 .06054 L
.00125 .06074 L
.00125 .06094 L
.00126 .06115 L
.00127 .06137 L
.00129 .0616 L
.0013 .06184 L
.00131 .06208 L
.00132 .06233 L
.00134 .0626 L
.00135 .06287 L
.00137 .06315 L
.00139 .06344 L
.0014 .06374 L
.00142 .06405 L
.00145 .06437 L
.00147 .0647 L
.00149 .06505 L
.00152 .0654 L
.00155 .06577 L
.00158 .06615 L
.00161 .06654 L
.00165 .06695 L
.00168 .06737 L
.00172 .06781 L
.00177 .06826 L
.00181 .06873 L
.00186 .06921 L
.00191 .06971 L
.00197 .07022 L
.00203 .07075 L
.00209 .0713 L
.00216 .07187 L
.00223 .07246 L
.00231 .07307 L
.00239 .0737 L
.00248 .07435 L
.00258 .07501 L
.00268 .07571 L
.00278 .07642 L
.0029 .07716 L
.00302 .07792 L
.00315 .0787 L
.00329 .07951 L
Mistroke
.00344 .08035 L
.0036 .08121 L
.00376 .08209 L
.00394 .08301 L
.00413 .08395 L
.00433 .08492 L
.00454 .08592 L
.00477 .08695 L
.00501 .08801 L
.00526 .0891 L
.00553 .09022 L
.00582 .09137 L
.00612 .09255 L
.00643 .09376 L
.00677 .09501 L
.00712 .09629 L
.00749 .0976 L
.00788 .09894 L
.00828 .10032 L
.00871 .10173 L
.00916 .10318 L
.00963 .10466 L
.01012 .10617 L
.01063 .10772 L
.01116 .1093 L
.01171 .11092 L
.01228 .11257 L
.01287 .11426 L
.01349 .11598 L
.01412 .11773 L
.01477 .11952 L
.01544 .12135 L
.01612 .12322 L
.01683 .12512 L
.01755 .12705 L
.01828 .12903 L
.01902 .13105 L
.01978 .13311 L
.02054 .13521 L
.02131 .13735 L
.02209 .13955 L
.02288 .14179 L
.02366 .14408 L
.02445 .14642 L
.02523 .14882 L
.02602 .15128 L
.02679 .1538 L
.02757 .15639 L
.02833 .15904 L
.02908 .16177 L
Mistroke
.02982 .16458 L
.03055 .16748 L
.03127 .17046 L
.03197 .17353 L
.03265 .1767 L
.03332 .17998 L
.03397 .18336 L
.0346 .18686 L
.03521 .19048 L
.0358 .19423 L
.03637 .19811 L
.03692 .20213 L
.03745 .2063 L
.03796 .21062 L
.03845 .2151 L
.03892 .21975 L
.03937 .22457 L
.0398 .22957 L
.04021 .23477 L
.0406 .24016 L
.04097 .24575 L
.04132 .25156 L
.04166 .25759 L
.04198 .26384 L
.04228 .27034 L
.04256 .27708 L
.04284 .28408 L
.04309 .29135 L
.04333 .29888 L
.04356 .30671 L
.04378 .31483 L
.04398 .32325 L
.04417 .33199 L
.04436 .34106 L
.04453 .35047 L
.04469 .36023 L
.04484 .37035 L
.04498 .38085 L
.04511 .39173 L
.04524 .40302 L
.04535 .41473 L
.04546 .42686 L
.04557 .43944 L
.04566 .45248 L
.04575 .466 L
.04584 .48001 L
.04592 .49453 L
.04599 .50958 L
.04606 .52518 L
.04613 .54134 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0558811 0.97619 1.12028 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.00112267 0.718224 0.0549004 0.718224 [
[.14477 .0424 -7.2 -7.2 ]
[.14477 .0424 7.2 0 ]
[.28841 .0424 -7.2 -7.2 ]
[.28841 .0424 7.2 0 ]
[.43206 .0424 -7.2 -7.2 ]
[.43206 .0424 7.2 0 ]
[.5757 .0424 -7.2 -7.2 ]
[.5757 .0424 7.2 0 ]
[.71935 .0424 -2.4 -7.2 ]
[.71935 .0424 2.4 0 ]
[.86299 .0424 -7.2 -7.2 ]
[.86299 .0424 7.2 0 ]
[-0.01138 .41401 -14.4 -3.6 ]
[-0.01138 .41401 0 3.6 ]
[-0.01138 .77312 -4.8 -3.6 ]
[-0.01138 .77312 0 3.6 ]
[-0.01138 1.13224 -14.4 -3.6 ]
[-0.01138 1.13224 0 3.6 ]
[-0.01138 1.49135 -4.8 -3.6 ]
[-0.01138 1.49135 0 3.6 ]
[-0.01138 1.85046 -14.4 -3.6 ]
[-0.01138 1.85046 0 3.6 ]
[-0.01138 2.20957 -4.8 -3.6 ]
[-0.01138 2.20957 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14477 .0549 m
.14477 .06115 L
s
[(0.2)] .14477 .0424 0 1 Mshowa
.28841 .0549 m
.28841 .06115 L
s
[(0.4)] .28841 .0424 0 1 Mshowa
.43206 .0549 m
.43206 .06115 L
s
[(0.6)] .43206 .0424 0 1 Mshowa
.5757 .0549 m
.5757 .06115 L
s
[(0.8)] .5757 .0424 0 1 Mshowa
.71935 .0549 m
.71935 .06115 L
s
[(1)] .71935 .0424 0 1 Mshowa
.86299 .0549 m
.86299 .06115 L
s
[(1.2)] .86299 .0424 0 1 Mshowa
.125 Mabswid
.03703 .0549 m
.03703 .05865 L
s
.07295 .0549 m
.07295 .05865 L
s
.10886 .0549 m
.10886 .05865 L
s
.18068 .0549 m
.18068 .05865 L
s
.21659 .0549 m
.21659 .05865 L
s
.2525 .0549 m
.2525 .05865 L
s
.32432 .0549 m
.32432 .05865 L
s
.36023 .0549 m
.36023 .05865 L
s
.39615 .0549 m
.39615 .05865 L
s
.46797 .0549 m
.46797 .05865 L
s
.50388 .0549 m
.50388 .05865 L
s
.53979 .0549 m
.53979 .05865 L
s
.61161 .0549 m
.61161 .05865 L
s
.64752 .0549 m
.64752 .05865 L
s
.68344 .0549 m
.68344 .05865 L
s
.75526 .0549 m
.75526 .05865 L
s
.79117 .0549 m
.79117 .05865 L
s
.82708 .0549 m
.82708 .05865 L
s
.8989 .0549 m
.8989 .05865 L
s
.93481 .0549 m
.93481 .05865 L
s
.97073 .0549 m
.97073 .05865 L
s
.25 Mabswid
0 .0549 m
1 .0549 L
s
.00112 .41401 m
.00737 .41401 L
s
[(0.5)] -0.01138 .41401 1 0 Mshowa
.00112 .77312 m
.00737 .77312 L
s
[(1)] -0.01138 .77312 1 0 Mshowa
.00112 1.13224 m
.00737 1.13224 L
s
[(1.5)] -0.01138 1.13224 1 0 Mshowa
.00112 1.49135 m
.00737 1.49135 L
s
[(2)] -0.01138 1.49135 1 0 Mshowa
.00112 1.85046 m
.00737 1.85046 L
s
[(2.5)] -0.01138 1.85046 1 0 Mshowa
.00112 2.20957 m
.00737 2.20957 L
s
[(3)] -0.01138 2.20957 1 0 Mshowa
.125 Mabswid
.00112 .12672 m
.00487 .12672 L
s
.00112 .19855 m
.00487 .19855 L
s
.00112 .27037 m
.00487 .27037 L
s
.00112 .34219 m
.00487 .34219 L
s
.00112 .48583 m
.00487 .48583 L
s
.00112 .55766 m
.00487 .55766 L
s
.00112 .62948 m
.00487 .62948 L
s
.00112 .7013 m
.00487 .7013 L
s
.00112 .84495 m
.00487 .84495 L
s
.00112 .91677 m
.00487 .91677 L
s
.00112 .98859 m
.00487 .98859 L
s
.00112 1.06041 m
.00487 1.06041 L
s
.00112 1.20406 m
.00487 1.20406 L
s
.00112 1.27588 m
.00487 1.27588 L
s
.00112 1.3477 m
.00487 1.3477 L
s
.00112 1.41953 m
.00487 1.41953 L
s
.00112 1.56317 m
.00487 1.56317 L
s
.00112 1.63499 m
.00487 1.63499 L
s
.00112 1.70682 m
.00487 1.70682 L
s
.00112 1.77864 m
.00487 1.77864 L
s
.00112 1.92228 m
.00487 1.92228 L
s
.00112 1.99411 m
.00487 1.99411 L
s
.00112 2.06593 m
.00487 2.06593 L
s
.00112 2.13775 m
.00487 2.13775 L
s
.00112 2.2814 m
.00487 2.2814 L
s
.25 Mabswid
.00112 0 m
.00112 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
.5 Mabswid
.58951 .05669 m
.58951 .05675 L
.58951 .05682 L
.58951 .05688 L
.58951 .05696 L
.58951 .05703 L
.58951 .0571 L
.58951 .05718 L
.58951 .05726 L
.58951 .05734 L
.58951 .05743 L
.58951 .05752 L
.58951 .05761 L
.58951 .05771 L
.58951 .05781 L
.58951 .05791 L
.58951 .05802 L
.58951 .05813 L
.58951 .05824 L
.58951 .05836 L
.58951 .05848 L
.58951 .05861 L
.5895 .05874 L
.5895 .05887 L
.5895 .05901 L
.5895 .05916 L
.5895 .05931 L
.5895 .05947 L
.5895 .05963 L
.5895 .05979 L
.5895 .05997 L
.5895 .06015 L
.58949 .06033 L
.58949 .06052 L
.58949 .06072 L
.58949 .06093 L
.58949 .06114 L
.58949 .06136 L
.58948 .06159 L
.58948 .06183 L
.58948 .06207 L
.58948 .06232 L
.58947 .06259 L
.58947 .06286 L
.58947 .06314 L
.58946 .06343 L
.58946 .06373 L
.58946 .06404 L
.58945 .06437 L
.58945 .0647 L
Mistroke
.58944 .06505 L
.58944 .06541 L
.58943 .06578 L
.58943 .06616 L
.58942 .06656 L
.58941 .06697 L
.58941 .0674 L
.5894 .06784 L
.58939 .0683 L
.58938 .06877 L
.58937 .06926 L
.58936 .06977 L
.58935 .0703 L
.58934 .07084 L
.58933 .0714 L
.58931 .07199 L
.5893 .07259 L
.58928 .07322 L
.58927 .07387 L
.58925 .07454 L
.58923 .07523 L
.58921 .07595 L
.58919 .0767 L
.58917 .07747 L
.58914 .07827 L
.58911 .0791 L
.58909 .07996 L
.58906 .08085 L
.58902 .08177 L
.58899 .08272 L
.58895 .08371 L
.58891 .08473 L
.58887 .08579 L
.58882 .08688 L
.58877 .08802 L
.58872 .0892 L
.58866 .09042 L
.5886 .09168 L
.58854 .09299 L
.58847 .09435 L
.5884 .09575 L
.58832 .09721 L
.58824 .09872 L
.58815 .10028 L
.58806 .1019 L
.58796 .10359 L
.58785 .10533 L
.58773 .10713 L
.58761 .10901 L
.58748 .11095 L
Mistroke
.58734 .11296 L
.5872 .11505 L
.58704 .11721 L
.58687 .11946 L
.5867 .12178 L
.58651 .1242 L
.58631 .12671 L
.5861 .12931 L
.58588 .13201 L
.58564 .13481 L
.58539 .13771 L
.58512 .14073 L
.58485 .14386 L
.58455 .14712 L
.58424 .1505 L
.58391 .154 L
.58357 .15765 L
.58321 .16143 L
.58283 .16536 L
.58244 .16945 L
.58202 .17369 L
.58159 .1781 L
.58114 .18269 L
.58067 .18745 L
.58018 .1924 L
.57967 .19755 L
.57915 .2029 L
.57861 .20846 L
.57805 .21424 L
.57747 .22025 L
.57688 .22649 L
.57627 .23298 L
.57565 .23972 L
.57501 .24673 L
.57436 .25402 L
.5737 .26159 L
.57304 .26945 L
.57236 .27761 L
.57168 .2861 L
.57099 .29491 L
.5703 .30405 L
.56961 .31355 L
.56892 .3234 L
.56823 .33363 L
.56754 .34424 L
.56686 .35524 L
.56619 .36666 L
.56553 .37849 L
.56487 .39077 L
.56423 .40349 L
Mistroke
.5636 .41667 L
.56299 .43033 L
.56239 .44448 L
.5618 .45914 L
.56124 .47433 L
.56069 .49005 L
.56016 .50633 L
.55964 .52319 L
.55915 .54064 L
.55867 .55871 L
.55822 .57741 L
.55778 .59677 L
.55736 .6168 L
.55696 .63753 L
.55658 .65898 L
.55622 .68118 L
.55588 .70415 L
.55555 .72792 L
.55524 .75251 L
.55494 .77796 L
.55466 .8043 L
.5544 .83155 L
.55415 .85974 L
.55391 .88892 L
.55369 .91911 L
.55348 .95035 L
.55329 .98267 L
.5531 1.01612 L
.55293 1.05074 L
.55276 1.08656 L
.55261 1.12363 L
.55246 1.16199 L
.55233 1.20169 L
.5522 1.24277 L
.55208 1.28529 L
.55197 1.3293 L
.55186 1.37484 L
.55176 1.42198 L
.55167 1.47077 L
.55158 1.52127 L
.5515 1.57353 L
.55143 1.62763 L
.55136 1.68362 L
.55129 1.74158 L
.55123 1.80157 L
.55117 1.86367 L
.55112 1.92795 L
.55107 1.99448 L
.55102 2.06336 L
.55097 2.13465 L
Mistroke
Mfstroke
newpath
.58951 .05669 .00081 0 365.73 arc
s
newpath
.58951 .05703 .00096 0 365.73 arc
s
newpath
.58951 .05743 .00114 0 365.73 arc
s
newpath
.58951 .05791 .00136 0 365.73 arc
s
newpath
.58951 .05848 .00162 0 365.73 arc
s
newpath
.5895 .05916 .00192 0 365.73 arc
s
newpath
.5895 .05997 .00229 0 365.73 arc
s
newpath
.58949 .06093 .00272 0 365.73 arc
s
newpath
.58948 .06207 .00324 0 365.73 arc
s
newpath
.58946 .06343 .00385 0 365.73 arc
s
newpath
.58944 .06505 .00458 0 365.73 arc
s
newpath
.58941 .06697 .00545 0 365.73 arc
s
newpath
.58937 .06926 .00648 0 365.73 arc
s
newpath
.58931 .07199 .0077 0 365.73 arc
s
newpath
.58923 .07523 .00915 0 365.73 arc
s
newpath
.58911 .0791 .01088 0 365.73 arc
s
newpath
.58895 .08371 .01292 0 365.73 arc
s
newpath
.58872 .0892 .01534 0 365.73 arc
s
newpath
.5884 .09575 .01821 0 365.73 arc
s
newpath
.58796 .10359 .02158 0 365.73 arc
s
newpath
.58734 .11296 .02555 0 365.73 arc
s
newpath
.58651 .1242 .03019 0 365.73 arc
s
newpath
.58539 .13771 .03559 0 365.73 arc
s
newpath
.58391 .154 .04182 0 365.73 arc
s
newpath
.58202 .17369 .04894 0 365.73 arc
s
newpath
.57967 .19755 .05701 0 365.73 arc
s
newpath
.57688 .22649 .06605 0 365.73 arc
s
newpath
.5737 .26159 .07609 0 365.73 arc
s
newpath
.5703 .30405 .0872 0 365.73 arc
s
newpath
.56686 .35524 .09954 0 365.73 arc
s
newpath
.5636 .41667 .11338 0 365.73 arc
s
newpath
.56069 .49005 .12916 0 365.73 arc
s
newpath
.55822 .57741 .14749 0 365.73 arc
s
newpath
.55622 .68118 .16913 0 365.73 arc
s
newpath
.55466 .8043 .19497 0 365.73 arc
s
newpath
.55348 .95035 .22601 0 365.73 arc
s
newpath
.55261 1.12363 .2634 0 365.73 arc
s
newpath
.55197 1.3293 .30842 0 365.73 arc
s
newpath
.5515 1.57353 .36253 0 365.73 arc
s
newpath
.55117 1.86367 .42746 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.22672 0.477324 2.29113 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.00112267 0.718224 0.0549004 0.718224 [
[.14477 .0424 -7.2 -7.2 ]
[.14477 .0424 7.2 0 ]
[.28841 .0424 -7.2 -7.2 ]
[.28841 .0424 7.2 0 ]
[.43206 .0424 -7.2 -7.2 ]
[.43206 .0424 7.2 0 ]
[.5757 .0424 -7.2 -7.2 ]
[.5757 .0424 7.2 0 ]
[.71935 .0424 -2.4 -7.2 ]
[.71935 .0424 2.4 0 ]
[.86299 .0424 -7.2 -7.2 ]
[.86299 .0424 7.2 0 ]
[-0.01138 .41401 -14.4 -3.6 ]
[-0.01138 .41401 0 3.6 ]
[-0.01138 .77312 -4.8 -3.6 ]
[-0.01138 .77312 0 3.6 ]
[-0.01138 1.13224 -14.4 -3.6 ]
[-0.01138 1.13224 0 3.6 ]
[-0.01138 1.49135 -4.8 -3.6 ]
[-0.01138 1.49135 0 3.6 ]
[-0.01138 1.85046 -14.4 -3.6 ]
[-0.01138 1.85046 0 3.6 ]
[-0.01138 2.20957 -4.8 -3.6 ]
[-0.01138 2.20957 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14477 .0549 m
.14477 .06115 L
s
[(0.2)] .14477 .0424 0 1 Mshowa
.28841 .0549 m
.28841 .06115 L
s
[(0.4)] .28841 .0424 0 1 Mshowa
.43206 .0549 m
.43206 .06115 L
s
[(0.6)] .43206 .0424 0 1 Mshowa
.5757 .0549 m
.5757 .06115 L
s
[(0.8)] .5757 .0424 0 1 Mshowa
.71935 .0549 m
.71935 .06115 L
s
[(1)] .71935 .0424 0 1 Mshowa
.86299 .0549 m
.86299 .06115 L
s
[(1.2)] .86299 .0424 0 1 Mshowa
.125 Mabswid
.03703 .0549 m
.03703 .05865 L
s
.07295 .0549 m
.07295 .05865 L
s
.10886 .0549 m
.10886 .05865 L
s
.18068 .0549 m
.18068 .05865 L
s
.21659 .0549 m
.21659 .05865 L
s
.2525 .0549 m
.2525 .05865 L
s
.32432 .0549 m
.32432 .05865 L
s
.36023 .0549 m
.36023 .05865 L
s
.39615 .0549 m
.39615 .05865 L
s
.46797 .0549 m
.46797 .05865 L
s
.50388 .0549 m
.50388 .05865 L
s
.53979 .0549 m
.53979 .05865 L
s
.61161 .0549 m
.61161 .05865 L
s
.64752 .0549 m
.64752 .05865 L
s
.68344 .0549 m
.68344 .05865 L
s
.75526 .0549 m
.75526 .05865 L
s
.79117 .0549 m
.79117 .05865 L
s
.82708 .0549 m
.82708 .05865 L
s
.8989 .0549 m
.8989 .05865 L
s
.93481 .0549 m
.93481 .05865 L
s
.97073 .0549 m
.97073 .05865 L
s
.25 Mabswid
0 .0549 m
1 .0549 L
s
.00112 .41401 m
.00737 .41401 L
s
[(0.5)] -0.01138 .41401 1 0 Mshowa
.00112 .77312 m
.00737 .77312 L
s
[(1)] -0.01138 .77312 1 0 Mshowa
.00112 1.13224 m
.00737 1.13224 L
s
[(1.5)] -0.01138 1.13224 1 0 Mshowa
.00112 1.49135 m
.00737 1.49135 L
s
[(2)] -0.01138 1.49135 1 0 Mshowa
.00112 1.85046 m
.00737 1.85046 L
s
[(2.5)] -0.01138 1.85046 1 0 Mshowa
.00112 2.20957 m
.00737 2.20957 L
s
[(3)] -0.01138 2.20957 1 0 Mshowa
.125 Mabswid
.00112 .12672 m
.00487 .12672 L
s
.00112 .19855 m
.00487 .19855 L
s
.00112 .27037 m
.00487 .27037 L
s
.00112 .34219 m
.00487 .34219 L
s
.00112 .48583 m
.00487 .48583 L
s
.00112 .55766 m
.00487 .55766 L
s
.00112 .62948 m
.00487 .62948 L
s
.00112 .7013 m
.00487 .7013 L
s
.00112 .84495 m
.00487 .84495 L
s
.00112 .91677 m
.00487 .91677 L
s
.00112 .98859 m
.00487 .98859 L
s
.00112 1.06041 m
.00487 1.06041 L
s
.00112 1.20406 m
.00487 1.20406 L
s
.00112 1.27588 m
.00487 1.27588 L
s
.00112 1.3477 m
.00487 1.3477 L
s
.00112 1.41953 m
.00487 1.41953 L
s
.00112 1.56317 m
.00487 1.56317 L
s
.00112 1.63499 m
.00487 1.63499 L
s
.00112 1.70682 m
.00487 1.70682 L
s
.00112 1.77864 m
.00487 1.77864 L
s
.00112 1.92228 m
.00487 1.92228 L
s
.00112 1.99411 m
.00487 1.99411 L
s
.00112 2.06593 m
.00487 2.06593 L
s
.00112 2.13775 m
.00487 2.13775 L
s
.00112 2.2814 m
.00487 2.2814 L
s
.25 Mabswid
.00112 0 m
.00112 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
.5 Mabswid
.58951 .05669 m
.58951 .05675 L
.58951 .05682 L
.58951 .05688 L
.58951 .05696 L
.58951 .05703 L
.58951 .0571 L
.58951 .05718 L
.58951 .05726 L
.58951 .05734 L
.58951 .05743 L
.58951 .05752 L
.58951 .05761 L
.58951 .05771 L
.58951 .05781 L
.58951 .05791 L
.58951 .05802 L
.58951 .05813 L
.58951 .05824 L
.58951 .05836 L
.58951 .05848 L
.58951 .05861 L
.5895 .05874 L
.5895 .05887 L
.5895 .05901 L
.5895 .05916 L
.5895 .05931 L
.5895 .05947 L
.5895 .05963 L
.5895 .05979 L
.5895 .05997 L
.5895 .06015 L
.58949 .06033 L
.58949 .06052 L
.58949 .06072 L
.58949 .06093 L
.58949 .06114 L
.58949 .06136 L
.58948 .06159 L
.58948 .06183 L
.58948 .06207 L
.58948 .06232 L
.58947 .06259 L
.58947 .06286 L
.58947 .06314 L
.58946 .06343 L
.58946 .06373 L
.58946 .06404 L
.58945 .06437 L
.58945 .0647 L
Mistroke
.58944 .06505 L
.58944 .06541 L
.58943 .06578 L
.58943 .06616 L
.58942 .06656 L
.58941 .06697 L
.58941 .0674 L
.5894 .06784 L
.58939 .0683 L
.58938 .06877 L
.58937 .06926 L
.58936 .06977 L
.58935 .0703 L
.58934 .07084 L
.58933 .0714 L
.58931 .07199 L
.5893 .07259 L
.58928 .07322 L
.58927 .07387 L
.58925 .07454 L
.58923 .07523 L
.58921 .07595 L
.58919 .0767 L
.58917 .07747 L
.58914 .07827 L
.58911 .0791 L
.58909 .07996 L
.58906 .08085 L
.58902 .08177 L
.58899 .08272 L
.58895 .08371 L
.58891 .08473 L
.58887 .08579 L
.58882 .08688 L
.58877 .08802 L
.58872 .0892 L
.58866 .09042 L
.5886 .09168 L
.58854 .09299 L
.58847 .09435 L
.5884 .09575 L
.58832 .09721 L
.58824 .09872 L
.58815 .10028 L
.58806 .1019 L
.58796 .10359 L
.58785 .10533 L
.58773 .10713 L
.58761 .10901 L
.58748 .11095 L
Mistroke
.58734 .11296 L
.5872 .11505 L
.58704 .11721 L
.58687 .11946 L
.5867 .12178 L
.58651 .1242 L
.58631 .12671 L
.5861 .12931 L
.58588 .13201 L
.58564 .13481 L
.58539 .13771 L
.58512 .14073 L
.58485 .14386 L
.58455 .14712 L
.58424 .1505 L
.58391 .154 L
.58357 .15765 L
.58321 .16143 L
.58283 .16536 L
.58244 .16945 L
.58202 .17369 L
.58159 .1781 L
.58114 .18269 L
.58067 .18745 L
.58018 .1924 L
.57967 .19755 L
.57915 .2029 L
.57861 .20846 L
.57805 .21424 L
.57747 .22025 L
.57688 .22649 L
.57627 .23298 L
.57565 .23972 L
.57501 .24673 L
.57436 .25402 L
.5737 .26159 L
.57304 .26945 L
.57236 .27761 L
.57168 .2861 L
.57099 .29491 L
.5703 .30405 L
.56961 .31355 L
.56892 .3234 L
.56823 .33363 L
.56754 .34424 L
.56686 .35524 L
.56619 .36666 L
.56553 .37849 L
.56487 .39077 L
.56423 .40349 L
Mistroke
.5636 .41667 L
.56299 .43033 L
.56239 .44448 L
.5618 .45914 L
.56124 .47433 L
.56069 .49005 L
.56016 .50633 L
.55964 .52319 L
.55915 .54064 L
.55867 .55871 L
.55822 .57741 L
.55778 .59677 L
.55736 .6168 L
.55696 .63753 L
.55658 .65898 L
.55622 .68118 L
.55588 .70415 L
.55555 .72792 L
.55524 .75251 L
.55494 .77796 L
.55466 .8043 L
.5544 .83155 L
.55415 .85974 L
.55391 .88892 L
.55369 .91911 L
.55348 .95035 L
.55329 .98267 L
.5531 1.01612 L
.55293 1.05074 L
.55276 1.08656 L
.55261 1.12363 L
.55246 1.16199 L
.55233 1.20169 L
.5522 1.24277 L
.55208 1.28529 L
.55197 1.3293 L
.55186 1.37484 L
.55176 1.42198 L
.55167 1.47077 L
.55158 1.52127 L
.5515 1.57353 L
.55143 1.62763 L
.55136 1.68362 L
.55129 1.74158 L
.55123 1.80157 L
.55117 1.86367 L
.55112 1.92795 L
.55107 1.99448 L
.55102 2.06336 L
.55097 2.13465 L
Mistroke
Mfstroke
newpath
.58951 .05669 .00081 0 365.73 arc
s
newpath
.58951 .05703 .00096 0 365.73 arc
s
newpath
.58951 .05743 .00114 0 365.73 arc
s
newpath
.58951 .05791 .00136 0 365.73 arc
s
newpath
.58951 .05848 .00162 0 365.73 arc
s
newpath
.5895 .05916 .00192 0 365.73 arc
s
newpath
.5895 .05997 .00229 0 365.73 arc
s
newpath
.58949 .06093 .00272 0 365.73 arc
s
newpath
.58948 .06207 .00324 0 365.73 arc
s
newpath
.58946 .06343 .00385 0 365.73 arc
s
newpath
.58944 .06505 .00458 0 365.73 arc
s
newpath
.58941 .06697 .00545 0 365.73 arc
s
newpath
.58937 .06926 .00648 0 365.73 arc
s
newpath
.58931 .07199 .0077 0 365.73 arc
s
newpath
.58923 .07523 .00915 0 365.73 arc
s
newpath
.58911 .0791 .01088 0 365.73 arc
s
newpath
.58895 .08371 .01292 0 365.73 arc
s
newpath
.58872 .0892 .01534 0 365.73 arc
s
newpath
.5884 .09575 .01821 0 365.73 arc
s
newpath
.58796 .10359 .02158 0 365.73 arc
s
newpath
.58734 .11296 .02555 0 365.73 arc
s
newpath
.58651 .1242 .03019 0 365.73 arc
s
newpath
.58539 .13771 .03559 0 365.73 arc
s
newpath
.58391 .154 .04182 0 365.73 arc
s
newpath
.58202 .17369 .04894 0 365.73 arc
s
newpath
.57967 .19755 .05701 0 365.73 arc
s
newpath
.57688 .22649 .06605 0 365.73 arc
s
newpath
.5737 .26159 .07609 0 365.73 arc
s
newpath
.5703 .30405 .0872 0 365.73 arc
s
newpath
.56686 .35524 .09954 0 365.73 arc
s
newpath
.5636 .41667 .11338 0 365.73 arc
s
newpath
.56069 .49005 .12916 0 365.73 arc
s
newpath
.55822 .57741 .14749 0 365.73 arc
s
newpath
.55622 .68118 .16913 0 365.73 arc
s
newpath
.55466 .8043 .19497 0 365.73 arc
s
newpath
.55348 .95035 .22601 0 365.73 arc
s
newpath
.55261 1.12363 .2634 0 365.73 arc
s
newpath
.55197 1.3293 .30842 0 365.73 arc
s
newpath
.5515 1.57353 .36253 0 365.73 arc
s
newpath
.55117 1.86367 .42746 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 1.22672 0.97619 2.29113 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.00112267 0.718224 0.0549004 0.718224 [
[.14477 .0424 -7.2 -7.2 ]
[.14477 .0424 7.2 0 ]
[.28841 .0424 -7.2 -7.2 ]
[.28841 .0424 7.2 0 ]
[.43206 .0424 -7.2 -7.2 ]
[.43206 .0424 7.2 0 ]
[.5757 .0424 -7.2 -7.2 ]
[.5757 .0424 7.2 0 ]
[.71935 .0424 -2.4 -7.2 ]
[.71935 .0424 2.4 0 ]
[.86299 .0424 -7.2 -7.2 ]
[.86299 .0424 7.2 0 ]
[-0.01138 .41401 -14.4 -3.6 ]
[-0.01138 .41401 0 3.6 ]
[-0.01138 .77312 -4.8 -3.6 ]
[-0.01138 .77312 0 3.6 ]
[-0.01138 1.13224 -14.4 -3.6 ]
[-0.01138 1.13224 0 3.6 ]
[-0.01138 1.49135 -4.8 -3.6 ]
[-0.01138 1.49135 0 3.6 ]
[-0.01138 1.85046 -14.4 -3.6 ]
[-0.01138 1.85046 0 3.6 ]
[-0.01138 2.20957 -4.8 -3.6 ]
[-0.01138 2.20957 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14477 .0549 m
.14477 .06115 L
s
[(0.2)] .14477 .0424 0 1 Mshowa
.28841 .0549 m
.28841 .06115 L
s
[(0.4)] .28841 .0424 0 1 Mshowa
.43206 .0549 m
.43206 .06115 L
s
[(0.6)] .43206 .0424 0 1 Mshowa
.5757 .0549 m
.5757 .06115 L
s
[(0.8)] .5757 .0424 0 1 Mshowa
.71935 .0549 m
.71935 .06115 L
s
[(1)] .71935 .0424 0 1 Mshowa
.86299 .0549 m
.86299 .06115 L
s
[(1.2)] .86299 .0424 0 1 Mshowa
.125 Mabswid
.03703 .0549 m
.03703 .05865 L
s
.07295 .0549 m
.07295 .05865 L
s
.10886 .0549 m
.10886 .05865 L
s
.18068 .0549 m
.18068 .05865 L
s
.21659 .0549 m
.21659 .05865 L
s
.2525 .0549 m
.2525 .05865 L
s
.32432 .0549 m
.32432 .05865 L
s
.36023 .0549 m
.36023 .05865 L
s
.39615 .0549 m
.39615 .05865 L
s
.46797 .0549 m
.46797 .05865 L
s
.50388 .0549 m
.50388 .05865 L
s
.53979 .0549 m
.53979 .05865 L
s
.61161 .0549 m
.61161 .05865 L
s
.64752 .0549 m
.64752 .05865 L
s
.68344 .0549 m
.68344 .05865 L
s
.75526 .0549 m
.75526 .05865 L
s
.79117 .0549 m
.79117 .05865 L
s
.82708 .0549 m
.82708 .05865 L
s
.8989 .0549 m
.8989 .05865 L
s
.93481 .0549 m
.93481 .05865 L
s
.97073 .0549 m
.97073 .05865 L
s
.25 Mabswid
0 .0549 m
1 .0549 L
s
.00112 .41401 m
.00737 .41401 L
s
[(0.5)] -0.01138 .41401 1 0 Mshowa
.00112 .77312 m
.00737 .77312 L
s
[(1)] -0.01138 .77312 1 0 Mshowa
.00112 1.13224 m
.00737 1.13224 L
s
[(1.5)] -0.01138 1.13224 1 0 Mshowa
.00112 1.49135 m
.00737 1.49135 L
s
[(2)] -0.01138 1.49135 1 0 Mshowa
.00112 1.85046 m
.00737 1.85046 L
s
[(2.5)] -0.01138 1.85046 1 0 Mshowa
.00112 2.20957 m
.00737 2.20957 L
s
[(3)] -0.01138 2.20957 1 0 Mshowa
.125 Mabswid
.00112 .12672 m
.00487 .12672 L
s
.00112 .19855 m
.00487 .19855 L
s
.00112 .27037 m
.00487 .27037 L
s
.00112 .34219 m
.00487 .34219 L
s
.00112 .48583 m
.00487 .48583 L
s
.00112 .55766 m
.00487 .55766 L
s
.00112 .62948 m
.00487 .62948 L
s
.00112 .7013 m
.00487 .7013 L
s
.00112 .84495 m
.00487 .84495 L
s
.00112 .91677 m
.00487 .91677 L
s
.00112 .98859 m
.00487 .98859 L
s
.00112 1.06041 m
.00487 1.06041 L
s
.00112 1.20406 m
.00487 1.20406 L
s
.00112 1.27588 m
.00487 1.27588 L
s
.00112 1.3477 m
.00487 1.3477 L
s
.00112 1.41953 m
.00487 1.41953 L
s
.00112 1.56317 m
.00487 1.56317 L
s
.00112 1.63499 m
.00487 1.63499 L
s
.00112 1.70682 m
.00487 1.70682 L
s
.00112 1.77864 m
.00487 1.77864 L
s
.00112 1.92228 m
.00487 1.92228 L
s
.00112 1.99411 m
.00487 1.99411 L
s
.00112 2.06593 m
.00487 2.06593 L
s
.00112 2.13775 m
.00487 2.13775 L
s
.00112 2.2814 m
.00487 2.2814 L
s
.25 Mabswid
.00112 0 m
.00112 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
.5 Mabswid
.00113 .05571 m
.00113 .05574 L
.00113 .05577 L
.00113 .0558 L
.00113 .05583 L
.00113 .05586 L
.00113 .05589 L
.00113 .05593 L
.00113 .05597 L
.00113 .056 L
.00113 .05604 L
.00113 .05608 L
.00113 .05613 L
.00113 .05617 L
.00113 .05621 L
.00113 .05626 L
.00113 .05631 L
.00113 .05636 L
.00113 .05641 L
.00113 .05646 L
.00113 .05652 L
.00113 .05657 L
.00113 .05663 L
.00113 .05669 L
.00114 .05676 L
.00114 .05682 L
.00114 .05689 L
.00114 .05696 L
.00114 .05703 L
.00114 .05711 L
.00114 .05719 L
.00114 .05727 L
.00114 .05735 L
.00115 .05744 L
.00115 .05753 L
.00115 .05762 L
.00115 .05772 L
.00115 .05782 L
.00116 .05792 L
.00116 .05803 L
.00116 .05814 L
.00116 .05825 L
.00117 .05837 L
.00117 .05849 L
.00117 .05862 L
.00118 .05875 L
.00118 .05889 L
.00118 .05903 L
.00119 .05917 L
.00119 .05932 L
Mistroke
.0012 .05948 L
.0012 .05964 L
.00121 .05981 L
.00122 .05998 L
.00122 .06016 L
.00123 .06034 L
.00124 .06054 L
.00125 .06074 L
.00125 .06094 L
.00126 .06115 L
.00127 .06137 L
.00129 .0616 L
.0013 .06184 L
.00131 .06208 L
.00132 .06233 L
.00134 .0626 L
.00135 .06287 L
.00137 .06315 L
.00139 .06344 L
.0014 .06374 L
.00142 .06405 L
.00145 .06437 L
.00147 .0647 L
.00149 .06505 L
.00152 .0654 L
.00155 .06577 L
.00158 .06615 L
.00161 .06654 L
.00165 .06695 L
.00168 .06737 L
.00172 .06781 L
.00177 .06826 L
.00181 .06873 L
.00186 .06921 L
.00191 .06971 L
.00197 .07022 L
.00203 .07075 L
.00209 .0713 L
.00216 .07187 L
.00223 .07246 L
.00231 .07307 L
.00239 .0737 L
.00248 .07435 L
.00258 .07501 L
.00268 .07571 L
.00278 .07642 L
.0029 .07716 L
.00302 .07792 L
.00315 .0787 L
.00329 .07951 L
Mistroke
.00344 .08035 L
.0036 .08121 L
.00376 .08209 L
.00394 .08301 L
.00413 .08395 L
.00433 .08492 L
.00454 .08592 L
.00477 .08695 L
.00501 .08801 L
.00526 .0891 L
.00553 .09022 L
.00582 .09137 L
.00612 .09255 L
.00643 .09376 L
.00677 .09501 L
.00712 .09629 L
.00749 .0976 L
.00788 .09894 L
.00828 .10032 L
.00871 .10173 L
.00916 .10318 L
.00963 .10466 L
.01012 .10617 L
.01063 .10772 L
.01116 .1093 L
.01171 .11092 L
.01228 .11257 L
.01287 .11426 L
.01349 .11598 L
.01412 .11773 L
.01477 .11952 L
.01544 .12135 L
.01612 .12322 L
.01683 .12512 L
.01755 .12705 L
.01828 .12903 L
.01902 .13105 L
.01978 .13311 L
.02054 .13521 L
.02131 .13735 L
.02209 .13955 L
.02288 .14179 L
.02366 .14408 L
.02445 .14642 L
.02523 .14882 L
.02602 .15128 L
.02679 .1538 L
.02757 .15639 L
.02833 .15904 L
.02908 .16177 L
Mistroke
.02982 .16458 L
.03055 .16748 L
.03127 .17046 L
.03197 .17353 L
.03265 .1767 L
.03332 .17998 L
.03397 .18336 L
.0346 .18686 L
.03521 .19048 L
.0358 .19423 L
.03637 .19811 L
.03692 .20213 L
.03745 .2063 L
.03796 .21062 L
.03845 .2151 L
.03892 .21975 L
.03937 .22457 L
.0398 .22957 L
.04021 .23477 L
.0406 .24016 L
.04097 .24575 L
.04132 .25156 L
.04166 .25759 L
.04198 .26384 L
.04228 .27034 L
.04256 .27708 L
.04284 .28408 L
.04309 .29135 L
.04333 .29888 L
.04356 .30671 L
.04378 .31483 L
.04398 .32325 L
.04417 .33199 L
.04436 .34106 L
.04453 .35047 L
.04469 .36023 L
.04484 .37035 L
.04498 .38085 L
.04511 .39173 L
.04524 .40302 L
.04535 .41473 L
.04546 .42686 L
.04557 .43944 L
.04566 .45248 L
.04575 .466 L
.04584 .48001 L
.04592 .49453 L
.04599 .50958 L
.04606 .52518 L
.04613 .54134 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{151.688, 361.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002G0001JB000`400?l00000o`00003oUoooool0
09Oooooo002Gooooo`00Uoooool009Oo000000000ol0003oooooooooo`2Cooooo`7o000000000ol0
003oooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o000000000ol0003ooooo
ooooo`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2C
ooooo`7o000000000ol0003oooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o
000000000ol0003oooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o00000000
0ol0003oooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o000000000ol0003o
ooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o000000000ol0003ooooooooo
o`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2Coooo
o`7o000000000ol0003oooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o0000
00000ol0003oooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o000000000ol0
003oooooooooo`2Cooooo`7o000000000ol0003oooooooooo`2Cooooo`7o000000000ol0003ooooo
ooooo`2Cooooo`7o000000000ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?l000001Ooooooo0000oooooooooooo000000;ooooo00Go0000ooooool0003o
ooooo`000002ooooo`?o00000oooool9o`0000?ooooo00Co0000oooooooooooooooo0ol0000Hoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?l000001Ooooooo0000oooooooooooo
000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`?o00000oooool9o`0000?ooooo00Co
0000oooooooooooooooo0ol00004ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oo
oooo000000Gooooo00Co0000ooooool0003o00001?ooool00ol0003oooooo`000002o`0000;ooooo
00Ko0000ooooool0003o0000ooooool00004ooooo`05o`000?oooooo0000ooooool000000_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000001Oooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooo000000;o00000_ooool01_l0003oooooo`00
0?l0003oooooo`0000Cooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool04?ooool00ol0003o
ooooo`000005ooooo`05o`000?oooooo0000ooooool000000oooool01Ol0003oooooo`000?oooooo
000000;ooooo00?o0000ooooool000000ol00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo000000Gooooo00Go
0000ooooool0003oooooo`000003ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003o
ooooo`000003o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo0Ol000000003o`000?oooooooooo00oooooo0_l000000ooooooo
0000ooooo`04ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003oooooo`000002o`00
00;ooooo00Co0000ooooool0003o00001_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?ooool01?oo
ool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_l00002ooooo`04o`00
0?oooooo0000o`0000Kooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool1o`00000000?o0000ooooooooool03oooool00ol0003o
ooooo`000007ooooo`Co00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00;o00001?ooool5o`000003ooooool0003o000000Sooooo0ol0000Fooooo`03o`000?oooooo0000
00Oooooo1?l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l00004
ooooo`Go000000?oooooo`000?l000002?ooool3o`0000Cooooo0Ol000000003o`000?oooooooooo
00oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0fooooo`7o000000000ol0003o
ooooooooo`0?ooooocKo00005Ooooolfo`0000?ooooo0Ol000000003o`000?oooooooooo00oooooo
0_l00019ooooo`03o`000?oooooooooo01cooooo0_l0000Hooooo`7o000000000ol0003ooooooooo
o`0?ooooo`;o0000BOooool00ol0003oooooooooo`0Looooo`?o00005oooool1o`00000000?o0000
ooooooooool03oooool2o`0004Wooooo00?o0000ooooooooool06oooool4o`0001Oooooo0Ol00000
0003o`000?oooooooooo00oooooo0_l00019ooooo`;o00006oooool5o`0001Oooooo0Ol000000003
o`000?oooooooooo00oooooo0ol00018ooooo`03o`000?oooooooooo01[ooooo1_l0000Fooooo`7o
000000000ol0003oooooooooo`0?ooooo`03o`000?oooooo000004Sooooo00?o0000ooooooooool0
6_ooool6o`0001Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooool00000B?oo
ool00ol0003oooooooooo`0Iooooo`Oo00005_ooool1o`00000000?o0000ooooooooool03oooool0
0ol0003oooooo`000018ooooo`;o00006_ooool7o`0001Kooooo0Ol000000003o`000?oooooooooo
00oooooo00?o0000ooooool00000B?ooool00ol0003oooooooooo`0Hooooo`So00005_ooool1o`00
000000?o0000ooooooooool03oooool00ol0003oooooo`000018ooooo`03o`000?oooooooooo01So
oooo2?l0000Fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooo000004Sooooo
00?o0000ooooooooool05oooool:o`0001Gooooo0Ol000000003o`000?oooooooooo00oooooo00?o
0000ooooool00000B?ooool2o`0001Sooooo2?l000000ooooooo0000ooooo`0Dooooo`7o00000000
0ol0003oooooooooo`0?ooooo`04o`000?oooooo0000o`0004Oooooo00?o0000ooooooooool05ooo
ool3o`000005ooooool0003o0000o`000?ooool00_l0000Eooooo`7o000000000ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooo`0004Oooooo00?o0000ooooooooool05oooool6o`000004oooo
ool0003o0000o`0001Gooooo0Ol000000003o`000?oooooooooo00oooooo00Co0000oooooooooooo
0000Aoooool2o`0001Sooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo
01?ooooo0Ol000000003o`000?oooooooooo00oooooo00Co0000oooooooooooo0000Aoooool00ol0
003oooooooooo`0Fooooo`;o00000oooool3o`0000;ooooo0_l0000Dooooo`7o000000000ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooo`0004Oooooo00?o0000ooooooooool05_ooool00ol0
003oooooo`000003o`0000;ooooo0_l000000ooooooo0000ooooo`0Cooooo`7o000000000ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol000001Ooo
oooo0000oooooooooooo000003[ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool3o`000003ooooool0003ooooo01Oooooo0_l00002ooooo`Co000000Coooooo`000?l0003o0000
5?ooool1o`00000000Oo0000ooooooooooooooooo`000?oooooo000000Wooooo00Ko0000ooooool0
003o0000ooooool0000iooooo`03o`000?oooooo000000Wooooo00Co0000ooooool0003o00005_oo
ool3o`0000?ooooo00?o0000ooooooooool00_ooool2o`0001Cooooo0Ol000000007o`000?oooooo
ooooooooool0003oooooo`000007ooooo`?o000000Goooooo`000?ooooooooooo`00000iooooo`03
o`000?oooooo000000Oooooo0ol000000ooooooo0000ooooo`0Fooooo`03o`000?oooooooooo00So
000000?oooooo`000?ooool04oooool1o`00000000Oo0000ooooooooooooooooo`000?oooooo0000
00Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooool000001oooool01Ol0003ooooooooooooooooo000001Oooooo0ol000000ooooooo0000o`00
0003o`000003ooooool0003ooooo00;o00004oooool1o`00000000?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`?o000000Goooooo`000?ooooooooooo`00000jooooo`03o`000?oo
oooooooo00Kooooo0ol000000ooooooo0000ooooo`0Eooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool00_ooool3o`0001?ooooo0Ol000000003o`000?oooooooooo00oooooo00Co0000
oooooooooooo0000Aoooool2o`0001Gooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00;ooooo0ol0000Cooooo`7o000000000ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooo`0004Oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool5o`000004oooo
ool0003o0000ooooo`;o00004oooool1o`00000000?o0000ooooooooool03oooool01?l0003ooooo
ooooool00017ooooo`03o`000?oooooooooo01Cooooo0_l000000ooooooo0000o`000007o`000003
ooooool0003o000001?ooooo0Ol000000003o`000?oooooooooo00oooooo00Co0000oooooooooooo
0000Aoooool00ol0003oooooooooo`0Dooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o
00004oooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`;o0000
5?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
4_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo01?ooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`02ooooo`04o`00
0?oooooo0000o`0001;ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Cooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`00000Booooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool04oooool01?l0003oooooooooooooool8o`00
00Cooooo00?o0000ooooooooool04?ooool1o`00000000?o0000ooooooooool03oooool00ol0003o
ooooooooo`18ooooo`;o00004oooool00ol0003oooooo`000002o`0000Cooooo00Co0000oooooooo
oooooooo0_l000000ooooooo0000o`00000Booooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool04_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooooooo00?ooooo0ol0000Booooo`7o000000000ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool04_ooool2o`000003ooooool0003o000000Cooooo
00?o0000ooooooooool00oooool01?l0003oooooo`000?l0000Aooooo`7o000000000ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04Sooooo0_l0000Cooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool2o`00017ooooo0Ol000000003o`00
0?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Aooooo`;o0000
1Oooool4o`000003ooooool0003o000000Gooooo00?o0000ooooooooool03oooool1o`00000000?o
0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo017ooooo0_l0
0003ooooo`[o00001?ooool00ol0003oooooooooo`0?ooooo`7o000000000ol0003oooooooooo`0;
ooooo`?o000000?oooooo`000?ooool0AOooool3o`000003ooooool0003ooooo01;ooooo0_l00002
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o
ooooo`00013ooooo0Ol000000003o`000?oooooooooo00cooooo00?o0000ooooooooool00_l00016
ooooo`03o`000?oooooooooo00;o00004_ooool01?l0003oooooo`000?l00006ooooo`03o`000?oo
oooooooo00Cooooo0_l000000ooooooo0000ooooo`0?ooooo`7o000000000ol0003oooooooooo`0<
ooooo`04o`000?ooooooooooo`0004Oooooo00Co0000oooooooooooo00004_ooool01?l0003ooooo
o`000?l00007ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000ooooo`0?ooooo`7o
000000000ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0004Oooooo00Co0000oooooooo
oooo00004_ooool2o`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l00002oooo
o`;o00004?ooool1o`00000000?o0000ooooooooool02oooool2o`0000;ooooo00?o0000oooooooo
ool0A?ooool2o`0000;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00004?ooool1o`00
000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`;o00004Oooool2o`0000Go
oooo2?l00006ooooo`03o`000?oooooooooo00kooooo0Ol000000003o`000?oooooooooo00oooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0@ooooo`;o00001_ooool9o`0000Cooooo
00?o0000ooooooooool03_ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo013ooooo0_l00003ooooo`?o00000oooool00ol0003ooooooooo
o`03ooooo`06o`000?ooooooooooo`000?oooooo00003oooool1o`00000000?o0000ooooooooool0
3oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0ol00006ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooool0003oooooo`00000?ooooo`7o
000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo0_l0000@ooooo`04o`00
0?oooooo0000o`0000Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0?ooooo`;o00000_ooool2o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00cooooo0Ol000000003o`000?oooooooooo00oooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`07o`000?ooooooooooooooool0
003oooooo`00000>ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`;o00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l0000>ooooo`7o000000000ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04Sooooo0_l0000?ooooo`;o00002?ooool8o`0000Kooooo
0_l0000>ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool03_ooool2o`0000[ooooo0_l0000:ooooo`;o00003_ooool1o`00000000?o0000
ooooooooool03oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo0_l00004
ooooo`Ko000000?oooooo`000?l000001Ol00004ooooo`03o`000?oooooo000000gooooo0Ol00000
0003o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`;o00000_ooool00ol0003oooooo`00000=ooooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04Sooooo0_l0000>ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool0
0ol0003oooooooooo`06ooooo`;o00000_ooool00ol0003oooooooooo`0;ooooo`7o000000000ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03Oooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01_ooool2o`0000?ooooo00?o0000
ooooooooool02_ooool1o`00000000Co0000oooooooooooooooo0ol00003ooooo`04o`000?oooooo
ooooooooo`?o000000?oooooo`000?ooool0>oooool3o`0000?ooooo00Co0000oooooooooooooooo
0ol000000ooooooo0000ooooo`0>ooooo`05o`000?ooooooooooo`000?ooool00_l00007ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0:oooo
o`7o000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Co0000ooooool0
003o0000??ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo0000o`0000kooooo00?o0000
ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`00000<ooooo`7o000000000ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo
00Kooooo0ol000000ooooooo0000ooooo`0>ooooo`;o00001_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooo000000cooooo0Ol000000003
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
03gooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000oooooo0_l00007
ooooo`Co000000Coooooo`000?oooooooooo0_l00008ooooo`03o`000?oooooooooo00_ooooo0Ol0
00000004o`000?ooooooooooooooo`;o00002?ooool3o`000003ooooool0003ooooo03_ooooo0_l0
0008ooooo`?o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`0:ooooo`Co00002_oo
ool2o`0000cooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool2
o`0000gooooo0_l0000=ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`7o000000000ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02oooool00ol0
003oooooo`000007ooooo`go00001_ooool00ol0003oooooo`00000;ooooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02oooool01?l0003o
ooooooooool00003ooooo`?o00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000002oooool1o`00000000?o0000ooooooooool03oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0ol00009oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`04o`000?ooooooooooo`0000_ooooo0Ol00000
0003o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool2o`0000_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo0_l00004oooo
o`03o`000?oooooooooo00Sooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0:ooooo`07o`000?ooooooooooooooool0003oooooo`00000:
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000oooool00ol0003oooooooooo`08
ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool02_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02?oo
ool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooool000001Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000[ooooo0Ol000000003o`000?oooooooooo
00oooooo00?o0000ooooooooool0B?ooool2o`0000_ooooo0_l00008ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool2o`0000Oooooo0_l0000:ooooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02_ooool2o`0000Wo
oooo0ol00003ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`08oooo
o`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`Oo00003?ooool00ol0003oooooooooo`08ooooo`7o
000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
2_ooool2o`0000oooooo00?o0000ooooooooool03Oooool2o`0000Wooooo0Ol000000003o`000?oo
oooooooo00oooooo00?o0000ooooooooool0B?ooool2o`0000[ooooo00?o0000ooooool000003ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooo000000Wooooo0Ol000000003o`000?oooooo
oooo00oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0000Wooooo3_l00007ooooo`03o`000?oooooo000000Wooooo0Ol000000003o`000?oooooo
oooo00_ooooo0ol000000ooooooo0000ooooo`15ooooo`?o000000?oooooo`000?ooool02Oooool0
1Ol0003ooooooooooooooooo000000Gooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo0_l0
0005ooooo`04o`000?ooooooooooo`0000Sooooo0Ol000000003o`000?oooooooooo00cooooo00?o
0000ooooooooool00_l00016ooooo`03o`000?oooooooooo00;o00002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;o00002Oooool00ol0003oooooooooo`07ooooo`;o00000_oo
ool01Ol0003ooooooooooooooooo000000Sooooo0Ol000000003o`000?oooooooooo00gooooo00?o
0000ooooool00000B?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00;ooooo0ol0
000;ooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo0Ol0
00000003o`000?oooooooooo00gooooo00?o0000ooooool00000B?ooool00ol0003oooooo`00000:
ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`7o000000000ol0003oooooooooo`0;oooo
o`?o000000?oooooo`000?ooool0AOooool3o`000003ooooool0003ooooo00Wooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo00Gooooo0Ol000000003o`000?oooooooooo
00oooooo00?o0000ooooooooool0B?ooool2o`0000Sooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01Oooool1o`00000000?o0000ooooooooool03oooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001_oo
ool2o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Oooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003oooooo`000007ooooo`7o00000000
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01oooool2
o`0000_ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`;o00001oooool1
o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`;o00002?ooool2o`00
00kooooo2Ol0000>ooooo`03o`000?oooooooooo00Gooooo0Ol000000003o`000?oooooooooo00oo
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`;o00004_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooo000000Kooooo0Ol000000003o`000?oooooooooo00oooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000001;ooooo
00?o0000ooooooooool03oooool00ol0003oooooo`000006ooooo`7o000000000ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00
000Booooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00001Oooool1o`00000000?o
0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`;o00001_ooool01?l0003ooooooooo
ool0000Booooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000005ooooo`7o
000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool03_ooool01Ol0003o
oooooooooooooooo000000Gooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000004Oooool00ol0
003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000001Oooool1o`00000000?o0000oooo
ooooool03oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00Go0000oooo
ooooooooooooo`000005ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
04Sooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool1o`00
000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`7o000000000ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo0Ol000000004o`000?ooooooooooooooo`?o0000
0oooool01?l0003oooooooooooooool3o`000003ooooool0003ooooo03_ooooo0ol00003ooooo`04
o`000?ooooooooooooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool2o`0000Sooooo00?o0000oooo
ooooool00_ooool1o`00000000?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`04
o`000?oooooo0000o`0003cooooo00?o0000ooooooooool02?ooool01?l0003oooooo`000?l00005
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool1o`00000000?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`?o000000?oooooo`000?ooool0?Oooool00ol0
003oooooooooo`05ooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`08oooo
o`;o00002_ooool00ol0003oooooooooo`06ooooo`;o00002oooool00ol0003oooooooooo`02oooo
o`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`00000nooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00[ooooo0ol00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`02ooooo`7o000000001?l0003oooooooooooooool3
o`0000Oooooo0ol000000ooooooo0000ooooo`0kooooo`?o00001oooool3o`000003ooooool0003o
000000Gooooo00?o0000ooooooooool03Oooool2o`0000Gooooo00Co0000oooooooooooooooo1?l0
000>ooooo`03o`000?oooooooooo00;ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo2Ol0000B
ooooo`03o`000?oooooooooo00;ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`02ooooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool1o`00000000?o0000ooooooooool0
3oooool00ol0003oooooooooo`18ooooo`;o00001_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool03ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooo
oooo00oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`7o000000000ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool1o`00
000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`;o00001oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool1o`000000
00?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo
0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`06ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`18oooo
o`;o00002_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01oooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00[ooooo0_l0000Oooooo`03o`000?oooooooooo00Sooooo0Ol000000003o`00
0?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02Oooool1o`00000000?o0000ooooooooool02ooo
ool3o`000003ooooool0003ooooo04Gooooo0ol000000ooooooo0000ooooo`0=ooooo`03o`000?oo
oooooooo01Wooooo0_l0000<ooooo`7o000000000ol0003oooooooooo`0=ooooo`04o`000?oooooo
0000o`0004Oooooo00Co0000ooooool0003o00003_ooool2o`0001Sooooo00?o0000ooooooooool0
3?ooool1o`00000000?o0000ooooooooool03?ooool01?l0003oooooooooool00017ooooo`04o`00
0?ooooooooooo`00017ooooo0_l0000Eooooo`03o`000?oooooooooo00gooooo0Ol000000003o`00
0?oooooooooo00gooooo00?o0000ooooool00000B?ooool00ol0003oooooo`00000Cooooo`;o0000
3oooool4o`00013ooooo0Ol000000003o`000?oooooooooo00_ooooo0ol000000ooooooo0000oooo
o`15ooooo`?o000000?oooooo`000?ooool05?ooool5o`0000Sooooo0_l0000Dooooo`7o00000000
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo0_l0000Iooooo`So00005_ooool1
o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
03Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0=_ooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000
ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000oooooooo
ool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Tooo
ool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00
000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o
0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000oooo
ooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0
Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1
o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`000000
00?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000
ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000oooooooo
ool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Tooo
ool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00
000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o
0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000oooo
ooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0
Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1
o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`000000
00?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000
ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000oooooooo
ool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Tooo
ool1o`00000000?o0000ooooooooool0Toooool1o`00000000?o0000ooooooooool0Toooool1o`00
000000?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
000000Goooooo`000?ooooooooooo`000002ooooo`05o`000?oooooo0000ooooool000000_ooool3
o`0000?ooooo2Ol00003ooooo`04o`000?ooooooooooooooo`?o00006?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Co000000Goooooo`000?ooooooooooo`000002ooooo`05o`00
0?oooooo0000ooooool000000_ooool3o`0000?ooooo2Ol00003ooooo`04o`000?oooooooooooooo
o`?o00001?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooo`000005ooooo`04
o`000?oooooo0000o`0000Cooooo00?o0000ooooool000000_l00002ooooo`06o`000?oooooo0000
o`000?oooooo00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000Gooooo00Co0000ooooool0003o
00001?ooool00ol0003oooooo`000002o`0000;ooooo00Ko0000ooooool0003o0000ooooool00004
ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo0Ol000000003o`000?oooooooooo00oooooo0_l000000ooooooo0000ooooo`04
ooooo`05o`000?oooooo0000ooooool000000oooool01Ol0003oooooo`000?oooooo000000;ooooo
00?o0000ooooool000000ol00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`000?ooool01?ooool01Ol0003o
ooooo`000?oooooo000000?ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooo
000000?o00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool1o`00000000?o0000ooooooooool03oooool2o`000003ooooool0003o
oooo00Cooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo000000;o00000_oo
ool01?l0003oooooo`000?l00006ooooo`05o`000?oooooo0000ooooool000000_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Cooooo0_l000000ooooooo0000ooooo`04ooooo`05
o`000?oooooo0000ooooool000000oooool00ol0003oooooo`000002o`0000;ooooo00Co0000oooo
ool0003o00001_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`02ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooo
000000Oooooo1?l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l0
0004ooooo`Go000000?oooooo`000?l000002?ooool3o`0001Kooooo00?o0000ooooool000001ooo
ool4o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02o`0000Cooooo
1Ol000000ooooooo0000o`000008ooooo`?o00001?ooool1o`00000000?o0000ooooooooool03ooo
oolfo`0001Gooooo=_l00003ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool2
o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool2o`00
02[ooooo0_l0000gooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_o
oooo1?l0000Yooooo`;o0000=oooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Kooooo`Co0000:Oooool2o`0003Oooooo0Ol000000003o`000?oooooooooo00oooooo00?o
0000ooooooooool06_ooool5o`0002Wooooo0ol0000fooooo`7o000000000ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01[ooooo1Ol0000Yooooo`03o`000?oooooo000003Kooooo0Ol00000
0003o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool6o`0002Sooooo00?o0000oooo
ool00000=_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`Oo
0000:?ooool3o`0003Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0
6?ooool8o`0002Sooooo00?o0000ooooool00000=_ooool1o`00000000?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000Go0000:?ooool00ol0003oooooo`00
000fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo2_l0000W
ooooo`03o`000?oooooo000003Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooo
ooooool05oooool8o`000003ooooool0003ooooo02Kooooo0_l000000ooooooo0000ooooo`0doooo
o`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo0ol000001Ooooooo
0000o`000?l0003ooooo00;o00009oooool01?l0003oooooooooool0000eooooo`7o000000000ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo1Ol00002ooooo`?o00009oooool01?l0
003oooooooooool0000eooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Oooooo00Co0000oooooooooooooooo0ol000000ooooooo0000o`00000Wooooo`04o`000?oooooo
ooooo`0003Gooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool2
o`0000?ooooo00?o0000ooooooooool00_ooool2o`0002Kooooo0_l000000ooooooo0000ooooo`0d
ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ool000002Ol0000Vooooo`04o`000?ooooooooooo`0003Gooooo0Ol000000003o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`000003ooooool0003o
oooo01Oooooo0_l00002ooooo`Co000000Coooooo`000?l0003o00006Oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`?o000000Goooooo`000?ooooooooooo`00000eooooo`7o
000000001ol0003ooooooooooooooooo0000ooooool000002Oooool01?l0003oooooo`000?l0000F
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o00006?ooool00ol0003oooooo`000009
ooooo`06o`000?oooooo0000o`000?oooooo0000=Oooool1o`00000000Oo0000oooooooooooooooo
o`000?oooooo000000Oooooo0ol000000ooooooo0000ooooo`0Fooooo`03o`000?oooooo000000So
000000?oooooo`000?ooool05oooool00ol0003oooooo`000007ooooo`?o000000Goooooo`000?oo
ooooooooo`00000eooooo`7o000000001ol0003ooooooooooooooooo0000ooooool000001oooool0
1Ol0003ooooooooooooooooo000001Oooooo2ol000000ooooooo0000o`00000Gooooo`03o`000?oo
oooo000000Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo03?ooooo
0Ol000000003o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool3o`000003ooooool0
003ooooo01Gooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`?o00006?oo
ool00ol0003oooooooooo`06ooooo`?o000000Goooooo`000?ooooooooooo`00000eooooo`7o0000
00000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`02ooooo`?o00009Oooool2o`000003ooooool0003ooooo03Cooooo0Ol0
00000003o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool2o`000003ooooool0003o
000000;ooooo00?o0000ooooooooool00_l000000ooooooo0000o`00000Uooooo`04o`000?oooooo
ooooo`0003Gooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool2
o`000003ooooool0003o000000Ko00000_ooool2o`0002Gooooo00Co0000oooooooooooo0000=Ooo
ool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`?o00001?ooool0
1?l0003oooooooooooooool4o`0002Gooooo00Co0000oooooooooooo0000=Oooool1o`00000000?o
0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooo`00000Tooooo`;o0000=oooool1o`00000000?o0000
ooooooooool03oooool00ol0003oooooooooo`0Cooooo`04o`000?oooooo0000o`0000Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooo`000?l0000Tooooo`03o`000?oooooooooo03Kooooo
0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003o
ooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo
00Co0000oooooooooooooooo2?l00004ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0=_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooo000000;o00001?ooool01?l0003oooooooooooooool2o`000003ooooool0003o000002Co
oooo0_l0000gooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooool000001_ooool00ol0003oooooooooo`03ooooo`?o00009?ooool00ol0003ooooo
ooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo0_l0
00000ooooooo0000o`000004ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooool0003o0000
8oooool00ol0003oooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00002ooooo`;o00008oooool00ol0003oooooooooo`0fooooo`7o000000000ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool4o`000003ooooool0
003o000000Gooooo00?o0000ooooooooool08Oooool2o`0003Oooooo0Ol000000003o`000?oooooo
oooo00oooooo00?o0000ooooooooool04Oooool2o`0000?ooooo2_l00004ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0=_ooool1o`00000000?o0000ooooooooool02oooool3o`00
0003ooooool0003ooooo01;ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool2o`000004ooooool0003oooooo`0001kooooo0ol000000ooooooo0000ooooo`0g
ooooo`7o000000000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o00004_ooool2o`00
0003ooooool0003ooooo00Gooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003ooooo
01kooooo00?o0000ooooooooool00_l0000gooooo`7o000000000ol0003oooooooooo`0<ooooo`04
o`000?ooooooooooo`0001?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04oooo
o`;o000000?oooooo`000?ooool07_ooool01?l0003oooooooooool0000hooooo`7o000000000ol0
003oooooooooo`0<ooooo`04o`000?ooooooooooo`0001;ooooo00Co0000ooooool0003ooooo0_l0
0005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00007oooool01?l0003ooooooooo
ool0000hooooo`7o000000000ol0003oooooooooo`0;ooooo`;o00000_ooool00ol0003ooooooooo
o`0@ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1?ooool2o`0001kooooo0_l00002ooooo`03o`000?oooooooooo03Kooooo0Ol000000003o`000?oo
oooooooo00oooooo00?o0000ooooooooool04?ooool2o`0000Gooooo2?l00006ooooo`03o`000?oo
oooooooo023ooooo0_l0000gooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01Oooool6o`0000Oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo0_l00003ooooo`?o00000oooool00ol0003oooooooooo`03o`0000?ooooo00?o0000oooo
ool000008Oooool00ol0003oooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00ol00006ooooo`03o`000?oooooooooo00?o
oooo0_l000001?oooooo0000ooooool0000Qooooo`03o`000?oooooooooo03Kooooo0Ol000000003
o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000Pooooo`;o0000=oooool1
o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`05o`000?oooooo0000
ooooool000001oooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooo
ooooool03oooool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo03Kooooo0Ol000000003
o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00005ooooo`;o00008?ooool00ol0
003oooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool9o`0000Oooooo0_l0000Pooooo`;o0000=oooool1o`000000
00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`;o00002oooool00ol0003ooooo
ooooo`08ooooo`;o00008?ooool00ol0003oooooooooo`0fooooo`7o000000000ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`ko00001?ooool00ol0003oooooo`00
000Oooooo`03o`000?oooooooooo03Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000
ooooooooool03Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool2o`0000;ooooo00?o0000ooooool000007oooool00ol0003oooooooooo`0f
ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00Ko0000oooo
oooooooo0000ooooool00008ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooool0003ooooo
o`00000Oooooo`;o0000=oooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooooooo
o`0=ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`06ooooo`;o0000
0oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Kooooo0Ol000000003o`000?oo
oooooooo00oooooo00?o0000ooooooooool03Oooool01_l0003oooooo`000?l0003oooooo`0000So
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0=_ooool1o`00000000Co0000oooooooooooooooo0ol00003oooo
o`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool03_ooool2o`0000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000004?ooool3o`0000?ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000oooo
o`0gooooo`7o000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Co0000
ooooool0003o00003_ooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003ooooooooo
o`02ooooo`;o00001Oooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00Sooooo00Co
0000ooooool0003o0000=oooool1o`00000000?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`?o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`06ooooo`;o00000ooo
ool00ol0003oooooooooo`02o`0000Sooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`06ooooo`?o000000?oooooo`000?ooool0=oooool1o`00000000?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000003_ooool2o`0000[ooooo1_l0
000:ooooo`;o00004Oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
>?ooool1o`00000000Co0000oooooooooooooooo0_l00008ooooo`?o000000?oooooo`000?ooool0
3Oooool2o`0000gooooo00?o0000ooooooooool02_ooool2o`00013ooooo0_l00008ooooo`?o0000
00?oooooo`000?l00000=oooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooo000000Oooooo3Ol00005ooooo`04o`000?ooooooooooo`0001gooooo
00?o0000ooooooooool0=_ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooooooo
o`0;ooooo`04o`000?ooooooooooo`0000?ooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo03Ko
oooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool01?l0003ooooo
ooooooooool3o`0000Wooooo00?o0000ooooooooool01Oooool2o`0000;ooooo00Co0000oooooooo
oooo00007Oooool00ol0003oooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo
00Oooooo0_l00004ooooo`03o`000?oooooooooo01[ooooo0_l0000gooooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`0000[o
oooo00?o0000ooooooooool01oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0=_ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000002Oooool00ol0003ooooo
ooooo`06ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooool000001Oooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool0=_ooool1o`000000
00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`;o00002?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooo000001cooooo
0_l0000gooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo0_l0
0009ooooo`;o00001?ooool01?l0003oooooooooooooool2o`0000Wooooo0_l0000Looooo`03o`00
0?oooooooooo03Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`So00002oooool2o`0001cooooo00?o0000ooooooooool0=_oo
ool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`;o00003oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=_ooool1
o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0000
00oooooo00?o0000ooooooooool03?ooool2o`0001cooooo0_l0000gooooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool=o`00
00Wooooo00?o0000ooooool000006oooool00ol0003oooooooooo`0fooooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00001_ooool2o`00
00Oooooo00?o0000ooooooooool00oooool4o`0000Gooooo00Co0000oooooooooooo00006_ooool0
0ol0003oooooooooo`0fooooo`7o000000000ol0003oooooooooo`0;ooooo`?o000000?oooooo`00
0?ooool02Oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00009ooooo`03o`000?oooooo
oooo00Oooooo0_l00002ooooo`05o`000?ooooooooooooooool000005_ooool3o`000003ooooool0
003ooooo03Oooooo0Ol000000003o`000?oooooooooo00cooooo00?o0000ooooooooool00_l00009
ooooo`03o`000?oooooooooo00;ooooo0ol0000;ooooo`03o`000?oooooooooo00Wooooo0_l00004
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_l0000gooooo`7o000000000ol0
003oooooooooo`0=ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool3o`00
00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooool00000>?ooool1o`00000000?o0000ooooooooool03Oooool00ol0003o
ooooo`000009ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooo000003Sooooo0Ol000000003o`000?oooooooooo00_ooooo0ol000000ooooooo
0000ooooo`08ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo0_l00003ooooo`05o`000?ooooooooooooooool000005Oooool3
o`000003ooooool0003o000003Oooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool00006ooooo`;o00002?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00006Oooool00ol0003ooooooooo
o`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00008
ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool0=_ooool1o`00000000?o0000oooo
ooooool03oooool00ol0003oooooooooo`07ooooo`;o00002oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo0_l0000:ooooo`03o`000?oooooo000001Wooooo00?o0000oooo
ooooool0=_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`;o
00003?ooool;o`0000gooooo0_l0000Iooooo`;o0000=oooool1o`00000000?o0000ooooooooool0
3oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Kooooo0Ol000000003o`000?oo
oooooooo00oooooo00?o0000ooooooooool01oooool2o`0001;ooooo00?o0000ooooooooool03ooo
ool2o`0001Wooooo00?o0000ooooooooool0=_ooool1o`00000000?o0000ooooooooool03oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooo000001;ooooo00?o0000ooooooooool03oooool2
o`0001Wooooo00?o0000ooooooooool0=_ooool1o`00000000?o0000ooooooooool03oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooo000001;ooooo00?o0000ooooooooool03_ooool01?l0
003oooooooooool0000Hooooo`;o0000=oooool1o`00000000?o0000ooooooooool03oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`0>
ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool0=_ooool1o`00000000?o0000
ooooooooool03oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000004Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo03Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo0_l0000gooooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo03Kooooo0Ol000000003o`000?oooooooooo00oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0=_ooool1o`00000000Co0000oooooooooooooooo0ol00003ooooo`04o`00
0?ooooooooooooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool2o`0000Sooooo00?o0000oooooooo
ool01_ooool3o`0000?ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000ooooo`0goooo
o`7o000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Co0000ooooool0
003o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool01?l0003oooooo`000?l0000gooooo`7o000000000ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo0ol000000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo
00Sooooo0_l0000:ooooo`03o`000?oooooooooo00Kooooo0_l0000;ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool3o`000003ooooool0003ooooo03Oooooo0Ol000000003
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool02_ooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000003Sooooo0Ol000000004o`000?ooooooooooooooo`?o00001oooool3
o`000003ooooool0003ooooo00Gooooo00?o0000ooooooooool03?ooool3o`0000Gooooo00?o0000
ooooooooool00oooool2o`0000kooooo00?o0000ooooooooool01_ooool3o`0000Oooooo0ol00000
0ooooooo0000ooooo`0gooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03oooool;o`00013ooooo00?o0000ooooooooool05?ooool2o`00
03Oooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0=_ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Eooooo`;o0000=oooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo03Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0fooooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0=_ooool1o`00000000?o0000ooooooooool0
3oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Gooooo`;o0000=oooool1o`00000000?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Kooooo0Ol000000003o`000?oooooo
oooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0fooooo`7o000000000ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=_ooool1o`00
000000?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`;o0000=oooool1o`000000
00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0fooooo`7o000000000ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo03Kooooo0Ol000000003o`000?oooooooooo00_ooooo0ol00000
0ooooooo0000ooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool3
o`000003ooooool0003ooooo03Oooooo0Ol000000003o`000?oooooooooo00gooooo00Co0000oooo
ool0003o00003_ooool2o`0001Wooooo00?o0000ooooooooool06oooool01?l0003oooooo`000?l0
000gooooo`7o000000000ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`00017ooooo0_l0
000Eooooo`;o00007Oooool01?l0003oooooooooool0000hooooo`7o000000000ol0003ooooooooo
o`0=ooooo`03o`000?oooooo000001?ooooo0_l0000Aooooo`;o00008?ooool00ol0003oooooo`00
000hooooo`7o000000000ol0003oooooooooo`0;ooooo`?o000000?oooooo`000?ooool05?ooool2
o`0000_ooooo1?l0000Pooooo`?o000000?oooooo`000?ooool0=oooool1o`00000000?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Eooooo`_o0000:?ooool2o`0003Oooooo0Ol000000003
o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0fooooo`7o
000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
=_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo03Kooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo
09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo09?ooooo
0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol00000
0003o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003o`00
0?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooo
oooo09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo09?o
oooo0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol0
00000003o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003
o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003o`000?oo
oooooooo09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol000000003o`000?oooooooooo
09?ooooo0Ol000000003o`000?oooooooooo09?ooooo0Ol0000009Oo0000002Gooooo`00Uoooool0
09Oooooo0000\
\>"],
  ImageRangeCache->{{{0, 150.688}, {360.688, 0}} -> {-0.0517554, -0.170485, \
0.0139594, 0.0139594}, {{3.6875, 71.875}, {348.438, 188.312}} -> {-0.490954, \
-0.924058, 0.0261805, 0.0261805}, {{78.75, 146.938}, {348.438, 188.312}} -> \
{-2.45613, -0.924058, 0.0261805, 0.0261805}, {{3.6875, 71.875}, {172.312, \
12.1875}} -> {-0.490954, -5.53509, 0.0261805, 0.0261805}, {{78.75, 146.938}, \
{172.312, 12.1875}} -> {-2.45613, -5.53509, 0.0261805, 0.0261805}},
  CellTags->"5.3.5"]
}, Open  ]],

Cell["\<\
As you are using the inverse-system Nyquist array, the effect of \
additional feedback loop gains on the interaction present in the system can \
be assessed by superimposing the Ostrowski circles on the diagonal terms of \
the inverse-system Nyquist array.\
\>", "Text",
  CellTags->"5.3.5"],

Cell["\<\
As can be seen from the Ostrowski circles, further significant \
reduction in the interaction in both loops can be achieved by closing the \
loops, for example, with unity feedback.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NyquistArrayPlot[InverseSystem[fp], {0.001, 1}, 
        GershgorinCircles \[Rule] RowDominance, 
        OstrowskiCircleLoopGains \[Rule] {1, 1}];\)\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"5.3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.34701 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0558811 0.47619 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 2.34701 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 2.34701 L
s
0 2.34701 m
1 2.34701 L
s
1 0 m
1 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0558811 0.477324 1.12028 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.00112267 0.718224 0.0549004 0.718224 [
[.14477 .0424 -7.2 -7.2 ]
[.14477 .0424 7.2 0 ]
[.28841 .0424 -7.2 -7.2 ]
[.28841 .0424 7.2 0 ]
[.43206 .0424 -7.2 -7.2 ]
[.43206 .0424 7.2 0 ]
[.5757 .0424 -7.2 -7.2 ]
[.5757 .0424 7.2 0 ]
[.71935 .0424 -2.4 -7.2 ]
[.71935 .0424 2.4 0 ]
[.86299 .0424 -7.2 -7.2 ]
[.86299 .0424 7.2 0 ]
[-0.01138 .41401 -14.4 -3.6 ]
[-0.01138 .41401 0 3.6 ]
[-0.01138 .77312 -4.8 -3.6 ]
[-0.01138 .77312 0 3.6 ]
[-0.01138 1.13224 -14.4 -3.6 ]
[-0.01138 1.13224 0 3.6 ]
[-0.01138 1.49135 -4.8 -3.6 ]
[-0.01138 1.49135 0 3.6 ]
[-0.01138 1.85046 -14.4 -3.6 ]
[-0.01138 1.85046 0 3.6 ]
[-0.01138 2.20957 -4.8 -3.6 ]
[-0.01138 2.20957 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14477 .0549 m
.14477 .06115 L
s
[(0.2)] .14477 .0424 0 1 Mshowa
.28841 .0549 m
.28841 .06115 L
s
[(0.4)] .28841 .0424 0 1 Mshowa
.43206 .0549 m
.43206 .06115 L
s
[(0.6)] .43206 .0424 0 1 Mshowa
.5757 .0549 m
.5757 .06115 L
s
[(0.8)] .5757 .0424 0 1 Mshowa
.71935 .0549 m
.71935 .06115 L
s
[(1)] .71935 .0424 0 1 Mshowa
.86299 .0549 m
.86299 .06115 L
s
[(1.2)] .86299 .0424 0 1 Mshowa
.125 Mabswid
.03703 .0549 m
.03703 .05865 L
s
.07295 .0549 m
.07295 .05865 L
s
.10886 .0549 m
.10886 .05865 L
s
.18068 .0549 m
.18068 .05865 L
s
.21659 .0549 m
.21659 .05865 L
s
.2525 .0549 m
.2525 .05865 L
s
.32432 .0549 m
.32432 .05865 L
s
.36023 .0549 m
.36023 .05865 L
s
.39615 .0549 m
.39615 .05865 L
s
.46797 .0549 m
.46797 .05865 L
s
.50388 .0549 m
.50388 .05865 L
s
.53979 .0549 m
.53979 .05865 L
s
.61161 .0549 m
.61161 .05865 L
s
.64752 .0549 m
.64752 .05865 L
s
.68344 .0549 m
.68344 .05865 L
s
.75526 .0549 m
.75526 .05865 L
s
.79117 .0549 m
.79117 .05865 L
s
.82708 .0549 m
.82708 .05865 L
s
.8989 .0549 m
.8989 .05865 L
s
.93481 .0549 m
.93481 .05865 L
s
.97073 .0549 m
.97073 .05865 L
s
.25 Mabswid
0 .0549 m
1 .0549 L
s
.00112 .41401 m
.00737 .41401 L
s
[(0.5)] -0.01138 .41401 1 0 Mshowa
.00112 .77312 m
.00737 .77312 L
s
[(1)] -0.01138 .77312 1 0 Mshowa
.00112 1.13224 m
.00737 1.13224 L
s
[(1.5)] -0.01138 1.13224 1 0 Mshowa
.00112 1.49135 m
.00737 1.49135 L
s
[(2)] -0.01138 1.49135 1 0 Mshowa
.00112 1.85046 m
.00737 1.85046 L
s
[(2.5)] -0.01138 1.85046 1 0 Mshowa
.00112 2.20957 m
.00737 2.20957 L
s
[(3)] -0.01138 2.20957 1 0 Mshowa
.125 Mabswid
.00112 .12672 m
.00487 .12672 L
s
.00112 .19855 m
.00487 .19855 L
s
.00112 .27037 m
.00487 .27037 L
s
.00112 .34219 m
.00487 .34219 L
s
.00112 .48583 m
.00487 .48583 L
s
.00112 .55766 m
.00487 .55766 L
s
.00112 .62948 m
.00487 .62948 L
s
.00112 .7013 m
.00487 .7013 L
s
.00112 .84495 m
.00487 .84495 L
s
.00112 .91677 m
.00487 .91677 L
s
.00112 .98859 m
.00487 .98859 L
s
.00112 1.06041 m
.00487 1.06041 L
s
.00112 1.20406 m
.00487 1.20406 L
s
.00112 1.27588 m
.00487 1.27588 L
s
.00112 1.3477 m
.00487 1.3477 L
s
.00112 1.41953 m
.00487 1.41953 L
s
.00112 1.56317 m
.00487 1.56317 L
s
.00112 1.63499 m
.00487 1.63499 L
s
.00112 1.70682 m
.00487 1.70682 L
s
.00112 1.77864 m
.00487 1.77864 L
s
.00112 1.92228 m
.00487 1.92228 L
s
.00112 1.99411 m
.00487 1.99411 L
s
.00112 2.06593 m
.00487 2.06593 L
s
.00112 2.13775 m
.00487 2.13775 L
s
.00112 2.2814 m
.00487 2.2814 L
s
.25 Mabswid
.00112 0 m
.00112 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
.5 Mabswid
.00113 .05571 m
.00113 .05574 L
.00113 .05577 L
.00113 .0558 L
.00113 .05583 L
.00113 .05586 L
.00113 .05589 L
.00113 .05593 L
.00113 .05597 L
.00113 .056 L
.00113 .05604 L
.00113 .05608 L
.00113 .05613 L
.00113 .05617 L
.00113 .05621 L
.00113 .05626 L
.00113 .05631 L
.00113 .05636 L
.00113 .05641 L
.00113 .05646 L
.00113 .05652 L
.00113 .05657 L
.00113 .05663 L
.00113 .05669 L
.00114 .05676 L
.00114 .05682 L
.00114 .05689 L
.00114 .05696 L
.00114 .05703 L
.00114 .05711 L
.00114 .05719 L
.00114 .05727 L
.00114 .05735 L
.00115 .05744 L
.00115 .05753 L
.00115 .05762 L
.00115 .05772 L
.00115 .05782 L
.00116 .05792 L
.00116 .05803 L
.00116 .05814 L
.00116 .05825 L
.00117 .05837 L
.00117 .05849 L
.00117 .05862 L
.00118 .05875 L
.00118 .05889 L
.00118 .05903 L
.00119 .05917 L
.00119 .05932 L
Mistroke
.0012 .05948 L
.0012 .05964 L
.00121 .05981 L
.00122 .05998 L
.00122 .06016 L
.00123 .06034 L
.00124 .06054 L
.00125 .06074 L
.00125 .06094 L
.00126 .06115 L
.00127 .06137 L
.00129 .0616 L
.0013 .06184 L
.00131 .06208 L
.00132 .06233 L
.00134 .0626 L
.00135 .06287 L
.00137 .06315 L
.00139 .06344 L
.0014 .06374 L
.00142 .06405 L
.00145 .06437 L
.00147 .0647 L
.00149 .06505 L
.00152 .0654 L
.00155 .06577 L
.00158 .06615 L
.00161 .06654 L
.00165 .06695 L
.00168 .06737 L
.00172 .06781 L
.00177 .06826 L
.00181 .06873 L
.00186 .06921 L
.00191 .06971 L
.00197 .07022 L
.00203 .07075 L
.00209 .0713 L
.00216 .07187 L
.00223 .07246 L
.00231 .07307 L
.00239 .0737 L
.00248 .07435 L
.00258 .07501 L
.00268 .07571 L
.00278 .07642 L
.0029 .07716 L
.00302 .07792 L
.00315 .0787 L
.00329 .07951 L
Mistroke
.00344 .08035 L
.0036 .08121 L
.00376 .08209 L
.00394 .08301 L
.00413 .08395 L
.00433 .08492 L
.00454 .08592 L
.00477 .08695 L
.00501 .08801 L
.00526 .0891 L
.00553 .09022 L
.00582 .09137 L
.00612 .09255 L
.00643 .09376 L
.00677 .09501 L
.00712 .09629 L
.00749 .0976 L
.00788 .09894 L
.00828 .10032 L
.00871 .10173 L
.00916 .10318 L
.00963 .10466 L
.01012 .10617 L
.01063 .10772 L
.01116 .1093 L
.01171 .11092 L
.01228 .11257 L
.01287 .11426 L
.01349 .11598 L
.01412 .11773 L
.01477 .11952 L
.01544 .12135 L
.01612 .12322 L
.01683 .12512 L
.01755 .12705 L
.01828 .12903 L
.01902 .13105 L
.01978 .13311 L
.02054 .13521 L
.02131 .13735 L
.02209 .13955 L
.02288 .14179 L
.02366 .14408 L
.02445 .14642 L
.02523 .14882 L
.02602 .15128 L
.02679 .1538 L
.02757 .15639 L
.02833 .15904 L
.02908 .16177 L
Mistroke
.02982 .16458 L
.03055 .16748 L
.03127 .17046 L
.03197 .17353 L
.03265 .1767 L
.03332 .17998 L
.03397 .18336 L
.0346 .18686 L
.03521 .19048 L
.0358 .19423 L
.03637 .19811 L
.03692 .20213 L
.03745 .2063 L
.03796 .21062 L
.03845 .2151 L
.03892 .21975 L
.03937 .22457 L
.0398 .22957 L
.04021 .23477 L
.0406 .24016 L
.04097 .24575 L
.04132 .25156 L
.04166 .25759 L
.04198 .26384 L
.04228 .27034 L
.04256 .27708 L
.04284 .28408 L
.04309 .29135 L
.04333 .29888 L
.04356 .30671 L
.04378 .31483 L
.04398 .32325 L
.04417 .33199 L
.04436 .34106 L
.04453 .35047 L
.04469 .36023 L
.04484 .37035 L
.04498 .38085 L
.04511 .39173 L
.04524 .40302 L
.04535 .41473 L
.04546 .42686 L
.04557 .43944 L
.04566 .45248 L
.04575 .466 L
.04584 .48001 L
.04592 .49453 L
.04599 .50958 L
.04606 .52518 L
.04613 .54134 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0558811 0.97619 1.12028 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.00112267 0.718224 0.0549004 0.718224 [
[.14477 .0424 -7.2 -7.2 ]
[.14477 .0424 7.2 0 ]
[.28841 .0424 -7.2 -7.2 ]
[.28841 .0424 7.2 0 ]
[.43206 .0424 -7.2 -7.2 ]
[.43206 .0424 7.2 0 ]
[.5757 .0424 -7.2 -7.2 ]
[.5757 .0424 7.2 0 ]
[.71935 .0424 -2.4 -7.2 ]
[.71935 .0424 2.4 0 ]
[.86299 .0424 -7.2 -7.2 ]
[.86299 .0424 7.2 0 ]
[-0.01138 .41401 -14.4 -3.6 ]
[-0.01138 .41401 0 3.6 ]
[-0.01138 .77312 -4.8 -3.6 ]
[-0.01138 .77312 0 3.6 ]
[-0.01138 1.13224 -14.4 -3.6 ]
[-0.01138 1.13224 0 3.6 ]
[-0.01138 1.49135 -4.8 -3.6 ]
[-0.01138 1.49135 0 3.6 ]
[-0.01138 1.85046 -14.4 -3.6 ]
[-0.01138 1.85046 0 3.6 ]
[-0.01138 2.20957 -4.8 -3.6 ]
[-0.01138 2.20957 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14477 .0549 m
.14477 .06115 L
s
[(0.2)] .14477 .0424 0 1 Mshowa
.28841 .0549 m
.28841 .06115 L
s
[(0.4)] .28841 .0424 0 1 Mshowa
.43206 .0549 m
.43206 .06115 L
s
[(0.6)] .43206 .0424 0 1 Mshowa
.5757 .0549 m
.5757 .06115 L
s
[(0.8)] .5757 .0424 0 1 Mshowa
.71935 .0549 m
.71935 .06115 L
s
[(1)] .71935 .0424 0 1 Mshowa
.86299 .0549 m
.86299 .06115 L
s
[(1.2)] .86299 .0424 0 1 Mshowa
.125 Mabswid
.03703 .0549 m
.03703 .05865 L
s
.07295 .0549 m
.07295 .05865 L
s
.10886 .0549 m
.10886 .05865 L
s
.18068 .0549 m
.18068 .05865 L
s
.21659 .0549 m
.21659 .05865 L
s
.2525 .0549 m
.2525 .05865 L
s
.32432 .0549 m
.32432 .05865 L
s
.36023 .0549 m
.36023 .05865 L
s
.39615 .0549 m
.39615 .05865 L
s
.46797 .0549 m
.46797 .05865 L
s
.50388 .0549 m
.50388 .05865 L
s
.53979 .0549 m
.53979 .05865 L
s
.61161 .0549 m
.61161 .05865 L
s
.64752 .0549 m
.64752 .05865 L
s
.68344 .0549 m
.68344 .05865 L
s
.75526 .0549 m
.75526 .05865 L
s
.79117 .0549 m
.79117 .05865 L
s
.82708 .0549 m
.82708 .05865 L
s
.8989 .0549 m
.8989 .05865 L
s
.93481 .0549 m
.93481 .05865 L
s
.97073 .0549 m
.97073 .05865 L
s
.25 Mabswid
0 .0549 m
1 .0549 L
s
.00112 .41401 m
.00737 .41401 L
s
[(0.5)] -0.01138 .41401 1 0 Mshowa
.00112 .77312 m
.00737 .77312 L
s
[(1)] -0.01138 .77312 1 0 Mshowa
.00112 1.13224 m
.00737 1.13224 L
s
[(1.5)] -0.01138 1.13224 1 0 Mshowa
.00112 1.49135 m
.00737 1.49135 L
s
[(2)] -0.01138 1.49135 1 0 Mshowa
.00112 1.85046 m
.00737 1.85046 L
s
[(2.5)] -0.01138 1.85046 1 0 Mshowa
.00112 2.20957 m
.00737 2.20957 L
s
[(3)] -0.01138 2.20957 1 0 Mshowa
.125 Mabswid
.00112 .12672 m
.00487 .12672 L
s
.00112 .19855 m
.00487 .19855 L
s
.00112 .27037 m
.00487 .27037 L
s
.00112 .34219 m
.00487 .34219 L
s
.00112 .48583 m
.00487 .48583 L
s
.00112 .55766 m
.00487 .55766 L
s
.00112 .62948 m
.00487 .62948 L
s
.00112 .7013 m
.00487 .7013 L
s
.00112 .84495 m
.00487 .84495 L
s
.00112 .91677 m
.00487 .91677 L
s
.00112 .98859 m
.00487 .98859 L
s
.00112 1.06041 m
.00487 1.06041 L
s
.00112 1.20406 m
.00487 1.20406 L
s
.00112 1.27588 m
.00487 1.27588 L
s
.00112 1.3477 m
.00487 1.3477 L
s
.00112 1.41953 m
.00487 1.41953 L
s
.00112 1.56317 m
.00487 1.56317 L
s
.00112 1.63499 m
.00487 1.63499 L
s
.00112 1.70682 m
.00487 1.70682 L
s
.00112 1.77864 m
.00487 1.77864 L
s
.00112 1.92228 m
.00487 1.92228 L
s
.00112 1.99411 m
.00487 1.99411 L
s
.00112 2.06593 m
.00487 2.06593 L
s
.00112 2.13775 m
.00487 2.13775 L
s
.00112 2.2814 m
.00487 2.2814 L
s
.25 Mabswid
.00112 0 m
.00112 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
.5 Mabswid
.58951 .05669 m
.58951 .05675 L
.58951 .05682 L
.58951 .05688 L
.58951 .05696 L
.58951 .05703 L
.58951 .0571 L
.58951 .05718 L
.58951 .05726 L
.58951 .05734 L
.58951 .05743 L
.58951 .05752 L
.58951 .05761 L
.58951 .05771 L
.58951 .05781 L
.58951 .05791 L
.58951 .05802 L
.58951 .05813 L
.58951 .05824 L
.58951 .05836 L
.58951 .05848 L
.58951 .05861 L
.5895 .05874 L
.5895 .05887 L
.5895 .05901 L
.5895 .05916 L
.5895 .05931 L
.5895 .05947 L
.5895 .05963 L
.5895 .05979 L
.5895 .05997 L
.5895 .06015 L
.58949 .06033 L
.58949 .06052 L
.58949 .06072 L
.58949 .06093 L
.58949 .06114 L
.58949 .06136 L
.58948 .06159 L
.58948 .06183 L
.58948 .06207 L
.58948 .06232 L
.58947 .06259 L
.58947 .06286 L
.58947 .06314 L
.58946 .06343 L
.58946 .06373 L
.58946 .06404 L
.58945 .06437 L
.58945 .0647 L
Mistroke
.58944 .06505 L
.58944 .06541 L
.58943 .06578 L
.58943 .06616 L
.58942 .06656 L
.58941 .06697 L
.58941 .0674 L
.5894 .06784 L
.58939 .0683 L
.58938 .06877 L
.58937 .06926 L
.58936 .06977 L
.58935 .0703 L
.58934 .07084 L
.58933 .0714 L
.58931 .07199 L
.5893 .07259 L
.58928 .07322 L
.58927 .07387 L
.58925 .07454 L
.58923 .07523 L
.58921 .07595 L
.58919 .0767 L
.58917 .07747 L
.58914 .07827 L
.58911 .0791 L
.58909 .07996 L
.58906 .08085 L
.58902 .08177 L
.58899 .08272 L
.58895 .08371 L
.58891 .08473 L
.58887 .08579 L
.58882 .08688 L
.58877 .08802 L
.58872 .0892 L
.58866 .09042 L
.5886 .09168 L
.58854 .09299 L
.58847 .09435 L
.5884 .09575 L
.58832 .09721 L
.58824 .09872 L
.58815 .10028 L
.58806 .1019 L
.58796 .10359 L
.58785 .10533 L
.58773 .10713 L
.58761 .10901 L
.58748 .11095 L
Mistroke
.58734 .11296 L
.5872 .11505 L
.58704 .11721 L
.58687 .11946 L
.5867 .12178 L
.58651 .1242 L
.58631 .12671 L
.5861 .12931 L
.58588 .13201 L
.58564 .13481 L
.58539 .13771 L
.58512 .14073 L
.58485 .14386 L
.58455 .14712 L
.58424 .1505 L
.58391 .154 L
.58357 .15765 L
.58321 .16143 L
.58283 .16536 L
.58244 .16945 L
.58202 .17369 L
.58159 .1781 L
.58114 .18269 L
.58067 .18745 L
.58018 .1924 L
.57967 .19755 L
.57915 .2029 L
.57861 .20846 L
.57805 .21424 L
.57747 .22025 L
.57688 .22649 L
.57627 .23298 L
.57565 .23972 L
.57501 .24673 L
.57436 .25402 L
.5737 .26159 L
.57304 .26945 L
.57236 .27761 L
.57168 .2861 L
.57099 .29491 L
.5703 .30405 L
.56961 .31355 L
.56892 .3234 L
.56823 .33363 L
.56754 .34424 L
.56686 .35524 L
.56619 .36666 L
.56553 .37849 L
.56487 .39077 L
.56423 .40349 L
Mistroke
.5636 .41667 L
.56299 .43033 L
.56239 .44448 L
.5618 .45914 L
.56124 .47433 L
.56069 .49005 L
.56016 .50633 L
.55964 .52319 L
.55915 .54064 L
.55867 .55871 L
.55822 .57741 L
.55778 .59677 L
.55736 .6168 L
.55696 .63753 L
.55658 .65898 L
.55622 .68118 L
.55588 .70415 L
.55555 .72792 L
.55524 .75251 L
.55494 .77796 L
.55466 .8043 L
.5544 .83155 L
.55415 .85974 L
.55391 .88892 L
.55369 .91911 L
.55348 .95035 L
.55329 .98267 L
.5531 1.01612 L
.55293 1.05074 L
.55276 1.08656 L
.55261 1.12363 L
.55246 1.16199 L
.55233 1.20169 L
.5522 1.24277 L
.55208 1.28529 L
.55197 1.3293 L
.55186 1.37484 L
.55176 1.42198 L
.55167 1.47077 L
.55158 1.52127 L
.5515 1.57353 L
.55143 1.62763 L
.55136 1.68362 L
.55129 1.74158 L
.55123 1.80157 L
.55117 1.86367 L
.55112 1.92795 L
.55107 1.99448 L
.55102 2.06336 L
.55097 2.13465 L
Mistroke
Mfstroke
newpath
.58951 .05669 .00081 0 365.73 arc
s
newpath
.58951 .05703 .00096 0 365.73 arc
s
newpath
.58951 .05743 .00114 0 365.73 arc
s
newpath
.58951 .05791 .00136 0 365.73 arc
s
newpath
.58951 .05848 .00162 0 365.73 arc
s
newpath
.5895 .05916 .00192 0 365.73 arc
s
newpath
.5895 .05997 .00229 0 365.73 arc
s
newpath
.58949 .06093 .00272 0 365.73 arc
s
newpath
.58948 .06207 .00324 0 365.73 arc
s
newpath
.58946 .06343 .00385 0 365.73 arc
s
newpath
.58944 .06505 .00458 0 365.73 arc
s
newpath
.58941 .06697 .00545 0 365.73 arc
s
newpath
.58937 .06926 .00648 0 365.73 arc
s
newpath
.58931 .07199 .0077 0 365.73 arc
s
newpath
.58923 .07523 .00915 0 365.73 arc
s
newpath
.58911 .0791 .01088 0 365.73 arc
s
newpath
.58895 .08371 .01292 0 365.73 arc
s
newpath
.58872 .0892 .01534 0 365.73 arc
s
newpath
.5884 .09575 .01821 0 365.73 arc
s
newpath
.58796 .10359 .02158 0 365.73 arc
s
newpath
.58734 .11296 .02555 0 365.73 arc
s
newpath
.58651 .1242 .03019 0 365.73 arc
s
newpath
.58539 .13771 .03559 0 365.73 arc
s
newpath
.58391 .154 .04182 0 365.73 arc
s
newpath
.58202 .17369 .04894 0 365.73 arc
s
newpath
.57967 .19755 .05701 0 365.73 arc
s
newpath
.57688 .22649 .06605 0 365.73 arc
s
newpath
.5737 .26159 .07609 0 365.73 arc
s
newpath
.5703 .30405 .0872 0 365.73 arc
s
newpath
.56686 .35524 .09954 0 365.73 arc
s
newpath
.5636 .41667 .11338 0 365.73 arc
s
newpath
.56069 .49005 .12916 0 365.73 arc
s
newpath
.55822 .57741 .14749 0 365.73 arc
s
newpath
.55622 .68118 .16913 0 365.73 arc
s
newpath
.55466 .8043 .19497 0 365.73 arc
s
newpath
.55348 .95035 .22601 0 365.73 arc
s
newpath
.55261 1.12363 .2634 0 365.73 arc
s
newpath
.55197 1.3293 .30842 0 365.73 arc
s
newpath
.5515 1.57353 .36253 0 365.73 arc
s
newpath
.55117 1.86367 .42746 0 365.73 arc
s
newpath
.58951 .05669 0 0 365.73 arc
s
newpath
.58951 .05703 0 0 365.73 arc
s
newpath
.58951 .05743 0 0 365.73 arc
s
newpath
.58951 .05791 0 0 365.73 arc
s
newpath
.58951 .05848 0 0 365.73 arc
s
newpath
.5895 .05916 0 0 365.73 arc
s
newpath
.5895 .05997 0 0 365.73 arc
s
newpath
.58949 .06093 1e-05 0 365.73 arc
s
newpath
.58948 .06207 1e-05 0 365.73 arc
s
newpath
.58946 .06343 1e-05 0 365.73 arc
s
newpath
.58944 .06505 2e-05 0 365.73 arc
s
newpath
.58941 .06697 2e-05 0 365.73 arc
s
newpath
.58937 .06926 3e-05 0 365.73 arc
s
newpath
.58931 .07199 5e-05 0 365.73 arc
s
newpath
.58923 .07523 6e-05 0 365.73 arc
s
newpath
.58911 .0791 9e-05 0 365.73 arc
s
newpath
.58895 .08371 .00013 0 365.73 arc
s
newpath
.58872 .0892 .00018 0 365.73 arc
s
newpath
.5884 .09575 .00025 0 365.73 arc
s
newpath
.58796 .10359 .00036 0 365.73 arc
s
newpath
.58734 .11296 .0005 0 365.73 arc
s
newpath
.58651 .1242 .0007 0 365.73 arc
s
newpath
.58539 .13771 .00097 0 365.73 arc
s
newpath
.58391 .154 .00134 0 365.73 arc
s
newpath
.58202 .17369 .00184 0 365.73 arc
s
newpath
.57967 .19755 .00249 0 365.73 arc
s
newpath
.57688 .22649 .00334 0 365.73 arc
s
newpath
.5737 .26159 .00443 0 365.73 arc
s
newpath
.5703 .30405 .0058 0 365.73 arc
s
newpath
.56686 .35524 .00751 0 365.73 arc
s
newpath
.5636 .41667 .00966 0 365.73 arc
s
newpath
.56069 .49005 .01236 0 365.73 arc
s
newpath
.55822 .57741 .01578 0 365.73 arc
s
newpath
.55622 .68118 .02016 0 365.73 arc
s
newpath
.55466 .8043 .02575 0 365.73 arc
s
newpath
.55348 .95035 .03286 0 365.73 arc
s
newpath
.55261 1.12363 .04181 0 365.73 arc
s
newpath
.55197 1.3293 .05289 0 365.73 arc
s
newpath
.5515 1.57353 .06642 0 365.73 arc
s
newpath
.55117 1.86367 .08271 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.22672 0.477324 2.29113 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.00112267 0.718224 0.0549004 0.718224 [
[.14477 .0424 -7.2 -7.2 ]
[.14477 .0424 7.2 0 ]
[.28841 .0424 -7.2 -7.2 ]
[.28841 .0424 7.2 0 ]
[.43206 .0424 -7.2 -7.2 ]
[.43206 .0424 7.2 0 ]
[.5757 .0424 -7.2 -7.2 ]
[.5757 .0424 7.2 0 ]
[.71935 .0424 -2.4 -7.2 ]
[.71935 .0424 2.4 0 ]
[.86299 .0424 -7.2 -7.2 ]
[.86299 .0424 7.2 0 ]
[-0.01138 .41401 -14.4 -3.6 ]
[-0.01138 .41401 0 3.6 ]
[-0.01138 .77312 -4.8 -3.6 ]
[-0.01138 .77312 0 3.6 ]
[-0.01138 1.13224 -14.4 -3.6 ]
[-0.01138 1.13224 0 3.6 ]
[-0.01138 1.49135 -4.8 -3.6 ]
[-0.01138 1.49135 0 3.6 ]
[-0.01138 1.85046 -14.4 -3.6 ]
[-0.01138 1.85046 0 3.6 ]
[-0.01138 2.20957 -4.8 -3.6 ]
[-0.01138 2.20957 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14477 .0549 m
.14477 .06115 L
s
[(0.2)] .14477 .0424 0 1 Mshowa
.28841 .0549 m
.28841 .06115 L
s
[(0.4)] .28841 .0424 0 1 Mshowa
.43206 .0549 m
.43206 .06115 L
s
[(0.6)] .43206 .0424 0 1 Mshowa
.5757 .0549 m
.5757 .06115 L
s
[(0.8)] .5757 .0424 0 1 Mshowa
.71935 .0549 m
.71935 .06115 L
s
[(1)] .71935 .0424 0 1 Mshowa
.86299 .0549 m
.86299 .06115 L
s
[(1.2)] .86299 .0424 0 1 Mshowa
.125 Mabswid
.03703 .0549 m
.03703 .05865 L
s
.07295 .0549 m
.07295 .05865 L
s
.10886 .0549 m
.10886 .05865 L
s
.18068 .0549 m
.18068 .05865 L
s
.21659 .0549 m
.21659 .05865 L
s
.2525 .0549 m
.2525 .05865 L
s
.32432 .0549 m
.32432 .05865 L
s
.36023 .0549 m
.36023 .05865 L
s
.39615 .0549 m
.39615 .05865 L
s
.46797 .0549 m
.46797 .05865 L
s
.50388 .0549 m
.50388 .05865 L
s
.53979 .0549 m
.53979 .05865 L
s
.61161 .0549 m
.61161 .05865 L
s
.64752 .0549 m
.64752 .05865 L
s
.68344 .0549 m
.68344 .05865 L
s
.75526 .0549 m
.75526 .05865 L
s
.79117 .0549 m
.79117 .05865 L
s
.82708 .0549 m
.82708 .05865 L
s
.8989 .0549 m
.8989 .05865 L
s
.93481 .0549 m
.93481 .05865 L
s
.97073 .0549 m
.97073 .05865 L
s
.25 Mabswid
0 .0549 m
1 .0549 L
s
.00112 .41401 m
.00737 .41401 L
s
[(0.5)] -0.01138 .41401 1 0 Mshowa
.00112 .77312 m
.00737 .77312 L
s
[(1)] -0.01138 .77312 1 0 Mshowa
.00112 1.13224 m
.00737 1.13224 L
s
[(1.5)] -0.01138 1.13224 1 0 Mshowa
.00112 1.49135 m
.00737 1.49135 L
s
[(2)] -0.01138 1.49135 1 0 Mshowa
.00112 1.85046 m
.00737 1.85046 L
s
[(2.5)] -0.01138 1.85046 1 0 Mshowa
.00112 2.20957 m
.00737 2.20957 L
s
[(3)] -0.01138 2.20957 1 0 Mshowa
.125 Mabswid
.00112 .12672 m
.00487 .12672 L
s
.00112 .19855 m
.00487 .19855 L
s
.00112 .27037 m
.00487 .27037 L
s
.00112 .34219 m
.00487 .34219 L
s
.00112 .48583 m
.00487 .48583 L
s
.00112 .55766 m
.00487 .55766 L
s
.00112 .62948 m
.00487 .62948 L
s
.00112 .7013 m
.00487 .7013 L
s
.00112 .84495 m
.00487 .84495 L
s
.00112 .91677 m
.00487 .91677 L
s
.00112 .98859 m
.00487 .98859 L
s
.00112 1.06041 m
.00487 1.06041 L
s
.00112 1.20406 m
.00487 1.20406 L
s
.00112 1.27588 m
.00487 1.27588 L
s
.00112 1.3477 m
.00487 1.3477 L
s
.00112 1.41953 m
.00487 1.41953 L
s
.00112 1.56317 m
.00487 1.56317 L
s
.00112 1.63499 m
.00487 1.63499 L
s
.00112 1.70682 m
.00487 1.70682 L
s
.00112 1.77864 m
.00487 1.77864 L
s
.00112 1.92228 m
.00487 1.92228 L
s
.00112 1.99411 m
.00487 1.99411 L
s
.00112 2.06593 m
.00487 2.06593 L
s
.00112 2.13775 m
.00487 2.13775 L
s
.00112 2.2814 m
.00487 2.2814 L
s
.25 Mabswid
.00112 0 m
.00112 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
.5 Mabswid
.58951 .05669 m
.58951 .05675 L
.58951 .05682 L
.58951 .05688 L
.58951 .05696 L
.58951 .05703 L
.58951 .0571 L
.58951 .05718 L
.58951 .05726 L
.58951 .05734 L
.58951 .05743 L
.58951 .05752 L
.58951 .05761 L
.58951 .05771 L
.58951 .05781 L
.58951 .05791 L
.58951 .05802 L
.58951 .05813 L
.58951 .05824 L
.58951 .05836 L
.58951 .05848 L
.58951 .05861 L
.5895 .05874 L
.5895 .05887 L
.5895 .05901 L
.5895 .05916 L
.5895 .05931 L
.5895 .05947 L
.5895 .05963 L
.5895 .05979 L
.5895 .05997 L
.5895 .06015 L
.58949 .06033 L
.58949 .06052 L
.58949 .06072 L
.58949 .06093 L
.58949 .06114 L
.58949 .06136 L
.58948 .06159 L
.58948 .06183 L
.58948 .06207 L
.58948 .06232 L
.58947 .06259 L
.58947 .06286 L
.58947 .06314 L
.58946 .06343 L
.58946 .06373 L
.58946 .06404 L
.58945 .06437 L
.58945 .0647 L
Mistroke
.58944 .06505 L
.58944 .06541 L
.58943 .06578 L
.58943 .06616 L
.58942 .06656 L
.58941 .06697 L
.58941 .0674 L
.5894 .06784 L
.58939 .0683 L
.58938 .06877 L
.58937 .06926 L
.58936 .06977 L
.58935 .0703 L
.58934 .07084 L
.58933 .0714 L
.58931 .07199 L
.5893 .07259 L
.58928 .07322 L
.58927 .07387 L
.58925 .07454 L
.58923 .07523 L
.58921 .07595 L
.58919 .0767 L
.58917 .07747 L
.58914 .07827 L
.58911 .0791 L
.58909 .07996 L
.58906 .08085 L
.58902 .08177 L
.58899 .08272 L
.58895 .08371 L
.58891 .08473 L
.58887 .08579 L
.58882 .08688 L
.58877 .08802 L
.58872 .0892 L
.58866 .09042 L
.5886 .09168 L
.58854 .09299 L
.58847 .09435 L
.5884 .09575 L
.58832 .09721 L
.58824 .09872 L
.58815 .10028 L
.58806 .1019 L
.58796 .10359 L
.58785 .10533 L
.58773 .10713 L
.58761 .10901 L
.58748 .11095 L
Mistroke
.58734 .11296 L
.5872 .11505 L
.58704 .11721 L
.58687 .11946 L
.5867 .12178 L
.58651 .1242 L
.58631 .12671 L
.5861 .12931 L
.58588 .13201 L
.58564 .13481 L
.58539 .13771 L
.58512 .14073 L
.58485 .14386 L
.58455 .14712 L
.58424 .1505 L
.58391 .154 L
.58357 .15765 L
.58321 .16143 L
.58283 .16536 L
.58244 .16945 L
.58202 .17369 L
.58159 .1781 L
.58114 .18269 L
.58067 .18745 L
.58018 .1924 L
.57967 .19755 L
.57915 .2029 L
.57861 .20846 L
.57805 .21424 L
.57747 .22025 L
.57688 .22649 L
.57627 .23298 L
.57565 .23972 L
.57501 .24673 L
.57436 .25402 L
.5737 .26159 L
.57304 .26945 L
.57236 .27761 L
.57168 .2861 L
.57099 .29491 L
.5703 .30405 L
.56961 .31355 L
.56892 .3234 L
.56823 .33363 L
.56754 .34424 L
.56686 .35524 L
.56619 .36666 L
.56553 .37849 L
.56487 .39077 L
.56423 .40349 L
Mistroke
.5636 .41667 L
.56299 .43033 L
.56239 .44448 L
.5618 .45914 L
.56124 .47433 L
.56069 .49005 L
.56016 .50633 L
.55964 .52319 L
.55915 .54064 L
.55867 .55871 L
.55822 .57741 L
.55778 .59677 L
.55736 .6168 L
.55696 .63753 L
.55658 .65898 L
.55622 .68118 L
.55588 .70415 L
.55555 .72792 L
.55524 .75251 L
.55494 .77796 L
.55466 .8043 L
.5544 .83155 L
.55415 .85974 L
.55391 .88892 L
.55369 .91911 L
.55348 .95035 L
.55329 .98267 L
.5531 1.01612 L
.55293 1.05074 L
.55276 1.08656 L
.55261 1.12363 L
.55246 1.16199 L
.55233 1.20169 L
.5522 1.24277 L
.55208 1.28529 L
.55197 1.3293 L
.55186 1.37484 L
.55176 1.42198 L
.55167 1.47077 L
.55158 1.52127 L
.5515 1.57353 L
.55143 1.62763 L
.55136 1.68362 L
.55129 1.74158 L
.55123 1.80157 L
.55117 1.86367 L
.55112 1.92795 L
.55107 1.99448 L
.55102 2.06336 L
.55097 2.13465 L
Mistroke
Mfstroke
newpath
.58951 .05669 .00081 0 365.73 arc
s
newpath
.58951 .05703 .00096 0 365.73 arc
s
newpath
.58951 .05743 .00114 0 365.73 arc
s
newpath
.58951 .05791 .00136 0 365.73 arc
s
newpath
.58951 .05848 .00162 0 365.73 arc
s
newpath
.5895 .05916 .00192 0 365.73 arc
s
newpath
.5895 .05997 .00229 0 365.73 arc
s
newpath
.58949 .06093 .00272 0 365.73 arc
s
newpath
.58948 .06207 .00324 0 365.73 arc
s
newpath
.58946 .06343 .00385 0 365.73 arc
s
newpath
.58944 .06505 .00458 0 365.73 arc
s
newpath
.58941 .06697 .00545 0 365.73 arc
s
newpath
.58937 .06926 .00648 0 365.73 arc
s
newpath
.58931 .07199 .0077 0 365.73 arc
s
newpath
.58923 .07523 .00915 0 365.73 arc
s
newpath
.58911 .0791 .01088 0 365.73 arc
s
newpath
.58895 .08371 .01292 0 365.73 arc
s
newpath
.58872 .0892 .01534 0 365.73 arc
s
newpath
.5884 .09575 .01821 0 365.73 arc
s
newpath
.58796 .10359 .02158 0 365.73 arc
s
newpath
.58734 .11296 .02555 0 365.73 arc
s
newpath
.58651 .1242 .03019 0 365.73 arc
s
newpath
.58539 .13771 .03559 0 365.73 arc
s
newpath
.58391 .154 .04182 0 365.73 arc
s
newpath
.58202 .17369 .04894 0 365.73 arc
s
newpath
.57967 .19755 .05701 0 365.73 arc
s
newpath
.57688 .22649 .06605 0 365.73 arc
s
newpath
.5737 .26159 .07609 0 365.73 arc
s
newpath
.5703 .30405 .0872 0 365.73 arc
s
newpath
.56686 .35524 .09954 0 365.73 arc
s
newpath
.5636 .41667 .11338 0 365.73 arc
s
newpath
.56069 .49005 .12916 0 365.73 arc
s
newpath
.55822 .57741 .14749 0 365.73 arc
s
newpath
.55622 .68118 .16913 0 365.73 arc
s
newpath
.55466 .8043 .19497 0 365.73 arc
s
newpath
.55348 .95035 .22601 0 365.73 arc
s
newpath
.55261 1.12363 .2634 0 365.73 arc
s
newpath
.55197 1.3293 .30842 0 365.73 arc
s
newpath
.5515 1.57353 .36253 0 365.73 arc
s
newpath
.55117 1.86367 .42746 0 365.73 arc
s
newpath
.58951 .05669 0 0 365.73 arc
s
newpath
.58951 .05703 0 0 365.73 arc
s
newpath
.58951 .05743 0 0 365.73 arc
s
newpath
.58951 .05791 0 0 365.73 arc
s
newpath
.58951 .05848 0 0 365.73 arc
s
newpath
.5895 .05916 0 0 365.73 arc
s
newpath
.5895 .05997 0 0 365.73 arc
s
newpath
.58949 .06093 1e-05 0 365.73 arc
s
newpath
.58948 .06207 1e-05 0 365.73 arc
s
newpath
.58946 .06343 1e-05 0 365.73 arc
s
newpath
.58944 .06505 2e-05 0 365.73 arc
s
newpath
.58941 .06697 2e-05 0 365.73 arc
s
newpath
.58937 .06926 3e-05 0 365.73 arc
s
newpath
.58931 .07199 5e-05 0 365.73 arc
s
newpath
.58923 .07523 6e-05 0 365.73 arc
s
newpath
.58911 .0791 9e-05 0 365.73 arc
s
newpath
.58895 .08371 .00013 0 365.73 arc
s
newpath
.58872 .0892 .00018 0 365.73 arc
s
newpath
.5884 .09575 .00025 0 365.73 arc
s
newpath
.58796 .10359 .00036 0 365.73 arc
s
newpath
.58734 .11296 .0005 0 365.73 arc
s
newpath
.58651 .1242 .0007 0 365.73 arc
s
newpath
.58539 .13771 .00097 0 365.73 arc
s
newpath
.58391 .154 .00134 0 365.73 arc
s
newpath
.58202 .17369 .00184 0 365.73 arc
s
newpath
.57967 .19755 .00249 0 365.73 arc
s
newpath
.57688 .22649 .00334 0 365.73 arc
s
newpath
.5737 .26159 .00443 0 365.73 arc
s
newpath
.5703 .30405 .0058 0 365.73 arc
s
newpath
.56686 .35524 .00751 0 365.73 arc
s
newpath
.5636 .41667 .00966 0 365.73 arc
s
newpath
.56069 .49005 .01236 0 365.73 arc
s
newpath
.55822 .57741 .01578 0 365.73 arc
s
newpath
.55622 .68118 .02016 0 365.73 arc
s
newpath
.55466 .8043 .02575 0 365.73 arc
s
newpath
.55348 .95035 .03286 0 365.73 arc
s
newpath
.55261 1.12363 .04181 0 365.73 arc
s
newpath
.55197 1.3293 .05289 0 365.73 arc
s
newpath
.5515 1.57353 .06642 0 365.73 arc
s
newpath
.55117 1.86367 .08271 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 1.22672 0.97619 2.29113 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.00112267 0.718224 0.0549004 0.718224 [
[.14477 .0424 -7.2 -7.2 ]
[.14477 .0424 7.2 0 ]
[.28841 .0424 -7.2 -7.2 ]
[.28841 .0424 7.2 0 ]
[.43206 .0424 -7.2 -7.2 ]
[.43206 .0424 7.2 0 ]
[.5757 .0424 -7.2 -7.2 ]
[.5757 .0424 7.2 0 ]
[.71935 .0424 -2.4 -7.2 ]
[.71935 .0424 2.4 0 ]
[.86299 .0424 -7.2 -7.2 ]
[.86299 .0424 7.2 0 ]
[-0.01138 .41401 -14.4 -3.6 ]
[-0.01138 .41401 0 3.6 ]
[-0.01138 .77312 -4.8 -3.6 ]
[-0.01138 .77312 0 3.6 ]
[-0.01138 1.13224 -14.4 -3.6 ]
[-0.01138 1.13224 0 3.6 ]
[-0.01138 1.49135 -4.8 -3.6 ]
[-0.01138 1.49135 0 3.6 ]
[-0.01138 1.85046 -14.4 -3.6 ]
[-0.01138 1.85046 0 3.6 ]
[-0.01138 2.20957 -4.8 -3.6 ]
[-0.01138 2.20957 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.34701 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14477 .0549 m
.14477 .06115 L
s
[(0.2)] .14477 .0424 0 1 Mshowa
.28841 .0549 m
.28841 .06115 L
s
[(0.4)] .28841 .0424 0 1 Mshowa
.43206 .0549 m
.43206 .06115 L
s
[(0.6)] .43206 .0424 0 1 Mshowa
.5757 .0549 m
.5757 .06115 L
s
[(0.8)] .5757 .0424 0 1 Mshowa
.71935 .0549 m
.71935 .06115 L
s
[(1)] .71935 .0424 0 1 Mshowa
.86299 .0549 m
.86299 .06115 L
s
[(1.2)] .86299 .0424 0 1 Mshowa
.125 Mabswid
.03703 .0549 m
.03703 .05865 L
s
.07295 .0549 m
.07295 .05865 L
s
.10886 .0549 m
.10886 .05865 L
s
.18068 .0549 m
.18068 .05865 L
s
.21659 .0549 m
.21659 .05865 L
s
.2525 .0549 m
.2525 .05865 L
s
.32432 .0549 m
.32432 .05865 L
s
.36023 .0549 m
.36023 .05865 L
s
.39615 .0549 m
.39615 .05865 L
s
.46797 .0549 m
.46797 .05865 L
s
.50388 .0549 m
.50388 .05865 L
s
.53979 .0549 m
.53979 .05865 L
s
.61161 .0549 m
.61161 .05865 L
s
.64752 .0549 m
.64752 .05865 L
s
.68344 .0549 m
.68344 .05865 L
s
.75526 .0549 m
.75526 .05865 L
s
.79117 .0549 m
.79117 .05865 L
s
.82708 .0549 m
.82708 .05865 L
s
.8989 .0549 m
.8989 .05865 L
s
.93481 .0549 m
.93481 .05865 L
s
.97073 .0549 m
.97073 .05865 L
s
.25 Mabswid
0 .0549 m
1 .0549 L
s
.00112 .41401 m
.00737 .41401 L
s
[(0.5)] -0.01138 .41401 1 0 Mshowa
.00112 .77312 m
.00737 .77312 L
s
[(1)] -0.01138 .77312 1 0 Mshowa
.00112 1.13224 m
.00737 1.13224 L
s
[(1.5)] -0.01138 1.13224 1 0 Mshowa
.00112 1.49135 m
.00737 1.49135 L
s
[(2)] -0.01138 1.49135 1 0 Mshowa
.00112 1.85046 m
.00737 1.85046 L
s
[(2.5)] -0.01138 1.85046 1 0 Mshowa
.00112 2.20957 m
.00737 2.20957 L
s
[(3)] -0.01138 2.20957 1 0 Mshowa
.125 Mabswid
.00112 .12672 m
.00487 .12672 L
s
.00112 .19855 m
.00487 .19855 L
s
.00112 .27037 m
.00487 .27037 L
s
.00112 .34219 m
.00487 .34219 L
s
.00112 .48583 m
.00487 .48583 L
s
.00112 .55766 m
.00487 .55766 L
s
.00112 .62948 m
.00487 .62948 L
s
.00112 .7013 m
.00487 .7013 L
s
.00112 .84495 m
.00487 .84495 L
s
.00112 .91677 m
.00487 .91677 L
s
.00112 .98859 m
.00487 .98859 L
s
.00112 1.06041 m
.00487 1.06041 L
s
.00112 1.20406 m
.00487 1.20406 L
s
.00112 1.27588 m
.00487 1.27588 L
s
.00112 1.3477 m
.00487 1.3477 L
s
.00112 1.41953 m
.00487 1.41953 L
s
.00112 1.56317 m
.00487 1.56317 L
s
.00112 1.63499 m
.00487 1.63499 L
s
.00112 1.70682 m
.00487 1.70682 L
s
.00112 1.77864 m
.00487 1.77864 L
s
.00112 1.92228 m
.00487 1.92228 L
s
.00112 1.99411 m
.00487 1.99411 L
s
.00112 2.06593 m
.00487 2.06593 L
s
.00112 2.13775 m
.00487 2.13775 L
s
.00112 2.2814 m
.00487 2.2814 L
s
.25 Mabswid
.00112 0 m
.00112 2.34701 L
s
0 0 m
1 0 L
1 2.34701 L
0 2.34701 L
closepath
clip
newpath
.5 Mabswid
.00113 .05571 m
.00113 .05574 L
.00113 .05577 L
.00113 .0558 L
.00113 .05583 L
.00113 .05586 L
.00113 .05589 L
.00113 .05593 L
.00113 .05597 L
.00113 .056 L
.00113 .05604 L
.00113 .05608 L
.00113 .05613 L
.00113 .05617 L
.00113 .05621 L
.00113 .05626 L
.00113 .05631 L
.00113 .05636 L
.00113 .05641 L
.00113 .05646 L
.00113 .05652 L
.00113 .05657 L
.00113 .05663 L
.00113 .05669 L
.00114 .05676 L
.00114 .05682 L
.00114 .05689 L
.00114 .05696 L
.00114 .05703 L
.00114 .05711 L
.00114 .05719 L
.00114 .05727 L
.00114 .05735 L
.00115 .05744 L
.00115 .05753 L
.00115 .05762 L
.00115 .05772 L
.00115 .05782 L
.00116 .05792 L
.00116 .05803 L
.00116 .05814 L
.00116 .05825 L
.00117 .05837 L
.00117 .05849 L
.00117 .05862 L
.00118 .05875 L
.00118 .05889 L
.00118 .05903 L
.00119 .05917 L
.00119 .05932 L
Mistroke
.0012 .05948 L
.0012 .05964 L
.00121 .05981 L
.00122 .05998 L
.00122 .06016 L
.00123 .06034 L
.00124 .06054 L
.00125 .06074 L
.00125 .06094 L
.00126 .06115 L
.00127 .06137 L
.00129 .0616 L
.0013 .06184 L
.00131 .06208 L
.00132 .06233 L
.00134 .0626 L
.00135 .06287 L
.00137 .06315 L
.00139 .06344 L
.0014 .06374 L
.00142 .06405 L
.00145 .06437 L
.00147 .0647 L
.00149 .06505 L
.00152 .0654 L
.00155 .06577 L
.00158 .06615 L
.00161 .06654 L
.00165 .06695 L
.00168 .06737 L
.00172 .06781 L
.00177 .06826 L
.00181 .06873 L
.00186 .06921 L
.00191 .06971 L
.00197 .07022 L
.00203 .07075 L
.00209 .0713 L
.00216 .07187 L
.00223 .07246 L
.00231 .07307 L
.00239 .0737 L
.00248 .07435 L
.00258 .07501 L
.00268 .07571 L
.00278 .07642 L
.0029 .07716 L
.00302 .07792 L
.00315 .0787 L
.00329 .07951 L
Mistroke
.00344 .08035 L
.0036 .08121 L
.00376 .08209 L
.00394 .08301 L
.00413 .08395 L
.00433 .08492 L
.00454 .08592 L
.00477 .08695 L
.00501 .08801 L
.00526 .0891 L
.00553 .09022 L
.00582 .09137 L
.00612 .09255 L
.00643 .09376 L
.00677 .09501 L
.00712 .09629 L
.00749 .0976 L
.00788 .09894 L
.00828 .10032 L
.00871 .10173 L
.00916 .10318 L
.00963 .10466 L
.01012 .10617 L
.01063 .10772 L
.01116 .1093 L
.01171 .11092 L
.01228 .11257 L
.01287 .11426 L
.01349 .11598 L
.01412 .11773 L
.01477 .11952 L
.01544 .12135 L
.01612 .12322 L
.01683 .12512 L
.01755 .12705 L
.01828 .12903 L
.01902 .13105 L
.01978 .13311 L
.02054 .13521 L
.02131 .13735 L
.02209 .13955 L
.02288 .14179 L
.02366 .14408 L
.02445 .14642 L
.02523 .14882 L
.02602 .15128 L
.02679 .1538 L
.02757 .15639 L
.02833 .15904 L
.02908 .16177 L
Mistroke
.02982 .16458 L
.03055 .16748 L
.03127 .17046 L
.03197 .17353 L
.03265 .1767 L
.03332 .17998 L
.03397 .18336 L
.0346 .18686 L
.03521 .19048 L
.0358 .19423 L
.03637 .19811 L
.03692 .20213 L
.03745 .2063 L
.03796 .21062 L
.03845 .2151 L
.03892 .21975 L
.03937 .22457 L
.0398 .22957 L
.04021 .23477 L
.0406 .24016 L
.04097 .24575 L
.04132 .25156 L
.04166 .25759 L
.04198 .26384 L
.04228 .27034 L
.04256 .27708 L
.04284 .28408 L
.04309 .29135 L
.04333 .29888 L
.04356 .30671 L
.04378 .31483 L
.04398 .32325 L
.04417 .33199 L
.04436 .34106 L
.04453 .35047 L
.04469 .36023 L
.04484 .37035 L
.04498 .38085 L
.04511 .39173 L
.04524 .40302 L
.04535 .41473 L
.04546 .42686 L
.04557 .43944 L
.04566 .45248 L
.04575 .466 L
.04584 .48001 L
.04592 .49453 L
.04599 .50958 L
.04606 .52518 L
.04613 .54134 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{160.688, 377.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002P0001NB000`400?l00000o`00003oX?ooool0
0:3o000000000ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o0000
00000ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0
003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0003ooooo
ooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2L
ooooo`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o
000000000ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o00000000
0ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0003o
ooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0003ooooooooo
o`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Loooo
o`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o0000
00000ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0
003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`2Looooo`7o000000000ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?l000000ooooooo0000
ooooo`02ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooo0000ooooo`02o`000003
ooooool0003ooooo00;ooooo2Ol00003ooooo`04o`000?ooooooooooooooo`?o00006oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Co000000Goooooo`000?ooooooooooo`000002
ooooo`03o`000?oooooo000000;ooooo00Ko0000ooooool0003o0000ooooool00003ooooo`?o0000
00?oooooo`000?l000001?l00003ooooo`04o`000?ooooooooooooooo`?o00001Oooool1o`000000
00?o0000ooooooooool04Oooool00ol0003oooooo`000005ooooo`04o`000?oooooo0000o`0000Go
oooo1?l00004ooooo`05o`000?oooooo0000ooooool000001Oooool01Ol0003oooooo`000?oooooo
000000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
000000Gooooo00Co0000ooooool0003o00001?ooool00ol0003oooooo`000002o`0000?ooooo00Go
0000ooooool0003oooooo`000005ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`04ooooo`7o000000000ol0003oooooooooo`0?ooooo`05o`00
0?oooooo0000ooooool000001Oooool01Ol0003oooooo`000?oooooo000000Cooooo1?l00004oooo
o`03o`000?oooooo000000;o00001_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05_ooool01Ol0003oooooo`000?oooooo000000Gooooo00Go
0000ooooool0003oooooo`000003ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003o
ooooo`000002o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool03oooool01Ol0003o
ooooo`000?oooooo000000Gooooo00Go0000ooooool0003oooooo`000004ooooo`04o`000?oooooo
0000o`0000Cooooo00?o0000ooooool000001oooool01Ol0003oooooo`000?oooooo000000;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo0000ooooool0
00001Oooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_l00003oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00oooooo00Co0000oooo
oooooooo00001oooool4o`0000Gooooo00?o0000ooooool000001Oooool01?l0003oooooo`000?l0
0005ooooo`Go000000?oooooo`000?l000002?ooool3o`0001Sooooo00Co0000oooooooooooo0000
1oooool4o`0000Cooooo00Co0000oooooooooooo00001?ooool01?l0003oooooo`000?l00005oooo
o`?o000000Coooooo`000?l0003ooooo0_l00008ooooo`?o00001Oooool1o`00000000?o0000oooo
ooooool03ooooolko`0001Gooooo>_l00003ooooo`7o000000000ol0003oooooooooo`0?ooooo`;o
000002;oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`00
0?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000oooo
ool0003oooooo`000?oooooo00000_ooool04ol0003oooooo`000?oooooo0000ooooool0003ooooo
o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool000005oooool03ol0003ooooo
o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`0@
o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooo`?o0000013oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003o
ooooo`000?oooooo00000_ooool00ol0003oooooo`000004ooooo`7o000000000ol0003ooooooooo
o`0?ooooo`;o0000C_ooool00ol0003oooooooooo`0Nooooo`?o00006Oooool1o`00000000?o0000
ooooooooool03oooool2o`0004kooooo00?o0000ooooooooool07Oooool4o`0001Wooooo0Ol00000
0003o`000?oooooooooo00oooooo0_l0001>ooooo`03o`000?oooooooooo01gooooo1?l0000Ioooo
o`7o000000000ol0003oooooooooo`0?ooooo`?o0000COooool00ol0003oooooooooo`0Looooo`Ko
00006?ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooo`00001=ooooo`03o`00
0?oooooooooo01cooooo1_l0000Hooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oo
oooo000004gooooo00?o0000ooooooooool07?ooool6o`0001Sooooo0Ol000000003o`000?oooooo
oooo00oooooo00?o0000ooooool00000COooool00ol0003oooooooooo`0Kooooo`Oo00006?ooool1
o`00000000?o0000ooooooooool03oooool2o`000003ooooool0003ooooo04_ooooo00?o0000oooo
ooooool06oooool7o`0001Sooooo0Ol000000003o`000?oooooooooo00oooooo00Co0000oooooooo
oooo0000C?ooool00ol0003oooooooooo`0Jooooo`Wo00005oooool1o`00000000?o0000oooooooo
ool03oooool01?l0003oooooooooool0001<ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ool000001?l000000ooooooo0000ooooo`0Fooooo`7o000000000ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooo`0004cooooo00?o0000ooooooooool06Oooool7o`000003ooooool0003o0000
01Oooooo0Ol000000003o`000?oooooooooo00oooooo0_l000000ooooooo0000ooooo`1;ooooo`03
o`000?oooooooooo01Wooooo1_l000001?oooooo0000o`000?l0000Gooooo`7o000000000ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooo`0004cooooo00?o0000ooooooooool06Oooool2o`00
00;ooooo0ol00002ooooo`03o`000?oooooooooo01Gooooo0Ol000000003o`000?oooooooooo00oo
oooo00Co0000oooooooooooo0000C?ooool00ol0003oooooooooo`0Hooooo`co00005_ooool1o`00
000000?o0000ooooooooool03oooool01?l0003oooooooooool0001<ooooo`03o`000?oooooooooo
01Sooooo0_l00002ooooo`Co000000Coooooo`000?oooooo00005_ooool1o`00000000?o0000oooo
ooooool03oooool2o`000003ooooool0003ooooo04_ooooo00?o0000ooooooooool06?ooool2o`00
00?ooooo0_l00003ooooo`;o00005_ooool1o`00000000?o0000ooooooooool03oooool01?l0003o
ooooooooool0001<ooooo`03o`000?oooooooooo01Oooooo0_l000000ooooooo0000o`000008o`00
01Kooooo0Ol000000003o`000?oooooooooo00oooooo00Co0000oooooooooooo0000C?ooool00ol0
003oooooooooo`0Gooooo`?o00000_ooool2o`000006ooooool0003o0000o`000?oooooo00005_oo
ool1o`00000000?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooooooo`?o000000Goooooo`000?ooooooooooo`00000nooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo01Oooooo0_l00004ooooo`;o
00000oooool2o`0001Kooooo0Ol000000007o`000?ooooooooooooooool0003oooooo`000009oooo
o`06o`000?oooooo0000o`000?oooooo0000?Oooool00ol0003oooooo`000009ooooo`04o`000?oo
ooooooooo`0001Wooooo0_l00004ooooo`;o00000oooool3o`0001Gooooo0Ol000000007o`000?oo
ooooooooooooool0003oooooo`000007ooooo`?o000000Goooooo`000?ooooooooooo`00000moooo
o`03o`000?oooooo000000Oooooo0ol00002ooooo`03o`000?oooooooooo01Kooooo0_l000000ooo
oooo0000o`000007o`000003ooooool0003o000001Gooooo0Ol000000007o`000?oooooooooooooo
ool0003oooooo`000007ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Fooooo`?o00000_ooool7o`000003ooooool0003o000001Gooooo0Ol000000003o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool3o`000005ooooool0003oooooooooool00000?_oo
ool00ol0003oooooooooo`06ooooo`?o00000_ooool00ol0003oooooooooo`0Fooooo`;o00001Ooo
ool00ol0003oooooooooo`02ooooo`?o00005Oooool1o`00000000?o0000ooooooooool03oooool2
o`000003ooooool0003ooooo04_ooooo00?o0000ooooooooool05_ooool3o`0000?ooooo0ol00004
ooooo`;o00005Oooool1o`00000000?o0000ooooooooool03oooool01?l0003oooooooooool0001<
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool4
o`0001Gooooo0Ol000000003o`000?oooooooooo00oooooo00Co0000oooooooooooo0000C?ooool0
0ol0003oooooooooo`0Eooooo`;o00000_ooool8o`0000?ooooo00?o0000ooooooooool04oooool1
o`00000000?o0000ooooooooool03oooool01?l0003oooooooooool0001<ooooo`03o`000?oooooo
oooo01Gooooo1?l00004ooooo`;o00000_ooool2o`000003ooooool0003o000001Cooooo0Ol00000
0003o`000?oooooooooo00oooooo0_l0001>ooooo`03o`000?oooooooooo01Gooooo0ol00005oooo
o`03o`000?oooooooooo00?ooooo0ol0000Dooooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool00003oooo
o`?o00001?ooool3o`0001Cooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000000_ooool3o`00
00;ooooo0_l000000ooooooo0000o`00000Dooooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool05?ooool2o`0000Cooooo1ol00004ooooo`03
o`000?oooooooooo01;ooooo0Ol000000003o`000?oooooooooo00oooooo0_l0001>ooooo`03o`00
0?oooooooooo01Cooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003o0000o`0000;o
oooo0_l0000Cooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool04oooool00ol0003oooooo`000002o`0000Gooooo00?o0000ooooooooool0
0oooool01?l0003oooooo`000?l0000Cooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool04oooool01?l0003oooooo`000?l00005ooooo`;o
00001_ooool00ol0003oooooo`00000Cooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool04oooool01Ol0003oooooo`000?oooooo000000Co
oooo0ol00003ooooo`;o000000Coooooo`000?l0003o00004_ooool1o`00000000?o0000oooooooo
ool03oooool2o`0004kooooo00?o0000ooooooooool04oooool2o`0000?ooooo00Co0000oooooooo
oooooooo0ol00002ooooo`03o`000?oooooooooo00;ooooo0_l0000Booooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04oooool2o`0000Co
oooo0_l00002ooooo`04o`000?oooooo0000o`0000Gooooo0_l0000Booooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`02ooooo`_o00000oooool2o`0001;ooooo0Ol000000003o`000?oooooooooo00oooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Cooooo`;o00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l0000Booooo`7o0000
00000ol0003oooooooooo`0;ooooo`?o000000?oooooo`000?ooool0BOooool3o`0000;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`02o`0000Kooooo00?o0000ooooooooool01?oo
ool01?l0003oooooo`000?l0000Booooo`7o000000000ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00;o0000B_ooool01Ol0003ooooooooooooooooo000001Cooooo00Co0000ooooool0003o
00001_ooool3o`0000Kooooo0_l000000ooooooo0000ooooo`0@ooooo`7o000000000ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000ooooooooooooooooo`00000Doooo
o`;o00000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000Cooooo0_l00002
ooooo`;o00004Oooool1o`00000000?o0000ooooooooool03?ooool01?l0003oooooooooool0001;
ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`02ooooo`;o00000ooo
ool3o`0000;ooooo0_l00004ooooo`;o00004Oooool1o`00000000?o0000ooooooooool02oooool2
o`0000;ooooo00?o0000ooooooooool0B?ooool2o`0000?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`04ooooo`;o00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo00oooooo0Ol000000003o`000?oooooooooo00oooooo0_l0001>ooooo`03o`000?oooooo
oooo017ooooo0_l00008ooooo`Go00002?ooool00ol0003oooooooooo`0?ooooo`7o000000000ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04Oooool2o`00
00Cooooo3Ol00004ooooo`03o`000?oooooooooo00oooooo0Ol000000003o`000?oooooooooo00oo
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooo`00
0?oooooo00004?ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool00ol00007ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooool0003oooooo`00000@ooooo`7o000000000ol0003oooooooooo`0?oooo
o`;o0000C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;o00001_ooool3o`00
00Sooooo00Go0000ooooooooooooooooo`00000?ooooo`7o000000000ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool01_l0003oooooooooool0003o
ooooo`0000Gooooo00Co0000ooooool0003o00001_ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00gooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_oo
ool01Ol0003oooooo`000?oooooo000000Cooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00oooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0@ooooo`;o00001Oooool01?l0003oooooooooooooool4o`0000?ooooo0_l00005oooo
o`;o00003oooool1o`00000000?o0000ooooooooool03oooool2o`0004kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`05ooooo`Co000000?oooooo`000?l000000ol00007ooooo`;o
00003oooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo00oooooo0_l0000;ooooo`;o00002oooool2o`0000oooooo0Ol000000003o`000?oo
oooooooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooo000000Kooooo2ol00006ooooo`03o`000?oooooo000000kooooo0Ol000000003o`000?oooooo
oooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0>ooooo`04o`000?oooooo
ooooo`0000?ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oo
oooo000000kooooo0Ol000000003o`000?oooooooooo00oooooo0_l0001>ooooo`03o`000?oooooo
oooo00kooooo00Co0000oooooooooooooooo0ol00008ooooo`03o`000?oooooooooo00Gooooo0_l0
00001Ooooooo0000oooooooooooo000000kooooo0Ol000000003o`000?oooooooooo00oooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000
2Oooool2o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`7o0000
00000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool03_oo
ool01_l0003oooooooooool0003oooooo`0000Oooooo00Co0000ooooool0003o00002?ooool2o`00
00?ooooo00?o0000ooooooooool02oooool1o`00000000Co0000oooooooooooooooo0ol00003oooo
o`04o`000?ooooooooooooooo`?o000000?oooooo`000?ooool0?oooool3o`0000?ooooo00Co0000
oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooo0000
ooooo`02o`0000Kooooo00Co0000ooooool0003o00001oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00_ooooo0Ol000000003o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool01?l0003oooooo`000?l00010ooooo`03o`000?oooooooooo00Sooooo00Co0000oooo
oooooooo00004?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Ko0000
oooooooooooo0000ooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
3Oooool1o`00000000?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`?o000000?o
ooooo`000?ooool0@?ooool00ol0003oooooooooo`06ooooo`?o00000_ooool00ol0003ooooooooo
o`0>ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`Co00001?ooool2o`0000Gooooo00?o
0000ooooool000003Oooool1o`00000000?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000@Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03_ooool2o`0000Oooooo1Ol000000ooooooo0000o`00
0004o`0000Sooooo00?o0000ooooooooool03?ooool1o`00000000Co0000oooooooooooooooo0_l0
0008ooooo`?o000000?oooooo`000?ooool0?oooool2o`0000Sooooo0ol00002ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool02oooool2o`0000gooooo0_l0000=ooooo`7o00000000
0ol0003oooooooooo`0?ooooo`;o0000C_ooool00ol0003oooooooooo`0=ooooo`;o00003_ooool0
0ol0003oooooooooo`0;ooooo`;o00003Oooool1o`00000000?o0000ooooooooool03oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000002?ooool=o`00
00Oooooo00?o0000ooooool000003?ooool1o`00000000?o0000ooooooooool03oooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000001?ooool4o`0000Ko
oooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooool000003?ooool1o`000000
00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00_ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01_ooool2o`0000;ooooo00Co0000oooooooooooo00003?ooool1o`00000000?o0000oooooooo
ool03oooool2o`0004kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o
00002_ooool3o`0000Wooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo0Ol000000003o`00
0?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo0_l00009ooooo`05o`000?oooooo0000ooooool000002?ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00Wooooo0Ol000000003o`000?oooooooooo00oooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o0000
0_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo0000ooooool000001oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Wooooo0Ol000000003o`000?oooooooooo00oo
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000;ooooo`7o000000000ol0
003oooooooooo`0?ooooo`;o0000C_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000
00Kooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l0
0006ooooo`03o`000?oooooo000000_ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0;ooooo`;o00002Oooool3o`000003ooooool0003o
000000;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`07ooooo`;o00002oooool1
o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
00_ooooo0_l0000<ooooo`?o000000Goooooo`000?l0003o0000ooooo`02o`0000_ooooo00?o0000
ooooooooool02Oooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0000gooooo0_l0000:oooo
o`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool02_ooool2o`00017ooooo00?o0000ooooooooool03_ooool2o`0000[ooooo0Ol000000003o`00
0?oooooooooo00oooooo0_l0001>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Wooooo0Ol000000003o`00
0?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0000Wooooo3ol00008ooooo`04o`000?ooooooooooo`0000Wooooo0Ol000000003
o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`09ooooo`05
o`000?ooooooooooooooool000001_ooool2o`0000Oooooo00?o0000ooooooooool01Oooool3o`00
00Gooooo00Co0000oooooooooooo00002Oooool1o`00000000?o0000ooooooooool02oooool3o`00
0003ooooool0003ooooo04Wooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooooooool3o`0000Wooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000009ooooo`7o000000000ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;o0000B_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o
0000ooooooooool00oooool3o`0000cooooo00?o0000ooooooooool02_ooool2o`0000Gooooo00?o
0000ooooooooool01_ooool1o`00000000?o0000ooooooooool03Oooool00ol0003oooooo`00001<
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool2o`0000cooooo0ol0
000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool1o`00000000?o0000
ooooooooool03Oooool00ol0003oooooo`00001<ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00009ooooo`;o000000Coooooo`000?oooooo
00002_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Kooooo0Ol000000003o`00
0?oooooooooo00_ooooo0ol000000ooooooo0000ooooo`19ooooo`?o00000_ooool00ol0003ooooo
ooooo`08ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`06
o`000?ooooooooooo`000?oooooo00002?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0008ooooo`7o000000000ol0003oooooooooo`0?ooooo`;o0000C_ooool00ol0003oooooooooo`08
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0000Sooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Oooooo0_l00005ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooool000002?ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo00Sooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo
00Ko0000oooooooooooo0000ooooool00004ooooo`;o00002_ooool2o`0000Sooooo0Ol000000003
o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`08ooooo`;o
00002oooool4o`000004ooooool0003o0000ooooo`?o000000Coooooo`000?l0003o00003Oooool0
0ol0003oooooooooo`06ooooo`7o000000000ol0003oooooooooo`0?ooooo`;o0000C_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo2?l0000@ooooo`03o`000?oooooooooo
00Kooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool2o`0000Oo
oooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`07ooooo`;o00005?ooool00ol0003oooooooooo`0Aooooo`;o00001oooool1o`00000000?o
0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Oooooo0_l0
000Dooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00001_ooool1o`00000000?o
0000ooooooooool03oooool2o`0004kooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool0000Cooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00001_ooool1o`000000
00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Kooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo013ooooo00Co0000oooooooo
oooo00001_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00oooooo
0_l0001>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0>ooooo`?o00003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool3o`000004ooooool0
003oooooo`0000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`7o0000
00000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`7o000000001?l0003oooooooooooooool3o`0000?ooooo00Co0000oooooooooooo
oooo0ol000000ooooooo0000ooooo`0oooooo`?o00000oooool01?l0003oooooooooooooool3o`00
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`;o00002Oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`7o000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00Co0000ooooool0003o0000@?ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`?o000000?oooooo`000?ooool0@Oooool00ol0003oooooooooo`05ooooo`?o00000_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo0_l00006ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00002_ooool00ol0003ooooo
ooooo`02ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000012ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00003?ooool00ol0003o
ooooooooo`02ooooo`7o000000001?l0003oooooooooooooool3o`0000Oooooo0ol000000ooooooo
0000ooooo`0oooooo`?o00001oooool3o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool2o`0000kooooo00?o0000ooooooooool00_ooool1o`00000000?o0000oooooooo
ool03oooool2o`0004kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`;o
000000?oooooo`000?l000000_ooool00ol0003oooooo`000005o`00013ooooo00?o0000oooooooo
ool00_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04Oooool9o`0001Cooooo00?o0000ooooooooool0
0_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05Oooool2o`0001Oooooo00?o0000ooooooooool00_oo
ool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00;ooooo0Ol000000003o`000?oooooooooo00oooooo0_l0001>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00?ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`03ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01?ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Cooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`04ooooo`7o000000000ol0003oooooooooo`0?oooo
o`;o0000C_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`05ooooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool1o`00000000?o0000ooooooooool0
3oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo0Ol000000003o`000?oo
oooooooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`7o00000000
0ol0003oooooooooo`0?ooooo`;o0000C_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`7o000000000ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo0Ol000000003o`000?oooooooooo00oo
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01ko
oooo0_l0000;ooooo`7o000000000ol0003oooooooooo`0;ooooo`?o000000?oooooo`000?ooool0
BOooool3o`0000;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00_ooooo0Ol000000003o`000?oooooooooo00gooooo00Co0000ooooool0003o0000
Boooool01?l0003oooooooooool0000@ooooo`;o00006oooool00ol0003oooooooooo`0<ooooo`7o
000000000ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0004_ooooo00Go0000oooooooo
ooooooooo`00000Booooo`;o00005oooool2o`0000oooooo0Ol000000003o`000?oooooooooo00go
oooo00?o0000ooooool00000C?ooool01?l0003oooooooooool0000Dooooo`?o00004_ooool2o`00
017ooooo0Ol000000003o`000?oooooooooo00_ooooo0ol000000ooooooo0000ooooo`19ooooo`?o
00000_ooool00ol0003oooooooooo`0Eooooo`;o00003Oooool3o`0001?ooooo0Ol000000003o`00
0?oooooooooo00oooooo0_l0001>ooooo`03o`000?oooooooooo01Oooooo3Ol0000Fooooo`7o0000
00000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0>_oo
ool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o
0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000oooo
ooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0
W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1
o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`000000
00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000
ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000oooooooo
ool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?oo
ool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00
000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o
0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000oooo
ooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0
W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1
o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`000000
00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000
ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000oooooooo
ool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?oo
ool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00
000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o
0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000oooo
ooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0
W?ooool1o`00000000?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0W?ooool1
o`00000000?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Co000000?oooooo`000?ooool00_ooool00ol0003oooooo`000002ooooo`05o`000?oooooooooo
o`000?ooool00_l000000ooooooo0000ooooo`02ooooo`Wo00000oooool01?l0003ooooooooooooo
ool3o`0001_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04o`000005ooooool0
003oooooooooool000000_ooool00ol0003oooooo`000002ooooo`06o`000?oooooo0000o`000?oo
oooo00000oooool3o`000003ooooool0003o000000Co00000oooool01?l0003oooooooooooooool3
o`0000Gooooo0Ol000000003o`000?oooooooooo017ooooo00?o0000ooooool000001Oooool01?l0
003oooooo`000?l00005ooooo`Co00001?ooool01Ol0003oooooo`000?oooooo000000Gooooo00Go
0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooo`000005ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooool0
00000_l00003ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003oooooo`000002oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool1o`00000000?o0000oooo
ooooool04Oooool00ol0003oooooo`000005ooooo`05o`000?oooooo0000ooooool000001?ooool4
o`0000Cooooo00?o0000ooooool000000_l00006ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000Gooooo00Go
0000ooooool0003oooooo`000003ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003o
ooooo`000002o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool03oooool01Ol0003o
ooooo`000?oooooo000000Gooooo00Go0000ooooool0003oooooo`000004ooooo`04o`000?oooooo
0000o`0000Cooooo00?o0000ooooool000001oooool01Ol0003oooooo`000?oooooo000000;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`05o`000?oooooo0000ooooool0
00001Oooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000000_l00003oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00oooooo00Co0000oooo
oooooooo00001oooool4o`0000Gooooo00?o0000ooooool000001Oooool01?l0003oooooo`000?l0
0005ooooo`Go000000?oooooo`000?l000002?ooool3o`0001Sooooo00Co0000oooooooooooo0000
1oooool4o`0000Cooooo00Co0000oooooooooooo00001?ooool01?l0003oooooo`000?l00005oooo
o`?o000000Coooooo`000?l0003ooooo0_l00008ooooo`?o00001Oooool1o`00000000?o0000oooo
ooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03[ooooo0Ol000000003
o`000?oooooooooo00oooooo>ol0000Eoooooc[o00000oooool1o`00000000?o0000ooooooooool0
3oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`?o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02Oooool1o`00000000?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Nooooo`?o0000;?ooool00ol0003oooooooooo`0jooooo`7o00000000
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo1?l0000[ooooo`;o0000>oooool1
o`00000000?o0000ooooooooool03oooool2o`0001kooooo1Ol0000[ooooo`;o0000>oooool1o`00
000000?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`Go0000:oooool2o`0003_o
oooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool6o`0002_ooooo
0ol0000jooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo1ol0
000Zooooo`03o`000?oooooo000003[ooooo0Ol000000003o`000?oooooooooo00oooooo0_l0000L
ooooo`So0000:_ooool00ol0003oooooo`00000jooooo`7o000000000ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooool000001Ol0000Zooooo`03o`000?oooooo0000
03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool3o`000003
ooooool0003o000000?o0000:_ooool00ol0003oooooo`00000jooooo`7o000000000ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01[ooooo1Ol000001?oooooo0000o`000?l0000Zooooo`03
o`000?oooooo000003[ooooo0Ol000000003o`000?oooooooooo00oooooo0_l0000Kooooo`[o0000
:Oooool00ol0003oooooo`00000jooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooool000000_l000001Ooooooo0000o`000?oooooo000002Wooooo
00?o0000ooooool00000>_ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Iooooo`;o00000_ooool4o`000003ooooool0003o000002Wooooo00?o0000ooooool00000>_oo
ool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`06o`000?oooooo
0000o`000?oooooo00000_ooool3o`0002Wooooo00?o0000ooooool00000>_ooool1o`00000000?o
0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`;o000000?oooooo`000?l000000ol0
00000ooooooo0000o`00000Yooooo`04o`000?ooooooooooo`0003Wooooo0Ol000000003o`000?oo
oooooooo00oooooo0_l0000Iooooo`;o00000oooool2o`0000Cooooo0_l0000Xooooo`04o`000?oo
ooooooooo`0003Wooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooo`00000:o`0002Sooooo00Co0000oooooooooooo0000>Oooool1o`00000000?o
0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`?o000000?oooooo`000?l000000ol0
00001?oooooo0000o`000?l0000Xooooo`04o`000?ooooooooooo`0003Wooooo0Ol000000003o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`000003
ooooool0003ooooo01Sooooo00?o0000ooooool000000oooool2o`0000Cooooo0_l0000Jooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00002ooooo`04o`000?oooooooooo
o`0003Wooooo0Ol000000007o`000?ooooooooooooooool0003oooooo`000009ooooo`04o`000?oo
oooo0000o`0001Sooooo0_l000001?oooooo0000ooooooooool2o`0000?ooooo0ol0000Iooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0goooo
o`7o000000001ol0003ooooooooooooooooo0000ooooool000001oooool3o`000003ooooool0003o
oooo01Sooooo00?o0000ooooooooool02?l00002ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooool000001oooool3o`0000;ooooo00Co0000oooooooooooo0000>Oooool1o`00000000Oo0000
ooooooooooooooooo`000?oooooo000000Oooooo00Go0000ooooooooooooooooo`00000Iooooo`?o
00000_ooool7o`000003ooooool0003o000001Sooooo00?o0000ooooool000001oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0003Wooooo0Ol000000003o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool3o`000003ooooool0003ooooo01Oooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`02ooooo`?o00006Oooool00ol0003oooooooooo`06ooooo`?o
00000_ooool01?l0003oooooooooool0000iooooo`7o000000000ol0003oooooooooo`0?ooooo`;o
00005oooool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`?o00009oooool01?l0003o
ooooooooool0000iooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Ko
oooo00Co0000oooooooooooooooo1_l000001?oooooo0000o`000?ooool2o`0002Oooooo00Co0000
oooooooooooo0000>Oooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0F
ooooo`;o000000?oooooo`000?l000002?l000000ooooooo0000o`00000Wooooo`04o`000?oooooo
ooooo`0003Wooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00?ooooo0ol0000Wooooo`04o`000?oo
ooooooooo`0003Wooooo0Ol000000003o`000?oooooooooo00oooooo0_l0000Fooooo`03o`000?oo
oooo000000Gooooo0_l00005ooooo`03o`000?oooooo000002Kooooo00?o0000ooooooooool0>_oo
ool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`;o000000?ooooo
o`000?ooool00_ooool3o`0000?ooooo0_l000000ooooooo0000o`00000Vooooo`03o`000?oooooo
oooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool2o`00
00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Gooooo00Co0000oooooooooooooooo2Ol00004ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool2o`00
01Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`;o000000Cooooo
o`000?oooooo00009Oooool00ol0003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Cooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooo
oooo00Cooooo0_l000000ooooooo0000ooooo`0Tooooo`03o`000?oooooooooo03[ooooo0Ol00000
0003o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool3o`0000Kooooo0_l00005oooo
o`;o000000?oooooo`000?ooool09?ooool00ol0003oooooooooo`0jooooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_l00003ooooo`?o
00000oooool2o`0000;ooooo0_l0000Uooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`00
0?oooooooooo00oooooo0_l0000Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0ol00002ooooo`03o`000?oooooooooo00;ooooo0_l0000Uooooo`03o`000?oooooooooo03[ooooo
0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool2o`0000Gooooo1ol0
0006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000
ooooooooool03oooool00ol0003oooooooooo`0Cooooo`;o00000oooool;o`0000Cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0;oooo
o`?o000000?oooooo`000?ooool04oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool2o`000004ooooool0003oooooo`0001oooooo0ol00002
ooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_l0000Cooooo`03o`000?oooooooooo00;o00001_ooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`00023ooooo00Go0000ooooooooooooooooo`00000looooo`7o00000000
0ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0001Cooooo00Co0000oooooooooooo0000
1_ooool3o`0000Kooooo0_l000000ooooooo0000ooooo`0Oooooo`05o`000?ooooooooooooooool0
0000??ooool1o`00000000?o0000ooooooooool03?ooool01?l0003oooooooooool0000Dooooo`04
o`000?oooooo0000ooooo`;o00001?ooool2o`000003ooooool0003ooooo00?ooooo00?o0000oooo
ooooool00_l0000Pooooo`05o`000?ooooooooooooooool00000??ooool1o`00000000?o0000oooo
ooooool02oooool2o`0000;ooooo00?o0000ooooooooool04_ooool2o`0000Cooooo00Co0000oooo
oooooooooooo0ol00003ooooo`;o00000oooool2o`0001oooooo0_l00003ooooo`03o`000?oooooo
oooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo0_l0000Cooooo`03o`000?oooooooooo
00Cooooo1Ol00002ooooo`;o00001_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool2o`0000Oo
oooo1ol00007ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>_ooool1o`000000
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000000?ooooo
0ol00003ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003oooooo`00000Sooooo`03
o`000?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool0
4Oooool01?l0003oooooo`000?ooool2o`0000Kooooo00?o0000ooooooooool01?ooool01_l0003o
ooooooooool0003oooooo`0002?ooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000oooo
ooooool03oooool2o`0001;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`05
ooooo`;o00000_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03[ooooo0Ol00000
0003o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02o`00
00Oooooo1?l00006ooooo`;o00000_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooo`000002ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000Cooooo0_l00002oooo
o`03o`000?oooooo000002;ooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000oooooooo
ool03oooool00ol0003oooooooooo`0@ooooo`;o00001Oooool2o`0000;ooooo00Go0000ooooool0
003oooooo`000002ooooo`;o00001Oooool2o`0002;ooooo00?o0000ooooooooool0>_ooool1o`00
000000?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`;o00001oooool2o`000005
ooooool0003o0000o`000?ooool00_l00007ooooo`;o00008_ooool00ol0003oooooooooo`0joooo
o`7o000000000ol0003oooooooooo`0?ooooo`;o00004Oooool00ol0003oooooooooo`08ooooo`Go
00002_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`00
0?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000:ooooo`;o0000
3?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`000?oo
oooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooo`000005ooooo`Go000000?o
ooooo`000?l000001?l00006ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool0>_oo
ool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`04o`000?oooooo
ooooo`0000?ooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo1?l00002ooooo`03o`000?oo
oooo0000027ooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool2
o`0000oooooo00Co0000oooooooooooooooo0ol00008ooooo`03o`000?oooooooooo00Oooooo0_l0
0002ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000
ooooooooool03oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooooooo`;o00002?oo
ool3o`0000Wooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo03[ooooo
0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooool0003oooooo`000007ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0jooooo`7o
000000001?l0003oooooooooooooool3o`0000?ooooo00Co0000oooooooooooooooo0ol000000ooo
oooo0000ooooo`0?ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool01Ol0
003oooooo`000?oooooo000000Gooooo0_l00003ooooo`03o`000?oooooo0000017ooooo0ol00003
ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`7o00000000
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Co0000ooooool0003o00003ooo
ool2o`0000Kooooo0_l00003ooooo`05o`000?oooooo0000ooooool000000oooool2o`0000Kooooo
0_l0000Booooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000??ooool1o`000000
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?ooool0
3oooool2o`0000Sooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Sooooo
0_l0000Booooo`03o`000?oooooooooo00Kooooo0ol00002ooooo`03o`000?oooooooooo03[ooooo
0Ol000000003o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooo
oooooooo0000013ooooo00?o0000ooooooooool02Oooool7o`0000_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>_ooool1o`00000000Co0000oooooooooooooooo0_l00008ooooo`?o000000?oooooo`000?ooool0
3_ooool2o`0000kooooo00?o0000ooooooooool03?ooool2o`00013ooooo0_l00008ooooo`?o0000
0_ooool00ol0003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0?ooooo`;o00003_oo
ool00ol0003oooooo`00000;ooooo`Ko00002_ooool00ol0003oooooo`00000Oooooo`03o`000?oo
oooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool0
1?l0003oooooooooool00005ooooo`Ko00000_ooool01?l0003oooooooooooooool4o`0000Kooooo
00?o0000ooooool000007oooool00ol0003oooooooooo`0jooooo`7o000000000ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0001kooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool0
3oooool00ol0003oooooooooo`0<ooooo`06o`000?ooooooooooooooool0003ooooo0_l00009oooo
o`03o`000?oooooooooo00Kooooo0_l00002ooooo`05o`000?ooooooooooooooool000007_ooool0
0ol0003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0?ooooo`;o00003Oooool01?l0
003oooooooooooooool2o`0000[ooooo0ol00009ooooo`?o00000oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooo
ooooool03?ooool01?l0003oooooooooooooool2o`0000Wooooo00Go0000ooooool0003oooooo`00
0009ooooo`;o00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03[ooooo0Ol0
00000003o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool01_ooool01Ol0003oooooo`000?oooooo000000Oooooo
0_l00002ooooo`05o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`0jooooo`7o
000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001gooooo00?o0000
ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool2o`0000cooooo00?o0000oooo
ool000001_ooool3o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooooooo
ool2o`0000Oooooo00?o0000ooooool000007Oooool00ol0003oooooooooo`0jooooo`7o00000000
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo0_l0000:ooooo`?o000000?ooooo
o`000?l000000ol00002ooooo`;o00002_ooool2o`0001gooooo00?o0000ooooooooool0>_ooool1
o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`;o00003Oooool8o`00
00cooooo0_l0000Mooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oo
oooo00?o0000ooooooooool02oooool2o`00013ooooo00?o0000ooooooooool03_ooool2o`0001go
oooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool2o`0000_ooooo
00?o0000ooooool000004?ooool00ol0003oooooooooo`0>ooooo`;o00007Oooool00ol0003ooooo
ooooo`0jooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooool000003?ooool8o`0000gooooo00?o0000ooooool000007?ooool00ol0003ooooooooo
o`0jooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooool000002_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00007ooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool02ooo
ool3o`000003ooooool0003ooooo00_ooooo00Co0000oooooooooooo00001Oooool4o`0000Kooooo
00?o0000ooooooooool01_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`00000Fooooo`?o
00000_ooool00ol0003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00;o00002_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002_ooool00ol0003oooooooooo`08ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
01Oooooo00Go0000ooooooooooooooooo`00000looooo`7o000000000ol0003oooooooooo`0=oooo
o`03o`000?oooooo000000_ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0000:
ooooo`?o00002oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo01Kooooo00Co0000
oooooooooooo0000??ooool1o`00000000?o0000ooooooooool03Oooool00ol0003oooooo`00000:
ooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o000000Coooooo`000?oooooo00002ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
??ooool1o`00000000?o0000ooooooooool02oooool3o`000003ooooool0003ooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Sooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000oooooooo
ool04oooool3o`0000;ooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool0
3oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooo
oooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo0_l00009ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001[ooooo
00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooo000000Wooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`;o00002?ooool00ol0003oooooo`00000Jooooo`03o`00
0?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool2o`0000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?o
oooo0_l0000:ooooo`03o`000?oooooo000001[ooooo00?o0000ooooooooool0>_ooool1o`000000
00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`;o00003Oooool7o`000003oooo
ool0003o000000?o00003Oooool2o`0001[ooooo00?o0000ooooooooool0>_ooool1o`00000000?o
0000ooooooooool03oooool2o`0000Wooooo00?o0000ooooooooool04?ooool6o`00013ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Sooooo0_l0000Cooooo`03o`000?oooooooooo017ooooo0_l0000J
ooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`00000Cooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ool000006Oooool00ol0003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`0Aoooo
o`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000oooo
ooooool03oooool2o`0000Oooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo013ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo03[ooooo0Ol0
00000003o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooo
oooo000001;ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000001Sooooo
00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0jooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03[ooooo0Ol00000
0003o`000?oooooooooo00oooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool4o`0000oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00003?ooool01Ol0003oooooooooool0003ooooo
00;o00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0>_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo03[ooooo0Ol000000004o`000?ooooooooooooooo`?o00000oooool01?l0
003oooooooooooooool3o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`06ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`?o00000oooool01?l0003ooooooooo
ooooool3o`0000;ooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool0
1oooool2o`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooo0000??ooool1o`00000000?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`?o000000?oooooo`000?ooool01_ooool00ol0003ooooo
ooooo`09ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool3o`0000;ooooo00?o0000ooooooooool0>_ooool1o`00000000?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03[o
oooo0Ol000000004o`000?ooooooooooooooo`?o00001oooool3o`000003ooooool0003ooooo00Ko
oooo00?o0000ooooooooool03?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?o00003_ooool00ol0003oooooooooo`06ooooo`?o00001oooool3o`00
00;ooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool2o`0000Ko
oooo00?o0000ooooooooool03_ooool5o`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`00
017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0jooooo`7o000000000ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool8o`0001?o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0jooooo`7o000000000ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>_ooool1o`00000000?o
0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03[ooooo0Ol0
00000003o`000?oooooooooo00oooooo0_l00006ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03[ooooo0Ol00000
0003o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0joooo
o`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0>_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo0_l00008ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0jooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo
0_l0000;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0j
ooooo`7o000000000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03[ooooo0Ol000000003
o`000?oooooooooo00_ooooo0ol000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo01[o
oooo0_l0000Kooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`7o000000000ol0003ooooo
ooooo`0=ooooo`04o`000?oooooo0000o`00013ooooo0_l0000Hooooo`;o00007oooool01?l0003o
ooooooooool0000looooo`7o000000000ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`00
01?ooooo0_l0000Eooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000l
ooooo`7o000000000ol0003oooooooooo`0=ooooo`03o`000?oooooo000001Gooooo0_l0000Boooo
o`03o`000?oooooooooo023ooooo00Co0000oooooooooooo0000??ooool1o`00000000?o0000oooo
ooooool02oooool3o`000003ooooool0003ooooo01Kooooo0ol0000;ooooo`Co00008Oooool3o`00
00;ooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000ooooooooool03oooool2o`0001Wo
oooo2ol0000Zooooo`03o`000?oooooooooo03[ooooo0Ol000000003o`000?oooooooooo00oooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0jooooo`7o000000000ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0>_ooool1o`00000000?o0000
ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03[ooooo0Ol00000
0003o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000003o`00
0?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000003o`000?oooooo
oooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09co
oooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol0
00000003o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000003
o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000003o`000?oo
oooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo
09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo
0Ol000000003o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol00000
0003o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000003o`00
0?oooooooooo09cooooo0Ol000000003o`000?oooooooooo09cooooo0Ol000000:3o00000000\
\>"],
  ImageRangeCache->{{{0, 159.688}, {376.125, 0}} -> {-0.0516569, -0.130043, \
0.0131715, 0.0131715}, {{3.875, 76.1875}, {366.25, 196.5}} -> {-0.461784, \
-0.804471, 0.0243157, 0.0243157}, {{83.4375, 155.75}, {366.25, 196.5}} -> \
{-2.3964, -0.804471, 0.0243157, 0.0243157}, {{3.875, 76.1875}, {179.562, \
9.8125}} -> {-0.461784, -5.3439, 0.0243157, 0.0243157}, {{83.4375, 155.75}, \
{179.562, 9.8125}} -> {-2.3964, -5.3439, 0.0243157, 0.0243157}},
  CellTags->"5.3.5"]
}, Open  ]],

Cell["\<\
As this system responds well when the same pseudo-diagonalization \
frequency is used for both rows, due to the symmetric form of the system \
model, a frequency of 0.4 rad/s produces a good uniform reduction in the \
Gershgorin circles for both diagonal elements of the inverse-system Nyquist \
array. Pseudo-diagonalization at other frequencies produces a less uniform \
reduction in the Gershgorin circles.\
\>", "Text",
  CellTags->"5.3.5"],

Cell["\<\
This applies the pseudo-diagonalization method to both rows at \
\[Omega] = 0.4 rad/s.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kinv = 
      PseudodiagonalizingCompensator[InverseSystem[tf], 0.4]\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->"5.3.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.8615057205073162`", "0.5077478641345232`"},
                    {"0.5077478641345233`", "0.8615057205073162`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Center},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox["\[Bullet]",
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[9]=",
  CellTags->"5.3.5"]
}, Open  ]],

Cell["This is the resulting forward-path transfer-function matrix.", \
"MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fp = 
      Together /@ SeriesConnect[Normal[InverseSystem[kinv]], tf]\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->"5.3.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(5.957738724559039`\ \[ScriptS] + 
                            1.0447950244870219`\)\/\(\((4.`\ \[ScriptS] + 
                                1.`)\)\ \((5.`\ \[ScriptS] + 
                                1.`)\)\)\), \(\(\(\(0.19675732130776735`\)\(\
\[InvisibleSpace]\)\) - 
                            0.26120443208882893`\ \[ScriptS]\)\/\(\((4.`\ \
\[ScriptS] + 1.`)\)\ \((5.`\ \[ScriptS] + 1.`)\)\)\)},
                    {\(\(\(\(0.19675732130776713`\)\(\[InvisibleSpace]\)\) - 
                            0.2612044320888298`\ \[ScriptS]\)\/\(\((4.`\ \
\[ScriptS] + 1.`)\)\ \((5.`\ \[ScriptS] + 
                                1.`)\)\)\), \(\(5.957738724559039`\ \
\[ScriptS] + 1.044795024487022`\)\/\(\((4.`\ \[ScriptS] + 
                                1.`)\)\ \((5.`\ \[ScriptS] + 1.`)\)\)\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Center},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[InvisibleSpace]\"\>",
                ShowStringCharacters->False],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[10]=",
  CellTags->"5.3.5"]
}, Open  ]],

Cell["\<\
Here is the resulting inverse-system Nyquist array with Gershgorin \
row dominance circles, and Ostrowski circles for additional loop gains {1, \
1}.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NyquistArrayPlot[InverseSystem[fp], {0.001, 1}, 
        GershgorinCircles \[Rule] RowDominance, 
        OstrowskiCircleLoopGains \[Rule] {1, 1}];\)\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->"5.3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.69275 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0641131 0.47619 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 2.69275 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 2.69275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 2.69275 L
s
0 2.69275 m
1 2.69275 L
s
1 0 m
1 2.69275 L
s
0 0 m
1 0 L
1 2.69275 L
0 2.69275 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0641131 0.477324 1.28532 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.137085 0.725035 0.197601 0.725035 [
[.28209 .1851 -7.2 -7.2 ]
[.28209 .1851 7.2 0 ]
[.4271 .1851 -7.2 -7.2 ]
[.4271 .1851 7.2 0 ]
[.57211 .1851 -7.2 -7.2 ]
[.57211 .1851 7.2 0 ]
[.71711 .1851 -7.2 -7.2 ]
[.71711 .1851 7.2 0 ]
[.86212 .1851 -2.4 -7.2 ]
[.86212 .1851 2.4 0 ]
[.12458 .56012 -14.4 -3.6 ]
[.12458 .56012 0 3.6 ]
[.12458 .92264 -4.8 -3.6 ]
[.12458 .92264 0 3.6 ]
[.12458 1.28515 -14.4 -3.6 ]
[.12458 1.28515 0 3.6 ]
[.12458 1.64767 -4.8 -3.6 ]
[.12458 1.64767 0 3.6 ]
[.12458 2.01019 -14.4 -3.6 ]
[.12458 2.01019 0 3.6 ]
[.12458 2.37271 -4.8 -3.6 ]
[.12458 2.37271 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.69275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.28209 .1976 m
.28209 .20385 L
s
[(0.2)] .28209 .1851 0 1 Mshowa
.4271 .1976 m
.4271 .20385 L
s
[(0.4)] .4271 .1851 0 1 Mshowa
.57211 .1976 m
.57211 .20385 L
s
[(0.6)] .57211 .1851 0 1 Mshowa
.71711 .1976 m
.71711 .20385 L
s
[(0.8)] .71711 .1851 0 1 Mshowa
.86212 .1976 m
.86212 .20385 L
s
[(1)] .86212 .1851 0 1 Mshowa
.125 Mabswid
.17334 .1976 m
.17334 .20135 L
s
.20959 .1976 m
.20959 .20135 L
s
.24584 .1976 m
.24584 .20135 L
s
.31834 .1976 m
.31834 .20135 L
s
.3546 .1976 m
.3546 .20135 L
s
.39085 .1976 m
.39085 .20135 L
s
.46335 .1976 m
.46335 .20135 L
s
.4996 .1976 m
.4996 .20135 L
s
.53585 .1976 m
.53585 .20135 L
s
.60836 .1976 m
.60836 .20135 L
s
.64461 .1976 m
.64461 .20135 L
s
.68086 .1976 m
.68086 .20135 L
s
.75336 .1976 m
.75336 .20135 L
s
.78962 .1976 m
.78962 .20135 L
s
.82587 .1976 m
.82587 .20135 L
s
.89837 .1976 m
.89837 .20135 L
s
.93462 .1976 m
.93462 .20135 L
s
.97088 .1976 m
.97088 .20135 L
s
.10083 .1976 m
.10083 .20135 L
s
.06458 .1976 m
.06458 .20135 L
s
.02833 .1976 m
.02833 .20135 L
s
.25 Mabswid
0 .1976 m
1 .1976 L
s
.13708 .56012 m
.14333 .56012 L
s
[(0.5)] .12458 .56012 1 0 Mshowa
.13708 .92264 m
.14333 .92264 L
s
[(1)] .12458 .92264 1 0 Mshowa
.13708 1.28515 m
.14333 1.28515 L
s
[(1.5)] .12458 1.28515 1 0 Mshowa
.13708 1.64767 m
.14333 1.64767 L
s
[(2)] .12458 1.64767 1 0 Mshowa
.13708 2.01019 m
.14333 2.01019 L
s
[(2.5)] .12458 2.01019 1 0 Mshowa
.13708 2.37271 m
.14333 2.37271 L
s
[(3)] .12458 2.37271 1 0 Mshowa
.125 Mabswid
.13708 .2701 m
.14083 .2701 L
s
.13708 .34261 m
.14083 .34261 L
s
.13708 .41511 m
.14083 .41511 L
s
.13708 .48762 m
.14083 .48762 L
s
.13708 .63262 m
.14083 .63262 L
s
.13708 .70513 m
.14083 .70513 L
s
.13708 .77763 m
.14083 .77763 L
s
.13708 .85013 m
.14083 .85013 L
s
.13708 .99514 m
.14083 .99514 L
s
.13708 1.06764 m
.14083 1.06764 L
s
.13708 1.14015 m
.14083 1.14015 L
s
.13708 1.21265 m
.14083 1.21265 L
s
.13708 1.35766 m
.14083 1.35766 L
s
.13708 1.43016 m
.14083 1.43016 L
s
.13708 1.50266 m
.14083 1.50266 L
s
.13708 1.57517 m
.14083 1.57517 L
s
.13708 1.72017 m
.14083 1.72017 L
s
.13708 1.79268 m
.14083 1.79268 L
s
.13708 1.86518 m
.14083 1.86518 L
s
.13708 1.93769 m
.14083 1.93769 L
s
.13708 2.08269 m
.14083 2.08269 L
s
.13708 2.1552 m
.14083 2.1552 L
s
.13708 2.2277 m
.14083 2.2277 L
s
.13708 2.3002 m
.14083 2.3002 L
s
.13708 .1251 m
.14083 .1251 L
s
.13708 .05259 m
.14083 .05259 L
s
.13708 2.44521 m
.14083 2.44521 L
s
.13708 2.51771 m
.14083 2.51771 L
s
.13708 2.59022 m
.14083 2.59022 L
s
.13708 2.66272 m
.14083 2.66272 L
s
.25 Mabswid
.13708 0 m
.13708 2.69275 L
s
0 0 m
1 0 L
1 2.69275 L
0 2.69275 L
closepath
clip
newpath
.5 Mabswid
.0016 .19818 m
.0016 .1982 L
.0016 .19822 L
.0016 .19824 L
.0016 .19826 L
.0016 .19829 L
.0016 .19831 L
.0016 .19834 L
.0016 .19836 L
.0016 .19839 L
.0016 .19842 L
.0016 .19844 L
.0016 .19847 L
.0016 .1985 L
.0016 .19854 L
.0016 .19857 L
.0016 .1986 L
.00161 .19864 L
.00161 .19868 L
.00161 .19871 L
.00161 .19875 L
.00161 .19879 L
.00161 .19884 L
.00161 .19888 L
.00161 .19893 L
.00161 .19897 L
.00161 .19902 L
.00162 .19907 L
.00162 .19912 L
.00162 .19918 L
.00162 .19923 L
.00162 .19929 L
.00163 .19935 L
.00163 .19941 L
.00163 .19947 L
.00163 .19954 L
.00164 .19961 L
.00164 .19968 L
.00164 .19975 L
.00164 .19983 L
.00165 .19991 L
.00165 .19999 L
.00166 .20007 L
.00166 .20016 L
.00167 .20025 L
.00167 .20034 L
.00168 .20044 L
.00168 .20054 L
.00169 .20064 L
.0017 .20075 L
Mistroke
.0017 .20086 L
.00171 .20098 L
.00172 .2011 L
.00173 .20122 L
.00174 .20135 L
.00175 .20148 L
.00176 .20161 L
.00177 .20176 L
.00178 .2019 L
.0018 .20205 L
.00181 .20221 L
.00183 .20237 L
.00184 .20254 L
.00186 .20271 L
.00188 .20289 L
.0019 .20308 L
.00192 .20327 L
.00195 .20347 L
.00197 .20367 L
.002 .20388 L
.00203 .2041 L
.00206 .20433 L
.00209 .20457 L
.00213 .20481 L
.00217 .20506 L
.00221 .20532 L
.00225 .20559 L
.0023 .20586 L
.00235 .20615 L
.0024 .20645 L
.00246 .20675 L
.00252 .20707 L
.00259 .20739 L
.00266 .20773 L
.00273 .20808 L
.00281 .20844 L
.0029 .20881 L
.00299 .20919 L
.00309 .20958 L
.00319 .20999 L
.0033 .21041 L
.00342 .21084 L
.00355 .21129 L
.00369 .21175 L
.00383 .21222 L
.00399 .2127 L
.00415 .2132 L
.00433 .21372 L
.00451 .21425 L
.00471 .21479 L
Mistroke
.00493 .21535 L
.00515 .21592 L
.00539 .2165 L
.00565 .21711 L
.00592 .21772 L
.00621 .21835 L
.00652 .219 L
.00684 .21966 L
.00719 .22033 L
.00755 .22101 L
.00794 .22171 L
.00834 .22243 L
.00877 .22315 L
.00923 .22388 L
.00971 .22463 L
.01021 .22539 L
.01074 .22615 L
.0113 .22693 L
.01189 .22771 L
.0125 .22849 L
.01315 .22928 L
.01382 .23007 L
.01452 .23087 L
.01525 .23167 L
.01601 .23246 L
.0168 .23325 L
.01762 .23404 L
.01847 .23482 L
.01935 .23559 L
.02026 .23636 L
.02119 .23711 L
.02215 .23785 L
.02313 .23857 L
.02414 .23928 L
.02516 .23998 L
.02621 .24065 L
.02728 .24131 L
.02835 .24195 L
.02945 .24256 L
.03055 .24316 L
.03166 .24373 L
.03278 .24428 L
.0339 .24481 L
.03502 .24532 L
.03614 .24581 L
.03725 .24629 L
.03836 .24674 L
.03945 .24718 L
.04054 .2476 L
.0416 .24801 L
Mistroke
.04266 .24841 L
.04369 .2488 L
.0447 .24919 L
.04569 .24957 L
.04666 .24996 L
.0476 .25034 L
.04852 .25073 L
.04941 .25113 L
.05027 .25153 L
.0511 .25196 L
.0519 .2524 L
.05268 .25286 L
.05342 .25334 L
.05414 .25385 L
.05482 .25439 L
.05548 .25496 L
.05611 .25556 L
.05671 .25621 L
.05728 .25689 L
.05782 .25762 L
.05834 .2584 L
.05883 .25923 L
.0593 .2601 L
.05975 .26104 L
.06017 .26203 L
.06057 .26308 L
.06094 .26419 L
.0613 .26537 L
.06163 .26662 L
.06195 .26794 L
.06225 .26933 L
.06253 .2708 L
.0628 .27235 L
.06305 .27398 L
.06329 .27569 L
.06351 .27749 L
.06372 .27938 L
.06391 .28136 L
.0641 .28343 L
.06427 .28561 L
.06443 .28788 L
.06458 .29027 L
.06472 .29275 L
.06486 .29535 L
.06498 .29807 L
.0651 .3009 L
.06521 .30386 L
.06531 .30694 L
.06541 .31015 L
.0655 .31349 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0641131 0.97619 1.28532 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.137085 0.725035 0.197601 0.725035 [
[.28209 .1851 -7.2 -7.2 ]
[.28209 .1851 7.2 0 ]
[.4271 .1851 -7.2 -7.2 ]
[.4271 .1851 7.2 0 ]
[.57211 .1851 -7.2 -7.2 ]
[.57211 .1851 7.2 0 ]
[.71711 .1851 -7.2 -7.2 ]
[.71711 .1851 7.2 0 ]
[.86212 .1851 -2.4 -7.2 ]
[.86212 .1851 2.4 0 ]
[.12458 .56012 -14.4 -3.6 ]
[.12458 .56012 0 3.6 ]
[.12458 .92264 -4.8 -3.6 ]
[.12458 .92264 0 3.6 ]
[.12458 1.28515 -14.4 -3.6 ]
[.12458 1.28515 0 3.6 ]
[.12458 1.64767 -4.8 -3.6 ]
[.12458 1.64767 0 3.6 ]
[.12458 2.01019 -14.4 -3.6 ]
[.12458 2.01019 0 3.6 ]
[.12458 2.37271 -4.8 -3.6 ]
[.12458 2.37271 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.69275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.28209 .1976 m
.28209 .20385 L
s
[(0.2)] .28209 .1851 0 1 Mshowa
.4271 .1976 m
.4271 .20385 L
s
[(0.4)] .4271 .1851 0 1 Mshowa
.57211 .1976 m
.57211 .20385 L
s
[(0.6)] .57211 .1851 0 1 Mshowa
.71711 .1976 m
.71711 .20385 L
s
[(0.8)] .71711 .1851 0 1 Mshowa
.86212 .1976 m
.86212 .20385 L
s
[(1)] .86212 .1851 0 1 Mshowa
.125 Mabswid
.17334 .1976 m
.17334 .20135 L
s
.20959 .1976 m
.20959 .20135 L
s
.24584 .1976 m
.24584 .20135 L
s
.31834 .1976 m
.31834 .20135 L
s
.3546 .1976 m
.3546 .20135 L
s
.39085 .1976 m
.39085 .20135 L
s
.46335 .1976 m
.46335 .20135 L
s
.4996 .1976 m
.4996 .20135 L
s
.53585 .1976 m
.53585 .20135 L
s
.60836 .1976 m
.60836 .20135 L
s
.64461 .1976 m
.64461 .20135 L
s
.68086 .1976 m
.68086 .20135 L
s
.75336 .1976 m
.75336 .20135 L
s
.78962 .1976 m
.78962 .20135 L
s
.82587 .1976 m
.82587 .20135 L
s
.89837 .1976 m
.89837 .20135 L
s
.93462 .1976 m
.93462 .20135 L
s
.97088 .1976 m
.97088 .20135 L
s
.10083 .1976 m
.10083 .20135 L
s
.06458 .1976 m
.06458 .20135 L
s
.02833 .1976 m
.02833 .20135 L
s
.25 Mabswid
0 .1976 m
1 .1976 L
s
.13708 .56012 m
.14333 .56012 L
s
[(0.5)] .12458 .56012 1 0 Mshowa
.13708 .92264 m
.14333 .92264 L
s
[(1)] .12458 .92264 1 0 Mshowa
.13708 1.28515 m
.14333 1.28515 L
s
[(1.5)] .12458 1.28515 1 0 Mshowa
.13708 1.64767 m
.14333 1.64767 L
s
[(2)] .12458 1.64767 1 0 Mshowa
.13708 2.01019 m
.14333 2.01019 L
s
[(2.5)] .12458 2.01019 1 0 Mshowa
.13708 2.37271 m
.14333 2.37271 L
s
[(3)] .12458 2.37271 1 0 Mshowa
.125 Mabswid
.13708 .2701 m
.14083 .2701 L
s
.13708 .34261 m
.14083 .34261 L
s
.13708 .41511 m
.14083 .41511 L
s
.13708 .48762 m
.14083 .48762 L
s
.13708 .63262 m
.14083 .63262 L
s
.13708 .70513 m
.14083 .70513 L
s
.13708 .77763 m
.14083 .77763 L
s
.13708 .85013 m
.14083 .85013 L
s
.13708 .99514 m
.14083 .99514 L
s
.13708 1.06764 m
.14083 1.06764 L
s
.13708 1.14015 m
.14083 1.14015 L
s
.13708 1.21265 m
.14083 1.21265 L
s
.13708 1.35766 m
.14083 1.35766 L
s
.13708 1.43016 m
.14083 1.43016 L
s
.13708 1.50266 m
.14083 1.50266 L
s
.13708 1.57517 m
.14083 1.57517 L
s
.13708 1.72017 m
.14083 1.72017 L
s
.13708 1.79268 m
.14083 1.79268 L
s
.13708 1.86518 m
.14083 1.86518 L
s
.13708 1.93769 m
.14083 1.93769 L
s
.13708 2.08269 m
.14083 2.08269 L
s
.13708 2.1552 m
.14083 2.1552 L
s
.13708 2.2277 m
.14083 2.2277 L
s
.13708 2.3002 m
.14083 2.3002 L
s
.13708 .1251 m
.14083 .1251 L
s
.13708 .05259 m
.14083 .05259 L
s
.13708 2.44521 m
.14083 2.44521 L
s
.13708 2.51771 m
.14083 2.51771 L
s
.13708 2.59022 m
.14083 2.59022 L
s
.13708 2.66272 m
.14083 2.66272 L
s
.25 Mabswid
.13708 0 m
.13708 2.69275 L
s
0 0 m
1 0 L
1 2.69275 L
0 2.69275 L
closepath
clip
newpath
.5 Mabswid
.85655 .1996 m
.85655 .19967 L
.85655 .19975 L
.85655 .19982 L
.85655 .1999 L
.85655 .19998 L
.85655 .20006 L
.85654 .20015 L
.85654 .20024 L
.85654 .20034 L
.85654 .20043 L
.85654 .20053 L
.85654 .20064 L
.85654 .20074 L
.85654 .20085 L
.85654 .20097 L
.85654 .20109 L
.85654 .20121 L
.85654 .20134 L
.85654 .20147 L
.85654 .20161 L
.85654 .20175 L
.85654 .20189 L
.85653 .20205 L
.85653 .2022 L
.85653 .20237 L
.85653 .20253 L
.85653 .20271 L
.85653 .20289 L
.85653 .20308 L
.85652 .20327 L
.85652 .20347 L
.85652 .20368 L
.85652 .20389 L
.85652 .20411 L
.85651 .20434 L
.85651 .20458 L
.85651 .20483 L
.8565 .20508 L
.8565 .20535 L
.8565 .20562 L
.85649 .20591 L
.85649 .2062 L
.85649 .2065 L
.85648 .20682 L
.85648 .20714 L
.85647 .20748 L
.85647 .20783 L
.85646 .20819 L
.85645 .20857 L
Mistroke
.85645 .20895 L
.85644 .20936 L
.85643 .20977 L
.85642 .2102 L
.85641 .21065 L
.8564 .21111 L
.85639 .21159 L
.85638 .21208 L
.85637 .21259 L
.85636 .21312 L
.85634 .21367 L
.85633 .21424 L
.85631 .21483 L
.85629 .21544 L
.85627 .21607 L
.85626 .21672 L
.85623 .2174 L
.85621 .2181 L
.85619 .21883 L
.85616 .21958 L
.85613 .22036 L
.8561 .22116 L
.85607 .222 L
.85604 .22286 L
.856 .22376 L
.85596 .22469 L
.85592 .22565 L
.85588 .22664 L
.85583 .22768 L
.85578 .22874 L
.85572 .22985 L
.85566 .231 L
.8556 .23218 L
.85553 .23342 L
.85546 .23469 L
.85538 .23601 L
.8553 .23738 L
.85521 .2388 L
.85512 .24027 L
.85502 .24179 L
.85491 .24337 L
.8548 .24501 L
.85468 .2467 L
.85455 .24846 L
.85441 .25029 L
.85426 .25218 L
.8541 .25414 L
.85393 .25617 L
.85376 .25828 L
.85356 .26046 L
Mistroke
.85336 .26273 L
.85314 .26509 L
.85292 .26753 L
.85267 .27006 L
.85241 .27269 L
.85214 .27543 L
.85184 .27826 L
.85153 .2812 L
.85121 .28426 L
.85086 .28743 L
.85049 .29073 L
.8501 .29416 L
.84969 .29771 L
.84926 .30141 L
.8488 .30526 L
.84832 .30925 L
.84782 .3134 L
.84729 .31772 L
.84673 .32221 L
.84615 .32688 L
.84554 .33174 L
.8449 .33679 L
.84424 .34205 L
.84355 .34752 L
.84283 .35321 L
.84208 .35913 L
.84131 .36529 L
.84051 .3717 L
.83968 .37837 L
.83883 .38531 L
.83795 .39253 L
.83706 .40005 L
.83614 .40787 L
.8352 .416 L
.83424 .42446 L
.83327 .43326 L
.83228 .44241 L
.83128 .45192 L
.83027 .46181 L
.82925 .47208 L
.82823 .48276 L
.8272 .49386 L
.82617 .50538 L
.82515 .51734 L
.82413 .52976 L
.82312 .54266 L
.82212 .55603 L
.82113 .56991 L
.82016 .58431 L
.8192 .59923 L
Mistroke
.81826 .6147 L
.81734 .63074 L
.81644 .64736 L
.81556 .66458 L
.81471 .68241 L
.81389 .70089 L
.81309 .72002 L
.81232 .73982 L
.81157 .76033 L
.81085 .78156 L
.81017 .80353 L
.8095 .82627 L
.80887 .8498 L
.80827 .87416 L
.80769 .89936 L
.80714 .92543 L
.80661 .95241 L
.80611 .98032 L
.80564 1.0092 L
.80519 1.03908 L
.80476 1.06999 L
.80436 1.10197 L
.80397 1.13506 L
.80361 1.1693 L
.80327 1.20471 L
.80295 1.24136 L
.80264 1.27927 L
.80236 1.3185 L
.80209 1.35909 L
.80184 1.40109 L
.8016 1.44455 L
.80137 1.48951 L
.80116 1.53604 L
.80097 1.58419 L
.80078 1.63402 L
.80061 1.68558 L
.80044 1.73894 L
.80029 1.79416 L
.80015 1.85131 L
.80001 1.91046 L
.79989 1.97167 L
.79977 2.03503 L
.79966 2.1006 L
.79955 2.16846 L
.79946 2.2387 L
.79937 2.31141 L
.79928 2.38666 L
.7992 2.46455 L
.79913 2.54518 L
.79906 2.62864 L
Mistroke
Mfstroke
newpath
.85655 .1996 .13549 0 365.73 arc
s
newpath
.85655 .19998 .13549 0 365.73 arc
s
newpath
.85654 .20043 .13549 0 365.73 arc
s
newpath
.85654 .20097 .13548 0 365.73 arc
s
newpath
.85654 .20161 .13548 0 365.73 arc
s
newpath
.85653 .20237 .13548 0 365.73 arc
s
newpath
.85652 .20327 .13547 0 365.73 arc
s
newpath
.85651 .20434 .13547 0 365.73 arc
s
newpath
.8565 .20562 .13546 0 365.73 arc
s
newpath
.85648 .20714 .13544 0 365.73 arc
s
newpath
.85645 .20895 .13542 0 365.73 arc
s
newpath
.8564 .21111 .13539 0 365.73 arc
s
newpath
.85634 .21367 .13535 0 365.73 arc
s
newpath
.85626 .21672 .13529 0 365.73 arc
s
newpath
.85613 .22036 .13521 0 365.73 arc
s
newpath
.85596 .22469 .1351 0 365.73 arc
s
newpath
.85572 .22985 .13494 0 365.73 arc
s
newpath
.85538 .23601 .13471 0 365.73 arc
s
newpath
.85491 .24337 .13439 0 365.73 arc
s
newpath
.85426 .25218 .13395 0 365.73 arc
s
newpath
.85336 .26273 .13334 0 365.73 arc
s
newpath
.85214 .27543 .13251 0 365.73 arc
s
newpath
.85049 .29073 .13138 0 365.73 arc
s
newpath
.84832 .30925 .12988 0 365.73 arc
s
newpath
.84554 .33174 .12792 0 365.73 arc
s
newpath
.84208 .35913 .12545 0 365.73 arc
s
newpath
.83795 .39253 .12244 0 365.73 arc
s
newpath
.83327 .43326 .11894 0 365.73 arc
s
newpath
.82823 .48276 .11507 0 365.73 arc
s
newpath
.82312 .54266 .11107 0 365.73 arc
s
newpath
.81826 .6147 .10723 0 365.73 arc
s
newpath
.81389 .70089 .10387 0 365.73 arc
s
newpath
.81017 .80353 .10128 0 365.73 arc
s
newpath
.80714 .92543 .09975 0 365.73 arc
s
newpath
.80476 1.06999 .09948 0 365.73 arc
s
newpath
.80295 1.24136 .10071 0 365.73 arc
s
newpath
.8016 1.44455 .10366 0 365.73 arc
s
newpath
.80061 1.68558 .10861 0 365.73 arc
s
newpath
.79989 1.97167 .11589 0 365.73 arc
s
newpath
.79937 2.31141 .12591 0 365.73 arc
s
newpath
.85655 .1996 .01271 0 365.73 arc
s
newpath
.85655 .19998 .01271 0 365.73 arc
s
newpath
.85654 .20043 .01271 0 365.73 arc
s
newpath
.85654 .20097 .01271 0 365.73 arc
s
newpath
.85654 .20161 .01271 0 365.73 arc
s
newpath
.85653 .20237 .01271 0 365.73 arc
s
newpath
.85652 .20327 .01271 0 365.73 arc
s
newpath
.85651 .20434 .0127 0 365.73 arc
s
newpath
.8565 .20562 .0127 0 365.73 arc
s
newpath
.85648 .20714 .0127 0 365.73 arc
s
newpath
.85645 .20895 .0127 0 365.73 arc
s
newpath
.8564 .21111 .01269 0 365.73 arc
s
newpath
.85634 .21367 .01268 0 365.73 arc
s
newpath
.85626 .21672 .01267 0 365.73 arc
s
newpath
.85613 .22036 .01266 0 365.73 arc
s
newpath
.85596 .22469 .01264 0 365.73 arc
s
newpath
.85572 .22985 .01261 0 365.73 arc
s
newpath
.85538 .23601 .01257 0 365.73 arc
s
newpath
.85491 .24337 .01251 0 365.73 arc
s
newpath
.85426 .25218 .01243 0 365.73 arc
s
newpath
.85336 .26273 .01232 0 365.73 arc
s
newpath
.85214 .27543 .01218 0 365.73 arc
s
newpath
.85049 .29073 .01197 0 365.73 arc
s
newpath
.84832 .30925 .01171 0 365.73 arc
s
newpath
.84554 .33174 .01137 0 365.73 arc
s
newpath
.84208 .35913 .01094 0 365.73 arc
s
newpath
.83795 .39253 .01042 0 365.73 arc
s
newpath
.83327 .43326 .00982 0 365.73 arc
s
newpath
.82823 .48276 .00917 0 365.73 arc
s
newpath
.82312 .54266 .00849 0 365.73 arc
s
newpath
.81826 .6147 .00784 0 365.73 arc
s
newpath
.81389 .70089 .00724 0 365.73 arc
s
newpath
.81017 .80353 .00673 0 365.73 arc
s
newpath
.80714 .92543 .00632 0 365.73 arc
s
newpath
.80476 1.06999 .00602 0 365.73 arc
s
newpath
.80295 1.24136 .00583 0 365.73 arc
s
newpath
.8016 1.44455 .00576 0 365.73 arc
s
newpath
.80061 1.68558 .0058 0 365.73 arc
s
newpath
.79989 1.97167 .00596 0 365.73 arc
s
newpath
.79937 2.31141 .00627 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.40744 0.477324 2.62864 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.137085 0.725035 0.197601 0.725035 [
[.28209 .1851 -7.2 -7.2 ]
[.28209 .1851 7.2 0 ]
[.4271 .1851 -7.2 -7.2 ]
[.4271 .1851 7.2 0 ]
[.57211 .1851 -7.2 -7.2 ]
[.57211 .1851 7.2 0 ]
[.71711 .1851 -7.2 -7.2 ]
[.71711 .1851 7.2 0 ]
[.86212 .1851 -2.4 -7.2 ]
[.86212 .1851 2.4 0 ]
[.12458 .56012 -14.4 -3.6 ]
[.12458 .56012 0 3.6 ]
[.12458 .92264 -4.8 -3.6 ]
[.12458 .92264 0 3.6 ]
[.12458 1.28515 -14.4 -3.6 ]
[.12458 1.28515 0 3.6 ]
[.12458 1.64767 -4.8 -3.6 ]
[.12458 1.64767 0 3.6 ]
[.12458 2.01019 -14.4 -3.6 ]
[.12458 2.01019 0 3.6 ]
[.12458 2.37271 -4.8 -3.6 ]
[.12458 2.37271 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.69275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.28209 .1976 m
.28209 .20385 L
s
[(0.2)] .28209 .1851 0 1 Mshowa
.4271 .1976 m
.4271 .20385 L
s
[(0.4)] .4271 .1851 0 1 Mshowa
.57211 .1976 m
.57211 .20385 L
s
[(0.6)] .57211 .1851 0 1 Mshowa
.71711 .1976 m
.71711 .20385 L
s
[(0.8)] .71711 .1851 0 1 Mshowa
.86212 .1976 m
.86212 .20385 L
s
[(1)] .86212 .1851 0 1 Mshowa
.125 Mabswid
.17334 .1976 m
.17334 .20135 L
s
.20959 .1976 m
.20959 .20135 L
s
.24584 .1976 m
.24584 .20135 L
s
.31834 .1976 m
.31834 .20135 L
s
.3546 .1976 m
.3546 .20135 L
s
.39085 .1976 m
.39085 .20135 L
s
.46335 .1976 m
.46335 .20135 L
s
.4996 .1976 m
.4996 .20135 L
s
.53585 .1976 m
.53585 .20135 L
s
.60836 .1976 m
.60836 .20135 L
s
.64461 .1976 m
.64461 .20135 L
s
.68086 .1976 m
.68086 .20135 L
s
.75336 .1976 m
.75336 .20135 L
s
.78962 .1976 m
.78962 .20135 L
s
.82587 .1976 m
.82587 .20135 L
s
.89837 .1976 m
.89837 .20135 L
s
.93462 .1976 m
.93462 .20135 L
s
.97088 .1976 m
.97088 .20135 L
s
.10083 .1976 m
.10083 .20135 L
s
.06458 .1976 m
.06458 .20135 L
s
.02833 .1976 m
.02833 .20135 L
s
.25 Mabswid
0 .1976 m
1 .1976 L
s
.13708 .56012 m
.14333 .56012 L
s
[(0.5)] .12458 .56012 1 0 Mshowa
.13708 .92264 m
.14333 .92264 L
s
[(1)] .12458 .92264 1 0 Mshowa
.13708 1.28515 m
.14333 1.28515 L
s
[(1.5)] .12458 1.28515 1 0 Mshowa
.13708 1.64767 m
.14333 1.64767 L
s
[(2)] .12458 1.64767 1 0 Mshowa
.13708 2.01019 m
.14333 2.01019 L
s
[(2.5)] .12458 2.01019 1 0 Mshowa
.13708 2.37271 m
.14333 2.37271 L
s
[(3)] .12458 2.37271 1 0 Mshowa
.125 Mabswid
.13708 .2701 m
.14083 .2701 L
s
.13708 .34261 m
.14083 .34261 L
s
.13708 .41511 m
.14083 .41511 L
s
.13708 .48762 m
.14083 .48762 L
s
.13708 .63262 m
.14083 .63262 L
s
.13708 .70513 m
.14083 .70513 L
s
.13708 .77763 m
.14083 .77763 L
s
.13708 .85013 m
.14083 .85013 L
s
.13708 .99514 m
.14083 .99514 L
s
.13708 1.06764 m
.14083 1.06764 L
s
.13708 1.14015 m
.14083 1.14015 L
s
.13708 1.21265 m
.14083 1.21265 L
s
.13708 1.35766 m
.14083 1.35766 L
s
.13708 1.43016 m
.14083 1.43016 L
s
.13708 1.50266 m
.14083 1.50266 L
s
.13708 1.57517 m
.14083 1.57517 L
s
.13708 1.72017 m
.14083 1.72017 L
s
.13708 1.79268 m
.14083 1.79268 L
s
.13708 1.86518 m
.14083 1.86518 L
s
.13708 1.93769 m
.14083 1.93769 L
s
.13708 2.08269 m
.14083 2.08269 L
s
.13708 2.1552 m
.14083 2.1552 L
s
.13708 2.2277 m
.14083 2.2277 L
s
.13708 2.3002 m
.14083 2.3002 L
s
.13708 .1251 m
.14083 .1251 L
s
.13708 .05259 m
.14083 .05259 L
s
.13708 2.44521 m
.14083 2.44521 L
s
.13708 2.51771 m
.14083 2.51771 L
s
.13708 2.59022 m
.14083 2.59022 L
s
.13708 2.66272 m
.14083 2.66272 L
s
.25 Mabswid
.13708 0 m
.13708 2.69275 L
s
0 0 m
1 0 L
1 2.69275 L
0 2.69275 L
closepath
clip
newpath
.5 Mabswid
.85655 .1996 m
.85655 .19967 L
.85655 .19975 L
.85655 .19982 L
.85655 .1999 L
.85655 .19998 L
.85655 .20006 L
.85654 .20015 L
.85654 .20024 L
.85654 .20034 L
.85654 .20043 L
.85654 .20053 L
.85654 .20064 L
.85654 .20074 L
.85654 .20085 L
.85654 .20097 L
.85654 .20109 L
.85654 .20121 L
.85654 .20134 L
.85654 .20147 L
.85654 .20161 L
.85654 .20175 L
.85654 .20189 L
.85653 .20205 L
.85653 .2022 L
.85653 .20237 L
.85653 .20253 L
.85653 .20271 L
.85653 .20289 L
.85653 .20308 L
.85652 .20327 L
.85652 .20347 L
.85652 .20368 L
.85652 .20389 L
.85652 .20411 L
.85651 .20434 L
.85651 .20458 L
.85651 .20483 L
.8565 .20508 L
.8565 .20535 L
.8565 .20562 L
.85649 .20591 L
.85649 .2062 L
.85649 .2065 L
.85648 .20682 L
.85648 .20714 L
.85647 .20748 L
.85647 .20783 L
.85646 .20819 L
.85645 .20857 L
Mistroke
.85645 .20895 L
.85644 .20936 L
.85643 .20977 L
.85642 .2102 L
.85641 .21065 L
.8564 .21111 L
.85639 .21159 L
.85638 .21208 L
.85637 .21259 L
.85636 .21312 L
.85634 .21367 L
.85633 .21424 L
.85631 .21483 L
.85629 .21544 L
.85627 .21607 L
.85626 .21672 L
.85623 .2174 L
.85621 .2181 L
.85619 .21883 L
.85616 .21958 L
.85613 .22036 L
.8561 .22116 L
.85607 .222 L
.85604 .22286 L
.856 .22376 L
.85596 .22469 L
.85592 .22565 L
.85588 .22664 L
.85583 .22768 L
.85578 .22874 L
.85572 .22985 L
.85566 .231 L
.8556 .23218 L
.85553 .23342 L
.85546 .23469 L
.85538 .23601 L
.8553 .23738 L
.85521 .2388 L
.85512 .24027 L
.85502 .24179 L
.85491 .24337 L
.8548 .24501 L
.85468 .2467 L
.85455 .24846 L
.85441 .25029 L
.85426 .25218 L
.8541 .25414 L
.85393 .25617 L
.85376 .25828 L
.85356 .26046 L
Mistroke
.85336 .26273 L
.85314 .26509 L
.85292 .26753 L
.85267 .27006 L
.85241 .27269 L
.85214 .27543 L
.85184 .27826 L
.85153 .2812 L
.85121 .28426 L
.85086 .28743 L
.85049 .29073 L
.8501 .29416 L
.84969 .29771 L
.84926 .30141 L
.8488 .30526 L
.84832 .30925 L
.84782 .3134 L
.84729 .31772 L
.84673 .32221 L
.84615 .32688 L
.84554 .33174 L
.8449 .33679 L
.84424 .34205 L
.84355 .34752 L
.84283 .35321 L
.84208 .35913 L
.84131 .36529 L
.84051 .3717 L
.83968 .37837 L
.83883 .38531 L
.83795 .39253 L
.83706 .40005 L
.83614 .40787 L
.8352 .416 L
.83424 .42446 L
.83327 .43326 L
.83228 .44241 L
.83128 .45192 L
.83027 .46181 L
.82925 .47208 L
.82823 .48276 L
.8272 .49386 L
.82617 .50538 L
.82515 .51734 L
.82413 .52976 L
.82312 .54266 L
.82212 .55603 L
.82113 .56991 L
.82016 .58431 L
.8192 .59923 L
Mistroke
.81826 .6147 L
.81734 .63074 L
.81644 .64736 L
.81556 .66458 L
.81471 .68241 L
.81389 .70089 L
.81309 .72002 L
.81232 .73982 L
.81157 .76033 L
.81085 .78156 L
.81017 .80353 L
.8095 .82627 L
.80887 .8498 L
.80827 .87416 L
.80769 .89936 L
.80714 .92543 L
.80661 .95241 L
.80611 .98032 L
.80564 1.0092 L
.80519 1.03908 L
.80476 1.06999 L
.80436 1.10197 L
.80397 1.13506 L
.80361 1.1693 L
.80327 1.20471 L
.80295 1.24136 L
.80264 1.27927 L
.80236 1.3185 L
.80209 1.35909 L
.80184 1.40109 L
.8016 1.44455 L
.80137 1.48951 L
.80116 1.53604 L
.80097 1.58419 L
.80078 1.63402 L
.80061 1.68558 L
.80044 1.73894 L
.80029 1.79416 L
.80015 1.85131 L
.80001 1.91046 L
.79989 1.97167 L
.79977 2.03503 L
.79966 2.1006 L
.79955 2.16846 L
.79946 2.2387 L
.79937 2.31141 L
.79928 2.38666 L
.7992 2.46455 L
.79913 2.54518 L
.79906 2.62864 L
Mistroke
Mfstroke
newpath
.85655 .1996 .13549 0 365.73 arc
s
newpath
.85655 .19998 .13549 0 365.73 arc
s
newpath
.85654 .20043 .13549 0 365.73 arc
s
newpath
.85654 .20097 .13548 0 365.73 arc
s
newpath
.85654 .20161 .13548 0 365.73 arc
s
newpath
.85653 .20237 .13548 0 365.73 arc
s
newpath
.85652 .20327 .13547 0 365.73 arc
s
newpath
.85651 .20434 .13547 0 365.73 arc
s
newpath
.8565 .20562 .13546 0 365.73 arc
s
newpath
.85648 .20714 .13544 0 365.73 arc
s
newpath
.85645 .20895 .13542 0 365.73 arc
s
newpath
.8564 .21111 .13539 0 365.73 arc
s
newpath
.85634 .21367 .13535 0 365.73 arc
s
newpath
.85626 .21672 .13529 0 365.73 arc
s
newpath
.85613 .22036 .13521 0 365.73 arc
s
newpath
.85596 .22469 .1351 0 365.73 arc
s
newpath
.85572 .22985 .13494 0 365.73 arc
s
newpath
.85538 .23601 .13471 0 365.73 arc
s
newpath
.85491 .24337 .13439 0 365.73 arc
s
newpath
.85426 .25218 .13395 0 365.73 arc
s
newpath
.85336 .26273 .13334 0 365.73 arc
s
newpath
.85214 .27543 .13251 0 365.73 arc
s
newpath
.85049 .29073 .13138 0 365.73 arc
s
newpath
.84832 .30925 .12988 0 365.73 arc
s
newpath
.84554 .33174 .12792 0 365.73 arc
s
newpath
.84208 .35913 .12545 0 365.73 arc
s
newpath
.83795 .39253 .12244 0 365.73 arc
s
newpath
.83327 .43326 .11894 0 365.73 arc
s
newpath
.82823 .48276 .11507 0 365.73 arc
s
newpath
.82312 .54266 .11107 0 365.73 arc
s
newpath
.81826 .6147 .10723 0 365.73 arc
s
newpath
.81389 .70089 .10387 0 365.73 arc
s
newpath
.81017 .80353 .10128 0 365.73 arc
s
newpath
.80714 .92543 .09975 0 365.73 arc
s
newpath
.80476 1.06999 .09948 0 365.73 arc
s
newpath
.80295 1.24136 .10071 0 365.73 arc
s
newpath
.8016 1.44455 .10366 0 365.73 arc
s
newpath
.80061 1.68558 .10861 0 365.73 arc
s
newpath
.79989 1.97167 .11589 0 365.73 arc
s
newpath
.79937 2.31141 .12591 0 365.73 arc
s
newpath
.85655 .1996 .01271 0 365.73 arc
s
newpath
.85655 .19998 .01271 0 365.73 arc
s
newpath
.85654 .20043 .01271 0 365.73 arc
s
newpath
.85654 .20097 .01271 0 365.73 arc
s
newpath
.85654 .20161 .01271 0 365.73 arc
s
newpath
.85653 .20237 .01271 0 365.73 arc
s
newpath
.85652 .20327 .01271 0 365.73 arc
s
newpath
.85651 .20434 .0127 0 365.73 arc
s
newpath
.8565 .20562 .0127 0 365.73 arc
s
newpath
.85648 .20714 .0127 0 365.73 arc
s
newpath
.85645 .20895 .0127 0 365.73 arc
s
newpath
.8564 .21111 .01269 0 365.73 arc
s
newpath
.85634 .21367 .01268 0 365.73 arc
s
newpath
.85626 .21672 .01267 0 365.73 arc
s
newpath
.85613 .22036 .01266 0 365.73 arc
s
newpath
.85596 .22469 .01264 0 365.73 arc
s
newpath
.85572 .22985 .01261 0 365.73 arc
s
newpath
.85538 .23601 .01257 0 365.73 arc
s
newpath
.85491 .24337 .01251 0 365.73 arc
s
newpath
.85426 .25218 .01243 0 365.73 arc
s
newpath
.85336 .26273 .01232 0 365.73 arc
s
newpath
.85214 .27543 .01218 0 365.73 arc
s
newpath
.85049 .29073 .01197 0 365.73 arc
s
newpath
.84832 .30925 .01171 0 365.73 arc
s
newpath
.84554 .33174 .01137 0 365.73 arc
s
newpath
.84208 .35913 .01094 0 365.73 arc
s
newpath
.83795 .39253 .01042 0 365.73 arc
s
newpath
.83327 .43326 .00982 0 365.73 arc
s
newpath
.82823 .48276 .00917 0 365.73 arc
s
newpath
.82312 .54266 .00849 0 365.73 arc
s
newpath
.81826 .6147 .00784 0 365.73 arc
s
newpath
.81389 .70089 .00724 0 365.73 arc
s
newpath
.81017 .80353 .00673 0 365.73 arc
s
newpath
.80714 .92543 .00632 0 365.73 arc
s
newpath
.80476 1.06999 .00602 0 365.73 arc
s
newpath
.80295 1.24136 .00583 0 365.73 arc
s
newpath
.8016 1.44455 .00576 0 365.73 arc
s
newpath
.80061 1.68558 .0058 0 365.73 arc
s
newpath
.79989 1.97167 .00596 0 365.73 arc
s
newpath
.79937 2.31141 .00627 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 1.40744 0.97619 2.62864 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.137085 0.725035 0.197601 0.725035 [
[.28209 .1851 -7.2 -7.2 ]
[.28209 .1851 7.2 0 ]
[.4271 .1851 -7.2 -7.2 ]
[.4271 .1851 7.2 0 ]
[.57211 .1851 -7.2 -7.2 ]
[.57211 .1851 7.2 0 ]
[.71711 .1851 -7.2 -7.2 ]
[.71711 .1851 7.2 0 ]
[.86212 .1851 -2.4 -7.2 ]
[.86212 .1851 2.4 0 ]
[.12458 .56012 -14.4 -3.6 ]
[.12458 .56012 0 3.6 ]
[.12458 .92264 -4.8 -3.6 ]
[.12458 .92264 0 3.6 ]
[.12458 1.28515 -14.4 -3.6 ]
[.12458 1.28515 0 3.6 ]
[.12458 1.64767 -4.8 -3.6 ]
[.12458 1.64767 0 3.6 ]
[.12458 2.01019 -14.4 -3.6 ]
[.12458 2.01019 0 3.6 ]
[.12458 2.37271 -4.8 -3.6 ]
[.12458 2.37271 0 3.6 ]
[ 0 0 0 0 ]
[ 1 2.69275 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.28209 .1976 m
.28209 .20385 L
s
[(0.2)] .28209 .1851 0 1 Mshowa
.4271 .1976 m
.4271 .20385 L
s
[(0.4)] .4271 .1851 0 1 Mshowa
.57211 .1976 m
.57211 .20385 L
s
[(0.6)] .57211 .1851 0 1 Mshowa
.71711 .1976 m
.71711 .20385 L
s
[(0.8)] .71711 .1851 0 1 Mshowa
.86212 .1976 m
.86212 .20385 L
s
[(1)] .86212 .1851 0 1 Mshowa
.125 Mabswid
.17334 .1976 m
.17334 .20135 L
s
.20959 .1976 m
.20959 .20135 L
s
.24584 .1976 m
.24584 .20135 L
s
.31834 .1976 m
.31834 .20135 L
s
.3546 .1976 m
.3546 .20135 L
s
.39085 .1976 m
.39085 .20135 L
s
.46335 .1976 m
.46335 .20135 L
s
.4996 .1976 m
.4996 .20135 L
s
.53585 .1976 m
.53585 .20135 L
s
.60836 .1976 m
.60836 .20135 L
s
.64461 .1976 m
.64461 .20135 L
s
.68086 .1976 m
.68086 .20135 L
s
.75336 .1976 m
.75336 .20135 L
s
.78962 .1976 m
.78962 .20135 L
s
.82587 .1976 m
.82587 .20135 L
s
.89837 .1976 m
.89837 .20135 L
s
.93462 .1976 m
.93462 .20135 L
s
.97088 .1976 m
.97088 .20135 L
s
.10083 .1976 m
.10083 .20135 L
s
.06458 .1976 m
.06458 .20135 L
s
.02833 .1976 m
.02833 .20135 L
s
.25 Mabswid
0 .1976 m
1 .1976 L
s
.13708 .56012 m
.14333 .56012 L
s
[(0.5)] .12458 .56012 1 0 Mshowa
.13708 .92264 m
.14333 .92264 L
s
[(1)] .12458 .92264 1 0 Mshowa
.13708 1.28515 m
.14333 1.28515 L
s
[(1.5)] .12458 1.28515 1 0 Mshowa
.13708 1.64767 m
.14333 1.64767 L
s
[(2)] .12458 1.64767 1 0 Mshowa
.13708 2.01019 m
.14333 2.01019 L
s
[(2.5)] .12458 2.01019 1 0 Mshowa
.13708 2.37271 m
.14333 2.37271 L
s
[(3)] .12458 2.37271 1 0 Mshowa
.125 Mabswid
.13708 .2701 m
.14083 .2701 L
s
.13708 .34261 m
.14083 .34261 L
s
.13708 .41511 m
.14083 .41511 L
s
.13708 .48762 m
.14083 .48762 L
s
.13708 .63262 m
.14083 .63262 L
s
.13708 .70513 m
.14083 .70513 L
s
.13708 .77763 m
.14083 .77763 L
s
.13708 .85013 m
.14083 .85013 L
s
.13708 .99514 m
.14083 .99514 L
s
.13708 1.06764 m
.14083 1.06764 L
s
.13708 1.14015 m
.14083 1.14015 L
s
.13708 1.21265 m
.14083 1.21265 L
s
.13708 1.35766 m
.14083 1.35766 L
s
.13708 1.43016 m
.14083 1.43016 L
s
.13708 1.50266 m
.14083 1.50266 L
s
.13708 1.57517 m
.14083 1.57517 L
s
.13708 1.72017 m
.14083 1.72017 L
s
.13708 1.79268 m
.14083 1.79268 L
s
.13708 1.86518 m
.14083 1.86518 L
s
.13708 1.93769 m
.14083 1.93769 L
s
.13708 2.08269 m
.14083 2.08269 L
s
.13708 2.1552 m
.14083 2.1552 L
s
.13708 2.2277 m
.14083 2.2277 L
s
.13708 2.3002 m
.14083 2.3002 L
s
.13708 .1251 m
.14083 .1251 L
s
.13708 .05259 m
.14083 .05259 L
s
.13708 2.44521 m
.14083 2.44521 L
s
.13708 2.51771 m
.14083 2.51771 L
s
.13708 2.59022 m
.14083 2.59022 L
s
.13708 2.66272 m
.14083 2.66272 L
s
.25 Mabswid
.13708 0 m
.13708 2.69275 L
s
0 0 m
1 0 L
1 2.69275 L
0 2.69275 L
closepath
clip
newpath
.5 Mabswid
.0016 .19818 m
.0016 .1982 L
.0016 .19822 L
.0016 .19824 L
.0016 .19826 L
.0016 .19829 L
.0016 .19831 L
.0016 .19834 L
.0016 .19836 L
.0016 .19839 L
.0016 .19842 L
.0016 .19844 L
.0016 .19847 L
.0016 .1985 L
.0016 .19854 L
.0016 .19857 L
.0016 .1986 L
.00161 .19864 L
.00161 .19868 L
.00161 .19871 L
.00161 .19875 L
.00161 .19879 L
.00161 .19884 L
.00161 .19888 L
.00161 .19893 L
.00161 .19897 L
.00161 .19902 L
.00162 .19907 L
.00162 .19912 L
.00162 .19918 L
.00162 .19923 L
.00162 .19929 L
.00163 .19935 L
.00163 .19941 L
.00163 .19947 L
.00163 .19954 L
.00164 .19961 L
.00164 .19968 L
.00164 .19975 L
.00164 .19983 L
.00165 .19991 L
.00165 .19999 L
.00166 .20007 L
.00166 .20016 L
.00167 .20025 L
.00167 .20034 L
.00168 .20044 L
.00168 .20054 L
.00169 .20064 L
.0017 .20075 L
Mistroke
.0017 .20086 L
.00171 .20098 L
.00172 .2011 L
.00173 .20122 L
.00174 .20135 L
.00175 .20148 L
.00176 .20161 L
.00177 .20176 L
.00178 .2019 L
.0018 .20205 L
.00181 .20221 L
.00183 .20237 L
.00184 .20254 L
.00186 .20271 L
.00188 .20289 L
.0019 .20308 L
.00192 .20327 L
.00195 .20347 L
.00197 .20367 L
.002 .20388 L
.00203 .2041 L
.00206 .20433 L
.00209 .20457 L
.00213 .20481 L
.00217 .20506 L
.00221 .20532 L
.00225 .20559 L
.0023 .20586 L
.00235 .20615 L
.0024 .20645 L
.00246 .20675 L
.00252 .20707 L
.00259 .20739 L
.00266 .20773 L
.00273 .20808 L
.00281 .20844 L
.0029 .20881 L
.00299 .20919 L
.00309 .20958 L
.00319 .20999 L
.0033 .21041 L
.00342 .21084 L
.00355 .21129 L
.00369 .21175 L
.00383 .21222 L
.00399 .2127 L
.00415 .2132 L
.00433 .21372 L
.00451 .21425 L
.00471 .21479 L
Mistroke
.00493 .21535 L
.00515 .21592 L
.00539 .2165 L
.00565 .21711 L
.00592 .21772 L
.00621 .21835 L
.00652 .219 L
.00684 .21966 L
.00719 .22033 L
.00755 .22101 L
.00794 .22171 L
.00834 .22243 L
.00877 .22315 L
.00923 .22388 L
.00971 .22463 L
.01021 .22539 L
.01074 .22615 L
.0113 .22693 L
.01189 .22771 L
.0125 .22849 L
.01315 .22928 L
.01382 .23007 L
.01452 .23087 L
.01525 .23167 L
.01601 .23246 L
.0168 .23325 L
.01762 .23404 L
.01847 .23482 L
.01935 .23559 L
.02026 .23636 L
.02119 .23711 L
.02215 .23785 L
.02313 .23857 L
.02414 .23928 L
.02516 .23998 L
.02621 .24065 L
.02728 .24131 L
.02835 .24195 L
.02945 .24256 L
.03055 .24316 L
.03166 .24373 L
.03278 .24428 L
.0339 .24481 L
.03502 .24532 L
.03614 .24581 L
.03725 .24629 L
.03836 .24674 L
.03945 .24718 L
.04054 .2476 L
.0416 .24801 L
Mistroke
.04266 .24841 L
.04369 .2488 L
.0447 .24919 L
.04569 .24957 L
.04666 .24996 L
.0476 .25034 L
.04852 .25073 L
.04941 .25113 L
.05027 .25153 L
.0511 .25196 L
.0519 .2524 L
.05268 .25286 L
.05342 .25334 L
.05414 .25385 L
.05482 .25439 L
.05548 .25496 L
.05611 .25556 L
.05671 .25621 L
.05728 .25689 L
.05782 .25762 L
.05834 .2584 L
.05883 .25923 L
.0593 .2601 L
.05975 .26104 L
.06017 .26203 L
.06057 .26308 L
.06094 .26419 L
.0613 .26537 L
.06163 .26662 L
.06195 .26794 L
.06225 .26933 L
.06253 .2708 L
.0628 .27235 L
.06305 .27398 L
.06329 .27569 L
.06351 .27749 L
.06372 .27938 L
.06391 .28136 L
.0641 .28343 L
.06427 .28561 L
.06443 .28788 L
.06458 .29027 L
.06472 .29275 L
.06486 .29535 L
.06498 .29807 L
.0651 .3009 L
.06521 .30386 L
.06531 .30694 L
.06541 .31015 L
.0655 .31349 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[11]:=",
  ImageSize->{177.938, 479.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002a0001gb000`400?l00000o`00003o/Oooool0
0;7ooooo002ao`00000000?o0000ooooooooool0[Oooool1o`00000000?o0000ooooooooool0[Ooo
ool1o`00000000?o0000ooooooooool0[Oooool1o`00000000?o0000ooooooooool0[Oooool1o`00
000000?o0000ooooooooool0[Oooool1o`00000000?o0000ooooooooool0[Oooool1o`00000000?o
0000ooooooooool0[Oooool1o`00000000?o0000ooooooooool0[Oooool1o`00000000?o0000oooo
ooooool0[Oooool1o`00000000?o0000ooooooooool0[Oooool1o`00000000?o0000ooooooooool0
[Oooool1o`00000000?o0000ooooooooool0[Oooool1o`00000000?o0000ooooooooool0[Oooool1
o`00000000?o0000ooooooooool0[Oooool1o`00000000?o0000ooooooooool0[Oooool1o`000000
00?o0000ooooooooool0[Oooool1o`00000000?o0000ooooooooool0[Oooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo04;ooooo0Ol00000
0003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`12oooo
o`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`00
0?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOoo
ool2o`0004?ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0_ooooo`Wo00002_ooool1o`00000000?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo02kooooo3?l00008ooooo`7o000000000ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0;Oooool>o`0000Oo
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0/oooooa3o00001_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool01?l0003oooooooooooooool3o`0000?ooooo0ol0000Pooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`02oooo
o`;o00000oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`0Ao`00
00Kooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000007ooooo`?o00001oooool4o`0000Oooooo1?l00007ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000So
oooo00?o0000ooooool000001oooool3o`0000Oooooo1?l00005oooooa?o00001Oooool1o`000000
00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooool000001oooool4o`0000Oooooo1?l00008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Sooooo
0ol00007ooooo`03o`000?oooooo000000Oooooo1?l00005ooooo`[o00000_ooool7o`0000Gooooo
0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooo000000Sooooo0ol00007ooooo`;o000000?oooooo`000?ooool01_oo
ool00ol0003oooooo`000004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000008ooooo`?o00001oooool3o`0000Oooooo0_l000000ooooooo0000oooo
o`03ooooo`ko000000?oooooo`000?l000001?l00004ooooo`7o000000000ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool3o`0000Wooooo00?o0000
ooooooooool01oooool2o`0000Sooooo0ol00003ooooo`;o00008Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo0ol00009ooooo`;o00002?ooool2o`0000Gooooo1_l00002
ooooo`Co00000_ooool7o`0000Cooooo0Ol000000003o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo1?l00002oooo
o`;o00000_ooool7o`000004ooooool0003o0000o`0000Cooooo0Ol000000003o`000?oooooooooo
00KoooooC?l0000<ooooodco00000oooool1o`00000000?o0000ooooooooool01_ooool2o`0000So
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`Oo00000_ooool3o`0000;o
oooo0ol000001?oooooo0000o`000?l00004ooooo`7o000000000ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`Co
00000oooool5o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`7o000000000ol0003ooooo
ooooo`07ooooo`Co00001Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo
1?l00002ooooo`03o`000?oooooooooo00Ko00000_ooool4o`0000Cooooo0Ol000000003o`000?oo
oooooooo00Wooooo0_l00005ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:Ooo
ool3o`000003ooooool0003o000000?ooooo0ol00002ooooo`03o`000?oooooooooo00Co00001?oo
ool1o`00000000?o0000ooooooooool02_ooool2o`0000Cooooo00?o0000ooooooooool0EOooool2
o`0002[ooooo1?l000000ooooooo0000o`000006o`0000;ooooo00?o0000ooooooooool00ol00004
ooooo`7o000000000ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`0Yooooo`Go00001?ooool3o`000006ooooool0003o0000
ooooool0003ooooo0ol00004ooooo`7o000000000ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`Co00001Oooool3
o`0000?ooooo00?o0000ooooool000000ol00004ooooo`7o000000000ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yoooo
o`Ko000000?oooooo`000?l000000ol00003ooooo`Ko00001?ooool1o`00000000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo2?l000000ooooooo
0000o`00000:o`0000Cooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0
EOooool2o`0002[ooooo5?l00005ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool0:OoooolDo`0000Gooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0YoooooaCo00001Oooool1
o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
02Wooooo0_l000000ooooooo0000o`00000?o`0000Gooooo0Ol000000003o`000?oooooooooo013o
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`Co00000_ooool=o`0000Ko
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0Yooooo`Ko00000_ooool;o`0000Kooooo0Ol000000003o`000?oooooooooo013ooooo00?o
0000ooooooooool0EOooool2o`0002[ooooo4?l000000ooooooo0000o`000006ooooo`7o00000000
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:Oooool2
o`0000;ooooo2_l00002ooooo`?o00001_ooool1o`00000000?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool000001?l000000ooo
oooo0000o`000003o`000003ooooool0003o000000;o00001oooool1o`00000000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo1Ol00002ooooo`Oo
000000Coooooo`000?l0003o00001oooool1o`00000000?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool000000_ooool2o`000003
ooooool0003ooooo00;ooooo0ol000000ooooooo0000o`000007ooooo`7o000000000ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05Gooooo0_l0000Zooooo`;o000000?oooooo`000?ooool0
0_ooool5o`0000;ooooo0_l000000ooooooo0000ooooo`06ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000004ooooo`?o000000?oooooo`000?ooool01_ooool1o`00000000?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooool000002_l00003ooooo`;o00001oooool1o`00000000?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00_l00003
ooooo`03o`000?oooooooooo00;o000000Coooooo`000?l0003o00002?ooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Sooooo0_l00000
1?oooooo0000ooooooooool4o`0000Cooooo00Co0000oooooooooooo00002?ooool1o`00000000?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o0000
0_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
oooo0ol00002ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000001Oooool6o`000004
ooooool0003o0000o`0000Sooooo0Ol000000007o`000?ooooooooooooooool0003oooooo`000009
ooooo`03o`000?oooooooooo00;o0000Aoooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo00;o0000:_ooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000ooooo`07ooooo`7o000000001ol0003ooooooooooooooooo0000ooooool00000
1oooool3o`0000;ooooo00?o0000ooooooooool0A_ooool00ol0003oooooo`000007ooooo`?o0000
0_ooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo0_l00008ooooo`7o000000001ol0003ooooooooooooooooo0000
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00_ooool7o`0000?ooooo00?o0000ooooooooool01oooool1o`00000000?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`?o00000_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00Kooooo0ol00002ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ool000000_ooool8o`0000?ooooo00?o0000ooooooooool01oooool1o`00000000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool00_l00003ooooo`;o00000oooool4o`0000Wooooo0Ol000000003o`000?oooooooooo013ooooo
00?o0000ooooooooool0EOooool2o`0002Wooooo00?o0000ooooooooool00_l00003ooooo`03o`00
0?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`08ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooo`00
0002ooooo`;o000000Coooooo`000?oooooooooo0_l000001?oooooo0000ooooool00009ooooo`7o
000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`03ooooo`Co00001?ooool2o`0000Wooooo0Ol000000003o`000?oo
oooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`;o00001Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Xooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Wooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Xooooo`05o`000?oooooo
ooooooooool000000_ooool4o`0000;ooooo0_l000000ooooooo0000ooooo`08ooooo`7o00000000
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo0_l0000Yooooo`04o`000?oooooo
ooooooooo`?o000000Coooooo`000?oooooooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo
0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0000?ooooo1?l00002ooooo`04o`000?ooooooooooo`0000Wo
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool2o`0000[ooooo
0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooooooo
o`0Yooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`;o00002_ooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo0_l00005
ooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`7o000000000ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo05Gooooo0_l0000Zooooo`Co00000oooool00ol0003oooooooooo`02oooo
o`?o00002_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool4o`0000?ooooo00Co0000oooooooo
oooo00002_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool5o`0000?ooooo00?o0000oooooooo
ool02?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Sooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Yooooo`04o`000?ooooooooooooooo`Ko00001?ooool00ol0003ooooo
ooooo`08ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool0:Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o0000
0_ooool00ol0003oooooooooo`08ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05Gooooo0_l0000Zooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_oo
ool2o`0000_ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Zooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`0Yooooo`04o`000?ooooooooooo`0000?ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000_ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Yooooo`04o`000?ooooooooooooooo`Co000000?oooooo`000?l00000
0oooool00ol0003oooooooooo`08ooooo`7o000000000ol0003oooooooooo`0;ooooo`?o00000_oo
ool00ol0003oooooooooo`1@ooooo`?o00000_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo0Ol000000003o`000?oooooo
oooo00cooooo00Co0000oooooooooooooooo0_l0001Booooo`04o`000?ooooooooooooooo`;o0000
:Oooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`08ooooo`7o0000
00000ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000Doooool01Ol0003ooooo
oooooooooooo000002[ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000oooooooo
ool02?ooool1o`00000000?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000005?o
oooo00Go0000ooooooooooooooooo`00000[ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`7o000000000ol0003oooooooooo`0;ooooo`;o
00000oooool00ol0003oooooooooo`1@ooooo`;o00000oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`7o
000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`08o`0000;ooooo00?o0000ooooooooool02Oooool1o`00000000?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`;o0000:oooool2o`0000Cooooo00Co
0000oooooooooooooooo0_l0000<ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooo`000002ooooo`03o`000?oo
oooooooo00;ooooo0_l0000<ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooooooool3o`000006ooooool0
003o0000o`000?oooooo00003?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool2o`0000Gooooo
00?o0000ooooooooool02Oooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Sooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`7o000000000ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo05Gooooo0_l0000Yooooo`03o`000?oooooooooo00Cooooo0_l00006oooo
o`03o`000?oooooooooo00Sooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000oooooooo
ool0EOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`08ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool1o`00000000?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`7o000000000ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo0_l0000[ooooo`03o`000?oooooooooo
00;ooooo1?l000000ooooooo0000o`00000<ooooo`7o000000000ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo05Gooooo00?o0000ooooooooool0:oooool5o`0000?ooooo00?o0000oooooooo
ool03?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`00
0?oooooooooo02[ooooo1_l000001Ooooooo0000o`000?oooooo000000gooooo0Ol000000003o`00
0?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo0Ol000000003o`000?oo
oooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`7o00000000
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool1
o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`;o0000:Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool1o`00
000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wo
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00Sooooo
0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`7o000000001?l0003oooooooooooooool3o`0000?ooooo00Co0000oooooooooooooooo
0ol00002ooooo`03o`000?oooooooooo04Kooooo0ol00003ooooo`04o`000?ooooooooooooooo`?o
00000_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`7o000000000ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_l00018ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_l0000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`7o000000000ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo0ol00002ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01_oo
ool3o`0000;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02Oooool1o`00000000?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`7o000000001?l0
003oooooooooooooool2o`0000Sooooo0ol00002ooooo`03o`000?oooooooooo04Kooooo0_l00008
ooooo`?o00000_ooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0<ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool0;?ooool7o`0000oooooo0Ol000000003o`000?oooooooooo
013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0/ooooo`;o000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0<ooooo`7o000000000ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo05Gooooo0_l0000[ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00_ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0
EOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0:ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02_ooool1o`00000000?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo0Ol000000003o`000?oooooooooo
013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`7o000000000ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo0_l0000Xooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`7o000000000ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`08ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0Ol00000
0003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09oooo
o`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02Oooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`;o0000
:_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`7o0000
00000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:ooo
ool01Ol0003ooooooooooooooooo000000Cooooo0_l0000<ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0;?ooool4o`0000;ooooo0_l0
000>ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0;oooool3o`00013ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo0Ol000000003
o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool2o`0002kooooo1_l0000?ooooo`7o
000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
:oooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`7o000000000ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool1o`00000000?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo0Ol0
00000003o`000?oooooooooo00_ooooo0ol00002ooooo`03o`000?oooooooooo053ooooo0ol00002
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo0Ol000000003o`000?oooooooooo00cooooo00Co0000oooo
oooooooooooo0_l0001Booooo`04o`000?ooooooooooooooo`;o0000:Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool1o`00000000?o0000
ooooooooool03Oooool01?l0003oooooooooool0001Dooooo`04o`000?ooooooooooo`0002Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
0Ol000000003o`000?oooooooooo00gooooo00Co0000oooooooooooo0000E?ooool01?l0003ooooo
ooooool0000Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`08ooooo`7o000000000ol0003oooooooooo`0;ooooo`?o00000_ooool00ol0003ooooo
ooooo`1@ooooo`?o00000_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo
0_l00006ooooo`03o`000?oooooooooo00Sooooo0Ol000000003o`000?oooooooooo013ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`7o000000000ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool1o`00000000?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Eooooo`;o0000:?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool1o`00000000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0Ol000000003o`00
0?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`7o0000
00000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:Ooo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000cooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0[ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0<ooooo`7o000000000ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05Gooooo0_l0000]ooooo`Oo00003oooool1o`00000000?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool04?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool04?ooool1o`00000000?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
4?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool04?ooool1o`00000000?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02gooooo1_l0000?ooooo`7o000000000ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo0_l0000/ooooo`;o00000_ooool01?l0
003oooooooooooooool2o`0000gooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`0Yooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00[ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000oooooooo
ool0EOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool1o`00000000?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0EOooool2o`0002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0Ol000000003o`000?oooooooooo
013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`7o000000000ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool1o`000000
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`7o000000001?l0003oooooooooooooool3o`0000?ooooo00Co0000oooooooooooooooo
0ol00002ooooo`03o`000?oooooooooo04Kooooo0ol00003ooooo`04o`000?ooooooooooooooo`?o
00000_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`7o000000000ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_l00018ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_l0000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`08ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo0ol00002ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01Ooo
ool3o`0000;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool1o`00000000?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool1
o`00000000Co0000oooooooooooooooo0ol00007ooooo`?o00000_ooool00ol0003oooooooooo`16
ooooo`?o00001oooool3o`0000;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo0_l0000<ooooo`7o000000000ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000003_ooool1o`00000000?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Eooooo`;o0000;?ooool8o`0000oooooo0Ol000000003o`000?oooooooooo013o
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013o
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo013ooooo0Ol000000003o`000?oooooooooo013ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo0Ol0
00000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo013ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo0Ol000000003
o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool2o`00033ooooo00?o0000oooooooo
ool04?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool04?ooool1o`00000000?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02_ooooo2?l0000?ooooo`7o00000000
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00003Oooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo0Ol00000
0003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool2o`0002Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo0Ol000000003
o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`7o
000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05Gooooo0_l0000Wooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo0Ol000000003o`000?oooooooooo013ooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`7o000000000ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool1o`00000000?o0000oooo
ooooool02oooool3o`0000;ooooo00?o0000ooooooooool0D?ooool3o`0000;ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool1o`00000000?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0005?o
oooo00?o0000ooooooooool00_l0000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`7o000000000ol0003oooooooooo`0<ooooo`05o`00
0?ooooooooooooooool00000Doooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0Ol000000003
o`000?oooooooooo00gooooo00Co0000oooooooooooo0000E?ooool01?l0003oooooooooool0000Z
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000_ooooo0Ol00000
0003o`000?oooooooooo00_ooooo0ol00002ooooo`03o`000?oooooooooo053ooooo0ol00002oooo
o`03o`000?oooooooooo02Wooooo0_l00004ooooo`04o`000?ooooooooooooooo`;o00003Oooool1
o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
02_ooooo1Ol00002ooooo`03o`000?oooooooooo00gooooo0Ol000000003o`000?oooooooooo013o
oooo00?o0000ooooooooool0EOooool2o`00033ooooo0ol0000@ooooo`7o000000000ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0@ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0@ooooo`7o000000000ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0@
ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0@ooooo`7o000000000ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo05Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0@ooooo`7o
000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo0_l0000`ooooo`03o`00
0?oooooooooo013ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo013ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo0Ol000000003o`000?oooooooooo013o
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013o
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool2o`00033ooooo
00?o0000ooooooooool04?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooooooo
o`1Eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04?ooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool04?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool04?ooool1o`00000000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`00
0?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`12ooooo`7o0000
00000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo0_l00013ooooo`7o00000000
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0@_ooool1
o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
04;ooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo
0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol00000
0003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`00
0?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooo
oooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:go
oooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol0
00000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003
o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oo
oooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo
0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo
0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol00000
0003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`00
0?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooo
oooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:go
oooo0Ol000000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo0:gooooo0Ol0
00000003o`000?oooooooooo0:gooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo05Gooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oo
oooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`12ooooo`7o00000000
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Gooooo0_l00013ooooo`7o000000000ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02oooooo2Ol0000Mooooo`03o`000?oooooooooo
04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0;Oooool=o`0001_o
oooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0/ooooo`oo00006_ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02cooooo4?l0000Iooooo`03o`000?oooooooooo04;ooooo0Ol0
00000003o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool04Ol0
000Iooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o0000
1?ooool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool01?l0003oooooooooooooool3o`0000?ooooo0ol0000=ooooo`7o000000000ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001oooool3o`0000Oooooo
1?l00007ooooo`Co00001_ooool<o`000003ooooool0003o000000?o00006?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool000001oooool3o`0000Oooooo
1?l00007ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool03?ooool1o`00000000?o
0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooool000001oooool4o`0000Oooooo1?l00005oooooa?o00006?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000Sooooo0ol00007ooooo`03o`000?oooooo000000Oooooo1?l0
0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooool000002?ooool3o`0000Oooooo0_l000000ooooooo0000ooooo`04ooooo`Go00000_ooool=
o`0001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000008ooooo`?o00001oooool3
o`0000Oooooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooo000000Cooooo00?o0000
ooooooooool03?ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo0ol00009ooooo`03o`000?oooooooooo00Oooooo0_l00005oooo
o`So000000?oooooo`000?l000000oooool3o`000004ooooool0003o0000o`0001Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`?o00002Oooool2o`0000Sooooo0_l00008
ooooo`?o00000oooool2o`0000kooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000oooo
ooooool0:Oooool4o`0000;ooooo2?l00002ooooo`Go00005oooool00ol0003oooooooooo`12oooo
o`7o000000000ol0003oooooooooo`06ooooodco00003?oooom<o`0000?ooooo0Ol000000003o`00
0?oooooooooo013ooooo00?o0000ooooooooool0:Oooool4o`0000;ooooo00?o0000ooooooooool0
1_l000001?oooooo0000o`000?ooool2o`0000gooooo0_l00008ooooo`03o`000?oooooooooo04;o
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:Oooool3o`000003oooo
ool0003o000000?ooooo0ol00003ooooo`03o`000?oooooo000000?o00003_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o
0000ooooooooool0:Oooool4o`000003ooooool0003o000000Ko00000oooool5o`0000kooooo0ol0
0006ooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000
ooooooooool0:Oooool2o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000002
ooooo`Co00004?ooool2o`0000Gooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Yooooo`Co00000oooool5o`0000?ooooo00?o0000oooo
ooooool00ol0000Aooooo`;o00001?ooool2o`0004?ooooo0Ol000000003o`000?oooooooooo013o
oooo00?o0000ooooooooool0:Oooool4o`000003ooooool0003o000000;ooooo1Ol00002ooooo`03
o`000?oooooo000000;o00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04;o
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:Oooool5o`0000Cooooo
0ol00002ooooo`03o`000?oooooo000000Co00004_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:Ooo
ool6o`0000?ooooo0_l00004ooooo`03o`000?oooooo000000?o00004_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000
ooooooooool0:Oooool<o`000003ooooool0003o000000Ko00004_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000oooo
ooooool0:OoooolDo`0001Sooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0YoooooaCo00006?ooool2o`0004?ooooo0Ol000000003o`00
0?oooooooooo013ooooo00?o0000ooooooooool0:OoooolDo`0001Sooooo00?o0000ooooooooool0
@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`;o000000?o
ooooo`000?l000003ol0000Hooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:OoooolCo`0001Wooooo00?o0000ooooooooool0@_ooool1
o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yoooooa?o00006Oooool00ol0
003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Wo
oooo00Co0000ooooool0003ooooo3?l000000ooooooo0000o`00000Iooooo`;o0000@oooool1o`00
000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`;o000000Koooooo`000?oo
ooooooooo`000?ooool6o`000003ooooool0003o000000;o00006Oooool00ol0003oooooooooo`12
ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Wooooo00Co0000oooo
ool0003ooooo2Ol000000ooooooo0000o`000002o`0001[ooooo00?o0000ooooooooool0@_ooool1
o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`;o000000?oooooo`00
0?ooool01?l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0001[ooooo00?o0000
ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yoooo
o`?o000000?oooooo`000?ooool00_ooool2o`0000Cooooo00Co0000ooooool0003o00006_ooool0
0ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02Sooooo1Ol000000ooooooo0000o`000009o`000003ooooool0003ooooo01Wooooo00?o0000oooo
ooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`;o
00000oooool01?l0003oooooooooooooool2o`0000?ooooo0ol000000ooooooo0000ooooo`0Ioooo
o`;o0000@oooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`;o
00000oooool8o`0000?ooooo0_l0000Jooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`00
0?oooooooooo013ooooo00?o0000ooooooooool0:Oooool00ol0003oooooo`000003o`0000;ooooo
1?l00002ooooo`Co00006_ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02Sooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
0oooool2o`0000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`12ooooo`7o0000
00000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo
0ol00002ooooo`03o`000?oooooooooo02Sooooo00Co0000ooooool0003o00000_ooool9o`000003
ooooool0003o000000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`00
00;ooooo00?o0000ooooooooool0@_ooool1o`00000000Oo0000ooooooooooooooooo`000?oooooo
000000Wooooo00?o0000ooooooooool00_l0000Yooooo`04o`000?oooooo0000o`0000Gooooo00?o
0000ooooooooool00_ooool2o`000003ooooool0003ooooo00_ooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`02o`0004?ooooo0Ol000000007o`000?ooooooooooooooool0003ooooo
o`000007ooooo`?o00000_ooool00ol0003oooooooooo`0Xooooo`;o00000_ooool00ol0003ooooo
ooooo`02ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000cooooo00?o0000
ooooool000001oooool3o`0000;ooooo00?o0000ooooooooool0@_ooool1o`00000000Oo0000oooo
ooooooooooooo`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Xooooo`;o00000oooool2o`000003ooooool0003ooooo00;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`12ooooo`7o000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0ol0
0002ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000000_ooool7o`0000Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`?o00000_ooool00ol0003ooooooooo
o`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool00_l00003ooooo`;o00000_ooool00ol0003oooooooooo`02o`0001cooooo00?o0000
ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00;o00000oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`0Koooo
o`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooo`000002ooooo`;o000000?oooooo`000?ooool00oooool2o`000003
ooooool0003ooooo01_ooooo0_l00013ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool00oooool6o`000004ooooool0003oooooo`0001co
oooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2o`0001cooooo
00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000
ooooooooool0:?ooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooooooool7o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool06_ooool2o`0004?ooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooooooool:o`0000;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000001cooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Yooooo`;o00001Oooool00ol0003oooooooooo`03oooo
o`;o00007Oooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo02Wooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo0_l0000Mooooo`03
o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0
:Oooool3o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Mooooo`;o0000
@oooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool00_ooool7o`0000?ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02Wooooo00Co0000oooooooooooooooo1_l00004ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Y
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`0Kooooo`;o0000@oooool1o`00000000?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool2o`0001kooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Yooooo`Co00000oooool01?l0003oooooooooooooool3o`0001kooooo00?o
0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Y
ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_l00003ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool02oooool3
o`0000;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`;o00001_ooool0
0ol0003oooooooooo`0Fooooo`?o00000_ooool00ol0003oooooooooo`12ooooo`7o000000000ol0
003oooooooooo`0<ooooo`04o`000?ooooooooooooooo`;o0000:Oooool00ol0003oooooooooo`04
ooooo`;o00001_ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooooooo`;o0000@ooo
ool1o`00000000?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000002[ooooo00?o
0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool05oooool01Ol0003ooooooooo
oooooooo000004Cooooo0Ol000000003o`000?oooooooooo00cooooo00Go0000oooooooooooooooo
o`00000Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Gooooo`05o`000?ooooooooooooooool00000A?ooool1o`00000000?o0000ooooooooool0
2oooool2o`0000?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05oooool2o`0000?ooooo00?o0000ooooooooool0
@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`04o`000?oo
ooooooooooooo`Oo00000oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04;ooooo
0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:Oooool00ol0003oooooo`00
0003ooooo`07o`000?ooooooooooooooool0003oooooo`00000Oooooo`03o`000?oooooooooo04;o
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:_ooool2o`0000?ooooo
00?o0000ooooooooool00_ooool2o`0001oooooo0_l00013ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool000000ol000001_oooooo0000o`00
0?l0003oooooo`0001oooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`12ooooo`7o000000000ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool2o`00
00Kooooo00?o0000ooooooooool06oooool2o`0004?ooooo0Ol000000003o`000?oooooooooo013o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04;ooooo0Ol00000
0003o`000?oooooooooo013ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`12oooo
o`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo2_l0000Pooooo`;o
0000@oooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0[ooooo`Go0000
00?oooooo`000?l000000_l0000Pooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oo
oooooooo013ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02ooooo`;o00001?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`12ooooo`7o000000000ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool1o`00
000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`;o0000@oooool1o`000000
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04;ooooo
0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`04ooooo`;o00001_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo0Ol0
00000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12
ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0@_ooool1o`00000000Co0000oooooooooooooooo0ol00003ooooo`04o`000?oooooooooo
ooooo`?o00000_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`?o00000oooool01?l0003ooooooooooooo
ool3o`0000;ooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o0000:_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00;o0000@oooool1o`00000000?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`?o00000_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Kooooo0ol00002ooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_o
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00004_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@_ooool1o`00000000Co0000oooooooo
oooooooo0_l00008ooooo`?o00000_ooool00ol0003oooooooooo`0/ooooo`Co000000?oooooo`00
0?l000004oooool2o`0000Sooooo0ol00002ooooo`03o`000?oooooooooo04;ooooo0Ol000000003
o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool7o`0002;ooooo00?o0000oooooooo
ool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0[ooooo`05o`00
0?ooooooooooooooool000000oooool2o`00023ooooo0_l00013ooooo`7o000000000ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@_ooool1o`00000000?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04;ooooo0Ol0
00000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`12
ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`;o
0000@oooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01gooooo0_l00013ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02Wooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0/ooooo`Oo00008_ooool00ol0003oooooooooo`12ooooo`7o000000000ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02go
oooo1?l0000Tooooo`;o0000@oooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0[ooooo`;o00000_ooool00ol0003oooooo`000002o`00027ooooo00?o0000ooooooooool0
@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool02oooool3o`0000;o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05oooool3o`0000;ooooo00?o0000ooooooooool0@_ooool1o`000000
00?o0000ooooooooool03?ooool01?l0003oooooooooooooool2o`0002Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooo
oooooooo0_l00013ooooo`7o000000000ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`00
02Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Sooooo00Co0000oooooooooooo0000A?ooool1o`00000000?o0000ooooooooool03Oooool01?l0
003oooooooooool0000Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0004Cooooo0Ol000000003o`000?oooooo
oooo00_ooooo0ol00002ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_o
oooo0_l00013ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000
ooooooooool0:Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`0001oooooo00?o0000
ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0[oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0;?ooool01Ol0
003oooooooooool0003ooooo00;o00008_ooool00ol0003oooooooooo`12ooooo`7o000000000ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02gooooo1?l0000Tooooo`;o0000@oooool1o`00
000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@_ooool1o`00000000?o
0000ooooooooool04?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0]
ooooo`Co00009?ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02_ooooo0_l00002ooooo`03o`000?oooooo000000?o00008?ooool2o`00
04?ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Kooooo`;o0000@oooool1o`00000000?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oo
oooooooo013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`;o00002?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooo
oooo013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`12ooooo`7o000000001?l0
003oooooooooooooool3o`0000?ooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00cooooo0ol00003ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003ooooo
ooooo`12ooooo`7o000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_l0000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_l0
0013ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0ol00002
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool3o`0000;ooooo00?o0000
ooooooooool0@_ooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@_ooool1o`00000000Co0000oooooooo
oooooooo0ol00007ooooo`?o00000_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool2o`00013ooooo0ol00007ooooo`?o00000_ooool00ol0
003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000027ooooo00?o0000oooo
ooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0[ooooo`;o
00000_ooool01?l0003oooooo`000?l0000Rooooo`;o0000@oooool1o`00000000?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0]ooooo`Co00009?ooool00ol0003oooooooooo`12ooooo`7o
000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`12ooooo`7o00000000
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`12ooooo`7o000000000ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08oooool2o`0004?o
oooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o
0000ooooooooool0;Oooool6o`0002;ooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Zooooo`?o00000_ooool01Ol0003ooooooooooooo
oooo0000027ooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo
013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07Oooool2o`0004?ooooo0Ol000000003o`000?oooooooooo013o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool1o`00000000?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo0Ol0
00000003o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`12
ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`;o
0000@oooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0;ooooo`?o00000_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Eooooo`?o00000_ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;o00009oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02o`0004?o
oooo0Ol000000003o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000Yooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0001Wooooo00Go0000oooooooo
ooooooooo`000014ooooo`7o000000000ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`00
02[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01[ooooo00Co0000oooooooooooo0000A?ooool1o`00000000?o0000ooooooooool02oooool3o`00
00;ooooo00?o0000ooooooooool0:Oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02_ooooo0_l00002ooooo`03o`000?oooooooooo00?o
00008?ooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02gooooo1Ol0000Sooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oo
oooooooo013ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Sooooo`;o0000@ooo
ool1o`00000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@_ooool1o`00
000000?o0000ooooooooool04?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0@_ooool1o`00000000?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@_ooool1o`00000000?o
0000ooooooooool04?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02?ooooo0_l0
0013ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`12oooo
o`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`12ooooo`7o0000
00000ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`12ooooo`7o000000000ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool08oooool2o`0004?ooooo0Ol000000003o`000?oooooooooo
013ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
04;ooooo0Ol000000003o`000?oooooooooo013ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo04;ooooo0Ol000000003o`000?oooooooooo013ooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`12ooooo`7o000000000ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0@_ooool1o`00000000?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Eooooo`;o0000@oooool1o`00000000?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo04;ooooo0Ol000000003
o`000?oooooooooo013ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`12ooooo`7o
000000000ol0003oooooooooo`2]ooooo`7o000000000ol0003oooooooooo`2]ooooo`7o00000000
0ol0003oooooooooo`2]ooooo`7o000000000ol0003oooooooooo`2]ooooo`7o000000000ol0003o
ooooooooo`2]ooooo`7o000000000ol0003oooooooooo`2]ooooo`7o000000000ol0003ooooooooo
o`2]ooooo`7o000000000ol0003oooooooooo`2]ooooo`7o000000000ol0003oooooooooo`2]oooo
o`7o000000000ol0003oooooooooo`2]ooooo`7o000000000ol0003oooooooooo`2]ooooo`7o0000
00000ol0003oooooooooo`2]ooooo`7o000000000ol0003oooooooooo`2]ooooo`7o000000000ol0
003oooooooooo`2]ooooo`7o000000000ol0003oooooooooo`2]ooooo`7o000000000ol0003ooooo
ooooo`2]ooooo`7o000000000ol0003oooooooooo`2]ooooo`7o0000002ao`000000/Oooool00001
\
\>"],
  ImageRangeCache->{{{0, 176.938}, {478.125, 0}} -> {-0.0514962, -0.14863, \
0.0118855, 0.0118855}, {{4.3125, 84.4375}, {465.562, 249.812}} -> {-0.36102, \
-0.62811, 0.0183709, 0.0183709}, {{92.4375, 172.562}, {465.562, 249.812}} -> \
{-1.97996, -0.62811, 0.0183709, 0.0183709}, {{4.3125, 84.4375}, {228.25, \
12.5}} -> {-0.36102, -4.98776, 0.0183709, 0.0183709}, {{92.4375, 172.562}, \
{228.25, 12.5}} -> {-1.97996, -4.98776, 0.0183709, 0.0183709}},
  CellTags->"5.3.5"]
}, Open  ]],

Cell["\<\
Now, both the low-frequency and high-frequency interactions in the \
system have been significantly reduced in both loops. The very small \
Ostrowski circles indicate that most of the interaction in the system will be \
eliminated when both feedback loops are closed with unity feedback.\
\>", \
"Text",
  CellTags->"5.3.5"],

Cell["This is the explicit form of the compensator.", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(kmx = Normal[InverseSystem[kinv]]\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->"5.3.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.7785586266109508`", \(-1.0482337173198981`\)},
                    {\(-1.0482337173198983`\), "1.7785586266109508`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Center},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox["\[Bullet]",
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[12]=",
  CellTags->"5.3.5"]
}, Open  ]],

Cell["This closes the feedback loops.", "MathCaption",
  CellTags->"5.3.5"],

Cell[BoxData[
    \(\(h = Together /@ FeedbackConnect[fp];\)\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->"5.3.5"],

Cell["Here is a simulation of the resulting closed-loop system.", \
"MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SimulationPlot[h, UnitStep[t - 1], {t, 0, 30}, 
        PlotRange \[Rule] All];\)\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0198536 1.1411 [
[.18254 .00735 -2.4 -7.2 ]
[.18254 .00735 2.4 0 ]
[.34127 .00735 -4.8 -7.2 ]
[.34127 .00735 4.8 0 ]
[.5 .00735 -4.8 -7.2 ]
[.5 .00735 4.8 0 ]
[.65873 .00735 -4.8 -7.2 ]
[.65873 .00735 4.8 0 ]
[.81746 .00735 -4.8 -7.2 ]
[.81746 .00735 4.8 0 ]
[.97619 .00735 -4.8 -7.2 ]
[.97619 .00735 4.8 0 ]
[.01131 .13396 -14.4 -3.6 ]
[.01131 .13396 0 3.6 ]
[.01131 .24807 -14.4 -3.6 ]
[.01131 .24807 0 3.6 ]
[.01131 .36218 -14.4 -3.6 ]
[.01131 .36218 0 3.6 ]
[.01131 .47629 -14.4 -3.6 ]
[.01131 .47629 0 3.6 ]
[.01131 .59041 -14.4 -3.6 ]
[.01131 .59041 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01985 m
.18254 .0261 L
s
[(5)] .18254 .00735 0 1 Mshowa
.34127 .01985 m
.34127 .0261 L
s
[(10)] .34127 .00735 0 1 Mshowa
.5 .01985 m
.5 .0261 L
s
[(15)] .5 .00735 0 1 Mshowa
.65873 .01985 m
.65873 .0261 L
s
[(20)] .65873 .00735 0 1 Mshowa
.81746 .01985 m
.81746 .0261 L
s
[(25)] .81746 .00735 0 1 Mshowa
.97619 .01985 m
.97619 .0261 L
s
[(30)] .97619 .00735 0 1 Mshowa
.125 Mabswid
.05556 .01985 m
.05556 .0236 L
s
.0873 .01985 m
.0873 .0236 L
s
.11905 .01985 m
.11905 .0236 L
s
.15079 .01985 m
.15079 .0236 L
s
.21429 .01985 m
.21429 .0236 L
s
.24603 .01985 m
.24603 .0236 L
s
.27778 .01985 m
.27778 .0236 L
s
.30952 .01985 m
.30952 .0236 L
s
.37302 .01985 m
.37302 .0236 L
s
.40476 .01985 m
.40476 .0236 L
s
.43651 .01985 m
.43651 .0236 L
s
.46825 .01985 m
.46825 .0236 L
s
.53175 .01985 m
.53175 .0236 L
s
.56349 .01985 m
.56349 .0236 L
s
.59524 .01985 m
.59524 .0236 L
s
.62698 .01985 m
.62698 .0236 L
s
.69048 .01985 m
.69048 .0236 L
s
.72222 .01985 m
.72222 .0236 L
s
.75397 .01985 m
.75397 .0236 L
s
.78571 .01985 m
.78571 .0236 L
s
.84921 .01985 m
.84921 .0236 L
s
.88095 .01985 m
.88095 .0236 L
s
.9127 .01985 m
.9127 .0236 L
s
.94444 .01985 m
.94444 .0236 L
s
.25 Mabswid
0 .01985 m
1 .01985 L
s
.02381 .13396 m
.03006 .13396 L
s
[(0.1)] .01131 .13396 1 0 Mshowa
.02381 .24807 m
.03006 .24807 L
s
[(0.2)] .01131 .24807 1 0 Mshowa
.02381 .36218 m
.03006 .36218 L
s
[(0.3)] .01131 .36218 1 0 Mshowa
.02381 .47629 m
.03006 .47629 L
s
[(0.4)] .01131 .47629 1 0 Mshowa
.02381 .59041 m
.03006 .59041 L
s
[(0.5)] .01131 .59041 1 0 Mshowa
.125 Mabswid
.02381 .04268 m
.02756 .04268 L
s
.02381 .0655 m
.02756 .0655 L
s
.02381 .08832 m
.02756 .08832 L
s
.02381 .11114 m
.02756 .11114 L
s
.02381 .15679 m
.02756 .15679 L
s
.02381 .17961 m
.02756 .17961 L
s
.02381 .20243 m
.02756 .20243 L
s
.02381 .22525 m
.02756 .22525 L
s
.02381 .2709 m
.02756 .2709 L
s
.02381 .29372 m
.02756 .29372 L
s
.02381 .31654 m
.02756 .31654 L
s
.02381 .33936 m
.02756 .33936 L
s
.02381 .38501 m
.02756 .38501 L
s
.02381 .40783 m
.02756 .40783 L
s
.02381 .43065 m
.02756 .43065 L
s
.02381 .45347 m
.02756 .45347 L
s
.02381 .49912 m
.02756 .49912 L
s
.02381 .52194 m
.02756 .52194 L
s
.02381 .54476 m
.02756 .54476 L
s
.02381 .56758 m
.02756 .56758 L
s
.02381 .61323 m
.02756 .61323 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(1) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 1 r
.5 Mabswid
.02381 .01985 m
.03279 .01985 L
.04262 .01985 L
.04758 .01985 L
.0503 .01985 L
.05288 .01985 L
.05405 .01985 L
.05528 .01985 L
.05593 .02383 L
.05664 .03133 L
.05789 .04432 L
.06244 .08922 L
.07293 .1795 L
.0842 .25931 L
.10458 .36808 L
.11468 .40881 L
.12571 .44552 L
.13625 .47433 L
.1458 .49606 L
.16548 .53043 L
.17628 .54461 L
.18645 .5556 L
.19621 .56435 L
.20653 .57199 L
.225 .58242 L
.23448 .58648 L
.24464 .59007 L
.26297 .59493 L
.27315 .59692 L
.28421 .59864 L
.29466 .59992 L
.30433 .60085 L
.31396 .60157 L
.323 .6021 L
.33291 .60254 L
.33845 .60274 L
.3436 .60289 L
.35317 .60309 L
.35823 .60317 L
.36364 .60324 L
.36637 .60326 L
.36933 .60328 L
.37212 .6033 L
.37345 .6033 L
.37469 .60331 L
.37591 .60331 L
.37702 .60331 L
.37825 .60332 L
.37893 .60332 L
.37957 .60332 L
Mistroke
.38086 .60332 L
.38205 .60332 L
.38335 .60332 L
.38408 .60332 L
.38474 .60332 L
.38595 .60331 L
.38707 .60331 L
.38963 .6033 L
.39212 .6033 L
.39479 .60328 L
.40402 .60322 L
.41493 .60312 L
.42486 .603 L
.46476 .60242 L
.50314 .60181 L
.54397 .60118 L
.58329 .60063 L
.62109 .60017 L
.66135 .59976 L
.70009 .59942 L
.74128 .59912 L
.78096 .59887 L
.81912 .59868 L
.85973 .59851 L
.89883 .59837 L
.94038 .59825 L
.97619 .59816 L
Mfstroke
1 0 0 r
.02381 .01985 m
.03279 .01985 L
.04262 .01985 L
.04758 .01985 L
.0503 .01985 L
.05288 .01985 L
.05405 .01985 L
.05528 .01985 L
.05593 .01968 L
.05664 .01936 L
.05789 .01883 L
.06244 .01721 L
.06525 .01644 L
.06792 .01586 L
.07031 .01545 L
.07293 .01511 L
.07441 .01497 L
.07576 .01487 L
.0765 .01482 L
.07731 .01478 L
.07807 .01476 L
.07877 .01474 L
.08003 .01472 L
.08074 .01472 L
.08141 .01472 L
.08212 .01473 L
.08276 .01474 L
.0835 .01477 L
.0842 .01479 L
.08537 .01485 L
.08666 .01493 L
.08927 .01514 L
.09396 .01567 L
.09944 .0165 L
.10458 .01746 L
.14327 .02738 L
.18441 .03843 L
.22403 .04709 L
.26214 .05339 L
.3027 .0583 L
.34175 .06176 L
.38324 .06446 L
.42323 .06641 L
.46169 .06785 L
.50261 .06905 L
.54201 .06997 L
.5799 .07068 L
.62024 .07129 L
.65906 .07177 L
.70034 .07219 L
Mistroke
.7401 .07252 L
.77835 .07278 L
.81905 .07301 L
.85823 .07319 L
.89986 .07335 L
.93998 .07347 L
.97619 .07356 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00@_ooool3o`0002?ooooo0ol00003ooooo`03o`000?oooooooooo023o
oooo0ol00002ooooo`?o00008?ooool3o`0000?ooooo00?o0000ooooooooool08?ooool3o`0000;o
oooo0ol0000Qooooo`?o00000oooool00ol0003oooooooooo`0<ooooo`00A?ooool00ol0003ooooo
ooooo`0Rooooo`07o`000?ooooooooooooooool0003oooooo`00000Rooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07oooool01ol0003ooooooooooooooooo0000ooooool000008_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00Ko0000oooooooooooo0000
ooooool0000=ooooo`00@_ooool3o`0002Cooooo00Oo0000ooooooooooooooooo`000?oooooo0000
02;ooooo00Co0000oooooooooooooooo0ol0000Rooooo`06o`000?ooooooooooo`000?oooooo0000
8oooool00ol0003oooooooooo`03o`0002;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00gooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool01ol0003o
oooooooooooooooo0000ooooool000008_ooool01Ol0003ooooooooooooooooo000002Cooooo00Ko
0000oooooooooooo0000ooooool0000Sooooo`04o`000?ooooooooooo`0002Gooooo00Ko0000oooo
oooooooo0000ooooool0000=ooooo`006oooool00ol0003oooooooooo`0Tooooo`?o00008oooool2
o`0000Cooooo00?o0000ooooooooool08?ooool2o`0000?ooooo0ol0000Pooooo`?o00000oooool0
0ol0003oooooooooo`0Pooooo`?o00000_ooool3o`00027ooooo0ol00003ooooo`03o`000?oooooo
oooo00cooooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool001_ooooo00?o0000oooooooo
ool0ooooool3ooooo`006oooool00ol0003oooooooooo`06ooooo`koo`00k_ooool001Gooooo1_l0
0009ool000ko00000ooo003Qo`0000[ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o0?oo
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?ooooooo`0000;oo`000oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool0
01_ooooo00?o0000ooooooooool01Oooool00ol0ooooooooooooo`0Booooo`Coo`001oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03_ooool001_o
oooo00?o0000ooooooooool01Oooool00ol0ooooooooooooo`0Fooooo`Coo`00h?ooool001_ooooo
00?o0000ooooooooool01Oooool00ol0ooooooooooooo`0Jooooo`?oo`00gOooool001_ooooo00?o
0000ooooooooool01Oooool00ol0ooooooooooooo`0Mooooo`Goo`00f?ooool001_ooooo0_l00006
ooooo`03o`3ooooooooooooo02;ooooo1Ooo003Cooooo`006oooool00ol0003oooooooooo`05oooo
o`03o`3ooooooooooooo02Oooooo1Ooo003>ooooo`006oooool00ol0003oooooooooo`05ooooo`03
o`3ooooooooooooo02cooooo1Ooo0039ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`3o
oooooooooooo037ooooo1ooo0032ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`3ooooo
oooooooo03Oooooo2_oo002hooooo`006oooool00ol0003oooooooooo`06ooooo`03o`3ooooooooo
oooo047ooooo5Ooo002Sooooo`006oooool2o`0000Oooooo00?o0?ooooooooooool0E_oooolDool0
08oooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0?ooooooooooool0J_oooom7ool004So
oooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0?ooooooooooool0/Ooooolhool0013ooooo
000Kooooo`03o`000?oooooooooo00Kooooo00?o0?ooooooooooool0nOooool001_ooooo00?o0000
ooooooooool01oooool00ol0ooooooooooooo`3hooooo`006oooool00ol0003oooooooooo`07oooo
o`03o`3ooooooooooooo0?Sooooo000Kooooo`;o00002?ooool00ol0ooooooooooooo`3hooooo`00
6oooool00ol0003oooooooooo`07ooooo`03o`3ooooooooooooo0?Sooooo000Kooooo`03o`000?oo
oooooooo00Oooooo00?o0?ooooooooooool0n?ooool001_ooooo00?o0000ooooooooool01oooool0
0ol0ooooooooooooo`3hooooo`006oooool00ol0003oooooooooo`07ooooo`03o`3ooooooooooooo
0?Sooooo000Kooooo`;o00002?ooool00ol0ooooooooooooo`3hooooo`006oooool00ol0003ooooo
ooooo`07ooooo`03o`3ooooooooooooo0?Sooooo000Kooooo`03o`000?oooooooooo00Sooooo00?o
0?ooooooooooool0moooool001_ooooo00?o0000ooooooooool02?ooool00ol0ooooooooooooo`3g
ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`3ooooooooooooo0?Oooooo000:ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00005ooooo`03o`000?oooooooooo
00Sooooo00?o0?ooooooooooool0moooool000Wooooo00?o0000ooooool000002?ooool00ol0003o
ooooooooo`04ooooo`;o00002Oooool00ol0ooooooooooooo`3gooooo`002Oooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0oooooooo
ooooo`3gooooo`002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool00ol0ooooooooooooo`3gooooo`002_ooool00ol0003oooooooooo`06
ooooo`;o00001_ooool00ol0003oooooooooo`08ooooo`03o`3ooooooooooooo0?Oooooo000Koooo
o`03o`000?oooooooooo00Sooooo00?o0?ooooooooooool0moooool001_ooooo00?o0000oooooooo
ool02?ooool00ol0ooooooooooooo`3gooooo`006oooool2o`0000Wooooo00?o0?ooooooooooool0
moooool001_ooooo00?o0000ooooooooool02Oooool00ol0ooooooooooooo`3fooooo`006oooool0
0ol0003oooooooooo`09ooooo`03o`3ooooooooooooo0?Kooooo000Kooooo`03o`000?oooooooooo
00Wooooo00?o0?ooooooooooool0m_ooool001_ooooo00?o0000ooooooooool02Oooool00ol0oooo
ooooooooo`3fooooo`006oooool00ol0003oooooooooo`09ooooo`03o`3ooooooooooooo0?Kooooo
000Kooooo`;o00002_ooool00ol0ooooooooooooo`3fooooo`006oooool00ol0003oooooooooo`09
ooooo`03o`3ooooooooooooo0?Kooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0?oooooo
ooooool0m_ooool001_ooooo00?o0000ooooooooool02Oooool00ol0ooooooooooooo`3fooooo`00
6oooool00ol0003oooooooooo`0:ooooo`03o`3ooooooooooooo0?Gooooo000Kooooo`03o`000?oo
oooooooo00[ooooo00?o0?ooooooooooool0mOooool001_ooooo0_l0000;ooooo`03o`3ooooooooo
oooo0?Gooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o0?ooooooooooool0mOooool001_o
oooo00?o0000ooooooooool02_ooool00ol0ooooooooooooo`3eooooo`006oooool00ol0003ooooo
ooooo`0:ooooo`03o`3ooooooooooooo0?Gooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o
0?ooooooooooool0mOooool001_ooooo00?o0000ooooooooool02oooool00ol0ooooooooooooo`3d
ooooo`006oooool2o`0000cooooo00?o0?ooooooooooool0m?ooool001_ooooo00?o0000oooooooo
ool02oooool00ol0ooooooooooooo`3dooooo`006oooool00ol0003oooooooooo`0;ooooo`03o`3o
oooooooooooo0?Cooooo000Kooooo`03o`000?oooooooooo00_ooooo00?o0?ooooooooooool0m?oo
ool000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0000Gooooo00?o
0000ooooooooool02oooool00ol0ooooooooooooo`3dooooo`002Oooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00Cooooo0_l0000<ooooo`03o`3ooooooooooooo0?Cooooo0009oooo
o`03o`000?oooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03o`3ooooooooooooo0??ooooo0009ooooo`03o`000?oooooo000000Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0<ooooo`03o`3ooooooooooooo0??ooooo000:ooooo`03o`00
0?oooooooooo00Kooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?o0?ooooooooooool0
loooool001_ooooo00?o0000ooooooooool03?ooool00ol0ooooooooooooo`3cooooo`006oooool0
0ol0003oooooooooo`0<ooooo`03o`3ooooooooooooo0??ooooo000Kooooo`;o00003Oooool00ol0
ooooooooooooo`3cooooo`006oooool00ol0003oooooooooo`0=ooooo`03o`3ooooooooooooo0?;o
oooo000Kooooo`03o`000?oooooooooo00gooooo00?o0?ooooooooooool0l_ooool001_ooooo00?o
0000ooooooooool03Oooool00ol0ooooooooooooo`3booooo`006oooool00ol0003oooooooooo`0=
ooooo`03o`3ooooooooooooo0?;ooooo000Kooooo`03o`000?oooooooooo00gooooo00?o0?oooooo
ooooool0l_ooool001_ooooo0_l0000?ooooo`03o`3ooooooooooooo0?7ooooo000Kooooo`03o`00
0?oooooooooo00kooooo00?o0?ooooooooooool0lOooool001_ooooo00?o0000ooooooooool03_oo
ool00ol0ooooooooooooo`3aooooo`006oooool00ol0003oooooooooo`0>ooooo`03o`3ooooooooo
oooo0?7ooooo000Kooooo`03o`000?oooooooooo00kooooo00?o0?ooooooooooool0lOooool001_o
oooo00?o0000ooooooooool03_ooool00ol0ooooooooooooo`3aooooo`006oooool2o`00013ooooo
00?o0?ooooooooooool0l?ooool001_ooooo00?o0000ooooooooool03oooool00ol0oooooooooooo
o`3`ooooo`006oooool00ol0003oooooooooo`0?ooooo`03o`3ooooooooooooo0?3ooooo000Koooo
o`03o`000?oooooooooo00oooooo00?o0?ooooooooooool0l?ooool001_ooooo00?o0000oooooooo
ool03oooool00ol0ooooooooooooo`3`ooooo`006oooool00ol0003oooooooooo`0?ooooo`03o`3o
oooooooooooo0?3ooooo000Kooooo`;o00004Oooool00ol0ooooooooooooo`3_ooooo`006oooool0
0ol0003oooooooooo`0@ooooo`03o`3ooooooooooooo0>oooooo000Kooooo`03o`000?oooooooooo
013ooooo00?o0?ooooooooooool0koooool001_ooooo00?o0000ooooooooool04?ooool00ol0oooo
ooooooooo`3_ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`3ooooooooooooo0>oooooo
000:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00005ooooo`03o`00
0?oooooooooo017ooooo00?o0?ooooooooooool0k_ooool000Wooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`03ooooo`;o00004_ooool00ol0ooooooooooooo`3^ooooo`002Oooool0
0ol0003oooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool0
0ol0ooooooooooooo`3^ooooo`002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04Oooool00ol0ooooooooooooo`3^ooooo`002_ooool00ol0003o
ooooooooo`06ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03o`3ooooooooooooo0>ko
oooo000Kooooo`03o`000?oooooooooo01;ooooo00?o0?ooooooooooool0kOooool001_ooooo00?o
0000ooooooooool04_ooool00ol0ooooooooooooo`3]ooooo`006oooool2o`0001?ooooo00?o0?oo
ooooooooool0kOooool001_ooooo00?o0000ooooooooool04oooool00ol0ooooooooooooo`3/oooo
o`006oooool00ol0003oooooooooo`0Cooooo`03o`3ooooooooooooo0>cooooo000Kooooo`03o`00
0?oooooooooo01?ooooo00?o0?ooooooooooool0k?ooool001_ooooo00?o0000ooooooooool04ooo
ool00ol0ooooooooooooo`3/ooooo`006oooool2o`0001Gooooo00?o0?ooooooooooool0joooool0
01_ooooo00?o0000ooooooooool05?ooool00ol0ooooooooooooo`3[ooooo`006oooool00ol0003o
ooooooooo`0Dooooo`03o`3ooooooooooooo0>_ooooo000Kooooo`03o`000?oooooooooo01Gooooo
00?o0?ooooooooooool0j_ooool001_ooooo00?o0000ooooooooool05Oooool00ol0oooooooooooo
o`3Zooooo`006oooool00ol0003oooooooooo`0Eooooo`03o`3ooooooooooooo0>[ooooo000Koooo
o`;o00005oooool00ol0ooooooooooooo`3Yooooo`006oooool00ol0003oooooooooo`0Fooooo`03
o`3ooooooooooooo0>Wooooo000Kooooo`03o`000?oooooooooo01Kooooo00?o0?ooooooooooool0
jOooool001_ooooo00?o0000ooooooooool05oooool00ol0ooooooooooooo`3Xooooo`006oooool0
0ol0003oooooooooo`0Gooooo`03o`3ooooooooooooo0>Sooooo000Kooooo`03o`000?oooooooooo
01Oooooo00?o0?ooooooooooool0j?ooool001_ooooo0_l0000Iooooo`03o`3ooooooooooooo0>Oo
oooo000Kooooo`03o`000?oooooooooo01Sooooo00?o0?ooooooooooool0ioooool001_ooooo00?o
0000ooooooooool06Oooool00ol0ooooooooooooo`3Vooooo`006oooool00ol0003oooooooooo`0I
ooooo`03o`3ooooooooooooo0>Kooooo000Kooooo`03o`000?oooooooooo01Wooooo00?o0?oooooo
ooooool0i_ooool000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool00ol0ooooooooooooo`3Uooooo`00
2Oooool00ol0003oooooo`000007ooooo`?o00001Oooool2o`0001_ooooo00?o0?ooooooooooool0
iOooool000Wooooo00?o0000ooooool000001oooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo01_ooooo00?o0?ooooooooooool0i?ooool000Wooooo00?o0000ooooool000002?ooool2
o`0000Gooooo00?o0000ooooooooool06oooool00ol0ooooooooooooo`3Tooooo`002_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0
ooooooooooooo`3Tooooo`006oooool00ol0003oooooooooo`0Looooo`03o`3ooooooooooooo0>?o
oooo000Kooooo`03o`000?oooooooooo01cooooo00?o0?ooooooooooool0hoooool001_ooooo0_l0
000Mooooo`03o`3ooooooooooooo0>?ooooo000Kooooo`03o`000?oooooooooo01gooooo00?o0?oo
ooooooooool0h_ooool001_ooooo00?o0000ooooooooool07Oooool00ol0ooooooooooooo`3Roooo
o`006oooool00ol0003oooooooooo`0Nooooo`03o`3ooooooooooooo0>7ooooo000Kooooo`03o`00
0?oooooooooo01oooooo00?o0?ooooooooooool0h?ooool001_ooooo00?o0000ooooooooool07ooo
ool00ol0ooooooooooooo`3Pooooo`006oooool2o`00027ooooo00?o0?ooooooooooool0goooool0
01_ooooo00?o0000ooooooooool08?ooool00ol0ooooooooooooo`3Oooooo`006oooool00ol0003o
ooooooooo`0Qooooo`03o`3ooooooooooooo0=kooooo000Kooooo`03o`000?oooooooooo02;ooooo
00?o0?ooooooooooool0gOooool001_ooooo00?o0000ooooooooool08oooool00ol0oooooooooooo
o`3Looooo`006oooool00ol0003oooooooooo`0Tooooo`03o`3ooooooooooooo0=_ooooo000Koooo
o`;o00009Oooool00ol0ooooooooooooo`3Kooooo`006oooool00ol0003oooooooooo`0Uooooo`03
o`3ooooooooooooo0=[ooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0?ooooooooooool0
fOooool001_ooooo00?o0000ooooooooool09oooool00ol0ooooooooooooo`3Hooooo`006oooool0
0ol0003oooooooooo`0Xooooo`03o`3ooooooooooooo0=Oooooo000Kooooo`;o0000:_ooool3o`3o
omKooooo000Kooooo`03o`000?oooooooooo02cooooo0_l0oooDooooo`006oooool00ol0003ooooo
ooooo`0^ooooo`03o`3ooooooooooooo0=7ooooo000Kooooo`03o`000?oooooooooo02oooooo00?o
0?ooooooooooool0d?ooool001_ooooo00?o0000ooooooooool0<?ooool3o`3ooloooooo000:oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00005ooooo`03o`000?oooooo
oooo03?ooooo0_l0ooo=ooooo`002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo
00?ooooo0_l0000fooooo`Co0?oobOooool000Wooooo00?o0000ooooool000001oooool3o`0000Go
oooo00?o0000ooooooooool0>Oooool4o`3oolGooooo0009ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`Go0?ooK_oooom2o`3ooa3ooooo
000:ooooo`03o`000?oooooooooo00Kooooo0ol00005ooooo`03o`000?oooooooooo04;ooooo4_l0
ool9oooooe?o0?ooD_ooool001_ooooo00?o0000ooooooooool0E?ooool9o`3oojGooooo000Koooo
o`03o`000?oooooooooo0?oooooo0oooool001_ooooo0_l0003oooooo`Cooooo000Kooooo`03o`00
0?oooooooooo0?oooooo0oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool008kooooo0ol0002?ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00QOooool3
o`0000;ooooo00?o0000ooooool000000_ooool3o`0000;ooooo0ol00002ooooo`?o00001_ooool3
o`0007_ooooo0026ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`08o`000?oo
ooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0N_ooool008Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00So0000
oooooooooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1jooooo`00Q_ooool00ol0003oooooooooo`04o`000003ooooool0003o000000;o0000
00Koooooo`000?l0003oooooo`000?ooool4o`0000Oooooo00?o0000ooooooooool0N_ooool008Go
oooo0ol0000Aooooo`03o`000?oooooooooo00Kooooo0_l0001looooo`00oooooolQooooo`00oooo
oolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.34161, -0.0355764, \
0.122892, 0.00341891}},
  CellTags->"5.3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0198536 1.1411 [
[.18254 .00735 -2.4 -7.2 ]
[.18254 .00735 2.4 0 ]
[.34127 .00735 -4.8 -7.2 ]
[.34127 .00735 4.8 0 ]
[.5 .00735 -4.8 -7.2 ]
[.5 .00735 4.8 0 ]
[.65873 .00735 -4.8 -7.2 ]
[.65873 .00735 4.8 0 ]
[.81746 .00735 -4.8 -7.2 ]
[.81746 .00735 4.8 0 ]
[.97619 .00735 -4.8 -7.2 ]
[.97619 .00735 4.8 0 ]
[.01131 .13396 -14.4 -3.6 ]
[.01131 .13396 0 3.6 ]
[.01131 .24807 -14.4 -3.6 ]
[.01131 .24807 0 3.6 ]
[.01131 .36218 -14.4 -3.6 ]
[.01131 .36218 0 3.6 ]
[.01131 .47629 -14.4 -3.6 ]
[.01131 .47629 0 3.6 ]
[.01131 .59041 -14.4 -3.6 ]
[.01131 .59041 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01985 m
.18254 .0261 L
s
[(5)] .18254 .00735 0 1 Mshowa
.34127 .01985 m
.34127 .0261 L
s
[(10)] .34127 .00735 0 1 Mshowa
.5 .01985 m
.5 .0261 L
s
[(15)] .5 .00735 0 1 Mshowa
.65873 .01985 m
.65873 .0261 L
s
[(20)] .65873 .00735 0 1 Mshowa
.81746 .01985 m
.81746 .0261 L
s
[(25)] .81746 .00735 0 1 Mshowa
.97619 .01985 m
.97619 .0261 L
s
[(30)] .97619 .00735 0 1 Mshowa
.125 Mabswid
.05556 .01985 m
.05556 .0236 L
s
.0873 .01985 m
.0873 .0236 L
s
.11905 .01985 m
.11905 .0236 L
s
.15079 .01985 m
.15079 .0236 L
s
.21429 .01985 m
.21429 .0236 L
s
.24603 .01985 m
.24603 .0236 L
s
.27778 .01985 m
.27778 .0236 L
s
.30952 .01985 m
.30952 .0236 L
s
.37302 .01985 m
.37302 .0236 L
s
.40476 .01985 m
.40476 .0236 L
s
.43651 .01985 m
.43651 .0236 L
s
.46825 .01985 m
.46825 .0236 L
s
.53175 .01985 m
.53175 .0236 L
s
.56349 .01985 m
.56349 .0236 L
s
.59524 .01985 m
.59524 .0236 L
s
.62698 .01985 m
.62698 .0236 L
s
.69048 .01985 m
.69048 .0236 L
s
.72222 .01985 m
.72222 .0236 L
s
.75397 .01985 m
.75397 .0236 L
s
.78571 .01985 m
.78571 .0236 L
s
.84921 .01985 m
.84921 .0236 L
s
.88095 .01985 m
.88095 .0236 L
s
.9127 .01985 m
.9127 .0236 L
s
.94444 .01985 m
.94444 .0236 L
s
.25 Mabswid
0 .01985 m
1 .01985 L
s
.02381 .13396 m
.03006 .13396 L
s
[(0.1)] .01131 .13396 1 0 Mshowa
.02381 .24807 m
.03006 .24807 L
s
[(0.2)] .01131 .24807 1 0 Mshowa
.02381 .36218 m
.03006 .36218 L
s
[(0.3)] .01131 .36218 1 0 Mshowa
.02381 .47629 m
.03006 .47629 L
s
[(0.4)] .01131 .47629 1 0 Mshowa
.02381 .59041 m
.03006 .59041 L
s
[(0.5)] .01131 .59041 1 0 Mshowa
.125 Mabswid
.02381 .04268 m
.02756 .04268 L
s
.02381 .0655 m
.02756 .0655 L
s
.02381 .08832 m
.02756 .08832 L
s
.02381 .11114 m
.02756 .11114 L
s
.02381 .15679 m
.02756 .15679 L
s
.02381 .17961 m
.02756 .17961 L
s
.02381 .20243 m
.02756 .20243 L
s
.02381 .22525 m
.02756 .22525 L
s
.02381 .2709 m
.02756 .2709 L
s
.02381 .29372 m
.02756 .29372 L
s
.02381 .31654 m
.02756 .31654 L
s
.02381 .33936 m
.02756 .33936 L
s
.02381 .38501 m
.02756 .38501 L
s
.02381 .40783 m
.02756 .40783 L
s
.02381 .43065 m
.02756 .43065 L
s
.02381 .45347 m
.02756 .45347 L
s
.02381 .49912 m
.02756 .49912 L
s
.02381 .52194 m
.02756 .52194 L
s
.02381 .54476 m
.02756 .54476 L
s
.02381 .56758 m
.02756 .56758 L
s
.02381 .61323 m
.02756 .61323 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(2) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 1 r
.5 Mabswid
.02381 .01985 m
.03279 .01985 L
.04262 .01985 L
.04758 .01985 L
.0503 .01985 L
.05288 .01985 L
.05405 .01985 L
.05528 .01985 L
.05593 .01968 L
.05664 .01936 L
.05789 .01883 L
.06244 .01721 L
.06525 .01644 L
.06792 .01586 L
.07031 .01545 L
.07293 .01511 L
.07441 .01497 L
.07576 .01487 L
.0765 .01482 L
.07731 .01478 L
.07807 .01476 L
.07877 .01474 L
.08003 .01472 L
.08074 .01472 L
.08141 .01472 L
.08212 .01473 L
.08276 .01474 L
.0835 .01477 L
.0842 .01479 L
.08537 .01485 L
.08666 .01493 L
.08927 .01514 L
.09396 .01567 L
.09944 .0165 L
.10458 .01746 L
.14327 .02738 L
.18441 .03843 L
.22403 .04709 L
.26214 .05339 L
.3027 .0583 L
.34175 .06176 L
.38324 .06446 L
.42323 .06641 L
.46169 .06785 L
.50261 .06905 L
.54201 .06997 L
.5799 .07068 L
.62024 .07129 L
.65906 .07177 L
.70034 .07219 L
Mistroke
.7401 .07252 L
.77835 .07278 L
.81905 .07301 L
.85823 .07319 L
.89986 .07335 L
.93998 .07347 L
.97619 .07356 L
Mfstroke
1 0 0 r
.02381 .01985 m
.03279 .01985 L
.04262 .01985 L
.04758 .01985 L
.0503 .01985 L
.05288 .01985 L
.05405 .01985 L
.05528 .01985 L
.05593 .02383 L
.05664 .03133 L
.05789 .04432 L
.06244 .08922 L
.07293 .1795 L
.0842 .25931 L
.10458 .36808 L
.11468 .40881 L
.12571 .44552 L
.13625 .47433 L
.1458 .49606 L
.16548 .53043 L
.17628 .54461 L
.18645 .5556 L
.19621 .56435 L
.20653 .57199 L
.225 .58242 L
.23448 .58648 L
.24464 .59007 L
.26297 .59493 L
.27315 .59692 L
.28421 .59864 L
.29466 .59992 L
.30433 .60085 L
.31396 .60157 L
.323 .6021 L
.33291 .60254 L
.33845 .60274 L
.3436 .60289 L
.35317 .60309 L
.35823 .60317 L
.36364 .60324 L
.36637 .60326 L
.36933 .60328 L
.37212 .6033 L
.37345 .6033 L
.37469 .60331 L
.37591 .60331 L
.37702 .60331 L
.37825 .60332 L
.37893 .60332 L
.37957 .60332 L
Mistroke
.38086 .60332 L
.38205 .60332 L
.38335 .60332 L
.38408 .60332 L
.38474 .60332 L
.38595 .60331 L
.38707 .60331 L
.38963 .6033 L
.39212 .6033 L
.39479 .60328 L
.40402 .60322 L
.41493 .60312 L
.42486 .603 L
.46476 .60242 L
.50314 .60181 L
.54397 .60118 L
.58329 .60063 L
.62109 .60017 L
.66135 .59976 L
.70009 .59942 L
.74128 .59912 L
.78096 .59887 L
.81912 .59868 L
.85973 .59851 L
.89883 .59837 L
.94038 .59825 L
.97619 .59816 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00@_ooool3o`0002?ooooo0ol00003ooooo`03o`000?oooooooooo023o
oooo0ol00002ooooo`?o00008?ooool3o`0000?ooooo00?o0000ooooooooool08?ooool3o`0000;o
oooo0ol0000Qooooo`?o00000oooool00ol0003oooooooooo`0<ooooo`00A?ooool00ol0003ooooo
ooooo`0Rooooo`07o`000?ooooooooooooooool0003oooooo`00000Rooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07oooool01ol0003ooooooooooooooooo0000ooooool000008_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00Ko0000oooooooooooo0000
ooooool0000=ooooo`00@_ooool3o`0002Cooooo00Oo0000ooooooooooooooooo`000?oooooo0000
02;ooooo00Co0000oooooooooooooooo0ol0000Rooooo`06o`000?ooooooooooo`000?oooooo0000
8oooool00ol0003oooooooooo`03o`0002;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00gooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool01ol0003o
oooooooooooooooo0000ooooool000008_ooool01Ol0003ooooooooooooooooo000002Cooooo00Ko
0000oooooooooooo0000ooooool0000Sooooo`04o`000?ooooooooooo`0002Gooooo00Ko0000oooo
oooooooo0000ooooool0000=ooooo`006oooool00ol0003oooooooooo`0Tooooo`?o00008oooool2
o`0000Cooooo00?o0000ooooooooool08?ooool2o`0000?ooooo0ol0000Pooooo`?o00000oooool0
0ol0003oooooooooo`0Pooooo`?o00000_ooool3o`00027ooooo0ol00003ooooo`03o`000?oooooo
oooo00cooooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool001_ooooo00?o0000oooooooo
ool0ooooool3ooooo`006oooool00ol0003oooooooooo`06ooooo`ko0?ook_ooool001Gooooo1_l0
0009ool000ko00000ol0oooQo`0000[ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?oo`00
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo0?oo00;o0?oo0oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool0
01_ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Booooo`Co0?oo1oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03_ooool001_o
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Fooooo`Co0?ooh?ooool001_ooooo
00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Jooooo`?o0?oogOooool001_ooooo00?o
0000ooooooooool01Oooool00ooo003oooooooooo`0Mooooo`Go0?oof?ooool001_ooooo0_l00006
ooooo`03ool00?oooooooooo02;ooooo1Ol0oooCooooo`006oooool00ol0003oooooooooo`05oooo
o`03ool00?oooooooooo02Oooooo1Ol0ooo>ooooo`006oooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo02cooooo1Ol0ooo9ooooo`006oooool00ol0003oooooooooo`05ooooo`03ool0
0?oooooooooo037ooooo1ol0ooo2ooooo`006oooool00ol0003oooooooooo`06ooooo`03ool00?oo
oooooooo03Oooooo2_l0oonhooooo`006oooool00ol0003oooooooooo`06ooooo`03ool00?oooooo
oooo047ooooo5Ol0oonSooooo`006oooool2o`0000Oooooo00?oo`00ooooooooool0E_oooolDo`3o
ohoooooo000Kooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0J_oooom7o`3oodSo
oooo000Kooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0/Ooooolho`3ooa3ooooo
000Kooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0nOooool001_ooooo00?o0000
ooooooooool01oooool00ooo003oooooooooo`3hooooo`006oooool00ol0003oooooooooo`07oooo
o`03ool00?oooooooooo0?Sooooo000Kooooo`;o00002?ooool00ooo003oooooooooo`3hooooo`00
6oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo0?Sooooo000Kooooo`03o`000?oo
oooooooo00Oooooo00?oo`00ooooooooool0n?ooool001_ooooo00?o0000ooooooooool01oooool0
0ooo003oooooooooo`3hooooo`006oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo
0?Sooooo000Kooooo`;o00002?ooool00ooo003oooooooooo`3hooooo`006oooool00ol0003ooooo
ooooo`07ooooo`03ool00?oooooooooo0?Sooooo000Kooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool0moooool001_ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`3g
ooooo`006oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo0?Oooooo000:ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00005ooooo`03o`000?oooooooooo
00Sooooo00?oo`00ooooooooool0moooool000Wooooo00?o0000ooooool000002?ooool00ol0003o
ooooooooo`04ooooo`;o00002Oooool00ooo003oooooooooo`3gooooo`002Oooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`3gooooo`002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool00ooo003oooooooooo`3gooooo`002_ooool00ol0003oooooooooo`06
ooooo`;o00001_ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo0?Oooooo000Koooo
o`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0moooool001_ooooo00?o0000oooooooo
ool02?ooool00ooo003oooooooooo`3gooooo`006oooool2o`0000Wooooo00?oo`00ooooooooool0
moooool001_ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`3fooooo`006oooool0
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo0?Kooooo000Kooooo`03o`000?oooooooooo
00Wooooo00?oo`00ooooooooool0m_ooool001_ooooo00?o0000ooooooooool02Oooool00ooo003o
ooooooooo`3fooooo`006oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo0?Kooooo
000Kooooo`;o00002_ooool00ooo003oooooooooo`3fooooo`006oooool00ol0003oooooooooo`09
ooooo`03ool00?oooooooooo0?Kooooo000Kooooo`03o`000?oooooooooo00Wooooo00?oo`00oooo
ooooool0m_ooool001_ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`3fooooo`00
6oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo0?Gooooo000Kooooo`03o`000?oo
oooooooo00[ooooo00?oo`00ooooooooool0mOooool001_ooooo0_l0000;ooooo`03ool00?oooooo
oooo0?Gooooo000Kooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0mOooool001_o
oooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`3eooooo`006oooool00ol0003ooooo
ooooo`0:ooooo`03ool00?oooooooooo0?Gooooo000Kooooo`03o`000?oooooooooo00[ooooo00?o
o`00ooooooooool0mOooool001_ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`3d
ooooo`006oooool2o`0000cooooo00?oo`00ooooooooool0m?ooool001_ooooo00?o0000oooooooo
ool02oooool00ooo003oooooooooo`3dooooo`006oooool00ol0003oooooooooo`0;ooooo`03ool0
0?oooooooooo0?Cooooo000Kooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0m?oo
ool000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0000Gooooo00?o
0000ooooooooool02oooool00ooo003oooooooooo`3dooooo`002Oooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00Cooooo0_l0000<ooooo`03ool00?oooooooooo0?Cooooo0009oooo
o`03o`000?oooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo0??ooooo0009ooooo`03o`000?oooooo000000Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0??ooooo000:ooooo`03o`00
0?oooooooooo00Kooooo0ol00005ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0
loooool001_ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`3cooooo`006oooool0
0ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0??ooooo000Kooooo`;o00003Oooool00ooo
003oooooooooo`3cooooo`006oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo0?;o
oooo000Kooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0l_ooool001_ooooo00?o
0000ooooooooool03Oooool00ooo003oooooooooo`3booooo`006oooool00ol0003oooooooooo`0=
ooooo`03ool00?oooooooooo0?;ooooo000Kooooo`03o`000?oooooooooo00gooooo00?oo`00oooo
ooooool0l_ooool001_ooooo0_l0000?ooooo`03ool00?oooooooooo0?7ooooo000Kooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0lOooool001_ooooo00?o0000ooooooooool03_oo
ool00ooo003oooooooooo`3aooooo`006oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooo
oooo0?7ooooo000Kooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0lOooool001_o
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`3aooooo`006oooool2o`00013ooooo
00?oo`00ooooooooool0l?ooool001_ooooo00?o0000ooooooooool03oooool00ooo003ooooooooo
o`3`ooooo`006oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo0?3ooooo000Koooo
o`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0l?ooool001_ooooo00?o0000oooooooo
ool03oooool00ooo003oooooooooo`3`ooooo`006oooool00ol0003oooooooooo`0?ooooo`03ool0
0?oooooooooo0?3ooooo000Kooooo`;o00004Oooool00ooo003oooooooooo`3_ooooo`006oooool0
0ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>oooooo000Kooooo`03o`000?oooooooooo
013ooooo00?oo`00ooooooooool0koooool001_ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`3_ooooo`006oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo0>oooooo
000:ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00005ooooo`03o`00
0?oooooooooo017ooooo00?oo`00ooooooooool0k_ooool000Wooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`03ooooo`;o00004_ooool00ooo003oooooooooo`3^ooooo`002Oooool0
0ol0003oooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool0
0ooo003oooooooooo`3^ooooo`002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`3^ooooo`002_ooool00ol0003o
ooooooooo`06ooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo0>ko
oooo000Kooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0kOooool001_ooooo00?o
0000ooooooooool04_ooool00ooo003oooooooooo`3]ooooo`006oooool2o`0001?ooooo00?oo`00
ooooooooool0kOooool001_ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`3/oooo
o`006oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo0>cooooo000Kooooo`03o`00
0?oooooooooo01?ooooo00?oo`00ooooooooool0k?ooool001_ooooo00?o0000ooooooooool04ooo
ool00ooo003oooooooooo`3/ooooo`006oooool2o`0001Gooooo00?oo`00ooooooooool0joooool0
01_ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`3[ooooo`006oooool00ol0003o
ooooooooo`0Dooooo`03ool00?oooooooooo0>_ooooo000Kooooo`03o`000?oooooooooo01Gooooo
00?oo`00ooooooooool0j_ooool001_ooooo00?o0000ooooooooool05Oooool00ooo003ooooooooo
o`3Zooooo`006oooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo0>[ooooo000Koooo
o`;o00005oooool00ooo003oooooooooo`3Yooooo`006oooool00ol0003oooooooooo`0Fooooo`03
ool00?oooooooooo0>Wooooo000Kooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0
jOooool001_ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`3Xooooo`006oooool0
0ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0>Sooooo000Kooooo`03o`000?oooooooooo
01Oooooo00?oo`00ooooooooool0j?ooool001_ooooo0_l0000Iooooo`03ool00?oooooooooo0>Oo
oooo000Kooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool0ioooool001_ooooo00?o
0000ooooooooool06Oooool00ooo003oooooooooo`3Vooooo`006oooool00ol0003oooooooooo`0I
ooooo`03ool00?oooooooooo0>Kooooo000Kooooo`03o`000?oooooooooo01Wooooo00?oo`00oooo
ooooool0i_ooool000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`3Uooooo`00
2Oooool00ol0003oooooo`000007ooooo`?o00001Oooool2o`0001_ooooo00?oo`00ooooooooool0
iOooool000Wooooo00?o0000ooooool000001oooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo01_ooooo00?oo`00ooooooooool0i?ooool000Wooooo00?o0000ooooool000002?ooool2
o`0000Gooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`3Tooooo`002_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ooo
003oooooooooo`3Tooooo`006oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo0>?o
oooo000Kooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0hoooool001_ooooo0_l0
000Mooooo`03ool00?oooooooooo0>?ooooo000Kooooo`03o`000?oooooooooo01gooooo00?oo`00
ooooooooool0h_ooool001_ooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`3Roooo
o`006oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo0>7ooooo000Kooooo`03o`00
0?oooooooooo01oooooo00?oo`00ooooooooool0h?ooool001_ooooo00?o0000ooooooooool07ooo
ool00ooo003oooooooooo`3Pooooo`006oooool2o`00027ooooo00?oo`00ooooooooool0goooool0
01_ooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`3Oooooo`006oooool00ol0003o
ooooooooo`0Qooooo`03ool00?oooooooooo0=kooooo000Kooooo`03o`000?oooooooooo02;ooooo
00?oo`00ooooooooool0gOooool001_ooooo00?o0000ooooooooool08oooool00ooo003ooooooooo
o`3Looooo`006oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo0=_ooooo000Koooo
o`;o00009Oooool00ooo003oooooooooo`3Kooooo`006oooool00ol0003oooooooooo`0Uooooo`03
ool00?oooooooooo0=[ooooo000Kooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0
fOooool001_ooooo00?o0000ooooooooool09oooool00ooo003oooooooooo`3Hooooo`006oooool0
0ol0003oooooooooo`0Xooooo`03ool00?oooooooooo0=Oooooo000Kooooo`;o0000:_ooool3ool0
0=Kooooo000Kooooo`03o`000?oooooooooo02cooooo0_oo003Dooooo`006oooool00ol0003ooooo
ooooo`0^ooooo`03ool00?oooooooooo0=7ooooo000Kooooo`03o`000?oooooooooo02oooooo00?o
o`00ooooooooool0d?ooool001_ooooo00?o0000ooooooooool0<?ooool3ool00<oooooo000:oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00005ooooo`03o`000?oooooo
oooo03?ooooo0_oo003=ooooo`002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo
00?ooooo0_l0000fooooo`Coo`00bOooool000Wooooo00?o0000ooooool000001oooool3o`0000Go
oooo00?o0000ooooooooool0>Oooool4ool00<Gooooo0009ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`Goo`00K_oooom2ool0013ooooo
000:ooooo`03o`000?oooooooooo00Kooooo0ol00005ooooo`03o`000?oooooooooo04;ooooo4_oo
0009oooooe?oo`00D_ooool001_ooooo00?o0000ooooooooool0E?ooool9ool00:Gooooo000Koooo
o`03o`000?oooooooooo0?oooooo0oooool001_ooooo0_l0003oooooo`Cooooo000Kooooo`03o`00
0?oooooooooo0?oooooo0oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool008kooooo0ol0002?ooooo`00Soooool00ol0003oooooooooo`2>ooooo`00QOooool3
o`0000;ooooo00?o0000ooooool000000_ooool3o`0000;ooooo0ol00002ooooo`?o00001_ooool3
o`0007_ooooo0026ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`08o`000?oo
ooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0N_ooool008Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00So0000
oooooooooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1iooooo`00Q_ooool00ol0003oooooooooo`04o`000003ooooool0003o000000;o0000
00Koooooo`000?l0003oooooo`000?ooool4o`0000Sooooo00?o0000ooooooooool0NOooool008Go
oooo0ol0000Aooooo`03o`000?oooooooooo00Kooooo0ol0001kooooo`00oooooolQooooo`00oooo
oolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.34161, -0.0355764, \
0.122892, 0.00341891}},
  CellTags->"5.3.5"]
}, Open  ]]
}, Open  ]],

Cell["\<\
Here are two PI single-loop compensators that remove the \
steady-state error and further reduce the interaction.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pi = 
      TransferFunction[s, 
        DiagonalMatrix[{2 + 0.5\/s, 2 + 0.5\/s}]]\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->"5.3.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2 + 0.5`\/\[ScriptS]\), "0"},
                    {"0", \(2 + 0.5`\/\[ScriptS]\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Center},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[InvisibleSpace]\"\>",
                ShowStringCharacters->False],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[15]=",
  CellTags->"5.3.5"]
}, Open  ]],

Cell["This is the new closed-loop system.", "MathCaption",
  CellTags->"5.3.5"],

Cell[BoxData[
    \(\(fppi = SeriesConnect[pi, fp];\)\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->"5.3.5"],

Cell["\<\
This calculates the new closed-loop system transfer-function \
matrix.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[BoxData[
    \(\(hpi = Together /@ FeedbackConnect[fppi];\)\)], "Input",
  CellLabel->"In[17]:=",
  CellTags->"5.3.5"],

Cell["Here is its simulated response.", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SimulationPlot[hpi, UnitStep[t - 1], {t, 0, 30}, 
        PlotRange \[Rule] All];\)\)], "Input",
  CellLabel->"In[18]:=",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0191991 0.585277 [
[.18254 .0067 -2.4 -7.2 ]
[.18254 .0067 2.4 0 ]
[.34127 .0067 -4.8 -7.2 ]
[.34127 .0067 4.8 0 ]
[.5 .0067 -4.8 -7.2 ]
[.5 .0067 4.8 0 ]
[.65873 .0067 -4.8 -7.2 ]
[.65873 .0067 4.8 0 ]
[.81746 .0067 -4.8 -7.2 ]
[.81746 .0067 4.8 0 ]
[.97619 .0067 -4.8 -7.2 ]
[.97619 .0067 4.8 0 ]
[.01131 .13625 -14.4 -3.6 ]
[.01131 .13625 0 3.6 ]
[.01131 .25331 -14.4 -3.6 ]
[.01131 .25331 0 3.6 ]
[.01131 .37037 -14.4 -3.6 ]
[.01131 .37037 0 3.6 ]
[.01131 .48742 -14.4 -3.6 ]
[.01131 .48742 0 3.6 ]
[.01131 .60448 -4.8 -3.6 ]
[.01131 .60448 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .0192 m
.18254 .02545 L
s
[(5)] .18254 .0067 0 1 Mshowa
.34127 .0192 m
.34127 .02545 L
s
[(10)] .34127 .0067 0 1 Mshowa
.5 .0192 m
.5 .02545 L
s
[(15)] .5 .0067 0 1 Mshowa
.65873 .0192 m
.65873 .02545 L
s
[(20)] .65873 .0067 0 1 Mshowa
.81746 .0192 m
.81746 .02545 L
s
[(25)] .81746 .0067 0 1 Mshowa
.97619 .0192 m
.97619 .02545 L
s
[(30)] .97619 .0067 0 1 Mshowa
.125 Mabswid
.05556 .0192 m
.05556 .02295 L
s
.0873 .0192 m
.0873 .02295 L
s
.11905 .0192 m
.11905 .02295 L
s
.15079 .0192 m
.15079 .02295 L
s
.21429 .0192 m
.21429 .02295 L
s
.24603 .0192 m
.24603 .02295 L
s
.27778 .0192 m
.27778 .02295 L
s
.30952 .0192 m
.30952 .02295 L
s
.37302 .0192 m
.37302 .02295 L
s
.40476 .0192 m
.40476 .02295 L
s
.43651 .0192 m
.43651 .02295 L
s
.46825 .0192 m
.46825 .02295 L
s
.53175 .0192 m
.53175 .02295 L
s
.56349 .0192 m
.56349 .02295 L
s
.59524 .0192 m
.59524 .02295 L
s
.62698 .0192 m
.62698 .02295 L
s
.69048 .0192 m
.69048 .02295 L
s
.72222 .0192 m
.72222 .02295 L
s
.75397 .0192 m
.75397 .02295 L
s
.78571 .0192 m
.78571 .02295 L
s
.84921 .0192 m
.84921 .02295 L
s
.88095 .0192 m
.88095 .02295 L
s
.9127 .0192 m
.9127 .02295 L
s
.94444 .0192 m
.94444 .02295 L
s
.25 Mabswid
0 .0192 m
1 .0192 L
s
.02381 .13625 m
.03006 .13625 L
s
[(0.2)] .01131 .13625 1 0 Mshowa
.02381 .25331 m
.03006 .25331 L
s
[(0.4)] .01131 .25331 1 0 Mshowa
.02381 .37037 m
.03006 .37037 L
s
[(0.6)] .01131 .37037 1 0 Mshowa
.02381 .48742 m
.03006 .48742 L
s
[(0.8)] .01131 .48742 1 0 Mshowa
.02381 .60448 m
.03006 .60448 L
s
[(1)] .01131 .60448 1 0 Mshowa
.125 Mabswid
.02381 .04846 m
.02756 .04846 L
s
.02381 .07773 m
.02756 .07773 L
s
.02381 .10699 m
.02756 .10699 L
s
.02381 .16552 m
.02756 .16552 L
s
.02381 .19478 m
.02756 .19478 L
s
.02381 .22405 m
.02756 .22405 L
s
.02381 .28257 m
.02756 .28257 L
s
.02381 .31184 m
.02756 .31184 L
s
.02381 .3411 m
.02756 .3411 L
s
.02381 .39963 m
.02756 .39963 L
s
.02381 .42889 m
.02756 .42889 L
s
.02381 .45816 m
.02756 .45816 L
s
.02381 .51668 m
.02756 .51668 L
s
.02381 .54595 m
.02756 .54595 L
s
.02381 .57521 m
.02756 .57521 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(1) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 1 r
.5 Mabswid
.02381 .0192 m
.03279 .0192 L
.04262 .0192 L
.04758 .0192 L
.0503 .0192 L
.05288 .0192 L
.05405 .0192 L
.05528 .0192 L
.05593 .02327 L
.05664 .03096 L
.05789 .04425 L
.06244 .08999 L
.07293 .18098 L
.0842 .26022 L
.10458 .36615 L
.11468 .40514 L
.12571 .43993 L
.13625 .46699 L
.1458 .48728 L
.16548 .51919 L
.17628 .53233 L
.18645 .54253 L
.20653 .55789 L
.225 .56789 L
.24382 .57525 L
.26449 .58103 L
.284 .58498 L
.30491 .58807 L
.32615 .59039 L
.34627 .59207 L
.3846 .59435 L
.40438 .59523 L
.42538 .59602 L
.46314 .59718 L
.50334 .59818 L
.54203 .59898 L
.58317 .59972 L
.62279 .60033 L
.6609 .60085 L
.70146 .60133 L
.7405 .60174 L
.782 .60212 L
.82198 .60244 L
.86045 .6027 L
.90137 .60295 L
.94077 .60316 L
.97619 .60332 L
s
1 0 0 r
.02381 .0192 m
.03279 .0192 L
.04262 .0192 L
.04758 .0192 L
.0503 .0192 L
.05288 .0192 L
.05405 .0192 L
.05528 .0192 L
.05593 .01902 L
.05664 .0187 L
.05789 .01816 L
.06244 .01659 L
.06525 .0159 L
.06792 .0154 L
.07031 .01508 L
.07167 .01494 L
.07293 .01485 L
.07363 .01481 L
.0744 .01477 L
.07512 .01474 L
.07579 .01473 L
.07705 .01472 L
.07768 .01472 L
.07838 .01473 L
.07914 .01474 L
.07983 .01476 L
.08063 .0148 L
.08139 .01483 L
.0842 .01503 L
.08666 .01527 L
.08927 .01558 L
.09396 .01628 L
.10458 .01829 L
.14233 .02676 L
.1633 .03065 L
.17249 .03204 L
.18253 .03333 L
.19165 .0343 L
.20138 .03513 L
.21166 .03581 L
.22122 .03627 L
.22655 .03646 L
.23146 .0366 L
.23686 .03671 L
.23958 .03675 L
.24257 .03678 L
.24391 .03679 L
.24519 .0368 L
.24635 .03681 L
.24759 .03682 L
Mistroke
.24829 .03682 L
.24892 .03682 L
.25017 .03682 L
.25086 .03682 L
.25161 .03682 L
.25233 .03682 L
.25298 .03682 L
.25415 .03682 L
.25524 .03682 L
.25644 .03681 L
.25772 .0368 L
.26034 .03678 L
.26272 .03676 L
.26754 .03669 L
.27266 .03661 L
.28184 .0364 L
.30262 .03576 L
.34042 .03421 L
.38067 .03236 L
.41941 .03062 L
.46061 .02893 L
.50028 .0275 L
.53844 .02631 L
.57906 .02522 L
.61815 .02433 L
.6597 .02353 L
.69974 .02288 L
.73826 .02235 L
.77923 .02188 L
.81868 .02149 L
.85662 .02117 L
.89701 .02088 L
.93589 .02064 L
.97619 .02043 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00@_ooool3o`0002?ooooo0ol00003ooooo`03o`000?oooooooooo023o
oooo0ol00002ooooo`?o00008?ooool3o`0000?ooooo00?o0000ooooooooool08?ooool3o`0000;o
oooo0ol0000Qooooo`?o00000oooool00ol0003oooooooooo`0<ooooo`00A?ooool00ol0003ooooo
ooooo`0Rooooo`07o`000?ooooooooooooooool0003oooooo`00000Rooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07oooool01ol0003ooooooooooooooooo0000ooooool000008_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00Ko0000oooooooooooo0000
ooooool0000=ooooo`00@_ooool3o`0002Cooooo00Oo0000ooooooooooooooooo`000?oooooo0000
02;ooooo00Co0000oooooooooooooooo0ol0000Rooooo`06o`000?ooooooooooo`000?oooooo0000
8oooool00ol0003oooooooooo`03o`0002;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00gooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool01ol0003o
oooooooooooooooo0000ooooool000008_ooool01Ol0003ooooooooooooooooo000002Cooooo00Ko
0000oooooooooooo0000ooooool0000Sooooo`04o`000?ooooooooooo`0002Gooooo00Ko0000oooo
oooooooo0000ooooool0000=ooooo`006oooool00ol0003oooooooooo`0Tooooo`?o00008oooool2
o`0000Cooooo00?o0000ooooooooool08?ooool2o`0000?ooooo0ol0000Pooooo`?o00000oooool0
0ol0003oooooooooo`0Pooooo`?o00000_ooool3o`00027ooooo0ol00003ooooo`03o`000?oooooo
oooo00cooooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool001_ooooo00?o0000oooooooo
ool0ooooool3ooooo`006oooool00ol0003oooooooooo`07ooooo`_oo`00l?ooool001Gooooo1_l0
000:ool000_o00000ooo002ho`0002Goo`001_l0000:ooooo`006oooool00ol0003oooooooooo`05
ooooo`03o`3ooooooooooooo00Gooooo00?o0000ooooooooool01Oooool5ool000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo003oo`0003_oo`000oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo
00Gooooo00?o0?ooooooooooool04_ooool5ool000Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0GooooobSoo`003oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool03_ooool001_ooooo00?o0000ooooooooool01Oooool00ol0oooo
ooooooooo`0Gooooo`Koo`00;_oooolEool009[ooooo000Kooooo`03o`000?oooooooooo00Gooooo
00?o0?ooooooooooool07Oooool^ool00:oooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o
0?ooooooooooool0nOooool001_ooooo00?o0000ooooooooool01_ooool00ol0ooooooooooooo`3i
ooooo`006oooool2o`0000Oooooo00?o0?ooooooooooool0nOooool001_ooooo00?o0000oooooooo
ool01_ooool00ol0ooooooooooooo`3iooooo`006oooool00ol0003oooooooooo`06ooooo`03o`3o
oooooooooooo0?Wooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o0?ooooooooooool0nOoo
ool001_ooooo00?o0000ooooooooool01_ooool00ol0ooooooooooooo`3iooooo`006oooool00ol0
003oooooooooo`06ooooo`03o`3ooooooooooooo0?Wooooo000Kooooo`03o`000?oooooooooo00Oo
oooo00?o0?ooooooooooool0n?ooool001_ooooo00?o0000ooooooooool01oooool00ol0oooooooo
ooooo`3hooooo`006oooool2o`0000Sooooo00?o0?ooooooooooool0n?ooool001_ooooo00?o0000
ooooooooool01oooool00ol0ooooooooooooo`3hooooo`006oooool00ol0003oooooooooo`07oooo
o`03o`3ooooooooooooo0?Sooooo000Kooooo`03o`000?oooooooooo00Oooooo00?o0?oooooooooo
ool0n?ooool001_ooooo00?o0000ooooooooool01oooool00ol0ooooooooooooo`3hooooo`006ooo
ool00ol0003oooooooooo`07ooooo`03o`3ooooooooooooo0?Sooooo000Kooooo`03o`000?oooooo
oooo00Oooooo00?o0?ooooooooooool0n?ooool001_ooooo0_l00008ooooo`03o`3ooooooooooooo
0?Sooooo000Kooooo`03o`000?oooooooooo00Oooooo00?o0?ooooooooooool0n?ooool001_ooooo
00?o0000ooooooooool01oooool00ol0ooooooooooooo`3hooooo`006oooool00ol0003ooooooooo
o`08ooooo`03o`3ooooooooooooo0?Oooooo000Kooooo`03o`000?oooooooooo00Sooooo00?o0?oo
ooooooooool0moooool001_ooooo00?o0000ooooooooool02?ooool00ol0ooooooooooooo`3goooo
o`006oooool00ol0003oooooooooo`08ooooo`03o`3ooooooooooooo0?Oooooo000;ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00004ooooo`03o`000?oooooooooo00So
oooo00?o0?ooooooooooool0moooool000[ooooo00?o0000ooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`;o00002Oooool00ol0ooooooooooooo`3gooooo`002_ooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0oooooooooooo
o`3gooooo`002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0ooooooooooooo`3gooooo`002oooool00ol0003oooooooooo`06oooo
o`?o00001?ooool00ol0003oooooooooo`08ooooo`03o`3ooooooooooooo0?Oooooo000Kooooo`03
o`000?oooooooooo00Sooooo00?o0?ooooooooooool0moooool001_ooooo00?o0000ooooooooool0
2?ooool00ol0ooooooooooooo`3gooooo`006oooool00ol0003oooooooooo`09ooooo`03o`3ooooo
oooooooo0?Kooooo000Kooooo`;o00002_ooool00ol0ooooooooooooo`3fooooo`006oooool00ol0
003oooooooooo`09ooooo`03o`3ooooooooooooo0?Kooooo000Kooooo`03o`000?oooooooooo00Wo
oooo00?o0?ooooooooooool0m_ooool001_ooooo00?o0000ooooooooool02Oooool00ol0oooooooo
ooooo`3fooooo`006oooool00ol0003oooooooooo`09ooooo`03o`3ooooooooooooo0?Kooooo000K
ooooo`03o`000?oooooooooo00Wooooo00?o0?ooooooooooool0m_ooool001_ooooo00?o0000oooo
ooooool02Oooool00ol0ooooooooooooo`3fooooo`006oooool00ol0003oooooooooo`09ooooo`03
o`3ooooooooooooo0?Kooooo000Kooooo`;o00002oooool00ol0ooooooooooooo`3eooooo`006ooo
ool00ol0003oooooooooo`0:ooooo`03o`3ooooooooooooo0?Gooooo000Kooooo`03o`000?oooooo
oooo00[ooooo00?o0?ooooooooooool0mOooool001_ooooo00?o0000ooooooooool02_ooool00ol0
ooooooooooooo`3eooooo`006oooool00ol0003oooooooooo`0:ooooo`03o`3ooooooooooooo0?Go
oooo000Kooooo`03o`000?oooooooooo00[ooooo00?o0?ooooooooooool0mOooool001_ooooo00?o
0000ooooooooool02_ooool00ol0ooooooooooooo`3eooooo`006oooool2o`0000cooooo00?o0?oo
ooooooooool0m?ooool001_ooooo00?o0000ooooooooool02oooool00ol0ooooooooooooo`3doooo
o`006oooool00ol0003oooooooooo`0;ooooo`03o`3ooooooooooooo0?Cooooo000Kooooo`03o`00
0?oooooooooo00_ooooo00?o0?ooooooooooool0m?ooool001_ooooo00?o0000ooooooooool02ooo
ool00ol0ooooooooooooo`3dooooo`006oooool00ol0003oooooooooo`0;ooooo`03o`3ooooooooo
oooo0?Cooooo000Kooooo`03o`000?oooooooooo00_ooooo00?o0?ooooooooooool0m?ooool000_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03?ooool00ol0ooooooooooooo`3cooooo`002_ooool00ol0003ooooo
o`000007ooooo`?o00001?ooool2o`0000gooooo00?o0?ooooooooooool0loooool000[ooooo00?o
0000ooooool000001oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00cooooo00?o
0?ooooooooooool0loooool000[ooooo00?o0000ooooool000002?ooool2o`0000Cooooo00?o0000
ooooooooool03?ooool00ol0ooooooooooooo`3cooooo`002oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0ooooooooooooo`3coooo
o`006oooool00ol0003oooooooooo`0<ooooo`03o`3ooooooooooooo0??ooooo000Kooooo`03o`00
0?oooooooooo00gooooo00?o0?ooooooooooool0l_ooool001_ooooo00?o0000ooooooooool03Ooo
ool00ol0ooooooooooooo`3booooo`006oooool2o`0000kooooo00?o0?ooooooooooool0l_ooool0
01_ooooo00?o0000ooooooooool03Oooool00ol0ooooooooooooo`3booooo`006oooool00ol0003o
ooooooooo`0=ooooo`03o`3ooooooooooooo0?;ooooo000Kooooo`03o`000?oooooooooo00kooooo
00?o0?ooooooooooool0lOooool001_ooooo00?o0000ooooooooool03_ooool00ol0oooooooooooo
o`3aooooo`006oooool00ol0003oooooooooo`0>ooooo`03o`3ooooooooooooo0?7ooooo000Koooo
o`03o`000?oooooooooo00kooooo00?o0?ooooooooooool0lOooool001_ooooo00?o0000oooooooo
ool03oooool00ol0ooooooooooooo`3`ooooo`006oooool2o`00013ooooo00?o0?ooooooooooool0
l?ooool001_ooooo00?o0000ooooooooool03oooool00ol0ooooooooooooo`3`ooooo`006oooool0
0ol0003oooooooooo`0?ooooo`03o`3ooooooooooooo0?3ooooo000Kooooo`03o`000?oooooooooo
00oooooo00?o0?ooooooooooool0l?ooool001_ooooo00?o0000ooooooooool04?ooool00ol0oooo
ooooooooo`3_ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`3ooooooooooooo0>oooooo
000Kooooo`03o`000?oooooooooo013ooooo00?o0?ooooooooooool0koooool001_ooooo0_l0000A
ooooo`03o`3ooooooooooooo0>oooooo000Kooooo`03o`000?oooooooooo017ooooo00?o0?oooooo
ooooool0k_ooool001_ooooo00?o0000ooooooooool04Oooool00ol0ooooooooooooo`3^ooooo`00
6oooool00ol0003oooooooooo`0Aooooo`03o`3ooooooooooooo0>kooooo000Kooooo`03o`000?oo
oooooooo017ooooo00?o0?ooooooooooool0k_ooool001_ooooo00?o0000ooooooooool04Oooool0
0ol0ooooooooooooo`3^ooooo`006oooool00ol0003oooooooooo`0Booooo`03o`3ooooooooooooo
0>gooooo000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000Co
oooo00?o0000ooooooooool04_ooool00ol0ooooooooooooo`3]ooooo`002_ooool00ol0003ooooo
o`000007ooooo`03o`000?oooooo000000Cooooo0_l0000Cooooo`03o`3ooooooooooooo0>gooooo
000:ooooo`03o`000?oooooo000000Oooooo0ol00004ooooo`03o`000?oooooooooo01;ooooo00?o
0?ooooooooooool0kOooool000[ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01?ooooo00?o0?ooooooooooool0k?ooool000_ooooo00?o0000oooo
ooooool01oooool2o`0000Cooooo00?o0000ooooooooool04oooool00ol0ooooooooooooo`3/oooo
o`006oooool00ol0003oooooooooo`0Cooooo`03o`3ooooooooooooo0>cooooo000Kooooo`03o`00
0?oooooooooo01?ooooo00?o0?ooooooooooool0k?ooool001_ooooo00?o0000ooooooooool04ooo
ool00ol0ooooooooooooo`3/ooooo`006oooool2o`0001Gooooo00?o0?ooooooooooool0joooool0
01_ooooo00?o0000ooooooooool05?ooool00ol0ooooooooooooo`3[ooooo`006oooool00ol0003o
ooooooooo`0Dooooo`03o`3ooooooooooooo0>_ooooo000Kooooo`03o`000?oooooooooo01Cooooo
00?o0?ooooooooooool0joooool001_ooooo00?o0000ooooooooool05Oooool00ol0oooooooooooo
o`3Zooooo`006oooool00ol0003oooooooooo`0Eooooo`03o`3ooooooooooooo0>[ooooo000Koooo
o`03o`000?oooooooooo01Gooooo00?o0?ooooooooooool0j_ooool001_ooooo00?o0000oooooooo
ool05_ooool00ol0ooooooooooooo`3Yooooo`006oooool2o`0001Oooooo00?o0?ooooooooooool0
jOooool001_ooooo00?o0000ooooooooool05_ooool00ol0ooooooooooooo`3Yooooo`006oooool0
0ol0003oooooooooo`0Gooooo`03o`3ooooooooooooo0>Sooooo000Kooooo`03o`000?oooooooooo
01Oooooo00?o0?ooooooooooool0j?ooool001_ooooo00?o0000ooooooooool05oooool00ol0oooo
ooooooooo`3Xooooo`006oooool00ol0003oooooooooo`0Hooooo`03o`3ooooooooooooo0>Oooooo
000Kooooo`03o`000?oooooooooo01Sooooo00?o0?ooooooooooool0ioooool001_ooooo0_l0000J
ooooo`03o`3ooooooooooooo0>Kooooo000Kooooo`03o`000?oooooooooo01Wooooo00?o0?oooooo
ooooool0i_ooool001_ooooo00?o0000ooooooooool06Oooool00ol0ooooooooooooo`3Vooooo`00
6oooool00ol0003oooooooooo`0Jooooo`03o`3ooooooooooooo0>Gooooo000Kooooo`03o`000?oo
oooooooo01[ooooo00?o0?ooooooooooool0iOooool001_ooooo00?o0000ooooooooool06oooool0
0ol0ooooooooooooo`3Tooooo`006oooool00ol0003oooooooooo`0Kooooo`03o`3ooooooooooooo
0>Cooooo000;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00004oooo
o`03o`000?oooooooooo01_ooooo00?o0?ooooooooooool0i?ooool000[ooooo00?o0000ooooool0
00001oooool00ol0003oooooo`000004ooooo`;o00007Oooool00ol0ooooooooooooo`3Sooooo`00
2_ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7?ooool00ol0ooooooooooooo`3Sooooo`002_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool07Oooool00ol0ooooooooooooo`3Rooooo`002oooool0
0ol0003oooooooooo`06ooooo`?o00001?ooool00ol0003oooooooooo`0Nooooo`03o`3ooooooooo
oooo0>7ooooo000Kooooo`03o`000?oooooooooo01kooooo00?o0?ooooooooooool0hOooool001_o
oooo00?o0000ooooooooool07oooool00ol0ooooooooooooo`3Pooooo`006oooool00ol0003ooooo
ooooo`0Oooooo`03o`3ooooooooooooo0>3ooooo000Kooooo`;o00008Oooool00ol0oooooooooooo
o`3Oooooo`006oooool00ol0003oooooooooo`0Qooooo`03o`3ooooooooooooo0=kooooo000Koooo
o`03o`000?oooooooooo02;ooooo00?o0?ooooooooooool0gOooool001_ooooo00?o0000oooooooo
ool08oooool00ol0ooooooooooooo`3Looooo`006oooool00ol0003oooooooooo`0Tooooo`03o`3o
oooooooooooo0=_ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0?ooooooooooool0fooo
ool001_ooooo00?o0000ooooooooool09Oooool00ol0ooooooooooooo`3Jooooo`006oooool00ol0
003oooooooooo`0Vooooo`;o0?oof_ooool001_ooooo0_l0000Yooooo`03o`3ooooooooooooo0=Oo
oooo000Kooooo`03o`000?oooooooooo02Wooooo0_l0oooGooooo`006oooool00ol0003ooooooooo
o`0[ooooo`03o`3ooooooooooooo0=Cooooo000Kooooo`03o`000?oooooooooo02cooooo0_l0oooD
ooooo`006oooool00ol0003oooooooooo`0^ooooo`;o0?ood_ooool001_ooooo00?o0000oooooooo
ool0<?ooool2o`3oom3ooooo000Kooooo`03o`000?oooooooooo03;ooooo0ol0ooo=ooooo`006ooo
ool2o`0003Kooooo0_l0ooo;ooooo`006oooool00ol0003oooooooooo`0gooooo`?o0?oob?ooool0
01_ooooo00?o0000ooooooooool0>_ooool4o`3oolCooooo000Kooooo`03o`000?oooooooooo03ko
oooo1Ol0oonoooooo`006oooool00ol0003oooooooooo`13ooooo`_o0?oo]?ooool001_ooooo00?o
0000ooooooooool0C_oooolDo`3ooj3ooooo000Kooooo`03o`000?oooooooooo06;ooooo9_l0oomj
ooooo`005?ooool3o`0000Cooooo00?o0000ooooooooool0R?oooomVo`3ooaCooooo000Eooooo`03
o`000?oooooooooo00?ooooo0_l0003_ooooo`Co0?oo4?ooool001Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3oooooo`?ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0ooooool3ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0ooooool3
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00S_ooool3
o`0008oooooo002?ooooo`03o`000?oooooooooo08kooooo0025ooooo`?o00000_ooool00ol0003o
ooooo`000002ooooo`?o00000_ooool3o`0000;ooooo0ol00006ooooo`?o0000Noooool008Kooooo
00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00So0000oooooooooooo0000ooooool0
003oooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1jooooo`00Q_oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool02?l0003oooooooooool0003ooooo
o`000?oooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07[ooooo0026
ooooo`03o`000?oooooooooo00Co000000?oooooo`000?l000000_l000001_oooooo0000o`000?oo
oooo0000ooooo`Co00001oooool00ol0003oooooooooo`1jooooo`00QOooool3o`00017ooooo00?o
0000ooooooooool01_ooool2o`0007cooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.36092, -0.0694047, \
0.12302, 0.00667271}},
  CellTags->"5.3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0191991 0.585277 [
[.18254 .0067 -2.4 -7.2 ]
[.18254 .0067 2.4 0 ]
[.34127 .0067 -4.8 -7.2 ]
[.34127 .0067 4.8 0 ]
[.5 .0067 -4.8 -7.2 ]
[.5 .0067 4.8 0 ]
[.65873 .0067 -4.8 -7.2 ]
[.65873 .0067 4.8 0 ]
[.81746 .0067 -4.8 -7.2 ]
[.81746 .0067 4.8 0 ]
[.97619 .0067 -4.8 -7.2 ]
[.97619 .0067 4.8 0 ]
[.01131 .13625 -14.4 -3.6 ]
[.01131 .13625 0 3.6 ]
[.01131 .25331 -14.4 -3.6 ]
[.01131 .25331 0 3.6 ]
[.01131 .37037 -14.4 -3.6 ]
[.01131 .37037 0 3.6 ]
[.01131 .48742 -14.4 -3.6 ]
[.01131 .48742 0 3.6 ]
[.01131 .60448 -4.8 -3.6 ]
[.01131 .60448 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .0192 m
.18254 .02545 L
s
[(5)] .18254 .0067 0 1 Mshowa
.34127 .0192 m
.34127 .02545 L
s
[(10)] .34127 .0067 0 1 Mshowa
.5 .0192 m
.5 .02545 L
s
[(15)] .5 .0067 0 1 Mshowa
.65873 .0192 m
.65873 .02545 L
s
[(20)] .65873 .0067 0 1 Mshowa
.81746 .0192 m
.81746 .02545 L
s
[(25)] .81746 .0067 0 1 Mshowa
.97619 .0192 m
.97619 .02545 L
s
[(30)] .97619 .0067 0 1 Mshowa
.125 Mabswid
.05556 .0192 m
.05556 .02295 L
s
.0873 .0192 m
.0873 .02295 L
s
.11905 .0192 m
.11905 .02295 L
s
.15079 .0192 m
.15079 .02295 L
s
.21429 .0192 m
.21429 .02295 L
s
.24603 .0192 m
.24603 .02295 L
s
.27778 .0192 m
.27778 .02295 L
s
.30952 .0192 m
.30952 .02295 L
s
.37302 .0192 m
.37302 .02295 L
s
.40476 .0192 m
.40476 .02295 L
s
.43651 .0192 m
.43651 .02295 L
s
.46825 .0192 m
.46825 .02295 L
s
.53175 .0192 m
.53175 .02295 L
s
.56349 .0192 m
.56349 .02295 L
s
.59524 .0192 m
.59524 .02295 L
s
.62698 .0192 m
.62698 .02295 L
s
.69048 .0192 m
.69048 .02295 L
s
.72222 .0192 m
.72222 .02295 L
s
.75397 .0192 m
.75397 .02295 L
s
.78571 .0192 m
.78571 .02295 L
s
.84921 .0192 m
.84921 .02295 L
s
.88095 .0192 m
.88095 .02295 L
s
.9127 .0192 m
.9127 .02295 L
s
.94444 .0192 m
.94444 .02295 L
s
.25 Mabswid
0 .0192 m
1 .0192 L
s
.02381 .13625 m
.03006 .13625 L
s
[(0.2)] .01131 .13625 1 0 Mshowa
.02381 .25331 m
.03006 .25331 L
s
[(0.4)] .01131 .25331 1 0 Mshowa
.02381 .37037 m
.03006 .37037 L
s
[(0.6)] .01131 .37037 1 0 Mshowa
.02381 .48742 m
.03006 .48742 L
s
[(0.8)] .01131 .48742 1 0 Mshowa
.02381 .60448 m
.03006 .60448 L
s
[(1)] .01131 .60448 1 0 Mshowa
.125 Mabswid
.02381 .04846 m
.02756 .04846 L
s
.02381 .07773 m
.02756 .07773 L
s
.02381 .10699 m
.02756 .10699 L
s
.02381 .16552 m
.02756 .16552 L
s
.02381 .19478 m
.02756 .19478 L
s
.02381 .22405 m
.02756 .22405 L
s
.02381 .28257 m
.02756 .28257 L
s
.02381 .31184 m
.02756 .31184 L
s
.02381 .3411 m
.02756 .3411 L
s
.02381 .39963 m
.02756 .39963 L
s
.02381 .42889 m
.02756 .42889 L
s
.02381 .45816 m
.02756 .45816 L
s
.02381 .51668 m
.02756 .51668 L
s
.02381 .54595 m
.02756 .54595 L
s
.02381 .57521 m
.02756 .57521 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(2) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 1 r
.5 Mabswid
.02381 .0192 m
.03279 .0192 L
.04262 .0192 L
.04758 .0192 L
.0503 .0192 L
.05288 .0192 L
.05405 .0192 L
.05528 .0192 L
.05593 .01902 L
.05664 .0187 L
.05789 .01816 L
.06244 .01659 L
.06525 .0159 L
.06792 .0154 L
.07031 .01508 L
.07167 .01494 L
.07293 .01485 L
.07363 .01481 L
.0744 .01477 L
.07512 .01474 L
.07579 .01473 L
.07705 .01472 L
.07768 .01472 L
.07838 .01473 L
.07914 .01474 L
.07983 .01476 L
.08063 .0148 L
.08139 .01483 L
.0842 .01503 L
.08666 .01527 L
.08927 .01558 L
.09396 .01628 L
.10458 .01829 L
.14233 .02676 L
.1633 .03065 L
.17249 .03204 L
.18253 .03333 L
.19165 .0343 L
.20138 .03513 L
.21166 .03581 L
.22122 .03627 L
.22655 .03646 L
.23146 .0366 L
.23686 .03671 L
.23958 .03675 L
.24257 .03678 L
.24391 .03679 L
.24519 .0368 L
.24635 .03681 L
.24759 .03682 L
Mistroke
.24829 .03682 L
.24892 .03682 L
.25017 .03682 L
.25086 .03682 L
.25161 .03682 L
.25233 .03682 L
.25298 .03682 L
.25415 .03682 L
.25524 .03682 L
.25644 .03681 L
.25772 .0368 L
.26034 .03678 L
.26272 .03676 L
.26754 .03669 L
.27266 .03661 L
.28184 .0364 L
.30262 .03576 L
.34042 .03421 L
.38067 .03236 L
.41941 .03062 L
.46061 .02893 L
.50028 .0275 L
.53844 .02631 L
.57906 .02522 L
.61815 .02433 L
.6597 .02353 L
.69974 .02288 L
.73826 .02235 L
.77923 .02188 L
.81868 .02149 L
.85662 .02117 L
.89701 .02088 L
.93589 .02064 L
.97619 .02043 L
Mfstroke
1 0 0 r
.02381 .0192 m
.03279 .0192 L
.04262 .0192 L
.04758 .0192 L
.0503 .0192 L
.05288 .0192 L
.05405 .0192 L
.05528 .0192 L
.05593 .02327 L
.05664 .03096 L
.05789 .04425 L
.06244 .08999 L
.07293 .18098 L
.0842 .26022 L
.10458 .36615 L
.11468 .40514 L
.12571 .43993 L
.13625 .46699 L
.1458 .48728 L
.16548 .51919 L
.17628 .53233 L
.18645 .54253 L
.20653 .55789 L
.225 .56789 L
.24382 .57525 L
.26449 .58103 L
.284 .58498 L
.30491 .58807 L
.32615 .59039 L
.34627 .59207 L
.3846 .59435 L
.40438 .59523 L
.42538 .59602 L
.46314 .59718 L
.50334 .59818 L
.54203 .59898 L
.58317 .59972 L
.62279 .60033 L
.6609 .60085 L
.70146 .60133 L
.7405 .60174 L
.782 .60212 L
.82198 .60244 L
.86045 .6027 L
.90137 .60295 L
.94077 .60316 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00@_ooool3o`0002?ooooo0ol00003ooooo`03o`000?oooooooooo023o
oooo0ol00002ooooo`?o00008?ooool3o`0000?ooooo00?o0000ooooooooool08?ooool3o`0000;o
oooo0ol0000Qooooo`?o00000oooool00ol0003oooooooooo`0<ooooo`00A?ooool00ol0003ooooo
ooooo`0Rooooo`07o`000?ooooooooooooooool0003oooooo`00000Rooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07oooool01ol0003ooooooooooooooooo0000ooooool000008_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00Ko0000oooooooooooo0000
ooooool0000=ooooo`00@_ooool3o`0002Cooooo00Oo0000ooooooooooooooooo`000?oooooo0000
02;ooooo00Co0000oooooooooooooooo0ol0000Rooooo`06o`000?ooooooooooo`000?oooooo0000
8oooool00ol0003oooooooooo`03o`0002;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00gooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool01ol0003o
oooooooooooooooo0000ooooool000008_ooool01Ol0003ooooooooooooooooo000002Cooooo00Ko
0000oooooooooooo0000ooooool0000Sooooo`04o`000?ooooooooooo`0002Gooooo00Ko0000oooo
oooooooo0000ooooool0000=ooooo`006oooool00ol0003oooooooooo`0Tooooo`?o00008oooool2
o`0000Cooooo00?o0000ooooooooool08?ooool2o`0000?ooooo0ol0000Pooooo`?o00000oooool0
0ol0003oooooooooo`0Pooooo`?o00000_ooool3o`00027ooooo0ol00003ooooo`03o`000?oooooo
oooo00cooooo000Kooooo`03o`000?oooooooooo0?oooooo0oooool001_ooooo00?o0000oooooooo
ool0ooooool3ooooo`006oooool00ol0003oooooooooo`07ooooo`_o0?ool?ooool001Gooooo1_l0
0009ool00003o`3oool0003o000000Wo00000ol0oonho`0002Go0?oo1_l0000:ooooo`006oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01Oooool5
o`3oo`?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?l0oooo
0?oo03_o0?oo0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo000Koooo
o`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool04_ooool5o`3oo`Kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0GooooobSo0?oo3oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03_ooool001_ooooo00?o0000oooooooo
ool01Oooool00ooo003oooooooooo`0Gooooo`Ko0?oo;_oooolEo`3ooi[ooooo000Kooooo`03o`00
0?oooooooooo00Gooooo00?oo`00ooooooooool07Oooool^o`3oojoooooo000Kooooo`03o`000?oo
oooooooo00Kooooo00?oo`00ooooooooool0nOooool001_ooooo00?o0000ooooooooool01_ooool0
0ooo003oooooooooo`3iooooo`006oooool2o`0000Oooooo00?oo`00ooooooooool0nOooool001_o
oooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`3iooooo`006oooool00ol0003ooooo
ooooo`06ooooo`03ool00?oooooooooo0?Wooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o
o`00ooooooooool0nOooool001_ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`3i
ooooo`006oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo0?Wooooo000Kooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool0n?ooool001_ooooo00?o0000ooooooooool0
1oooool00ooo003oooooooooo`3hooooo`006oooool2o`0000Sooooo00?oo`00ooooooooool0n?oo
ool001_ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`3hooooo`006oooool00ol0
003oooooooooo`07ooooo`03ool00?oooooooooo0?Sooooo000Kooooo`03o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0n?ooool001_ooooo00?o0000ooooooooool01oooool00ooo003ooooo
ooooo`3hooooo`006oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo0?Sooooo000K
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0n?ooool001_ooooo0_l00008oooo
o`03ool00?oooooooooo0?Sooooo000Kooooo`03o`000?oooooooooo00Oooooo00?oo`00oooooooo
ool0n?ooool001_ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`3hooooo`006ooo
ool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo0?Oooooo000Kooooo`03o`000?oooooo
oooo00Sooooo00?oo`00ooooooooool0moooool001_ooooo00?o0000ooooooooool02?ooool00ooo
003oooooooooo`3gooooo`006oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo0?Oo
oooo000;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00004ooooo`03
o`000?oooooooooo00Sooooo00?oo`00ooooooooool0moooool000[ooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`03ooooo`;o00002Oooool00ooo003oooooooooo`3gooooo`002_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool00ooo003oooooooooo`3gooooo`002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`3gooooo`002oooool00ol0
003oooooooooo`06ooooo`?o00001?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo
0?Oooooo000Kooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0moooool001_ooooo
00?o0000ooooooooool02?ooool00ooo003oooooooooo`3gooooo`006oooool00ol0003ooooooooo
o`09ooooo`03ool00?oooooooooo0?Kooooo000Kooooo`;o00002_ooool00ooo003oooooooooo`3f
ooooo`006oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo0?Kooooo000Kooooo`03
o`000?oooooooooo00Wooooo00?oo`00ooooooooool0m_ooool001_ooooo00?o0000ooooooooool0
2Oooool00ooo003oooooooooo`3fooooo`006oooool00ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo0?Kooooo000Kooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0m_ooool0
01_ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`3fooooo`006oooool00ol0003o
ooooooooo`09ooooo`03ool00?oooooooooo0?Kooooo000Kooooo`;o00002oooool00ooo003ooooo
ooooo`3eooooo`006oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo0?Gooooo000K
ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0mOooool001_ooooo00?o0000oooo
ooooool02_ooool00ooo003oooooooooo`3eooooo`006oooool00ol0003oooooooooo`0:ooooo`03
ool00?oooooooooo0?Gooooo000Kooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0
mOooool001_ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`3eooooo`006oooool2
o`0000cooooo00?oo`00ooooooooool0m?ooool001_ooooo00?o0000ooooooooool02oooool00ooo
003oooooooooo`3dooooo`006oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo0?Co
oooo000Kooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0m?ooool001_ooooo00?o
0000ooooooooool02oooool00ooo003oooooooooo`3dooooo`006oooool00ol0003oooooooooo`0;
ooooo`03ool00?oooooooooo0?Cooooo000Kooooo`03o`000?oooooooooo00_ooooo00?oo`00oooo
ooooool0m?ooool000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`3cooooo`00
2_ooool00ol0003oooooo`000007ooooo`?o00001?ooool2o`0000gooooo00?oo`00ooooooooool0
loooool000[ooooo00?o0000ooooool000001oooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00cooooo00?oo`00ooooooooool0loooool000[ooooo00?o0000ooooool000002?ooool2
o`0000Cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`3cooooo`002oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ooo
003oooooooooo`3cooooo`006oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo0??o
oooo000Kooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0l_ooool001_ooooo00?o
0000ooooooooool03Oooool00ooo003oooooooooo`3booooo`006oooool2o`0000kooooo00?oo`00
ooooooooool0l_ooool001_ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`3boooo
o`006oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo0?;ooooo000Kooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0lOooool001_ooooo00?o0000ooooooooool03_oo
ool00ooo003oooooooooo`3aooooo`006oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooo
oooo0?7ooooo000Kooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0lOooool001_o
oooo00?o0000ooooooooool03oooool00ooo003oooooooooo`3`ooooo`006oooool2o`00013ooooo
00?oo`00ooooooooool0l?ooool001_ooooo00?o0000ooooooooool03oooool00ooo003ooooooooo
o`3`ooooo`006oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo0?3ooooo000Koooo
o`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0l?ooool001_ooooo00?o0000oooooooo
ool04?ooool00ooo003oooooooooo`3_ooooo`006oooool00ol0003oooooooooo`0@ooooo`03ool0
0?oooooooooo0>oooooo000Kooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0kooo
ool001_ooooo0_l0000Aooooo`03ool00?oooooooooo0>oooooo000Kooooo`03o`000?oooooooooo
017ooooo00?oo`00ooooooooool0k_ooool001_ooooo00?o0000ooooooooool04Oooool00ooo003o
ooooooooo`3^ooooo`006oooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo0>kooooo
000Kooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0k_ooool001_ooooo00?o0000
ooooooooool04Oooool00ooo003oooooooooo`3^ooooo`006oooool00ol0003oooooooooo`0Boooo
o`03ool00?oooooooooo0>gooooo000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool2o`0000Cooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`3]ooooo`00
2_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Cooooo0_l0000Cooooo`03ool0
0?oooooooooo0>gooooo000:ooooo`03o`000?oooooo000000Oooooo0ol00004ooooo`03o`000?oo
oooooooo01;ooooo00?oo`00ooooooooool0kOooool000[ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0k?ooool0
00_ooooo00?o0000ooooooooool01oooool2o`0000Cooooo00?o0000ooooooooool04oooool00ooo
003oooooooooo`3/ooooo`006oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo0>co
oooo000Kooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0k?ooool001_ooooo00?o
0000ooooooooool04oooool00ooo003oooooooooo`3/ooooo`006oooool2o`0001Gooooo00?oo`00
ooooooooool0joooool001_ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`3[oooo
o`006oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo0>_ooooo000Kooooo`03o`00
0?oooooooooo01Cooooo00?oo`00ooooooooool0joooool001_ooooo00?o0000ooooooooool05Ooo
ool00ooo003oooooooooo`3Zooooo`006oooool00ol0003oooooooooo`0Eooooo`03ool00?oooooo
oooo0>[ooooo000Kooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0j_ooool001_o
oooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`3Yooooo`006oooool2o`0001Oooooo
00?oo`00ooooooooool0jOooool001_ooooo00?o0000ooooooooool05_ooool00ooo003ooooooooo
o`3Yooooo`006oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo0>Sooooo000Koooo
o`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0j?ooool001_ooooo00?o0000oooooooo
ool05oooool00ooo003oooooooooo`3Xooooo`006oooool00ol0003oooooooooo`0Hooooo`03ool0
0?oooooooooo0>Oooooo000Kooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool0iooo
ool001_ooooo0_l0000Jooooo`03ool00?oooooooooo0>Kooooo000Kooooo`03o`000?oooooooooo
01Wooooo00?oo`00ooooooooool0i_ooool001_ooooo00?o0000ooooooooool06Oooool00ooo003o
ooooooooo`3Vooooo`006oooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo0>Gooooo
000Kooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0iOooool001_ooooo00?o0000
ooooooooool06oooool00ooo003oooooooooo`3Tooooo`006oooool00ol0003oooooooooo`0Koooo
o`03ool00?oooooooooo0>Cooooo000;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0i?ooool000[o
oooo00?o0000ooooool000001oooool00ol0003oooooo`000004ooooo`;o00007Oooool00ooo003o
ooooooooo`3Sooooo`002_ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool07?ooool00ooo003oooooooooo`3Sooooo`002_ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool07Oooool00ooo003ooooooooo
o`3Rooooo`002oooool00ol0003oooooooooo`06ooooo`?o00001?ooool00ol0003oooooooooo`0N
ooooo`03ool00?oooooooooo0>7ooooo000Kooooo`03o`000?oooooooooo01kooooo00?oo`00oooo
ooooool0hOooool001_ooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`3Pooooo`00
6oooool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo0>3ooooo000Kooooo`;o00008Ooo
ool00ooo003oooooooooo`3Oooooo`006oooool00ol0003oooooooooo`0Qooooo`03ool00?oooooo
oooo0=kooooo000Kooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool0gOooool001_o
oooo00?o0000ooooooooool08oooool00ooo003oooooooooo`3Looooo`006oooool00ol0003ooooo
ooooo`0Tooooo`03ool00?oooooooooo0=_ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o
o`00ooooooooool0foooool001_ooooo00?o0000ooooooooool09Oooool00ooo003oooooooooo`3J
ooooo`006oooool00ol0003oooooooooo`0Vooooo`;oo`00f_ooool001_ooooo0_l0000Yooooo`03
ool00?oooooooooo0=Oooooo000Kooooo`03o`000?oooooooooo02Wooooo0_oo003Gooooo`006ooo
ool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo0=Cooooo000Kooooo`03o`000?oooooo
oooo02cooooo0_oo003Dooooo`006oooool00ol0003oooooooooo`0^ooooo`;oo`00d_ooool001_o
oooo00?o0000ooooooooool0<?ooool2ool00=3ooooo000Kooooo`03o`000?oooooooooo03;ooooo
0ooo003=ooooo`006oooool2o`0003Kooooo0_oo003;ooooo`006oooool00ol0003oooooooooo`0g
ooooo`?oo`00b?ooool001_ooooo00?o0000ooooooooool0>_ooool4ool00<Cooooo000Kooooo`03
o`000?oooooooooo03kooooo1Ooo002oooooo`006oooool00ol0003oooooooooo`13ooooo`_oo`00
]?ooool001_ooooo00?o0000ooooooooool0C_oooolDool00:3ooooo000Kooooo`03o`000?oooooo
oooo06;ooooo9_oo001jooooo`005?ooool3o`0000Cooooo00?o0000ooooooooool0R?oooomVool0
01Cooooo000Eooooo`03o`000?oooooooooo00?ooooo0_l0003_ooooo`Coo`004?ooool001Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooo`?ooooo000Eooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0ooooool3ooooo`005?ooool2o`0000Gooooo00?o0000
ooooooooool0ooooool3ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00S_ooool3o`0008oooooo002?ooooo`03o`000?oooooooooo08kooooo0025ooooo`?o
00000_ooool00ol0003oooooo`000002ooooo`?o00000_ooool3o`0000;ooooo0ol00006ooooo`?o
0000Noooool008Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00So0000oooo
oooooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1jooooo`00Q_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool02?l0003o
ooooooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo07Wooooo0026ooooo`03o`000?oooooooooo00Co000000?oooooo`000?l000000_l00000
1_oooooo0000o`000?oooooo0000ooooo`Co00002?ooool00ol0003oooooooooo`1iooooo`00QOoo
ool3o`00017ooooo00?o0000ooooooooool01_ooool3o`0007_ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.36092, -0.0694047, \
0.12302, 0.00667271}},
  CellTags->"5.3.5"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The introduction of the two additional PI action single-loop controllers \
has clearly corrected the steady-state errors in the primary outputs, and has \
also removed any remaining steady-state interaction in both outputs due to \
the presence of the integrators. The resulting closed-loop control system has \
the simple structure shown in Figure 5.1, where ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(K\_p\),
          FontWeight->"Bold"], TraditionalForm]],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}}],
  " is the constant compensator designed using the ",
  "pseudo-diagonalization",
  " approach and ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_1\)(s)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_2\)(s)\)]],
  " are the two single-loop PI compensators."
}], "Text",
  CellTags->"5.3.5"],

Cell["\<\
This is the overall forward-path compensator designed for this \
system using the inverse-system Nyquist array.\
\>", "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesConnect[pi, Normal[InverseSystem[kinv]]]\)], "Input",
  CellLabel->"In[19]:=",
  CellTags->"5.3.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1.7785586266109508`\ \((2 + 
                            0.5`\/\[ScriptS])\)\), \(\(-1.0482337173198981`\)\
\ \((2 + 0.5`\/\[ScriptS])\)\)},
                    {\(\(-1.0482337173198983`\)\ \((2 + 
                            0.5`\/\[ScriptS])\)\), \(1.7785586266109508`\ \
\((2 + 0.5`\/\[ScriptS])\)\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Center},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[InvisibleSpace]\"\>",
                ShowStringCharacters->False],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[19]=",
  CellTags->"5.3.5"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1440}, {0, 805}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"EnhancedPrintout",
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{910, 661},
WindowMargins->{{19, Automatic}, {Automatic, 15}},
PrintingCopies->1,
PrintingStartingPageNumber->102,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ 
          StyleBox[ "Polynomial Control Systems", FontSlant -> "Italic"]], 
        "Header"]}, {Cell[ 
        TextData[ {"5 Frequency-Domain Design Methods"}], "Header"], 
      Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"PaperSize"->{Inherited, 792},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"FirstPageFace"->Left,
"PostScriptOutputFile":>"Automatic",
"Magnification"->1},
TaggingRules:>{"PaginationCache" -> {{2006, 5, 2, 12, 55, \
53.246682`8.478867525143704}, {102, 102, 102, 102, 102, 102, 103, 103, 103, \
103, 103, 103, 103, 103, 103, 104, 104, 104, 104, 104, 104, 104, 104, 104, \
104, 104, 105, 105, 105, 105, 105, 105, 105, 105, 106, 106, 106, 106, 106, \
106, 107, 107, 107, 107, 107, 107, 107, 108, 108, 108, 108, 108, 108, 108, \
108, 108, 108, 108, 109, 109, 109, 109, 109, 109, 109, 109, 109, 109, 109, \
109, 109, 110, 110, 110, 110, 110, 110, 110, 110, 110, 110, 111, 111, 111, \
111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 111, 112, 112, 112, 112, \
112, 112, 112, 112, 112, 112, 112, 112, 113, 113, 113, 113, 113, 113, 113, \
113, 113, 113, 114, 114, 114, 114, 114, 114, 115, 115, 115, 115, 115, 115, \
115, 116, 116, 116, 116, 116, 116, 116, 117, 117, 117, 117, 117, 118, 118, \
118, 118, 118, 118, 118, 118, 118, 118, 118, 118, 118, 119, 119, 119, 119, \
119, 119, 120, 120, 120, 120, 121, 121, 121, 121, 121, 121, 121, 122, 122, \
122, 122, 122, 123, 123, 123, 124, 124, 124, 124, 125, 125, 125, 125, 125, \
125, 125, 125, 125, 125, 125, 126, 126, 126, 126, 127, 127, 127, 127, 127, \
127, 127, 127, 127, 127, 127, 127, 127, 127, 127, 128, 128, 128, 128, 128, \
128, 128, 128, 129, 129, 130, 130, 130, 131, 131, 131, 131, 131, 132, 132, \
132, 132, 132, 132, 133, 133, 133, 133, 133, 133, 133, 133, 133, 133, 133, \
133, 133, 134, 134, 134, 134, 134, 134, 134, 134, 134, 134, 134, 134, 134, \
135, 135, 135, 135, 135, 135, 135, 135, 135, 136, 136, 136, 136, 136, 136, \
136, 136, 136, 137, 137, 137, 137, 137, 137, 138, 138, 138, 138, 138, 138, \
138, 138, 138, 138, 138, 138, 138, 138, 139, 139, 139, 139, 139, 139, 140, \
140, 140, 141, 141, 141, 141, 141, 141, 141, 141, 141, 141, 141, 142, 142, \
142, 142, 142, 142, 142, 142, 142, 142, 142, 143, 143, 143, 143, 144, 144, \
144, 144, 144, 144, 144, 145, 145, 145, 145, 145, 145, 146, 146, 146, 146, \
146, 146, 147, 147, 147, 147, 147, 147, 147, 147, 147, 147, 148, 148, 148, \
148, 148, 148, 148, 149, 149, 149, 149, 149, 149, 149, 149, 150, 150, 150, \
150, 150, 150, 151, 151, 151, 151, 151, 151, 151, 151, 152, 152, 152, 153, \
153, 153, 153, 153, 153, 153, 154, 154, 154, 154, 154, 154, 154, 154, 154, \
155, 155, 155, 155, 155, 155, 155, 155, 156, 156, 156, 156, 156, 156, 156, \
156, 157, 157, 157, 157, 157, 157, 157, 157, 157, 157, 157, 158, 158, 158, \
158, 158, 158, 158, 158, 158, 158, 158, 158, 158, 158, 159, 159, 160, 160, \
160, 160, 160, 160, 160, 161, 161, 161, 161, 161, 161, 162, 162, 162, 162, \
163, 163, 163, 163, 163, 163, 163, 164, 164, 165, 166, 166, 166, 166, 166, \
166, 166, 166, 166, 167, 167, 167, 167, 167, 167, 167, 167, 167, 167, 168, \
168, 168, 169, 169, 169, 169, 169, 169, 169, 169, 169, 169, 170, 170, 170, \
170, 170, 170, 170, 171, 171, 171, 171, 171, 171, 171, 171, 171, 172, 172, \
172, 172, 172, 172, 172, 172, 172, 172, 172, 172, 172, 172, 172, 173, 173, \
173, 174, 174, 174, 174, 174, 174, 174, 174, 174, 174, 174, 174, 174, 174, \
175, 175, 175, 175, 175, 176, 176, 176, 176, 176, 176, 176, 176, 176, 176, \
176, 176, 176, 176, 176, 177, 177, 177, 177, 177, 177, 177, 177, 177, 178, \
178, 178, 178, 178, 178, 178, 178, 178, 178, 179, 179, 179, 179, 179, 179, \
179, 179, 179, 180, 180, 180, 180, 180, 180, 180, 180, 181, 181, 181, 181, \
181, 181, 181, 182, 182, 182, 182, 182, 182, 182, 182, 183, 183, 183, 184, \
184, 184, 184, 184, 184, 184, 184, 184, 184, 184, 185, 185, 185, 185, 185, \
185, 185, 186, 186, 186, 186, 186}, Automatic}},
SpellingDictionaries->{"CorrectWords"->{
  "decoupling", "Frobenius", "Rosenbrock", "Patel", "Munro", "Gershgorin", 
    "Ostrowski", "precompensator", "wmin", "wmax", "Ostrowki", 
    "anticlockwise"}},
SpanMaxSize->Infinity,
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "5.0"->{
    Cell[1776, 53, 91, 1, 61, "Section",
      CellTags->{"5.0", "c:1"}]},
  "c:1"->{
    Cell[1776, 53, 91, 1, 61, "Section",
      CellTags->{"5.0", "c:1"}]},
  "5.3.5"->{
    Cell[1870, 56, 294, 6, 36, "Text",
      CellTags->"5.3.5"],
    Cell[2167, 64, 80, 1, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[2250, 67, 106, 3, 26, "Input",
      CellTags->"5.3.5"],
    Cell[2359, 72, 149, 4, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[2533, 80, 209, 6, 41, "Input",
      CellTags->"5.3.5"],
    Cell[2745, 88, 1176, 31, 77, "Output",
      CellTags->"5.3.5"],
    Cell[3936, 122, 220, 5, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[4181, 131, 162, 4, 26, "Input",
      CellTags->"5.3.5"],
    Cell[4368, 139, 21371, 557, 184, 5823, 359, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[25742, 698, 21371, 557, 184, 5823, 359, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[47140, 1259, 194, 5, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[47359, 1268, 179, 4, 26, "Input",
      CellTags->"5.3.5"],
    Cell[47541, 1274, 81000, 2667, 294, 29967, 2031, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[128556, 3944, 291, 6, 36, "Text",
      CellTags->"5.3.5"],
    Cell[128850, 3952, 202, 5, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[129077, 3961, 134, 3, 26, "Input",
      CellTags->"5.3.5"],
    Cell[129214, 3966, 998, 27, 42, "Output",
      CellTags->"5.3.5"],
    Cell[130227, 3996, 118, 4, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[130370, 4004, 165, 5, 26, "Input",
      CellTags->"5.3.5"],
    Cell[130538, 4011, 1661, 38, 81, "Output",
      CellTags->"5.3.5"],
    Cell[132214, 4052, 157, 4, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[132396, 4060, 179, 4, 26, "Input",
      CellTags->"5.3.5"],
    Cell[132578, 4066, 83346, 2762, 368, 31403, 2115, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[215939, 6831, 301, 6, 36, "Text",
      CellTags->"5.3.5"],
    Cell[216243, 6839, 233, 5, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[216501, 6848, 229, 5, 42, "Input",
      CellTags->"5.3.5"],
    Cell[216733, 6855, 91990, 3066, 384, 34809, 2355, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[308738, 9924, 454, 8, 50, "Text",
      CellTags->"5.3.5"],
    Cell[309195, 9934, 138, 4, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[309358, 9942, 146, 4, 26, "Input",
      CellTags->"5.3.5"],
    Cell[309507, 9948, 998, 27, 42, "Output",
      CellTags->"5.3.5"],
    Cell[310520, 9978, 106, 2, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[310651, 9984, 149, 4, 26, "Input",
      CellTags->"5.3.5"],
    Cell[310803, 9990, 1778, 40, 81, "Output",
      CellTags->"5.3.5"],
    Cell[312596, 10033, 201, 5, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[312822, 10042, 230, 5, 42, "Input",
      CellTags->"5.3.5"],
    Cell[313055, 10049, 103282, 3240, 486, 34995, 2391, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[416352, 13292, 334, 7, 36, "Text",
      CellTags->"5.3.5"],
    Cell[416689, 13301, 89, 1, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[416803, 13306, 112, 3, 26, "Input",
      CellTags->"5.3.5"],
    Cell[416918, 13311, 1005, 27, 42, "Output",
      CellTags->"5.3.5"],
    Cell[417938, 13341, 75, 1, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[418016, 13344, 119, 3, 26, "Input",
      CellTags->"5.3.5"],
    Cell[418138, 13349, 103, 2, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[418266, 13355, 162, 4, 26, "Input",
      CellTags->"5.3.5"],
    Cell[418453, 13363, 21274, 625, 184, 7035, 443, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[439730, 13990, 21274, 625, 184, 7035, 443, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[461031, 14619, 165, 4, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[461221, 14627, 161, 5, 41, "Input",
      CellTags->"5.3.5"],
    Cell[461385, 14634, 1055, 29, 77, "Output",
      CellTags->"5.3.5"],
    Cell[462455, 14666, 79, 1, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[462537, 14669, 112, 3, 26, "Input",
      CellTags->"5.3.5"],
    Cell[462652, 14674, 122, 4, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[462777, 14680, 123, 3, 26, "Input",
      CellTags->"5.3.5"],
    Cell[462903, 14685, 75, 1, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[463003, 14690, 164, 4, 26, "Input",
      CellTags->"5.3.5"],
    Cell[463192, 14698, 20461, 596, 184, 6730, 421, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[483656, 15296, 20482, 597, 184, 6730, 421, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3.5"],
    Cell[504165, 15897, 936, 23, 51, "Text",
      CellTags->"5.3.5"],
    Cell[505104, 15922, 163, 4, 40, "MathCaption",
      CellTags->"5.3.5"],
    Cell[505292, 15930, 125, 3, 26, "Input",
      CellTags->"5.3.5"],
    Cell[505420, 15935, 1277, 33, 79, "Output",
      CellTags->"5.3.5"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"5.0", 512039, 16068},
  {"c:1", 512125, 16071},
  {"5.3.5", 512213, 16074}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 91, 1, 61, "Section",
  CellTags->{"5.0", "c:1"}],
Cell[1870, 56, 294, 6, 36, "Text",
  CellTags->"5.3.5"],
Cell[2167, 64, 80, 1, 40, "MathCaption",
  CellTags->"5.3.5"],
Cell[2250, 67, 106, 3, 26, "Input",
  CellTags->"5.3.5"],
Cell[2359, 72, 149, 4, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[2533, 80, 209, 6, 41, "Input",
  CellTags->"5.3.5"],
Cell[2745, 88, 1176, 31, 77, "Output",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[3936, 122, 220, 5, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[4181, 131, 162, 4, 26, "Input",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[4368, 139, 21371, 557, 184, 5823, 359, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"5.3.5"],
Cell[25742, 698, 21371, 557, 184, 5823, 359, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"5.3.5"]
}, Open  ]]
}, Open  ]],
Cell[47140, 1259, 194, 5, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[47359, 1268, 179, 4, 26, "Input",
  CellTags->"5.3.5"],
Cell[47541, 1274, 81000, 2667, 294, 29967, 2031, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[128556, 3944, 291, 6, 36, "Text",
  CellTags->"5.3.5"],
Cell[128850, 3952, 202, 5, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[129077, 3961, 134, 3, 26, "Input",
  CellTags->"5.3.5"],
Cell[129214, 3966, 998, 27, 42, "Output",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[130227, 3996, 118, 4, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[130370, 4004, 165, 5, 26, "Input",
  CellTags->"5.3.5"],
Cell[130538, 4011, 1661, 38, 81, "Output",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[132214, 4052, 157, 4, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[132396, 4060, 179, 4, 26, "Input",
  CellTags->"5.3.5"],
Cell[132578, 4066, 83346, 2762, 368, 31403, 2115, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[215939, 6831, 301, 6, 36, "Text",
  CellTags->"5.3.5"],
Cell[216243, 6839, 233, 5, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[216501, 6848, 229, 5, 42, "Input",
  CellTags->"5.3.5"],
Cell[216733, 6855, 91990, 3066, 384, 34809, 2355, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[308738, 9924, 454, 8, 50, "Text",
  CellTags->"5.3.5"],
Cell[309195, 9934, 138, 4, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[309358, 9942, 146, 4, 26, "Input",
  CellTags->"5.3.5"],
Cell[309507, 9948, 998, 27, 42, "Output",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[310520, 9978, 106, 2, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[310651, 9984, 149, 4, 26, "Input",
  CellTags->"5.3.5"],
Cell[310803, 9990, 1778, 40, 81, "Output",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[312596, 10033, 201, 5, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[312822, 10042, 230, 5, 42, "Input",
  CellTags->"5.3.5"],
Cell[313055, 10049, 103282, 3240, 486, 34995, 2391, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[416352, 13292, 334, 7, 36, "Text",
  CellTags->"5.3.5"],
Cell[416689, 13301, 89, 1, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[416803, 13306, 112, 3, 26, "Input",
  CellTags->"5.3.5"],
Cell[416918, 13311, 1005, 27, 42, "Output",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[417938, 13341, 75, 1, 40, "MathCaption",
  CellTags->"5.3.5"],
Cell[418016, 13344, 119, 3, 26, "Input",
  CellTags->"5.3.5"],
Cell[418138, 13349, 103, 2, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[418266, 13355, 162, 4, 26, "Input",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[418453, 13363, 21274, 625, 184, 7035, 443, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"5.3.5"],
Cell[439730, 13990, 21274, 625, 184, 7035, 443, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"5.3.5"]
}, Open  ]]
}, Open  ]],
Cell[461031, 14619, 165, 4, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[461221, 14627, 161, 5, 41, "Input",
  CellTags->"5.3.5"],
Cell[461385, 14634, 1055, 29, 77, "Output",
  CellTags->"5.3.5"]
}, Open  ]],
Cell[462455, 14666, 79, 1, 40, "MathCaption",
  CellTags->"5.3.5"],
Cell[462537, 14669, 112, 3, 26, "Input",
  CellTags->"5.3.5"],
Cell[462652, 14674, 122, 4, 40, "MathCaption",
  CellTags->"5.3.5"],
Cell[462777, 14680, 123, 3, 26, "Input",
  CellTags->"5.3.5"],
Cell[462903, 14685, 75, 1, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[463003, 14690, 164, 4, 26, "Input",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[463192, 14698, 20461, 596, 184, 6730, 421, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"5.3.5"],
Cell[483656, 15296, 20482, 597, 184, 6730, 421, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"5.3.5"]
}, Open  ]]
}, Open  ]],
Cell[504165, 15897, 936, 23, 51, "Text",
  CellTags->"5.3.5"],
Cell[505104, 15922, 163, 4, 40, "MathCaption",
  CellTags->"5.3.5"],

Cell[CellGroupData[{
Cell[505292, 15930, 125, 3, 26, "Input",
  CellTags->"5.3.5"],
Cell[505420, 15935, 1277, 33, 79, "Output",
  CellTags->"5.3.5"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

